<!-- template for the WFS3 API links list, to be included in HEAD -->
{% for link in links %}
    <link rel="{{ link.rel }}" href="{{ link.href }}" title="{{ link.title }}" type="{{ link.type }}">
{% endfor %}
