/********************************************************************************
** Form generated from reading UI file 'qgsrangeconfigdlgbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSRANGECONFIGDLGBASE_H
#define UI_QGSRANGECONFIGDLGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include "qgscollapsiblegroupbox.h"
#include "qgsdoublespinbox.h"
#include "qgsspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_QgsRangeConfigDlgBase
{
public:
    QGridLayout *gridLayout;
    QLabel *rangeLabel;
    QgsCollapsibleGroupBox *groupBox;
    QFormLayout *formLayout_3;
    QLabel *suffixLabel;
    QLineEdit *suffixLineEdit;
    QLabel *precisionLabel;
    QgsSpinBox *precisionSpinBox;
    QComboBox *rangeWidget;
    QSpacerItem *verticalSpacer;
    QLabel *valuesLabel;
    QStackedWidget *rangeStackedWidget;
    QWidget *intPage;
    QFormLayout *formLayout;
    QLabel *minimumLabel;
    QgsSpinBox *minimumSpinBox;
    QLabel *maximumLabel;
    QgsSpinBox *maximumSpinBox;
    QLabel *stepLabel;
    QgsSpinBox *stepSpinBox;
    QWidget *doublePage;
    QFormLayout *formLayout_2;
    QLabel *stepLabel_2;
    QLabel *maximumLabel_2;
    QLabel *minimumLabel_2;
    QgsDoubleSpinBox *minimumDoubleSpinBox;
    QgsDoubleSpinBox *maximumDoubleSpinBox;
    QgsDoubleSpinBox *stepDoubleSpinBox;
    QCheckBox *allowNullCheckBox;

    void setupUi(QWidget *QgsRangeConfigDlgBase)
    {
        if (QgsRangeConfigDlgBase->objectName().isEmpty())
            QgsRangeConfigDlgBase->setObjectName("QgsRangeConfigDlgBase");
        QgsRangeConfigDlgBase->resize(549, 333);
        QgsRangeConfigDlgBase->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout = new QGridLayout(QgsRangeConfigDlgBase);
        gridLayout->setObjectName("gridLayout");
        rangeLabel = new QLabel(QgsRangeConfigDlgBase);
        rangeLabel->setObjectName("rangeLabel");
        rangeLabel->setWordWrap(true);

        gridLayout->addWidget(rangeLabel, 0, 0, 1, 2);

        groupBox = new QgsCollapsibleGroupBox(QgsRangeConfigDlgBase);
        groupBox->setObjectName("groupBox");
        formLayout_3 = new QFormLayout(groupBox);
        formLayout_3->setObjectName("formLayout_3");
        suffixLabel = new QLabel(groupBox);
        suffixLabel->setObjectName("suffixLabel");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, suffixLabel);

        suffixLineEdit = new QLineEdit(groupBox);
        suffixLineEdit->setObjectName("suffixLineEdit");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, suffixLineEdit);

        precisionLabel = new QLabel(groupBox);
        precisionLabel->setObjectName("precisionLabel");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, precisionLabel);

        precisionSpinBox = new QgsSpinBox(groupBox);
        precisionSpinBox->setObjectName("precisionSpinBox");
        precisionSpinBox->setValue(4);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, precisionSpinBox);


        gridLayout->addWidget(groupBox, 4, 0, 1, 1);

        rangeWidget = new QComboBox(QgsRangeConfigDlgBase);
        rangeWidget->setObjectName("rangeWidget");

        gridLayout->addWidget(rangeWidget, 1, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 1);

        valuesLabel = new QLabel(QgsRangeConfigDlgBase);
        valuesLabel->setObjectName("valuesLabel");
        valuesLabel->setWordWrap(true);

        gridLayout->addWidget(valuesLabel, 5, 0, 1, 1);

        rangeStackedWidget = new QStackedWidget(QgsRangeConfigDlgBase);
        rangeStackedWidget->setObjectName("rangeStackedWidget");
        intPage = new QWidget();
        intPage->setObjectName("intPage");
        formLayout = new QFormLayout(intPage);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(-1, -1, -1, 3);
        minimumLabel = new QLabel(intPage);
        minimumLabel->setObjectName("minimumLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, minimumLabel);

        minimumSpinBox = new QgsSpinBox(intPage);
        minimumSpinBox->setObjectName("minimumSpinBox");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, minimumSpinBox);

        maximumLabel = new QLabel(intPage);
        maximumLabel->setObjectName("maximumLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, maximumLabel);

        maximumSpinBox = new QgsSpinBox(intPage);
        maximumSpinBox->setObjectName("maximumSpinBox");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, maximumSpinBox);

        stepLabel = new QLabel(intPage);
        stepLabel->setObjectName("stepLabel");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, stepLabel);

        stepSpinBox = new QgsSpinBox(intPage);
        stepSpinBox->setObjectName("stepSpinBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, stepSpinBox);

        rangeStackedWidget->addWidget(intPage);
        doublePage = new QWidget();
        doublePage->setObjectName("doublePage");
        formLayout_2 = new QFormLayout(doublePage);
        formLayout_2->setObjectName("formLayout_2");
        formLayout_2->setContentsMargins(-1, -1, -1, 3);
        stepLabel_2 = new QLabel(doublePage);
        stepLabel_2->setObjectName("stepLabel_2");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, stepLabel_2);

        maximumLabel_2 = new QLabel(doublePage);
        maximumLabel_2->setObjectName("maximumLabel_2");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, maximumLabel_2);

        minimumLabel_2 = new QLabel(doublePage);
        minimumLabel_2->setObjectName("minimumLabel_2");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, minimumLabel_2);

        minimumDoubleSpinBox = new QgsDoubleSpinBox(doublePage);
        minimumDoubleSpinBox->setObjectName("minimumDoubleSpinBox");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, minimumDoubleSpinBox);

        maximumDoubleSpinBox = new QgsDoubleSpinBox(doublePage);
        maximumDoubleSpinBox->setObjectName("maximumDoubleSpinBox");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, maximumDoubleSpinBox);

        stepDoubleSpinBox = new QgsDoubleSpinBox(doublePage);
        stepDoubleSpinBox->setObjectName("stepDoubleSpinBox");
        stepDoubleSpinBox->setValue(1.000000000000000);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, stepDoubleSpinBox);

        rangeStackedWidget->addWidget(doublePage);

        gridLayout->addWidget(rangeStackedWidget, 2, 0, 1, 1);

        allowNullCheckBox = new QCheckBox(QgsRangeConfigDlgBase);
        allowNullCheckBox->setObjectName("allowNullCheckBox");

        gridLayout->addWidget(allowNullCheckBox, 3, 0, 1, 1);

        QWidget::setTabOrder(rangeWidget, minimumSpinBox);
        QWidget::setTabOrder(minimumSpinBox, maximumSpinBox);
        QWidget::setTabOrder(maximumSpinBox, stepSpinBox);
        QWidget::setTabOrder(stepSpinBox, minimumDoubleSpinBox);
        QWidget::setTabOrder(minimumDoubleSpinBox, maximumDoubleSpinBox);
        QWidget::setTabOrder(maximumDoubleSpinBox, stepDoubleSpinBox);
        QWidget::setTabOrder(stepDoubleSpinBox, allowNullCheckBox);
        QWidget::setTabOrder(allowNullCheckBox, groupBox);
        QWidget::setTabOrder(groupBox, suffixLineEdit);

        retranslateUi(QgsRangeConfigDlgBase);

        rangeStackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(QgsRangeConfigDlgBase);
    } // setupUi

    void retranslateUi(QWidget *QgsRangeConfigDlgBase)
    {
        rangeLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Allows setting of numeric values from a specified range. The edit widget can be either a slider or a spin box.", nullptr));
        groupBox->setTitle(QCoreApplication::translate("QgsRangeConfigDlgBase", "Advanced Options", nullptr));
        suffixLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Suffix", nullptr));
        suffixLineEdit->setPlaceholderText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Inactive", nullptr));
        precisionLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Precision", nullptr));
#if QT_CONFIG(tooltip)
        precisionSpinBox->setToolTip(QCoreApplication::translate("QgsRangeConfigDlgBase", "Number of decimal places", nullptr));
#endif // QT_CONFIG(tooltip)
        valuesLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Local minimum/maximum = 0/0", nullptr));
        minimumLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Minimum", nullptr));
        maximumLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Maximum", nullptr));
        stepLabel->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Step", nullptr));
        stepLabel_2->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Step", nullptr));
        maximumLabel_2->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Maximum", nullptr));
        minimumLabel_2->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Minimum", nullptr));
        allowNullCheckBox->setText(QCoreApplication::translate("QgsRangeConfigDlgBase", "Allow NULL", nullptr));
        (void)QgsRangeConfigDlgBase;
    } // retranslateUi

};

namespace Ui {
    class QgsRangeConfigDlgBase: public Ui_QgsRangeConfigDlgBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSRANGECONFIGDLGBASE_H
