/********************************************************************************
** Form generated from reading UI file 'qgsnewhttpconnectionbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSNEWHTTPCONNECTIONBASE_H
#define UI_QGSNEWHTTPCONNECTIONBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qgsauthsettingswidget.h"
#include "qgshttpheaderwidget.h"
#include "qgsscrollarea.h"

QT_BEGIN_NAMESPACE

class Ui_QgsNewHttpConnectionBase
{
public:
    QVBoxLayout *verticalLayout_3;
    QgsScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout;
    QGroupBox *mGroupBox;
    QGridLayout *gridLayout;
    QLabel *TextLabel1_2;
    QGroupBox *mAuthGroupBox;
    QVBoxLayout *verticalLayout;
    QgsAuthSettingsWidget *mAuthSettings;
    QLabel *TextLabel1;
    QLineEdit *txtName;
    QLineEdit *txtUrl;
    QgsHttpHeaderWidget *mHttpHeaders;
    QPushButton *mTestConnectionButton;
    QSpacerItem *verticalSpacer;
    QVBoxLayout *verticalLayout_2;
    QGroupBox *mWmsOptionsGroupBox;
    QGridLayout *gridLayout_2;
    QLabel *lblTilePixelRatio;
    QSpacerItem *verticalSpacer_2;
    QLabel *lblWmsFormat;
    QLabel *lblFeatureCount;
    QLabel *lblDpiMode;
    QPushButton *mWmsFormatDetectButton;
    QComboBox *mWmsPreferredFormatCombo;
    QComboBox *cmbDpiMode;
    QComboBox *cmbTilePixelRatio;
    QSpinBox *sbFeatureCount;
    QCheckBox *cbxIgnoreGetMapURI;
    QCheckBox *cbxIgnoreGetFeatureInfoURI;
    QCheckBox *cbxWmsIgnoreReportedLayerExtents;
    QCheckBox *cbxWmsIgnoreAxisOrientation;
    QCheckBox *cbxWmsInvertAxisOrientation;
    QCheckBox *cbxSmoothPixmapTransform;
    QGroupBox *mWfsOptionsGroupBox;
    QGridLayout *gridLayout1;
    QLabel *lblVersion;
    QComboBox *cmbVersion;
    QPushButton *mWfsVersionDetectButton;
    QLabel *lblFeatureFormat;
    QComboBox *mFeatureFormatComboBox;
    QPushButton *mFeatureFormatDetectButton;
    QLabel *lblVersion_2;
    QComboBox *mComboHttpMethod;
    QLabel *lblMaxNumFeatures;
    QLineEdit *txtMaxNumFeatures;
    QLabel *lblFeaturePaging;
    QComboBox *cmbFeaturePaging;
    QLabel *lblPageSize;
    QLineEdit *txtPageSize;
    QLabel *lblFeatureMode;
    QComboBox *mComboWfsFeatureMode;
    QCheckBox *cbxWfsIgnoreAxisOrientation;
    QCheckBox *cbxWfsInvertAxisOrientation;
    QCheckBox *cbxWfsUseGml2EncodingForTransactions;
    QCheckBox *cbxWfsForceInitialGetFeature;
    QSpacerItem *verticalSpacer_3;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QgsNewHttpConnectionBase)
    {
        if (QgsNewHttpConnectionBase->objectName().isEmpty())
            QgsNewHttpConnectionBase->setObjectName("QgsNewHttpConnectionBase");
        QgsNewHttpConnectionBase->resize(880, 857);
        QgsNewHttpConnectionBase->setSizeGripEnabled(true);
        QgsNewHttpConnectionBase->setModal(true);
        verticalLayout_3 = new QVBoxLayout(QgsNewHttpConnectionBase);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(11, 11, 11, 11);
        verticalLayout_3->setObjectName("verticalLayout_3");
        scrollArea = new QgsScrollArea(QgsNewHttpConnectionBase);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 862, 808));
        horizontalLayout = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout->setSpacing(6);
        horizontalLayout->setContentsMargins(11, 11, 11, 11);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        mGroupBox = new QGroupBox(scrollAreaWidgetContents);
        mGroupBox->setObjectName("mGroupBox");
        gridLayout = new QGridLayout(mGroupBox);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        TextLabel1_2 = new QLabel(mGroupBox);
        TextLabel1_2->setObjectName("TextLabel1_2");
        TextLabel1_2->setWordWrap(true);
        TextLabel1_2->setMargin(5);

        gridLayout->addWidget(TextLabel1_2, 2, 0, 1, 1);

        mAuthGroupBox = new QGroupBox(mGroupBox);
        mAuthGroupBox->setObjectName("mAuthGroupBox");
        verticalLayout = new QVBoxLayout(mAuthGroupBox);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(6, 6, 6, 6);
        mAuthSettings = new QgsAuthSettingsWidget(mAuthGroupBox);
        mAuthSettings->setObjectName("mAuthSettings");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mAuthSettings->sizePolicy().hasHeightForWidth());
        mAuthSettings->setSizePolicy(sizePolicy);

        verticalLayout->addWidget(mAuthSettings);


        gridLayout->addWidget(mAuthGroupBox, 6, 0, 1, 2);

        TextLabel1 = new QLabel(mGroupBox);
        TextLabel1->setObjectName("TextLabel1");
        TextLabel1->setMargin(5);

        gridLayout->addWidget(TextLabel1, 3, 0, 1, 1);

        txtName = new QLineEdit(mGroupBox);
        txtName->setObjectName("txtName");
        txtName->setMinimumSize(QSize(0, 0));
        txtName->setFrame(true);

        gridLayout->addWidget(txtName, 2, 1, 1, 1);

        txtUrl = new QLineEdit(mGroupBox);
        txtUrl->setObjectName("txtUrl");

        gridLayout->addWidget(txtUrl, 3, 1, 1, 1);

        mHttpHeaders = new QgsHttpHeaderWidget(mGroupBox);
        mHttpHeaders->setObjectName("mHttpHeaders");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mHttpHeaders->sizePolicy().hasHeightForWidth());
        mHttpHeaders->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(mHttpHeaders, 7, 0, 1, 2);

        mTestConnectionButton = new QPushButton(mGroupBox);
        mTestConnectionButton->setObjectName("mTestConnectionButton");

        gridLayout->addWidget(mTestConnectionButton, 8, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 9, 0, 1, 2);


        horizontalLayout->addWidget(mGroupBox);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setSpacing(6);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mWmsOptionsGroupBox = new QGroupBox(scrollAreaWidgetContents);
        mWmsOptionsGroupBox->setObjectName("mWmsOptionsGroupBox");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Minimum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mWmsOptionsGroupBox->sizePolicy().hasHeightForWidth());
        mWmsOptionsGroupBox->setSizePolicy(sizePolicy2);
        gridLayout_2 = new QGridLayout(mWmsOptionsGroupBox);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setContentsMargins(11, 11, 11, 11);
        gridLayout_2->setObjectName("gridLayout_2");
        lblTilePixelRatio = new QLabel(mWmsOptionsGroupBox);
        lblTilePixelRatio->setObjectName("lblTilePixelRatio");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(lblTilePixelRatio->sizePolicy().hasHeightForWidth());
        lblTilePixelRatio->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(lblTilePixelRatio, 2, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 15, 0, 1, 2);

        lblWmsFormat = new QLabel(mWmsOptionsGroupBox);
        lblWmsFormat->setObjectName("lblWmsFormat");

        gridLayout_2->addWidget(lblWmsFormat, 0, 0, 1, 1);

        lblFeatureCount = new QLabel(mWmsOptionsGroupBox);
        lblFeatureCount->setObjectName("lblFeatureCount");
        sizePolicy3.setHeightForWidth(lblFeatureCount->sizePolicy().hasHeightForWidth());
        lblFeatureCount->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(lblFeatureCount, 3, 0, 1, 1);

        lblDpiMode = new QLabel(mWmsOptionsGroupBox);
        lblDpiMode->setObjectName("lblDpiMode");
        sizePolicy3.setHeightForWidth(lblDpiMode->sizePolicy().hasHeightForWidth());
        lblDpiMode->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(lblDpiMode, 1, 0, 1, 1);

        mWmsFormatDetectButton = new QPushButton(mWmsOptionsGroupBox);
        mWmsFormatDetectButton->setObjectName("mWmsFormatDetectButton");

        gridLayout_2->addWidget(mWmsFormatDetectButton, 0, 2, 1, 1);

        mWmsPreferredFormatCombo = new QComboBox(mWmsOptionsGroupBox);
        mWmsPreferredFormatCombo->setObjectName("mWmsPreferredFormatCombo");

        gridLayout_2->addWidget(mWmsPreferredFormatCombo, 0, 1, 1, 1);

        cmbDpiMode = new QComboBox(mWmsOptionsGroupBox);
        cmbDpiMode->setObjectName("cmbDpiMode");

        gridLayout_2->addWidget(cmbDpiMode, 1, 1, 1, 2);

        cmbTilePixelRatio = new QComboBox(mWmsOptionsGroupBox);
        cmbTilePixelRatio->setObjectName("cmbTilePixelRatio");

        gridLayout_2->addWidget(cmbTilePixelRatio, 2, 1, 1, 2);

        sbFeatureCount = new QSpinBox(mWmsOptionsGroupBox);
        sbFeatureCount->setObjectName("sbFeatureCount");
        sbFeatureCount->setMinimum(0);
        sbFeatureCount->setMaximum(1000);
        sbFeatureCount->setValue(10);

        gridLayout_2->addWidget(sbFeatureCount, 3, 1, 1, 2);

        cbxIgnoreGetMapURI = new QCheckBox(mWmsOptionsGroupBox);
        cbxIgnoreGetMapURI->setObjectName("cbxIgnoreGetMapURI");

        gridLayout_2->addWidget(cbxIgnoreGetMapURI, 6, 0, 1, 3);

        cbxIgnoreGetFeatureInfoURI = new QCheckBox(mWmsOptionsGroupBox);
        cbxIgnoreGetFeatureInfoURI->setObjectName("cbxIgnoreGetFeatureInfoURI");

        gridLayout_2->addWidget(cbxIgnoreGetFeatureInfoURI, 7, 0, 1, 3);

        cbxWmsIgnoreReportedLayerExtents = new QCheckBox(mWmsOptionsGroupBox);
        cbxWmsIgnoreReportedLayerExtents->setObjectName("cbxWmsIgnoreReportedLayerExtents");

        gridLayout_2->addWidget(cbxWmsIgnoreReportedLayerExtents, 8, 0, 1, 3);

        cbxWmsIgnoreAxisOrientation = new QCheckBox(mWmsOptionsGroupBox);
        cbxWmsIgnoreAxisOrientation->setObjectName("cbxWmsIgnoreAxisOrientation");

        gridLayout_2->addWidget(cbxWmsIgnoreAxisOrientation, 9, 0, 1, 3);

        cbxWmsInvertAxisOrientation = new QCheckBox(mWmsOptionsGroupBox);
        cbxWmsInvertAxisOrientation->setObjectName("cbxWmsInvertAxisOrientation");

        gridLayout_2->addWidget(cbxWmsInvertAxisOrientation, 10, 0, 1, 3);

        cbxSmoothPixmapTransform = new QCheckBox(mWmsOptionsGroupBox);
        cbxSmoothPixmapTransform->setObjectName("cbxSmoothPixmapTransform");

        gridLayout_2->addWidget(cbxSmoothPixmapTransform, 14, 0, 1, 3);


        verticalLayout_2->addWidget(mWmsOptionsGroupBox);

        mWfsOptionsGroupBox = new QGroupBox(scrollAreaWidgetContents);
        mWfsOptionsGroupBox->setObjectName("mWfsOptionsGroupBox");
        sizePolicy2.setHeightForWidth(mWfsOptionsGroupBox->sizePolicy().hasHeightForWidth());
        mWfsOptionsGroupBox->setSizePolicy(sizePolicy2);
        gridLayout1 = new QGridLayout(mWfsOptionsGroupBox);
        gridLayout1->setSpacing(6);
        gridLayout1->setContentsMargins(11, 11, 11, 11);
        gridLayout1->setObjectName("gridLayout1");
        lblVersion = new QLabel(mWfsOptionsGroupBox);
        lblVersion->setObjectName("lblVersion");
        sizePolicy3.setHeightForWidth(lblVersion->sizePolicy().hasHeightForWidth());
        lblVersion->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblVersion, 0, 0, 1, 1);

        cmbVersion = new QComboBox(mWfsOptionsGroupBox);
        cmbVersion->setObjectName("cmbVersion");

        gridLayout1->addWidget(cmbVersion, 0, 1, 1, 1);

        mWfsVersionDetectButton = new QPushButton(mWfsOptionsGroupBox);
        mWfsVersionDetectButton->setObjectName("mWfsVersionDetectButton");

        gridLayout1->addWidget(mWfsVersionDetectButton, 0, 2, 1, 1);

        lblFeatureFormat = new QLabel(mWfsOptionsGroupBox);
        lblFeatureFormat->setObjectName("lblFeatureFormat");
        sizePolicy3.setHeightForWidth(lblFeatureFormat->sizePolicy().hasHeightForWidth());
        lblFeatureFormat->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblFeatureFormat, 1, 0, 1, 1);

        mFeatureFormatComboBox = new QComboBox(mWfsOptionsGroupBox);
        mFeatureFormatComboBox->setObjectName("mFeatureFormatComboBox");

        gridLayout1->addWidget(mFeatureFormatComboBox, 1, 1, 1, 1);

        mFeatureFormatDetectButton = new QPushButton(mWfsOptionsGroupBox);
        mFeatureFormatDetectButton->setObjectName("mFeatureFormatDetectButton");

        gridLayout1->addWidget(mFeatureFormatDetectButton, 1, 2, 1, 1);

        lblVersion_2 = new QLabel(mWfsOptionsGroupBox);
        lblVersion_2->setObjectName("lblVersion_2");
        sizePolicy3.setHeightForWidth(lblVersion_2->sizePolicy().hasHeightForWidth());
        lblVersion_2->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblVersion_2, 2, 0, 1, 1);

        mComboHttpMethod = new QComboBox(mWfsOptionsGroupBox);
        mComboHttpMethod->setObjectName("mComboHttpMethod");

        gridLayout1->addWidget(mComboHttpMethod, 2, 1, 1, 2);

        lblMaxNumFeatures = new QLabel(mWfsOptionsGroupBox);
        lblMaxNumFeatures->setObjectName("lblMaxNumFeatures");
        sizePolicy3.setHeightForWidth(lblMaxNumFeatures->sizePolicy().hasHeightForWidth());
        lblMaxNumFeatures->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblMaxNumFeatures, 3, 0, 1, 1);

        txtMaxNumFeatures = new QLineEdit(mWfsOptionsGroupBox);
        txtMaxNumFeatures->setObjectName("txtMaxNumFeatures");

        gridLayout1->addWidget(txtMaxNumFeatures, 3, 1, 1, 2);

        lblFeaturePaging = new QLabel(mWfsOptionsGroupBox);
        lblFeaturePaging->setObjectName("lblFeaturePaging");
        sizePolicy3.setHeightForWidth(lblFeaturePaging->sizePolicy().hasHeightForWidth());
        lblFeaturePaging->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblFeaturePaging, 4, 0, 1, 1);

        cmbFeaturePaging = new QComboBox(mWfsOptionsGroupBox);
        cmbFeaturePaging->setObjectName("cmbFeaturePaging");

        gridLayout1->addWidget(cmbFeaturePaging, 4, 1, 1, 2);

        lblPageSize = new QLabel(mWfsOptionsGroupBox);
        lblPageSize->setObjectName("lblPageSize");
        sizePolicy3.setHeightForWidth(lblPageSize->sizePolicy().hasHeightForWidth());
        lblPageSize->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblPageSize, 5, 0, 1, 1);

        txtPageSize = new QLineEdit(mWfsOptionsGroupBox);
        txtPageSize->setObjectName("txtPageSize");

        gridLayout1->addWidget(txtPageSize, 5, 1, 1, 2);

        lblFeatureMode = new QLabel(mWfsOptionsGroupBox);
        lblFeatureMode->setObjectName("lblFeatureMode");
        sizePolicy3.setHeightForWidth(lblFeatureMode->sizePolicy().hasHeightForWidth());
        lblFeatureMode->setSizePolicy(sizePolicy3);

        gridLayout1->addWidget(lblFeatureMode, 6, 0, 1, 1);

        mComboWfsFeatureMode = new QComboBox(mWfsOptionsGroupBox);
        mComboWfsFeatureMode->setObjectName("mComboWfsFeatureMode");

        gridLayout1->addWidget(mComboWfsFeatureMode, 6, 1, 1, 2);

        cbxWfsIgnoreAxisOrientation = new QCheckBox(mWfsOptionsGroupBox);
        cbxWfsIgnoreAxisOrientation->setObjectName("cbxWfsIgnoreAxisOrientation");

        gridLayout1->addWidget(cbxWfsIgnoreAxisOrientation, 7, 0, 1, 3);

        cbxWfsInvertAxisOrientation = new QCheckBox(mWfsOptionsGroupBox);
        cbxWfsInvertAxisOrientation->setObjectName("cbxWfsInvertAxisOrientation");

        gridLayout1->addWidget(cbxWfsInvertAxisOrientation, 8, 0, 1, 3);

        cbxWfsUseGml2EncodingForTransactions = new QCheckBox(mWfsOptionsGroupBox);
        cbxWfsUseGml2EncodingForTransactions->setObjectName("cbxWfsUseGml2EncodingForTransactions");

        gridLayout1->addWidget(cbxWfsUseGml2EncodingForTransactions, 9, 0, 1, 1);

        cbxWfsForceInitialGetFeature = new QCheckBox(mWfsOptionsGroupBox);
        cbxWfsForceInitialGetFeature->setObjectName("cbxWfsForceInitialGetFeature");

        gridLayout1->addWidget(cbxWfsForceInitialGetFeature, 10, 0, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout1->addItem(verticalSpacer_3, 11, 0, 1, 3);


        verticalLayout_2->addWidget(mWfsOptionsGroupBox);


        horizontalLayout->addLayout(verticalLayout_2);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_3->addWidget(scrollArea);

        buttonBox = new QDialogButtonBox(QgsNewHttpConnectionBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Help|QDialogButtonBox::StandardButton::Ok);

        verticalLayout_3->addWidget(buttonBox);

#if QT_CONFIG(shortcut)
        lblTilePixelRatio->setBuddy(cmbTilePixelRatio);
        lblDpiMode->setBuddy(cmbDpiMode);
#endif // QT_CONFIG(shortcut)
        QWidget::setTabOrder(scrollArea, txtName);
        QWidget::setTabOrder(txtName, txtUrl);
        QWidget::setTabOrder(txtUrl, mTestConnectionButton);
        QWidget::setTabOrder(mTestConnectionButton, cmbTilePixelRatio);
        QWidget::setTabOrder(cmbTilePixelRatio, sbFeatureCount);
        QWidget::setTabOrder(sbFeatureCount, cbxIgnoreGetMapURI);
        QWidget::setTabOrder(cbxIgnoreGetMapURI, cbxIgnoreGetFeatureInfoURI);
        QWidget::setTabOrder(cbxIgnoreGetFeatureInfoURI, cbxWmsIgnoreReportedLayerExtents);
        QWidget::setTabOrder(cbxWmsIgnoreReportedLayerExtents, cbxWmsIgnoreAxisOrientation);
        QWidget::setTabOrder(cbxWmsIgnoreAxisOrientation, cbxWmsInvertAxisOrientation);
        QWidget::setTabOrder(cbxWmsInvertAxisOrientation, cbxSmoothPixmapTransform);
        QWidget::setTabOrder(cbxSmoothPixmapTransform, cmbVersion);
        QWidget::setTabOrder(cmbVersion, mWfsVersionDetectButton);
        QWidget::setTabOrder(mWfsVersionDetectButton, mFeatureFormatComboBox);
        QWidget::setTabOrder(mFeatureFormatComboBox, mFeatureFormatDetectButton);
        QWidget::setTabOrder(mFeatureFormatDetectButton, mComboHttpMethod);
        QWidget::setTabOrder(mComboHttpMethod, txtMaxNumFeatures);
        QWidget::setTabOrder(txtMaxNumFeatures, cmbFeaturePaging);
        QWidget::setTabOrder(cmbFeaturePaging, txtPageSize);
        QWidget::setTabOrder(txtPageSize, mComboWfsFeatureMode);
        QWidget::setTabOrder(mComboWfsFeatureMode, cbxWfsIgnoreAxisOrientation);
        QWidget::setTabOrder(cbxWfsIgnoreAxisOrientation, cbxWfsInvertAxisOrientation);
        QWidget::setTabOrder(cbxWfsInvertAxisOrientation, cbxWfsUseGml2EncodingForTransactions);
        QWidget::setTabOrder(cbxWfsUseGml2EncodingForTransactions, cbxWfsForceInitialGetFeature);

        retranslateUi(QgsNewHttpConnectionBase);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, QgsNewHttpConnectionBase, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, QgsNewHttpConnectionBase, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(QgsNewHttpConnectionBase);
    } // setupUi

    void retranslateUi(QDialog *QgsNewHttpConnectionBase)
    {
        QgsNewHttpConnectionBase->setWindowTitle(QCoreApplication::translate("QgsNewHttpConnectionBase", "Create a New Connection", nullptr));
        mGroupBox->setTitle(QCoreApplication::translate("QgsNewHttpConnectionBase", "Connection Details", nullptr));
        TextLabel1_2->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Name", nullptr));
        mAuthGroupBox->setTitle(QCoreApplication::translate("QgsNewHttpConnectionBase", "Authentication", nullptr));
        TextLabel1->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "URL", nullptr));
#if QT_CONFIG(tooltip)
        txtName->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "Name of the new connection", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        txtUrl->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "HTTP address of the Web Map Server", nullptr));
#endif // QT_CONFIG(tooltip)
        mTestConnectionButton->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "&Test Connection", nullptr));
        mWmsOptionsGroupBox->setTitle(QCoreApplication::translate("QgsNewHttpConnectionBase", "WMS/WMTS Options", nullptr));
        lblTilePixelRatio->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "WMTS server-side tile pixel ratio", nullptr));
        lblWmsFormat->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Default image format", nullptr));
        lblFeatureCount->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Maximum number of GetFeatureInfo results", nullptr));
        lblDpiMode->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "WMS DPI-&Mode", nullptr));
#if QT_CONFIG(tooltip)
        mWmsFormatDetectButton->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "Ask the server for the available formats", nullptr));
#endif // QT_CONFIG(tooltip)
        mWmsFormatDetectButton->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Detect", nullptr));
#if QT_CONFIG(tooltip)
        sbFeatureCount->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "<html><head/><body><p>Specify a default value for FEATURE_COUNT when a new layer is created from this connection. </p><p>FEATURE_COUNT defines the maximum number of results returned by a GetFeatureInfo request, if not specified the server default value (usually 1) will be used.</p><p>Set to 0 to use server default: no FEATURE_COUNT parameter will be added to the request.</p><p><br/></p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        sbFeatureCount->setSpecialValueText(QCoreApplication::translate("QgsNewHttpConnectionBase", "server default", nullptr));
        cbxIgnoreGetMapURI->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Ignore GetMap/GetTile/GetLegendGraphic URI reported in capabilities", nullptr));
        cbxIgnoreGetFeatureInfoURI->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Ignore GetFeatureInfo URI reported in capabilities", nullptr));
        cbxWmsIgnoreReportedLayerExtents->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Ignore reported layer extents", nullptr));
        cbxWmsIgnoreAxisOrientation->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Ignore axis orientation (WMS 1.3/WMTS)", nullptr));
        cbxWmsInvertAxisOrientation->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Invert axis orientation", nullptr));
        cbxSmoothPixmapTransform->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Smooth pixmap transform", nullptr));
        mWfsOptionsGroupBox->setTitle(QCoreApplication::translate("QgsNewHttpConnectionBase", "WFS Options", nullptr));
        lblVersion->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Version", nullptr));
        mWfsVersionDetectButton->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Detect", nullptr));
        lblFeatureFormat->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Feature format", nullptr));
#if QT_CONFIG(tooltip)
        lblFeatureFormat->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "Only used for OGC-API Features", nullptr));
#endif // QT_CONFIG(tooltip)
        mFeatureFormatDetectButton->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Detect", nullptr));
#if QT_CONFIG(tooltip)
        mFeatureFormatDetectButton->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "Only used for OGC-API Features", nullptr));
#endif // QT_CONFIG(tooltip)
        lblVersion_2->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Preferred HTTP method", nullptr));
        lblMaxNumFeatures->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Max. number of features", nullptr));
#if QT_CONFIG(tooltip)
        txtMaxNumFeatures->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "<html><head/><body><p>Enter a number to limit the maximum number of features retrieved per feature request. If empty, no limit is set.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        lblFeaturePaging->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Feature paging", nullptr));
        lblPageSize->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Page size", nullptr));
#if QT_CONFIG(tooltip)
        txtPageSize->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "<html><head/><body><p>Enter a number to limit the maximum number of features retrieved in a single GetFeature request when paging is enabled. If let to empty, server default will apply.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        lblFeatureMode->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "<html><head/><body><p>Feature mode<br/>(Simple vs Complex)</p></body></html>", nullptr));
#if QT_CONFIG(tooltip)
        mComboWfsFeatureMode->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "Determines whether to return data as simple features or as complex features where nested data structures are exposed by QGIS as JSON", nullptr));
#endif // QT_CONFIG(tooltip)
        cbxWfsIgnoreAxisOrientation->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Ignore axis orientation (WFS 1.1/WFS 2.0)", nullptr));
        cbxWfsInvertAxisOrientation->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Invert axis orientation", nullptr));
#if QT_CONFIG(tooltip)
        cbxWfsUseGml2EncodingForTransactions->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "<html><head/><body><p>This might be necessary on some <span style=\" font-weight:600;\">broken</span> ESRI map servers when using WFS-T 1.1.0.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cbxWfsUseGml2EncodingForTransactions->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Use GML2 encoding for transactions", nullptr));
#if QT_CONFIG(tooltip)
        cbxWfsForceInitialGetFeature->setToolTip(QCoreApplication::translate("QgsNewHttpConnectionBase", "<html><head/><body><p>When checked, an initial GetFeature call will always be issued in order to determine the geometry type from the first downloaded feature.</p><p>This option can be used if the layer contains features with Z axis coordinates that are otherwise not correctly identified.</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        cbxWfsForceInitialGetFeature->setText(QCoreApplication::translate("QgsNewHttpConnectionBase", "Force initial GetFeature", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsNewHttpConnectionBase: public Ui_QgsNewHttpConnectionBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSNEWHTTPCONNECTIONBASE_H
