/********************************************************************************
** Form generated from reading UI file 'qgsvectorlayer3dpropertieswidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSVECTORLAYER3DPROPERTIESWIDGET_H
#define UI_QGSVECTORLAYER3DPROPERTIESWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qgscollapsiblegroupbox.h"
#include "qgsspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_QgsVectorLayer3DPropertiesWidget
{
public:
    QVBoxLayout *verticalLayout_2;
    QgsCollapsibleGroupBox *groupLayerRendering;
    QGridLayout *gridLayout;
    QCheckBox *chkShowBoundingBoxes;
    QgsSpinBox *mMaxFeaturesSpinBox;
    QLabel *lblMaxFeatures;

    void setupUi(QWidget *QgsVectorLayer3DPropertiesWidget)
    {
        if (QgsVectorLayer3DPropertiesWidget->objectName().isEmpty())
            QgsVectorLayer3DPropertiesWidget->setObjectName("QgsVectorLayer3DPropertiesWidget");
        QgsVectorLayer3DPropertiesWidget->resize(386, 310);
        QgsVectorLayer3DPropertiesWidget->setWindowTitle(QString::fromUtf8("Form"));
        verticalLayout_2 = new QVBoxLayout(QgsVectorLayer3DPropertiesWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        groupLayerRendering = new QgsCollapsibleGroupBox(QgsVectorLayer3DPropertiesWidget);
        groupLayerRendering->setObjectName("groupLayerRendering");
        gridLayout = new QGridLayout(groupLayerRendering);
        gridLayout->setObjectName("gridLayout");
        chkShowBoundingBoxes = new QCheckBox(groupLayerRendering);
        chkShowBoundingBoxes->setObjectName("chkShowBoundingBoxes");

        gridLayout->addWidget(chkShowBoundingBoxes, 1, 0, 1, 2);

        mMaxFeaturesSpinBox = new QgsSpinBox(groupLayerRendering);
        mMaxFeaturesSpinBox->setObjectName("mMaxFeaturesSpinBox");
        mMaxFeaturesSpinBox->setMaximum(999999);
        mMaxFeaturesSpinBox->setValue(1000);

        gridLayout->addWidget(mMaxFeaturesSpinBox, 0, 1, 1, 1);

        lblMaxFeatures = new QLabel(groupLayerRendering);
        lblMaxFeatures->setObjectName("lblMaxFeatures");

        gridLayout->addWidget(lblMaxFeatures, 0, 0, 1, 1);


        verticalLayout_2->addWidget(groupLayerRendering);

        QWidget::setTabOrder(mMaxFeaturesSpinBox, chkShowBoundingBoxes);

        retranslateUi(QgsVectorLayer3DPropertiesWidget);

        QMetaObject::connectSlotsByName(QgsVectorLayer3DPropertiesWidget);
    } // setupUi

    void retranslateUi(QWidget *QgsVectorLayer3DPropertiesWidget)
    {
        groupLayerRendering->setTitle(QCoreApplication::translate("QgsVectorLayer3DPropertiesWidget", "Layer Rendering", nullptr));
        chkShowBoundingBoxes->setText(QCoreApplication::translate("QgsVectorLayer3DPropertiesWidget", "Show bounding boxes of tiles", nullptr));
        lblMaxFeatures->setText(QCoreApplication::translate("QgsVectorLayer3DPropertiesWidget", "Maximum Features per Chunk", nullptr));
        (void)QgsVectorLayer3DPropertiesWidget;
    } // retranslateUi

};

namespace Ui {
    class QgsVectorLayer3DPropertiesWidget: public Ui_QgsVectorLayer3DPropertiesWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSVECTORLAYER3DPROPERTIESWIDGET_H
