/********************************************************************************
** Form generated from reading UI file 'qgschamferfilletuserinputwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSCHAMFERFILLETUSERINPUTWIDGET_H
#define UI_QGSCHAMFERFILLETUSERINPUTWIDGET_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>
#include "qgsdoublespinbox.h"

QT_BEGIN_NAMESPACE

class Ui_QgsChamferFilletUserInputBase
{
public:
    QGridLayout *gridLayout;
    QgsDoubleSpinBox *mValue1SpinBox;
    QgsDoubleSpinBox *mValue2SpinBox;
    QLabel *mVal1Label;
    QLabel *mOperationLabel;
    QLabel *mVal2Label;
    QComboBox *mOperationComboBox;
    QPushButton *mVal1Locker;
    QPushButton *mVal2Locker;

    void setupUi(QWidget *QgsChamferFilletUserInputBase)
    {
        if (QgsChamferFilletUserInputBase->objectName().isEmpty())
            QgsChamferFilletUserInputBase->setObjectName("QgsChamferFilletUserInputBase");
        QgsChamferFilletUserInputBase->resize(430, 142);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(QgsChamferFilletUserInputBase->sizePolicy().hasHeightForWidth());
        QgsChamferFilletUserInputBase->setSizePolicy(sizePolicy);
        QgsChamferFilletUserInputBase->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout = new QGridLayout(QgsChamferFilletUserInputBase);
        gridLayout->setObjectName("gridLayout");
        mValue1SpinBox = new QgsDoubleSpinBox(QgsChamferFilletUserInputBase);
        mValue1SpinBox->setObjectName("mValue1SpinBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mValue1SpinBox->sizePolicy().hasHeightForWidth());
        mValue1SpinBox->setSizePolicy(sizePolicy1);
        mValue1SpinBox->setMinimum(0.000000000000000);
        mValue1SpinBox->setMaximum(999999.989999999990687);

        gridLayout->addWidget(mValue1SpinBox, 2, 2, 1, 1);

        mValue2SpinBox = new QgsDoubleSpinBox(QgsChamferFilletUserInputBase);
        mValue2SpinBox->setObjectName("mValue2SpinBox");
        mValue2SpinBox->setEnabled(true);
        mValue2SpinBox->setMinimum(0.000000000000000);
        mValue2SpinBox->setMaximum(999999.989999999990687);
        mValue2SpinBox->setValue(0.000000000000000);

        gridLayout->addWidget(mValue2SpinBox, 4, 2, 1, 1);

        mVal1Label = new QLabel(QgsChamferFilletUserInputBase);
        mVal1Label->setObjectName("mVal1Label");

        gridLayout->addWidget(mVal1Label, 2, 0, 1, 1);

        mOperationLabel = new QLabel(QgsChamferFilletUserInputBase);
        mOperationLabel->setObjectName("mOperationLabel");
        mOperationLabel->setWordWrap(true);

        gridLayout->addWidget(mOperationLabel, 0, 0, 1, 1);

        mVal2Label = new QLabel(QgsChamferFilletUserInputBase);
        mVal2Label->setObjectName("mVal2Label");
        mVal2Label->setEnabled(true);
        mVal2Label->setWordWrap(true);

        gridLayout->addWidget(mVal2Label, 4, 0, 1, 1);

        mOperationComboBox = new QComboBox(QgsChamferFilletUserInputBase);
        mOperationComboBox->setObjectName("mOperationComboBox");

        gridLayout->addWidget(mOperationComboBox, 0, 2, 1, 1);

        mVal1Locker = new QPushButton(QgsChamferFilletUserInputBase);
        mVal1Locker->setObjectName("mVal1Locker");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/themes/default/unlocked.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        icon.addFile(QString::fromUtf8(":/images/themes/default/locked.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        mVal1Locker->setIcon(icon);
        mVal1Locker->setCheckable(true);

        gridLayout->addWidget(mVal1Locker, 2, 3, 1, 1);

        mVal2Locker = new QPushButton(QgsChamferFilletUserInputBase);
        mVal2Locker->setObjectName("mVal2Locker");
        mVal2Locker->setIcon(icon);
        mVal2Locker->setCheckable(true);

        gridLayout->addWidget(mVal2Locker, 4, 3, 1, 1);

#if QT_CONFIG(shortcut)
        mVal1Label->setBuddy(mValue1SpinBox);
        mOperationLabel->setBuddy(mOperationComboBox);
        mVal2Label->setBuddy(mValue2SpinBox);
#endif // QT_CONFIG(shortcut)

        retranslateUi(QgsChamferFilletUserInputBase);

        QMetaObject::connectSlotsByName(QgsChamferFilletUserInputBase);
    } // setupUi

    void retranslateUi(QWidget *QgsChamferFilletUserInputBase)
    {
        mVal1Label->setText(QCoreApplication::translate("QgsChamferFilletUserInputBase", "Distance", nullptr));
        mOperationLabel->setText(QCoreApplication::translate("QgsChamferFilletUserInputBase", "Operation", nullptr));
        mVal2Label->setText(QCoreApplication::translate("QgsChamferFilletUserInputBase", "Fillet segments", nullptr));
        mVal1Locker->setText(QString());
        mVal2Locker->setText(QString());
        (void)QgsChamferFilletUserInputBase;
    } // retranslateUi

};

namespace Ui {
    class QgsChamferFilletUserInputBase: public Ui_QgsChamferFilletUserInputBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSCHAMFERFILLETUSERINPUTWIDGET_H
