/********************************************************************************
** Form generated from reading UI file 'qgsrasterattributetablewidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSRASTERATTRIBUTETABLEWIDGETBASE_H
#define UI_QGSRASTERATTRIBUTETABLEWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTableView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_QgsRasterAttributeTableWidgetBase
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *mTopLayout;
    QLabel *label;
    QComboBox *mRasterBandsComboBox;
    QSpacerItem *horizontalSpacer_2;
    QLabel *mClassifyLabel;
    QComboBox *mClassifyComboBox;
    QPushButton *mClassifyButton;
    QTableView *mRATView;

    void setupUi(QWidget *QgsRasterAttributeTableWidgetBase)
    {
        if (QgsRasterAttributeTableWidgetBase->objectName().isEmpty())
            QgsRasterAttributeTableWidgetBase->setObjectName("QgsRasterAttributeTableWidgetBase");
        QgsRasterAttributeTableWidgetBase->resize(967, 489);
        verticalLayout = new QVBoxLayout(QgsRasterAttributeTableWidgetBase);
        verticalLayout->setSpacing(3);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(3, 3, 3, 3);
        mTopLayout = new QHBoxLayout();
        mTopLayout->setObjectName("mTopLayout");
        label = new QLabel(QgsRasterAttributeTableWidgetBase);
        label->setObjectName("label");

        mTopLayout->addWidget(label);

        mRasterBandsComboBox = new QComboBox(QgsRasterAttributeTableWidgetBase);
        mRasterBandsComboBox->setObjectName("mRasterBandsComboBox");

        mTopLayout->addWidget(mRasterBandsComboBox);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        mTopLayout->addItem(horizontalSpacer_2);

        mClassifyLabel = new QLabel(QgsRasterAttributeTableWidgetBase);
        mClassifyLabel->setObjectName("mClassifyLabel");

        mTopLayout->addWidget(mClassifyLabel);

        mClassifyComboBox = new QComboBox(QgsRasterAttributeTableWidgetBase);
        mClassifyComboBox->setObjectName("mClassifyComboBox");

        mTopLayout->addWidget(mClassifyComboBox);

        mClassifyButton = new QPushButton(QgsRasterAttributeTableWidgetBase);
        mClassifyButton->setObjectName("mClassifyButton");

        mTopLayout->addWidget(mClassifyButton);

        mTopLayout->setStretch(1, 1);
        mTopLayout->setStretch(4, 1);

        verticalLayout->addLayout(mTopLayout);

        mRATView = new QTableView(QgsRasterAttributeTableWidgetBase);
        mRATView->setObjectName("mRATView");
        mRATView->setSelectionMode(QAbstractItemView::SingleSelection);
        mRATView->setSortingEnabled(true);
        mRATView->verticalHeader()->setDefaultSectionSize(28);

        verticalLayout->addWidget(mRATView);


        retranslateUi(QgsRasterAttributeTableWidgetBase);

        QMetaObject::connectSlotsByName(QgsRasterAttributeTableWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *QgsRasterAttributeTableWidgetBase)
    {
        QgsRasterAttributeTableWidgetBase->setWindowTitle(QCoreApplication::translate("QgsRasterAttributeTableWidgetBase", "Raster Attribute Table", nullptr));
        label->setText(QCoreApplication::translate("QgsRasterAttributeTableWidgetBase", "Raster band", nullptr));
        mClassifyLabel->setText(QCoreApplication::translate("QgsRasterAttributeTableWidgetBase", "Classification", nullptr));
        mClassifyButton->setText(QCoreApplication::translate("QgsRasterAttributeTableWidgetBase", "Classify", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsRasterAttributeTableWidgetBase: public Ui_QgsRasterAttributeTableWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSRASTERATTRIBUTETABLEWIDGETBASE_H
