/********************************************************************************
** Form generated from reading UI file 'qgspointcloudelevationpropertieswidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSPOINTCLOUDELEVATIONPROPERTIESWIDGETBASE_H
#define UI_QGSPOINTCLOUDELEVATIONPROPERTIESWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qgscollapsiblegroupbox.h"
#include "qgscolorbutton.h"
#include "qgsdoublespinbox.h"
#include "qgsstackedwidget.h"
#include "qgssymbolbutton.h"
#include "qgsunitselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_QgsPointCloudElevationPropertiesWidgetBase
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_3;
    QVBoxLayout *verticalLayout_2;
    QgsStackedWidget *mVerticalCrsStackedWidget;
    QWidget *mCrsPageDisabled;
    QVBoxLayout *verticalLayout_3;
    QLabel *mCrsDisabledLabel;
    QWidget *mCrsPageEnabled;
    QLabel *label_4;
    QgsCollapsibleGroupBox *mCrsGroupBox_2;
    QGridLayout *gridLayout_2;
    QgsDoubleSpinBox *mOffsetZSpinBox;
    QFrame *line_3;
    QgsDoubleSpinBox *mScaleZSpinBox;
    QLabel *label;
    QLabel *label_2;
    QPushButton *mShiftPointCloudZAxisButton;
    QLabel *label_3;
    QGroupBox *mLayerRenderingGroupBox;
    QGridLayout *gridLayout_4;
    QgsDoubleSpinBox *mMaxErrorSpinBox;
    QgsUnitSelectionWidget *mMaxErrorUnitWidget;
    QLabel *lblTransparency_2;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout;
    QLabel *label_7;
    QComboBox *mTypeCombobox;
    QgsStackedWidget *mInterpretationStackedWidget;
    QWidget *pageIndividualPoints;
    QGridLayout *gridLayout_7;
    QGridLayout *gridLayoutIndividualPoints;
    QgsDoubleSpinBox *mPointSizeSpinBox;
    QCheckBox *mCheckBoxRespectLayerColors;
    QLabel *label_11;
    QCheckBox *mOpacityByDistanceCheckBox;
    QLabel *lblTransparency_6;
    QLabel *label_12;
    QgsUnitSelectionWidget *mPointSizeUnitWidget;
    QComboBox *mPointStyleComboBox;
    QgsColorButton *mPointColorButton;
    QWidget *pageTriangulatedSurface;
    QGridLayout *gridLayout_8;
    QGridLayout *gridLayoutTriangulatedSurface;
    QLabel *labelStyle;
    QgsSymbolButton *mFillStyleButton;
    QLabel *labelLimit;
    QLabel *labelLineStyle;
    QLabel *labelFillStyle;
    QComboBox *mSurfaceStyleCombobox;
    QgsSymbolButton *mLineStyleButton;
    QgsDoubleSpinBox *mElevationLimitSpinBox;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *QgsPointCloudElevationPropertiesWidgetBase)
    {
        if (QgsPointCloudElevationPropertiesWidgetBase->objectName().isEmpty())
            QgsPointCloudElevationPropertiesWidgetBase->setObjectName("QgsPointCloudElevationPropertiesWidgetBase");
        QgsPointCloudElevationPropertiesWidgetBase->resize(526, 804);
        verticalLayout = new QVBoxLayout(QgsPointCloudElevationPropertiesWidgetBase);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_3 = new QGroupBox(QgsPointCloudElevationPropertiesWidgetBase);
        groupBox_3->setObjectName("groupBox_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_3->sizePolicy().hasHeightForWidth());
        groupBox_3->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(groupBox_3);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mVerticalCrsStackedWidget = new QgsStackedWidget(groupBox_3);
        mVerticalCrsStackedWidget->setObjectName("mVerticalCrsStackedWidget");
        sizePolicy.setHeightForWidth(mVerticalCrsStackedWidget->sizePolicy().hasHeightForWidth());
        mVerticalCrsStackedWidget->setSizePolicy(sizePolicy);
        mCrsPageDisabled = new QWidget();
        mCrsPageDisabled->setObjectName("mCrsPageDisabled");
        verticalLayout_3 = new QVBoxLayout(mCrsPageDisabled);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        mCrsDisabledLabel = new QLabel(mCrsPageDisabled);
        mCrsDisabledLabel->setObjectName("mCrsDisabledLabel");
        mCrsDisabledLabel->setWordWrap(true);

        verticalLayout_3->addWidget(mCrsDisabledLabel);

        mVerticalCrsStackedWidget->addWidget(mCrsPageDisabled);
        mCrsPageEnabled = new QWidget();
        mCrsPageEnabled->setObjectName("mCrsPageEnabled");
        mVerticalCrsStackedWidget->addWidget(mCrsPageEnabled);

        verticalLayout_2->addWidget(mVerticalCrsStackedWidget);

        label_4 = new QLabel(groupBox_3);
        label_4->setObjectName("label_4");
        label_4->setWordWrap(true);

        verticalLayout_2->addWidget(label_4);


        verticalLayout->addWidget(groupBox_3);

        mCrsGroupBox_2 = new QgsCollapsibleGroupBox(QgsPointCloudElevationPropertiesWidgetBase);
        mCrsGroupBox_2->setObjectName("mCrsGroupBox_2");
        mCrsGroupBox_2->setFocusPolicy(Qt::FocusPolicy::StrongFocus);
        mCrsGroupBox_2->setCheckable(false);
        mCrsGroupBox_2->setProperty("syncGroup", QVariant(QString::fromUtf8("vectorgeneral")));
        gridLayout_2 = new QGridLayout(mCrsGroupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        mOffsetZSpinBox = new QgsDoubleSpinBox(mCrsGroupBox_2);
        mOffsetZSpinBox->setObjectName("mOffsetZSpinBox");
        mOffsetZSpinBox->setDecimals(6);
        mOffsetZSpinBox->setMinimum(-99999999999.000000000000000);
        mOffsetZSpinBox->setMaximum(99999999999.000000000000000);

        gridLayout_2->addWidget(mOffsetZSpinBox, 2, 1, 1, 1);

        line_3 = new QFrame(mCrsGroupBox_2);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::VLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(line_3, 3, 0, 1, 1);

        mScaleZSpinBox = new QgsDoubleSpinBox(mCrsGroupBox_2);
        mScaleZSpinBox->setObjectName("mScaleZSpinBox");
        mScaleZSpinBox->setDecimals(6);
        mScaleZSpinBox->setMinimum(-99999999999.000000000000000);
        mScaleZSpinBox->setMaximum(99999999999.000000000000000);
        mScaleZSpinBox->setValue(1.000000000000000);

        gridLayout_2->addWidget(mScaleZSpinBox, 1, 1, 1, 1);

        label = new QLabel(mCrsGroupBox_2);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 2, 0, 1, 1);

        label_2 = new QLabel(mCrsGroupBox_2);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 1, 0, 1, 1);

        mShiftPointCloudZAxisButton = new QPushButton(mCrsGroupBox_2);
        mShiftPointCloudZAxisButton->setObjectName("mShiftPointCloudZAxisButton");
        mShiftPointCloudZAxisButton->setMinimumSize(QSize(24, 24));
        mShiftPointCloudZAxisButton->setMaximumSize(QSize(24, 16777215));
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/themes/default/mActionRefresh.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::On);
        mShiftPointCloudZAxisButton->setIcon(icon);

        gridLayout_2->addWidget(mShiftPointCloudZAxisButton, 2, 2, 1, 1);

        label_3 = new QLabel(mCrsGroupBox_2);
        label_3->setObjectName("label_3");
        label_3->setWordWrap(true);

        gridLayout_2->addWidget(label_3, 0, 0, 1, 3);


        verticalLayout->addWidget(mCrsGroupBox_2);

        mLayerRenderingGroupBox = new QGroupBox(QgsPointCloudElevationPropertiesWidgetBase);
        mLayerRenderingGroupBox->setObjectName("mLayerRenderingGroupBox");
        mLayerRenderingGroupBox->setFlat(true);
        mLayerRenderingGroupBox->setCheckable(false);
        gridLayout_4 = new QGridLayout(mLayerRenderingGroupBox);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setContentsMargins(0, -1, 3, -1);
        mMaxErrorSpinBox = new QgsDoubleSpinBox(mLayerRenderingGroupBox);
        mMaxErrorSpinBox->setObjectName("mMaxErrorSpinBox");
        mMaxErrorSpinBox->setDecimals(6);
        mMaxErrorSpinBox->setMaximum(99999999999.000000000000000);
        mMaxErrorSpinBox->setValue(0.300000000000000);

        gridLayout_4->addWidget(mMaxErrorSpinBox, 0, 1, 1, 2);

        mMaxErrorUnitWidget = new QgsUnitSelectionWidget(mLayerRenderingGroupBox);
        mMaxErrorUnitWidget->setObjectName("mMaxErrorUnitWidget");
        mMaxErrorUnitWidget->setMinimumSize(QSize(0, 0));
        mMaxErrorUnitWidget->setFocusPolicy(Qt::FocusPolicy::StrongFocus);

        gridLayout_4->addWidget(mMaxErrorUnitWidget, 0, 3, 1, 1);

        lblTransparency_2 = new QLabel(mLayerRenderingGroupBox);
        lblTransparency_2->setObjectName("lblTransparency_2");

        gridLayout_4->addWidget(lblTransparency_2, 0, 0, 1, 1);

        gridLayout_4->setColumnStretch(0, 1);
        gridLayout_4->setColumnStretch(1, 2);
        gridLayout_4->setColumnStretch(2, 1);

        verticalLayout->addWidget(mLayerRenderingGroupBox);

        groupBox_2 = new QGroupBox(QgsPointCloudElevationPropertiesWidgetBase);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout = new QGridLayout(groupBox_2);
        gridLayout->setObjectName("gridLayout");
        label_7 = new QLabel(groupBox_2);
        label_7->setObjectName("label_7");
        label_7->setEnabled(true);

        gridLayout->addWidget(label_7, 0, 0, 1, 1);

        mTypeCombobox = new QComboBox(groupBox_2);
        mTypeCombobox->setObjectName("mTypeCombobox");

        gridLayout->addWidget(mTypeCombobox, 0, 1, 1, 2);

        mInterpretationStackedWidget = new QgsStackedWidget(groupBox_2);
        mInterpretationStackedWidget->setObjectName("mInterpretationStackedWidget");
        pageIndividualPoints = new QWidget();
        pageIndividualPoints->setObjectName("pageIndividualPoints");
        gridLayout_7 = new QGridLayout(pageIndividualPoints);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(0, 0, 0, 0);
        gridLayoutIndividualPoints = new QGridLayout();
        gridLayoutIndividualPoints->setObjectName("gridLayoutIndividualPoints");
        gridLayoutIndividualPoints->setContentsMargins(0, 0, 0, 0);
        mPointSizeSpinBox = new QgsDoubleSpinBox(pageIndividualPoints);
        mPointSizeSpinBox->setObjectName("mPointSizeSpinBox");
        mPointSizeSpinBox->setDecimals(6);
        mPointSizeSpinBox->setMaximum(99999999999.000000000000000);

        gridLayoutIndividualPoints->addWidget(mPointSizeSpinBox, 0, 1, 1, 1);

        mCheckBoxRespectLayerColors = new QCheckBox(pageIndividualPoints);
        mCheckBoxRespectLayerColors->setObjectName("mCheckBoxRespectLayerColors");

        gridLayoutIndividualPoints->addWidget(mCheckBoxRespectLayerColors, 3, 0, 1, 2);

        label_11 = new QLabel(pageIndividualPoints);
        label_11->setObjectName("label_11");

        gridLayoutIndividualPoints->addWidget(label_11, 1, 0, 1, 1);

        mOpacityByDistanceCheckBox = new QCheckBox(pageIndividualPoints);
        mOpacityByDistanceCheckBox->setObjectName("mOpacityByDistanceCheckBox");

        gridLayoutIndividualPoints->addWidget(mOpacityByDistanceCheckBox, 4, 0, 1, 2);

        lblTransparency_6 = new QLabel(pageIndividualPoints);
        lblTransparency_6->setObjectName("lblTransparency_6");

        gridLayoutIndividualPoints->addWidget(lblTransparency_6, 0, 0, 1, 1);

        label_12 = new QLabel(pageIndividualPoints);
        label_12->setObjectName("label_12");

        gridLayoutIndividualPoints->addWidget(label_12, 2, 0, 1, 1);

        mPointSizeUnitWidget = new QgsUnitSelectionWidget(pageIndividualPoints);
        mPointSizeUnitWidget->setObjectName("mPointSizeUnitWidget");
        mPointSizeUnitWidget->setFocusPolicy(Qt::FocusPolicy::StrongFocus);

        gridLayoutIndividualPoints->addWidget(mPointSizeUnitWidget, 0, 2, 1, 1);

        mPointStyleComboBox = new QComboBox(pageIndividualPoints);
        mPointStyleComboBox->setObjectName("mPointStyleComboBox");

        gridLayoutIndividualPoints->addWidget(mPointStyleComboBox, 1, 1, 1, 2);

        mPointColorButton = new QgsColorButton(pageIndividualPoints);
        mPointColorButton->setObjectName("mPointColorButton");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(mPointColorButton->sizePolicy().hasHeightForWidth());
        mPointColorButton->setSizePolicy(sizePolicy1);
        mPointColorButton->setMinimumSize(QSize(120, 0));

        gridLayoutIndividualPoints->addWidget(mPointColorButton, 2, 1, 1, 2);


        gridLayout_7->addLayout(gridLayoutIndividualPoints, 0, 0, 1, 1);

        mInterpretationStackedWidget->addWidget(pageIndividualPoints);
        pageTriangulatedSurface = new QWidget();
        pageTriangulatedSurface->setObjectName("pageTriangulatedSurface");
        gridLayout_8 = new QGridLayout(pageTriangulatedSurface);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setContentsMargins(0, 0, 0, 0);
        gridLayoutTriangulatedSurface = new QGridLayout();
        gridLayoutTriangulatedSurface->setObjectName("gridLayoutTriangulatedSurface");
        gridLayoutTriangulatedSurface->setContentsMargins(0, 0, 0, 0);
        labelStyle = new QLabel(pageTriangulatedSurface);
        labelStyle->setObjectName("labelStyle");

        gridLayoutTriangulatedSurface->addWidget(labelStyle, 0, 0, 1, 1);

        mFillStyleButton = new QgsSymbolButton(pageTriangulatedSurface);
        mFillStyleButton->setObjectName("mFillStyleButton");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(mFillStyleButton->sizePolicy().hasHeightForWidth());
        mFillStyleButton->setSizePolicy(sizePolicy2);

        gridLayoutTriangulatedSurface->addWidget(mFillStyleButton, 2, 1, 1, 1);

        labelLimit = new QLabel(pageTriangulatedSurface);
        labelLimit->setObjectName("labelLimit");

        gridLayoutTriangulatedSurface->addWidget(labelLimit, 3, 0, 1, 1);

        labelLineStyle = new QLabel(pageTriangulatedSurface);
        labelLineStyle->setObjectName("labelLineStyle");

        gridLayoutTriangulatedSurface->addWidget(labelLineStyle, 1, 0, 1, 1);

        labelFillStyle = new QLabel(pageTriangulatedSurface);
        labelFillStyle->setObjectName("labelFillStyle");

        gridLayoutTriangulatedSurface->addWidget(labelFillStyle, 2, 0, 1, 1);

        mSurfaceStyleCombobox = new QComboBox(pageTriangulatedSurface);
        mSurfaceStyleCombobox->setObjectName("mSurfaceStyleCombobox");

        gridLayoutTriangulatedSurface->addWidget(mSurfaceStyleCombobox, 0, 1, 1, 1);

        mLineStyleButton = new QgsSymbolButton(pageTriangulatedSurface);
        mLineStyleButton->setObjectName("mLineStyleButton");
        sizePolicy2.setHeightForWidth(mLineStyleButton->sizePolicy().hasHeightForWidth());
        mLineStyleButton->setSizePolicy(sizePolicy2);

        gridLayoutTriangulatedSurface->addWidget(mLineStyleButton, 1, 1, 1, 1);

        mElevationLimitSpinBox = new QgsDoubleSpinBox(pageTriangulatedSurface);
        mElevationLimitSpinBox->setObjectName("mElevationLimitSpinBox");

        gridLayoutTriangulatedSurface->addWidget(mElevationLimitSpinBox, 3, 1, 1, 1);


        gridLayout_8->addLayout(gridLayoutTriangulatedSurface, 0, 0, 1, 1);

        mInterpretationStackedWidget->addWidget(pageTriangulatedSurface);

        gridLayout->addWidget(mInterpretationStackedWidget, 1, 0, 2, 3);

        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(1, 1);
        gridLayout->setColumnStretch(2, 1);

        verticalLayout->addWidget(groupBox_2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(mCrsGroupBox_2, mScaleZSpinBox);
        QWidget::setTabOrder(mScaleZSpinBox, mOffsetZSpinBox);
        QWidget::setTabOrder(mOffsetZSpinBox, mShiftPointCloudZAxisButton);

        retranslateUi(QgsPointCloudElevationPropertiesWidgetBase);

        mInterpretationStackedWidget->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(QgsPointCloudElevationPropertiesWidgetBase);
    } // setupUi

    void retranslateUi(QWidget *QgsPointCloudElevationPropertiesWidgetBase)
    {
        QgsPointCloudElevationPropertiesWidgetBase->setWindowTitle(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Point Cloud Elevation Properties", nullptr));
        groupBox_3->setTitle(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Vertical Reference System", nullptr));
        mCrsDisabledLabel->setText(QString());
        label_4->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "<html><head/><body><p>Vertical reference systems are supported for point cloud layers by:</p>\n"
"<ul>\n"
"<li>Elevation profiles</li>\n"
"<li>Identify tool results</li>\n"
"<li>3D map views (when 3D view has a vertical reference system set)</li>\n"
"</ul>\n"
"<p><i>Other tools or plugins may ignore the vertical reference system, and care should be taken to validate results accordingly.</i></p>\n"
"</body></html>", nullptr));
        mCrsGroupBox_2->setTitle(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Elevation", nullptr));
        label->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Offset", nullptr));
        label_2->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Scale", nullptr));
#if QT_CONFIG(tooltip)
        mShiftPointCloudZAxisButton->setToolTip(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Automatically sets the offset so that the lowest point in the cloud sits at an elevation of 0.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "<html><head/><body><p><span style=\" font-weight:600;\">Elevation scaling and offset can be used to manually correct elevation values in the point cloud at render time.</span></p><p>The scale is applied to the point cloud elevation values before adding the offset.</p></body></html>", nullptr));
        mLayerRenderingGroupBox->setTitle(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Profile Chart Accuracy", nullptr));
        lblTransparency_2->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Maximum error", nullptr));
        groupBox_2->setTitle(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Profile Chart Appearance", nullptr));
        label_7->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Interpretation", nullptr));
        mCheckBoxRespectLayerColors->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Respect layer's coloring", nullptr));
        label_11->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Style", nullptr));
        mOpacityByDistanceCheckBox->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Apply opacity by distance from curve effect", nullptr));
        lblTransparency_6->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Point size", nullptr));
        label_12->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Color", nullptr));
        mPointColorButton->setText(QString());
        labelStyle->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Style", nullptr));
        mFillStyleButton->setText(QString());
        labelLimit->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Limit", nullptr));
        labelLineStyle->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Line style", nullptr));
        labelFillStyle->setText(QCoreApplication::translate("QgsPointCloudElevationPropertiesWidgetBase", "Fill style", nullptr));
        mLineStyleButton->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class QgsPointCloudElevationPropertiesWidgetBase: public Ui_QgsPointCloudElevationPropertiesWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSPOINTCLOUDELEVATIONPROPERTIESWIDGETBASE_H
