"""
***************************************************************************
    defaultproviders.py
    ---------------------
    Date                 : May 2016
    Copyright            : (C) 2016 by Victor Olaya
    Email                : volayaf at gmail dot com
***************************************************************************
*                                                                         *
*   This program is free software; you can redistribute it and/or modify  *
*   it under the terms of the GNU General Public License as published by  *
*   the Free Software Foundation; either version 2 of the License, or     *
*   (at your option) any later version.                                   *
*                                                                         *
***************************************************************************
"""

__author__ = "Victor Olaya"
__date__ = "May 2016"
__copyright__ = "(C) 2016, Victor Olaya"


def loadDefaultProviders():
    # this is here just to "trigger" the above imports so providers are loaded
    # and can be found by the Processing.initialize() method
    pass
