/********************************************************************************
** Form generated from reading UI file 'qgsauthmasterpassresetdialog.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSAUTHMASTERPASSRESETDIALOG_H
#define UI_QGSAUTHMASTERPASSRESETDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "qgspasswordlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_QgsMasterPasswordResetDialog
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label_6;
    QgsPasswordLineEdit *leMasterPassCurrent;
    QLabel *label_7;
    QgsPasswordLineEdit *leMasterPassNew;
    QLabel *label_8;
    QgsPasswordLineEdit *leMasterPassNew2;
    QCheckBox *chkKeepBackup;
    QLabel *lblWarning;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QgsMasterPasswordResetDialog)
    {
        if (QgsMasterPasswordResetDialog->objectName().isEmpty())
            QgsMasterPasswordResetDialog->setObjectName("QgsMasterPasswordResetDialog");
        QgsMasterPasswordResetDialog->resize(362, 290);
        verticalLayout = new QVBoxLayout(QgsMasterPasswordResetDialog);
        verticalLayout->setObjectName("verticalLayout");
        label_6 = new QLabel(QgsMasterPasswordResetDialog);
        label_6->setObjectName("label_6");
        QFont font;
        font.setBold(true);
        font.setItalic(false);
        label_6->setFont(font);

        verticalLayout->addWidget(label_6);

        leMasterPassCurrent = new QgsPasswordLineEdit(QgsMasterPasswordResetDialog);
        leMasterPassCurrent->setObjectName("leMasterPassCurrent");
        leMasterPassCurrent->setEchoMode(QLineEdit::EchoMode::Password);

        verticalLayout->addWidget(leMasterPassCurrent);

        label_7 = new QLabel(QgsMasterPasswordResetDialog);
        label_7->setObjectName("label_7");
        label_7->setFont(font);

        verticalLayout->addWidget(label_7);

        leMasterPassNew = new QgsPasswordLineEdit(QgsMasterPasswordResetDialog);
        leMasterPassNew->setObjectName("leMasterPassNew");
        leMasterPassNew->setEchoMode(QLineEdit::EchoMode::Password);

        verticalLayout->addWidget(leMasterPassNew);

        label_8 = new QLabel(QgsMasterPasswordResetDialog);
        label_8->setObjectName("label_8");
        label_8->setFont(font);

        verticalLayout->addWidget(label_8);

        leMasterPassNew2 = new QgsPasswordLineEdit(QgsMasterPasswordResetDialog);
        leMasterPassNew2->setObjectName("leMasterPassNew2");
        leMasterPassNew2->setEchoMode(QLineEdit::EchoMode::Password);

        verticalLayout->addWidget(leMasterPassNew2);

        chkKeepBackup = new QCheckBox(QgsMasterPasswordResetDialog);
        chkKeepBackup->setObjectName("chkKeepBackup");

        verticalLayout->addWidget(chkKeepBackup);

        lblWarning = new QLabel(QgsMasterPasswordResetDialog);
        lblWarning->setObjectName("lblWarning");
        lblWarning->setWordWrap(true);

        verticalLayout->addWidget(lblWarning);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(QgsMasterPasswordResetDialog);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Help|QDialogButtonBox::StandardButton::Ok);

        verticalLayout->addWidget(buttonBox);

        QWidget::setTabOrder(leMasterPassCurrent, leMasterPassNew);
        QWidget::setTabOrder(leMasterPassNew, leMasterPassNew2);
        QWidget::setTabOrder(leMasterPassNew2, chkKeepBackup);

        retranslateUi(QgsMasterPasswordResetDialog);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, QgsMasterPasswordResetDialog, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, QgsMasterPasswordResetDialog, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(QgsMasterPasswordResetDialog);
    } // setupUi

    void retranslateUi(QDialog *QgsMasterPasswordResetDialog)
    {
        QgsMasterPasswordResetDialog->setWindowTitle(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Reset Master Password", nullptr));
        label_6->setText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Enter CURRENT master authentication password", nullptr));
        leMasterPassCurrent->setPlaceholderText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Required", nullptr));
        label_7->setText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Enter NEW master authentication password", nullptr));
        leMasterPassNew->setPlaceholderText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Required", nullptr));
        label_8->setText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Re-enter NEW password", nullptr));
        leMasterPassNew2->setPlaceholderText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Required", nullptr));
        chkKeepBackup->setText(QCoreApplication::translate("QgsMasterPasswordResetDialog", "Keep backup of current database", nullptr));
        lblWarning->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class QgsMasterPasswordResetDialog: public Ui_QgsMasterPasswordResetDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSAUTHMASTERPASSRESETDIALOG_H
