/********************************************************************************
** Form generated from reading UI file 'qgsmapcoordsdialogbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSMAPCOORDSDIALOGBASE_H
#define UI_QGSMAPCOORDSDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include "qgsprojectionselectionwidget.h"

QT_BEGIN_NAMESPACE

class Ui_QgsMapCoordsDialogBase
{
public:
    QGridLayout *gridLayout;
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QGridLayout *coordinatesLayout;
    QLabel *textLabel1;
    QLineEdit *leXCoord;
    QLabel *textLabel2;
    QLineEdit *leYCoord;
    QgsProjectionSelectionWidget *mProjectionSelector;
    QCheckBox *mMinimizeWindowCheckBox;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QgsMapCoordsDialogBase)
    {
        if (QgsMapCoordsDialogBase->objectName().isEmpty())
            QgsMapCoordsDialogBase->setObjectName("QgsMapCoordsDialogBase");
        QgsMapCoordsDialogBase->resize(584, 421);
        QgsMapCoordsDialogBase->setSizeGripEnabled(true);
        gridLayout = new QGridLayout(QgsMapCoordsDialogBase);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setSpacing(6);
        verticalLayout->setObjectName("verticalLayout");
        label = new QLabel(QgsMapCoordsDialogBase);
        label->setObjectName("label");
        label->setWordWrap(true);

        verticalLayout->addWidget(label);

        coordinatesLayout = new QGridLayout();
        coordinatesLayout->setSpacing(6);
        coordinatesLayout->setObjectName("coordinatesLayout");
        textLabel1 = new QLabel(QgsMapCoordsDialogBase);
        textLabel1->setObjectName("textLabel1");

        coordinatesLayout->addWidget(textLabel1, 0, 0, 1, 1);

        leXCoord = new QLineEdit(QgsMapCoordsDialogBase);
        leXCoord->setObjectName("leXCoord");

        coordinatesLayout->addWidget(leXCoord, 0, 1, 1, 1);

        textLabel2 = new QLabel(QgsMapCoordsDialogBase);
        textLabel2->setObjectName("textLabel2");

        coordinatesLayout->addWidget(textLabel2, 1, 0, 1, 1);

        leYCoord = new QLineEdit(QgsMapCoordsDialogBase);
        leYCoord->setObjectName("leYCoord");

        coordinatesLayout->addWidget(leYCoord, 1, 1, 1, 1);


        verticalLayout->addLayout(coordinatesLayout);

        mProjectionSelector = new QgsProjectionSelectionWidget(QgsMapCoordsDialogBase);
        mProjectionSelector->setObjectName("mProjectionSelector");
        mProjectionSelector->setFocusPolicy(Qt::StrongFocus);

        verticalLayout->addWidget(mProjectionSelector);

        mMinimizeWindowCheckBox = new QCheckBox(QgsMapCoordsDialogBase);
        mMinimizeWindowCheckBox->setObjectName("mMinimizeWindowCheckBox");

        verticalLayout->addWidget(mMinimizeWindowCheckBox);

        verticalSpacer = new QSpacerItem(12, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(QgsMapCoordsDialogBase);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        gridLayout->addLayout(verticalLayout, 0, 0, 1, 1);

        QWidget::setTabOrder(leXCoord, leYCoord);

        retranslateUi(QgsMapCoordsDialogBase);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, QgsMapCoordsDialogBase, qOverload<>(&QDialog::close));
        QObject::connect(leXCoord, &QLineEdit::returnPressed, leYCoord, qOverload<>(&QLineEdit::setFocus));

        QMetaObject::connectSlotsByName(QgsMapCoordsDialogBase);
    } // setupUi

    void retranslateUi(QDialog *QgsMapCoordsDialogBase)
    {
        QgsMapCoordsDialogBase->setWindowTitle(QCoreApplication::translate("QgsMapCoordsDialogBase", "Enter Map Coordinates", nullptr));
        label->setText(QCoreApplication::translate("QgsMapCoordsDialogBase", "<html><head/><body><p>Enter X and Y coordinates (DMS (<span style=\" font-style:italic;\">dd mm ss.ss</span>), DD (<span style=\" font-style:italic;\">dd.dd</span>) or projected coordinates (<span style=\" font-style:italic;\">mmmm.mm</span>)) which correspond with the selected point on the image. Alternatively, click the button with icon of a pencil and then click a corresponding point on map canvas of QGIS to fill in coordinates of that point.</p></body></html>", nullptr));
        textLabel1->setText(QCoreApplication::translate("QgsMapCoordsDialogBase", "X / East", nullptr));
        textLabel2->setText(QCoreApplication::translate("QgsMapCoordsDialogBase", "Y / North", nullptr));
        mMinimizeWindowCheckBox->setText(QCoreApplication::translate("QgsMapCoordsDialogBase", "Automatically hide georeferencer window ", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsMapCoordsDialogBase: public Ui_QgsMapCoordsDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSMAPCOORDSDIALOGBASE_H
