
#ifndef QUICK_EXPORT_H
#define QUICK_EXPORT_H

#ifdef QUICK_STATIC_DEFINE
#  define QUICK_EXPORT
#  define QUICK_NO_EXPORT
#else
#  ifndef QUICK_EXPORT
#    ifdef qgis_quick_EXPORTS
        /* We are building this library */
#      define QUICK_EXPORT __attribute__((visibility("default")))
#    else
        /* We are using this library */
#      define QUICK_EXPORT __attribute__((visibility("default")))
#    endif
#  endif

#  ifndef QUICK_NO_EXPORT
#    define QUICK_NO_EXPORT __attribute__((visibility("hidden")))
#  endif
#endif

#ifndef QUICK_DEPRECATED
#  define QUICK_DEPRECATED __attribute__ ((__deprecated__))
#endif

#ifndef QUICK_DEPRECATED_EXPORT
#  define QUICK_DEPRECATED_EXPORT QUICK_EXPORT QUICK_DEPRECATED
#endif

#ifndef QUICK_DEPRECATED_NO_EXPORT
#  define QUICK_DEPRECATED_NO_EXPORT QUICK_NO_EXPORT QUICK_DEPRECATED
#endif

/* NOLINTNEXTLINE(readability-avoid-unconditional-preprocessor-if) */
#if 0 /* DEFINE_NO_DEPRECATED */
#  ifndef QUICK_NO_DEPRECATED
#    define QUICK_NO_DEPRECATED
#  endif
#endif

#endif /* QUICK_EXPORT_H */
