/********************************************************************************
** Form generated from reading UI file 'metalroughmaterialwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_METALROUGHMATERIALWIDGET_H
#define UI_METALROUGHMATERIALWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include "qgscolorbutton.h"
#include "qgsdoublespinbox.h"
#include "qgspercentagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_MetalRoughMaterialWidget
{
public:
    QGridLayout *gridLayout;
    QLabel *lblSpecular;
    QgsColorButton *mButtonBaseColor;
    QLabel *lblShininess;
    QgsPercentageWidget *mMetalnessWidget;
    QLabel *lblShininess_2;
    QgsPercentageWidget *mRoughnessWidget;

    void setupUi(QWidget *MetalRoughMaterialWidget)
    {
        if (MetalRoughMaterialWidget->objectName().isEmpty())
            MetalRoughMaterialWidget->setObjectName("MetalRoughMaterialWidget");
        MetalRoughMaterialWidget->resize(378, 107);
        MetalRoughMaterialWidget->setWindowTitle(QString::fromUtf8("Form"));
        gridLayout = new QGridLayout(MetalRoughMaterialWidget);
        gridLayout->setObjectName("gridLayout");
        lblSpecular = new QLabel(MetalRoughMaterialWidget);
        lblSpecular->setObjectName("lblSpecular");

        gridLayout->addWidget(lblSpecular, 0, 0, 1, 1);

        mButtonBaseColor = new QgsColorButton(MetalRoughMaterialWidget);
        mButtonBaseColor->setObjectName("mButtonBaseColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mButtonBaseColor->sizePolicy().hasHeightForWidth());
        mButtonBaseColor->setSizePolicy(sizePolicy);
        mButtonBaseColor->setMinimumSize(QSize(120, 0));

        gridLayout->addWidget(mButtonBaseColor, 0, 1, 1, 1);

        lblShininess = new QLabel(MetalRoughMaterialWidget);
        lblShininess->setObjectName("lblShininess");

        gridLayout->addWidget(lblShininess, 1, 0, 1, 1);

        mMetalnessWidget = new QgsPercentageWidget(MetalRoughMaterialWidget);
        mMetalnessWidget->setObjectName("mMetalnessWidget");
        mMetalnessWidget->setFocusPolicy(Qt::FocusPolicy::StrongFocus);

        gridLayout->addWidget(mMetalnessWidget, 1, 1, 1, 1);

        lblShininess_2 = new QLabel(MetalRoughMaterialWidget);
        lblShininess_2->setObjectName("lblShininess_2");

        gridLayout->addWidget(lblShininess_2, 2, 0, 1, 1);

        mRoughnessWidget = new QgsPercentageWidget(MetalRoughMaterialWidget);
        mRoughnessWidget->setObjectName("mRoughnessWidget");
        mRoughnessWidget->setFocusPolicy(Qt::FocusPolicy::StrongFocus);

        gridLayout->addWidget(mRoughnessWidget, 2, 1, 1, 1);

        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(1, 2);

        retranslateUi(MetalRoughMaterialWidget);

        QMetaObject::connectSlotsByName(MetalRoughMaterialWidget);
    } // setupUi

    void retranslateUi(QWidget *MetalRoughMaterialWidget)
    {
        lblSpecular->setText(QCoreApplication::translate("MetalRoughMaterialWidget", "Base color", nullptr));
        lblShininess->setText(QCoreApplication::translate("MetalRoughMaterialWidget", "Metalness", nullptr));
        lblShininess_2->setText(QCoreApplication::translate("MetalRoughMaterialWidget", "Roughness", nullptr));
        (void)MetalRoughMaterialWidget;
    } // retranslateUi

};

namespace Ui {
    class MetalRoughMaterialWidget: public Ui_MetalRoughMaterialWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_METALROUGHMATERIALWIDGET_H
