/********************************************************************************
** Form generated from reading UI file 'qgsbarchartplotwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSBARCHARTPLOTWIDGETBASE_H
#define UI_QGSBARCHARTPLOTWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <qgscollapsiblegroupbox.h>
#include "qgsdoublespinbox.h"
#include "qgsfontbutton.h"
#include "qgspanelwidget.h"
#include "qgspropertyoverridebutton.h"
#include "qgsscrollarea.h"
#include "qgssymbolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_QgsBarChartPlotWidgetBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QgsScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *mainLayout;
    QgsCollapsibleGroupBoxBasic *groupChartRanges;
    QGridLayout *gridLayout_4;
    QLabel *mLabelMinYAxis;
    QgsDoubleSpinBox *mSpinMinYAxis;
    QgsDoubleSpinBox *mSpinMinXAxis;
    QgsDoubleSpinBox *mSpinMaxXAxis;
    QLabel *mLabelMinXAxis;
    QgsDoubleSpinBox *mSpinMaxYAxis;
    QLabel *mLabelMaxYAxis;
    QLabel *mLabelMaxXAxis;
    QgsPropertyOverrideButton *mDDBtnMinXAxis;
    QgsPropertyOverrideButton *mDDBtnMaxXAxis;
    QgsPropertyOverrideButton *mDDBtnMinYAxis;
    QgsPropertyOverrideButton *mDDBtnMaxYAxis;
    QgsCollapsibleGroupBoxBasic *groupSymbolsList;
    QVBoxLayout *verticalBoxLayout;
    QHBoxLayout *symbolsControlsLayout;
    QPushButton *mAddSymbolPushButton;
    QPushButton *mRemoveSymbolPushButton;
    QTableWidget *mSymbolsList;
    QgsCollapsibleGroupBoxBasic *groupXAxis;
    QGridLayout *gridLayout_2;
    QLabel *label_10;
    QLabel *label_28;
    QgsPropertyOverrideButton *mDDBtnXAxisMinorInterval;
    QLabel *mXAxisMinorIntervalLabel;
    QgsFontButton *mXAxisLabelFontButton;
    QgsDoubleSpinBox *mXAxisMinorIntervalSpin;
    QLabel *label_18;
    QPushButton *mXAxisLabelFormatButton;
    QgsPropertyOverrideButton *mDDBtnXAxisMajorInterval;
    QLabel *label_8;
    QLabel *label_9;
    QLabel *mXAxisMajorLinesLabel;
    QgsSymbolButton *mXAxisMinorLinesSymbolButton;
    QgsPropertyOverrideButton *mDDBtnXAxisLabelInterval;
    QLabel *mXAxisMinorLinesLabel;
    QComboBox *mXAxisLabelsCombo;
    QgsDoubleSpinBox *mXAxisLabelIntervalSpin;
    QComboBox *mXAxisTypeCombo;
    QgsDoubleSpinBox *mXAxisMajorIntervalSpin;
    QLabel *mXAxisMajorIntervalLabel;
    QgsSymbolButton *mXAxisMajorLinesSymbolButton;
    QLabel *mXAxisLabelSuffixLabel;
    QLineEdit *mXAxisLabelSuffixEdit;
    QgsCollapsibleGroupBoxBasic *groupYAxis;
    QGridLayout *gridLayout_3;
    QgsDoubleSpinBox *mYAxisMajorIntervalSpin;
    QgsPropertyOverrideButton *mDDBtnYAxisLabelInterval;
    QgsDoubleSpinBox *mYAxisLabelIntervalSpin;
    QgsSymbolButton *mYAxisMajorLinesSymbolButton;
    QLabel *label_13;
    QLabel *label_12;
    QLabel *label_17;
    QgsPropertyOverrideButton *mDDBtnYAxisMajorInterval;
    QLabel *label_16;
    QgsDoubleSpinBox *mYAxisMinorIntervalSpin;
    QgsPropertyOverrideButton *mDDBtnYAxisMinorInterval;
    QLabel *label_11;
    QPushButton *mYAxisLabelFormatButton;
    QgsSymbolButton *mYAxisMinorLinesSymbolButton;
    QLabel *label_15;
    QLabel *label_14;
    QgsFontButton *mYAxisLabelFontButton;
    QgsCollapsibleGroupBoxBasic *groupChartArea;
    QGridLayout *gridLayout;
    QgsDoubleSpinBox *mSpinLeftMargin;
    QLabel *label_3;
    QLabel *label_24;
    QgsDoubleSpinBox *mSpinRightMargin;
    QgsDoubleSpinBox *mSpinBottomMargin;
    QLabel *label_25;
    QgsSymbolButton *mChartBorderSymbolButton;
    QgsPropertyOverrideButton *mDDBtnLeftMargin;
    QgsPropertyOverrideButton *mDDBtnTopMargin;
    QLabel *label_23;
    QLabel *label_22;
    QgsDoubleSpinBox *mSpinTopMargin;
    QgsSymbolButton *mChartBackgroundSymbolButton;
    QLabel *label_2;
    QgsPropertyOverrideButton *mDDBtnRightMargin;
    QgsPropertyOverrideButton *mDDBtnBottomMargin;

    void setupUi(QgsPanelWidget *QgsBarChartPlotWidgetBase)
    {
        if (QgsBarChartPlotWidgetBase->objectName().isEmpty())
            QgsBarChartPlotWidgetBase->setObjectName("QgsBarChartPlotWidgetBase");
        QgsBarChartPlotWidgetBase->resize(564, 749);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(QgsBarChartPlotWidgetBase->sizePolicy().hasHeightForWidth());
        QgsBarChartPlotWidgetBase->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(QgsBarChartPlotWidgetBase);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QgsScrollArea(QgsBarChartPlotWidgetBase);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::StyledPanel);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, -468, 548, 1215));
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scrollAreaWidgetContents->sizePolicy().hasHeightForWidth());
        scrollAreaWidgetContents->setSizePolicy(sizePolicy1);
        mainLayout = new QVBoxLayout(scrollAreaWidgetContents);
        mainLayout->setSpacing(6);
        mainLayout->setContentsMargins(11, 11, 11, 11);
        mainLayout->setObjectName("mainLayout");
        groupChartRanges = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupChartRanges->setObjectName("groupChartRanges");
        gridLayout_4 = new QGridLayout(groupChartRanges);
        gridLayout_4->setSpacing(6);
        gridLayout_4->setContentsMargins(11, 11, 11, 11);
        gridLayout_4->setObjectName("gridLayout_4");
        mLabelMinYAxis = new QLabel(groupChartRanges);
        mLabelMinYAxis->setObjectName("mLabelMinYAxis");

        gridLayout_4->addWidget(mLabelMinYAxis, 2, 0, 1, 1);

        mSpinMinYAxis = new QgsDoubleSpinBox(groupChartRanges);
        mSpinMinYAxis->setObjectName("mSpinMinYAxis");
        mSpinMinYAxis->setDecimals(6);
        mSpinMinYAxis->setMinimum(-999999999.000000000000000);
        mSpinMinYAxis->setMaximum(999999999.000000000000000);

        gridLayout_4->addWidget(mSpinMinYAxis, 2, 1, 1, 1);

        mSpinMinXAxis = new QgsDoubleSpinBox(groupChartRanges);
        mSpinMinXAxis->setObjectName("mSpinMinXAxis");
        mSpinMinXAxis->setDecimals(6);
        mSpinMinXAxis->setMinimum(-999999999.000000000000000);
        mSpinMinXAxis->setMaximum(999999999.000000000000000);

        gridLayout_4->addWidget(mSpinMinXAxis, 0, 1, 1, 1);

        mSpinMaxXAxis = new QgsDoubleSpinBox(groupChartRanges);
        mSpinMaxXAxis->setObjectName("mSpinMaxXAxis");
        mSpinMaxXAxis->setDecimals(6);
        mSpinMaxXAxis->setMinimum(-999999999.000000000000000);
        mSpinMaxXAxis->setMaximum(999999999.000000000000000);

        gridLayout_4->addWidget(mSpinMaxXAxis, 1, 1, 1, 1);

        mLabelMinXAxis = new QLabel(groupChartRanges);
        mLabelMinXAxis->setObjectName("mLabelMinXAxis");

        gridLayout_4->addWidget(mLabelMinXAxis, 0, 0, 1, 1);

        mSpinMaxYAxis = new QgsDoubleSpinBox(groupChartRanges);
        mSpinMaxYAxis->setObjectName("mSpinMaxYAxis");
        mSpinMaxYAxis->setDecimals(6);
        mSpinMaxYAxis->setMinimum(-999999999.000000000000000);
        mSpinMaxYAxis->setMaximum(999999999.000000000000000);

        gridLayout_4->addWidget(mSpinMaxYAxis, 3, 1, 1, 1);

        mLabelMaxYAxis = new QLabel(groupChartRanges);
        mLabelMaxYAxis->setObjectName("mLabelMaxYAxis");

        gridLayout_4->addWidget(mLabelMaxYAxis, 3, 0, 1, 1);

        mLabelMaxXAxis = new QLabel(groupChartRanges);
        mLabelMaxXAxis->setObjectName("mLabelMaxXAxis");

        gridLayout_4->addWidget(mLabelMaxXAxis, 1, 0, 1, 1);

        mDDBtnMinXAxis = new QgsPropertyOverrideButton(groupChartRanges);
        mDDBtnMinXAxis->setObjectName("mDDBtnMinXAxis");

        gridLayout_4->addWidget(mDDBtnMinXAxis, 0, 2, 1, 1);

        mDDBtnMaxXAxis = new QgsPropertyOverrideButton(groupChartRanges);
        mDDBtnMaxXAxis->setObjectName("mDDBtnMaxXAxis");

        gridLayout_4->addWidget(mDDBtnMaxXAxis, 1, 2, 1, 1);

        mDDBtnMinYAxis = new QgsPropertyOverrideButton(groupChartRanges);
        mDDBtnMinYAxis->setObjectName("mDDBtnMinYAxis");

        gridLayout_4->addWidget(mDDBtnMinYAxis, 2, 2, 1, 1);

        mDDBtnMaxYAxis = new QgsPropertyOverrideButton(groupChartRanges);
        mDDBtnMaxYAxis->setObjectName("mDDBtnMaxYAxis");

        gridLayout_4->addWidget(mDDBtnMaxYAxis, 3, 2, 1, 1);

        gridLayout_4->setColumnStretch(0, 1);
        gridLayout_4->setColumnStretch(1, 2);

        mainLayout->addWidget(groupChartRanges);

        groupSymbolsList = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupSymbolsList->setObjectName("groupSymbolsList");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupSymbolsList->sizePolicy().hasHeightForWidth());
        groupSymbolsList->setSizePolicy(sizePolicy2);
        groupSymbolsList->setMaximumSize(QSize(16777215, 320));
        verticalBoxLayout = new QVBoxLayout(groupSymbolsList);
        verticalBoxLayout->setSpacing(6);
        verticalBoxLayout->setContentsMargins(11, 11, 11, 11);
        verticalBoxLayout->setObjectName("verticalBoxLayout");
        symbolsControlsLayout = new QHBoxLayout();
        symbolsControlsLayout->setSpacing(6);
        symbolsControlsLayout->setObjectName("symbolsControlsLayout");
        mAddSymbolPushButton = new QPushButton(groupSymbolsList);
        mAddSymbolPushButton->setObjectName("mAddSymbolPushButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/themes/default/symbologyAdd.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mAddSymbolPushButton->setIcon(icon);

        symbolsControlsLayout->addWidget(mAddSymbolPushButton);

        mRemoveSymbolPushButton = new QPushButton(groupSymbolsList);
        mRemoveSymbolPushButton->setObjectName("mRemoveSymbolPushButton");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/themes/default/symbologyRemove.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mRemoveSymbolPushButton->setIcon(icon1);

        symbolsControlsLayout->addWidget(mRemoveSymbolPushButton);


        verticalBoxLayout->addLayout(symbolsControlsLayout);

        mSymbolsList = new QTableWidget(groupSymbolsList);
        mSymbolsList->setObjectName("mSymbolsList");
        sizePolicy2.setHeightForWidth(mSymbolsList->sizePolicy().hasHeightForWidth());
        mSymbolsList->setSizePolicy(sizePolicy2);
        mSymbolsList->setMaximumSize(QSize(16777215, 320));

        verticalBoxLayout->addWidget(mSymbolsList);


        mainLayout->addWidget(groupSymbolsList);

        groupXAxis = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupXAxis->setObjectName("groupXAxis");
        gridLayout_2 = new QGridLayout(groupXAxis);
        gridLayout_2->setSpacing(6);
        gridLayout_2->setContentsMargins(11, 11, 11, 11);
        gridLayout_2->setObjectName("gridLayout_2");
        label_10 = new QLabel(groupXAxis);
        label_10->setObjectName("label_10");

        gridLayout_2->addWidget(label_10, 7, 0, 1, 1);

        label_28 = new QLabel(groupXAxis);
        label_28->setObjectName("label_28");

        gridLayout_2->addWidget(label_28, 9, 0, 1, 1);

        mDDBtnXAxisMinorInterval = new QgsPropertyOverrideButton(groupXAxis);
        mDDBtnXAxisMinorInterval->setObjectName("mDDBtnXAxisMinorInterval");

        gridLayout_2->addWidget(mDDBtnXAxisMinorInterval, 4, 3, 1, 1);

        mXAxisMinorIntervalLabel = new QLabel(groupXAxis);
        mXAxisMinorIntervalLabel->setObjectName("mXAxisMinorIntervalLabel");

        gridLayout_2->addWidget(mXAxisMinorIntervalLabel, 4, 0, 1, 2);

        mXAxisLabelFontButton = new QgsFontButton(groupXAxis);
        mXAxisLabelFontButton->setObjectName("mXAxisLabelFontButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(mXAxisLabelFontButton->sizePolicy().hasHeightForWidth());
        mXAxisLabelFontButton->setSizePolicy(sizePolicy3);

        gridLayout_2->addWidget(mXAxisLabelFontButton, 8, 2, 1, 2);

        mXAxisMinorIntervalSpin = new QgsDoubleSpinBox(groupXAxis);
        mXAxisMinorIntervalSpin->setObjectName("mXAxisMinorIntervalSpin");
        mXAxisMinorIntervalSpin->setDecimals(6);
        mXAxisMinorIntervalSpin->setMinimum(0.000001000000000);
        mXAxisMinorIntervalSpin->setMaximum(999999999999.000000000000000);

        gridLayout_2->addWidget(mXAxisMinorIntervalSpin, 4, 2, 1, 1);

        label_18 = new QLabel(groupXAxis);
        label_18->setObjectName("label_18");

        gridLayout_2->addWidget(label_18, 0, 0, 1, 1);

        mXAxisLabelFormatButton = new QPushButton(groupXAxis);
        mXAxisLabelFormatButton->setObjectName("mXAxisLabelFormatButton");

        gridLayout_2->addWidget(mXAxisLabelFormatButton, 7, 2, 1, 2);

        mDDBtnXAxisMajorInterval = new QgsPropertyOverrideButton(groupXAxis);
        mDDBtnXAxisMajorInterval->setObjectName("mDDBtnXAxisMajorInterval");

        gridLayout_2->addWidget(mDDBtnXAxisMajorInterval, 2, 3, 1, 1);

        label_8 = new QLabel(groupXAxis);
        label_8->setObjectName("label_8");

        gridLayout_2->addWidget(label_8, 6, 0, 1, 2);

        label_9 = new QLabel(groupXAxis);
        label_9->setObjectName("label_9");

        gridLayout_2->addWidget(label_9, 8, 0, 1, 1);

        mXAxisMajorLinesLabel = new QLabel(groupXAxis);
        mXAxisMajorLinesLabel->setObjectName("mXAxisMajorLinesLabel");

        gridLayout_2->addWidget(mXAxisMajorLinesLabel, 3, 0, 1, 1);

        mXAxisMinorLinesSymbolButton = new QgsSymbolButton(groupXAxis);
        mXAxisMinorLinesSymbolButton->setObjectName("mXAxisMinorLinesSymbolButton");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(mXAxisMinorLinesSymbolButton->sizePolicy().hasHeightForWidth());
        mXAxisMinorLinesSymbolButton->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(mXAxisMinorLinesSymbolButton, 5, 2, 1, 2);

        mDDBtnXAxisLabelInterval = new QgsPropertyOverrideButton(groupXAxis);
        mDDBtnXAxisLabelInterval->setObjectName("mDDBtnXAxisLabelInterval");

        gridLayout_2->addWidget(mDDBtnXAxisLabelInterval, 6, 3, 1, 1);

        mXAxisMinorLinesLabel = new QLabel(groupXAxis);
        mXAxisMinorLinesLabel->setObjectName("mXAxisMinorLinesLabel");

        gridLayout_2->addWidget(mXAxisMinorLinesLabel, 5, 0, 1, 1);

        mXAxisLabelsCombo = new QComboBox(groupXAxis);
        mXAxisLabelsCombo->setObjectName("mXAxisLabelsCombo");

        gridLayout_2->addWidget(mXAxisLabelsCombo, 9, 2, 1, 2);

        mXAxisLabelIntervalSpin = new QgsDoubleSpinBox(groupXAxis);
        mXAxisLabelIntervalSpin->setObjectName("mXAxisLabelIntervalSpin");
        mXAxisLabelIntervalSpin->setDecimals(6);
        mXAxisLabelIntervalSpin->setMinimum(0.000000000000000);
        mXAxisLabelIntervalSpin->setMaximum(999999999999.000000000000000);

        gridLayout_2->addWidget(mXAxisLabelIntervalSpin, 6, 2, 1, 1);

        mXAxisTypeCombo = new QComboBox(groupXAxis);
        mXAxisTypeCombo->setObjectName("mXAxisTypeCombo");

        gridLayout_2->addWidget(mXAxisTypeCombo, 0, 2, 1, 2);

        mXAxisMajorIntervalSpin = new QgsDoubleSpinBox(groupXAxis);
        mXAxisMajorIntervalSpin->setObjectName("mXAxisMajorIntervalSpin");
        mXAxisMajorIntervalSpin->setDecimals(6);
        mXAxisMajorIntervalSpin->setMinimum(0.000001000000000);
        mXAxisMajorIntervalSpin->setMaximum(999999999999.000000000000000);

        gridLayout_2->addWidget(mXAxisMajorIntervalSpin, 2, 2, 1, 1);

        mXAxisMajorIntervalLabel = new QLabel(groupXAxis);
        mXAxisMajorIntervalLabel->setObjectName("mXAxisMajorIntervalLabel");

        gridLayout_2->addWidget(mXAxisMajorIntervalLabel, 2, 0, 1, 1);

        mXAxisMajorLinesSymbolButton = new QgsSymbolButton(groupXAxis);
        mXAxisMajorLinesSymbolButton->setObjectName("mXAxisMajorLinesSymbolButton");
        sizePolicy4.setHeightForWidth(mXAxisMajorLinesSymbolButton->sizePolicy().hasHeightForWidth());
        mXAxisMajorLinesSymbolButton->setSizePolicy(sizePolicy4);

        gridLayout_2->addWidget(mXAxisMajorLinesSymbolButton, 3, 2, 1, 2);

        mXAxisLabelSuffixLabel = new QLabel(groupXAxis);
        mXAxisLabelSuffixLabel->setObjectName("mXAxisLabelSuffixLabel");

        gridLayout_2->addWidget(mXAxisLabelSuffixLabel, 1, 0, 1, 1);

        mXAxisLabelSuffixEdit = new QLineEdit(groupXAxis);
        mXAxisLabelSuffixEdit->setObjectName("mXAxisLabelSuffixEdit");

        gridLayout_2->addWidget(mXAxisLabelSuffixEdit, 1, 2, 1, 2);

        gridLayout_2->setColumnStretch(0, 1);
        gridLayout_2->setColumnStretch(2, 2);

        mainLayout->addWidget(groupXAxis);

        groupYAxis = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupYAxis->setObjectName("groupYAxis");
        gridLayout_3 = new QGridLayout(groupYAxis);
        gridLayout_3->setSpacing(6);
        gridLayout_3->setContentsMargins(11, 11, 11, 11);
        gridLayout_3->setObjectName("gridLayout_3");
        mYAxisMajorIntervalSpin = new QgsDoubleSpinBox(groupYAxis);
        mYAxisMajorIntervalSpin->setObjectName("mYAxisMajorIntervalSpin");
        mYAxisMajorIntervalSpin->setDecimals(6);
        mYAxisMajorIntervalSpin->setMinimum(0.000001000000000);
        mYAxisMajorIntervalSpin->setMaximum(999999999999.000000000000000);

        gridLayout_3->addWidget(mYAxisMajorIntervalSpin, 0, 2, 1, 1);

        mDDBtnYAxisLabelInterval = new QgsPropertyOverrideButton(groupYAxis);
        mDDBtnYAxisLabelInterval->setObjectName("mDDBtnYAxisLabelInterval");

        gridLayout_3->addWidget(mDDBtnYAxisLabelInterval, 4, 3, 1, 1);

        mYAxisLabelIntervalSpin = new QgsDoubleSpinBox(groupYAxis);
        mYAxisLabelIntervalSpin->setObjectName("mYAxisLabelIntervalSpin");
        mYAxisLabelIntervalSpin->setDecimals(6);
        mYAxisLabelIntervalSpin->setMinimum(0.000000000000000);
        mYAxisLabelIntervalSpin->setMaximum(999999999999.000000000000000);

        gridLayout_3->addWidget(mYAxisLabelIntervalSpin, 4, 2, 1, 1);

        mYAxisMajorLinesSymbolButton = new QgsSymbolButton(groupYAxis);
        mYAxisMajorLinesSymbolButton->setObjectName("mYAxisMajorLinesSymbolButton");
        sizePolicy4.setHeightForWidth(mYAxisMajorLinesSymbolButton->sizePolicy().hasHeightForWidth());
        mYAxisMajorLinesSymbolButton->setSizePolicy(sizePolicy4);

        gridLayout_3->addWidget(mYAxisMajorLinesSymbolButton, 1, 2, 1, 2);

        label_13 = new QLabel(groupYAxis);
        label_13->setObjectName("label_13");

        gridLayout_3->addWidget(label_13, 0, 0, 1, 1);

        label_12 = new QLabel(groupYAxis);
        label_12->setObjectName("label_12");

        gridLayout_3->addWidget(label_12, 2, 0, 1, 2);

        label_17 = new QLabel(groupYAxis);
        label_17->setObjectName("label_17");

        gridLayout_3->addWidget(label_17, 5, 0, 1, 1);

        mDDBtnYAxisMajorInterval = new QgsPropertyOverrideButton(groupYAxis);
        mDDBtnYAxisMajorInterval->setObjectName("mDDBtnYAxisMajorInterval");

        gridLayout_3->addWidget(mDDBtnYAxisMajorInterval, 0, 3, 1, 1);

        label_16 = new QLabel(groupYAxis);
        label_16->setObjectName("label_16");

        gridLayout_3->addWidget(label_16, 4, 0, 1, 2);

        mYAxisMinorIntervalSpin = new QgsDoubleSpinBox(groupYAxis);
        mYAxisMinorIntervalSpin->setObjectName("mYAxisMinorIntervalSpin");
        mYAxisMinorIntervalSpin->setDecimals(6);
        mYAxisMinorIntervalSpin->setMinimum(0.000001000000000);
        mYAxisMinorIntervalSpin->setMaximum(999999999999.000000000000000);

        gridLayout_3->addWidget(mYAxisMinorIntervalSpin, 2, 2, 1, 1);

        mDDBtnYAxisMinorInterval = new QgsPropertyOverrideButton(groupYAxis);
        mDDBtnYAxisMinorInterval->setObjectName("mDDBtnYAxisMinorInterval");

        gridLayout_3->addWidget(mDDBtnYAxisMinorInterval, 2, 3, 1, 1);

        label_11 = new QLabel(groupYAxis);
        label_11->setObjectName("label_11");

        gridLayout_3->addWidget(label_11, 1, 0, 1, 1);

        mYAxisLabelFormatButton = new QPushButton(groupYAxis);
        mYAxisLabelFormatButton->setObjectName("mYAxisLabelFormatButton");

        gridLayout_3->addWidget(mYAxisLabelFormatButton, 5, 2, 1, 2);

        mYAxisMinorLinesSymbolButton = new QgsSymbolButton(groupYAxis);
        mYAxisMinorLinesSymbolButton->setObjectName("mYAxisMinorLinesSymbolButton");
        sizePolicy4.setHeightForWidth(mYAxisMinorLinesSymbolButton->sizePolicy().hasHeightForWidth());
        mYAxisMinorLinesSymbolButton->setSizePolicy(sizePolicy4);

        gridLayout_3->addWidget(mYAxisMinorLinesSymbolButton, 3, 2, 1, 2);

        label_15 = new QLabel(groupYAxis);
        label_15->setObjectName("label_15");

        gridLayout_3->addWidget(label_15, 3, 0, 1, 1);

        label_14 = new QLabel(groupYAxis);
        label_14->setObjectName("label_14");

        gridLayout_3->addWidget(label_14, 6, 0, 1, 1);

        mYAxisLabelFontButton = new QgsFontButton(groupYAxis);
        mYAxisLabelFontButton->setObjectName("mYAxisLabelFontButton");
        sizePolicy3.setHeightForWidth(mYAxisLabelFontButton->sizePolicy().hasHeightForWidth());
        mYAxisLabelFontButton->setSizePolicy(sizePolicy3);

        gridLayout_3->addWidget(mYAxisLabelFontButton, 6, 2, 1, 2);

        gridLayout_3->setColumnStretch(0, 1);
        gridLayout_3->setColumnStretch(2, 2);

        mainLayout->addWidget(groupYAxis);

        groupChartArea = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupChartArea->setObjectName("groupChartArea");
        gridLayout = new QGridLayout(groupChartArea);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        mSpinLeftMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinLeftMargin->setObjectName("mSpinLeftMargin");
        mSpinLeftMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinLeftMargin, 2, 1, 1, 1);

        label_3 = new QLabel(groupChartArea);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_24 = new QLabel(groupChartArea);
        label_24->setObjectName("label_24");

        gridLayout->addWidget(label_24, 4, 0, 1, 1);

        mSpinRightMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinRightMargin->setObjectName("mSpinRightMargin");
        mSpinRightMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinRightMargin, 4, 1, 1, 1);

        mSpinBottomMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinBottomMargin->setObjectName("mSpinBottomMargin");
        mSpinBottomMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinBottomMargin, 5, 1, 1, 1);

        label_25 = new QLabel(groupChartArea);
        label_25->setObjectName("label_25");

        gridLayout->addWidget(label_25, 5, 0, 1, 1);

        mChartBorderSymbolButton = new QgsSymbolButton(groupChartArea);
        mChartBorderSymbolButton->setObjectName("mChartBorderSymbolButton");
        sizePolicy4.setHeightForWidth(mChartBorderSymbolButton->sizePolicy().hasHeightForWidth());
        mChartBorderSymbolButton->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(mChartBorderSymbolButton, 1, 1, 1, 2);

        mDDBtnLeftMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnLeftMargin->setObjectName("mDDBtnLeftMargin");

        gridLayout->addWidget(mDDBtnLeftMargin, 2, 2, 1, 1);

        mDDBtnTopMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnTopMargin->setObjectName("mDDBtnTopMargin");

        gridLayout->addWidget(mDDBtnTopMargin, 3, 2, 1, 1);

        label_23 = new QLabel(groupChartArea);
        label_23->setObjectName("label_23");

        gridLayout->addWidget(label_23, 3, 0, 1, 1);

        label_22 = new QLabel(groupChartArea);
        label_22->setObjectName("label_22");

        gridLayout->addWidget(label_22, 2, 0, 1, 1);

        mSpinTopMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinTopMargin->setObjectName("mSpinTopMargin");
        mSpinTopMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinTopMargin, 3, 1, 1, 1);

        mChartBackgroundSymbolButton = new QgsSymbolButton(groupChartArea);
        mChartBackgroundSymbolButton->setObjectName("mChartBackgroundSymbolButton");
        sizePolicy4.setHeightForWidth(mChartBackgroundSymbolButton->sizePolicy().hasHeightForWidth());
        mChartBackgroundSymbolButton->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(mChartBackgroundSymbolButton, 0, 1, 1, 2);

        label_2 = new QLabel(groupChartArea);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        mDDBtnRightMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnRightMargin->setObjectName("mDDBtnRightMargin");

        gridLayout->addWidget(mDDBtnRightMargin, 4, 2, 1, 1);

        mDDBtnBottomMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnBottomMargin->setObjectName("mDDBtnBottomMargin");

        gridLayout->addWidget(mDDBtnBottomMargin, 5, 2, 1, 1);

        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(1, 2);

        mainLayout->addWidget(groupChartArea);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(scrollArea);

        QWidget::setTabOrder(scrollArea, mSpinMinXAxis);
        QWidget::setTabOrder(mSpinMinXAxis, mDDBtnMinXAxis);
        QWidget::setTabOrder(mDDBtnMinXAxis, mSpinMaxXAxis);
        QWidget::setTabOrder(mSpinMaxXAxis, mDDBtnMaxXAxis);
        QWidget::setTabOrder(mDDBtnMaxXAxis, mSpinMinYAxis);
        QWidget::setTabOrder(mSpinMinYAxis, mDDBtnMinYAxis);
        QWidget::setTabOrder(mDDBtnMinYAxis, mSpinMaxYAxis);
        QWidget::setTabOrder(mSpinMaxYAxis, mDDBtnMaxYAxis);
        QWidget::setTabOrder(mDDBtnMaxYAxis, mAddSymbolPushButton);
        QWidget::setTabOrder(mAddSymbolPushButton, mRemoveSymbolPushButton);
        QWidget::setTabOrder(mRemoveSymbolPushButton, mSymbolsList);
        QWidget::setTabOrder(mSymbolsList, mXAxisTypeCombo);
        QWidget::setTabOrder(mXAxisTypeCombo, mXAxisLabelSuffixEdit);
        QWidget::setTabOrder(mXAxisLabelSuffixEdit, mXAxisMajorIntervalSpin);
        QWidget::setTabOrder(mXAxisMajorIntervalSpin, mDDBtnXAxisMajorInterval);
        QWidget::setTabOrder(mDDBtnXAxisMajorInterval, mXAxisMajorLinesSymbolButton);
        QWidget::setTabOrder(mXAxisMajorLinesSymbolButton, mXAxisMinorIntervalSpin);
        QWidget::setTabOrder(mXAxisMinorIntervalSpin, mDDBtnXAxisMinorInterval);
        QWidget::setTabOrder(mDDBtnXAxisMinorInterval, mXAxisMinorLinesSymbolButton);
        QWidget::setTabOrder(mXAxisMinorLinesSymbolButton, mXAxisLabelIntervalSpin);
        QWidget::setTabOrder(mXAxisLabelIntervalSpin, mDDBtnXAxisLabelInterval);
        QWidget::setTabOrder(mDDBtnXAxisLabelInterval, mXAxisLabelFormatButton);
        QWidget::setTabOrder(mXAxisLabelFormatButton, mXAxisLabelFontButton);
        QWidget::setTabOrder(mXAxisLabelFontButton, mXAxisLabelsCombo);
        QWidget::setTabOrder(mXAxisLabelsCombo, mYAxisMajorIntervalSpin);
        QWidget::setTabOrder(mYAxisMajorIntervalSpin, mDDBtnYAxisMajorInterval);
        QWidget::setTabOrder(mDDBtnYAxisMajorInterval, mYAxisMajorLinesSymbolButton);
        QWidget::setTabOrder(mYAxisMajorLinesSymbolButton, mYAxisMinorIntervalSpin);
        QWidget::setTabOrder(mYAxisMinorIntervalSpin, mDDBtnYAxisMinorInterval);
        QWidget::setTabOrder(mDDBtnYAxisMinorInterval, mYAxisMinorLinesSymbolButton);
        QWidget::setTabOrder(mYAxisMinorLinesSymbolButton, mYAxisLabelIntervalSpin);
        QWidget::setTabOrder(mYAxisLabelIntervalSpin, mDDBtnYAxisLabelInterval);
        QWidget::setTabOrder(mDDBtnYAxisLabelInterval, mYAxisLabelFormatButton);
        QWidget::setTabOrder(mYAxisLabelFormatButton, mYAxisLabelFontButton);
        QWidget::setTabOrder(mYAxisLabelFontButton, mChartBackgroundSymbolButton);
        QWidget::setTabOrder(mChartBackgroundSymbolButton, mChartBorderSymbolButton);
        QWidget::setTabOrder(mChartBorderSymbolButton, mSpinLeftMargin);
        QWidget::setTabOrder(mSpinLeftMargin, mDDBtnLeftMargin);
        QWidget::setTabOrder(mDDBtnLeftMargin, mSpinTopMargin);
        QWidget::setTabOrder(mSpinTopMargin, mDDBtnTopMargin);
        QWidget::setTabOrder(mDDBtnTopMargin, mSpinRightMargin);
        QWidget::setTabOrder(mSpinRightMargin, mDDBtnRightMargin);
        QWidget::setTabOrder(mDDBtnRightMargin, mSpinBottomMargin);
        QWidget::setTabOrder(mSpinBottomMargin, mDDBtnBottomMargin);

        retranslateUi(QgsBarChartPlotWidgetBase);

        QMetaObject::connectSlotsByName(QgsBarChartPlotWidgetBase);
    } // setupUi

    void retranslateUi(QgsPanelWidget *QgsBarChartPlotWidgetBase)
    {
        QgsBarChartPlotWidgetBase->setWindowTitle(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Bar Chart Plot Options", nullptr));
        groupChartRanges->setTitle(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Chart Ranges", nullptr));
        mLabelMinYAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Minimum Y axis", nullptr));
        mLabelMinXAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Minimum X axis", nullptr));
        mLabelMaxYAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Maximum Y axis", nullptr));
        mLabelMaxXAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Maximum X axis", nullptr));
        mDDBtnMinXAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnMaxXAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnMinYAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnMaxYAxis->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        groupSymbolsList->setTitle(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Symbols list", nullptr));
#if QT_CONFIG(tooltip)
        mAddSymbolPushButton->setToolTip(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Add a series", nullptr));
#endif // QT_CONFIG(tooltip)
        mAddSymbolPushButton->setText(QString());
#if QT_CONFIG(tooltip)
        mRemoveSymbolPushButton->setToolTip(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Remove selected series", nullptr));
#endif // QT_CONFIG(tooltip)
        mRemoveSymbolPushButton->setText(QString());
        groupXAxis->setTitle(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "X Axis", nullptr));
        label_10->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label format", nullptr));
        label_28->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label placement", nullptr));
        mDDBtnXAxisMinorInterval->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mXAxisMinorIntervalLabel->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Minor interval", nullptr));
        mXAxisLabelFontButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Font", nullptr));
        label_18->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Axis type", nullptr));
        mXAxisLabelFormatButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Customize", nullptr));
        mDDBtnXAxisMajorInterval->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        label_8->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label interval", nullptr));
        label_9->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label font", nullptr));
        mXAxisMajorLinesLabel->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Major grid lines", nullptr));
        mXAxisMinorLinesSymbolButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Change\342\200\246", nullptr));
        mDDBtnXAxisLabelInterval->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mXAxisMinorLinesLabel->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Minor grid lines", nullptr));
        mXAxisMajorIntervalLabel->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Major interval", nullptr));
        mXAxisMajorLinesSymbolButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Change\342\200\246", nullptr));
        mXAxisLabelSuffixLabel->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Axis label suffix", nullptr));
        groupYAxis->setTitle(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Y Axis", nullptr));
        mDDBtnYAxisLabelInterval->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mYAxisMajorLinesSymbolButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Change\342\200\246", nullptr));
        label_13->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Major interval", nullptr));
        label_12->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Minor interval", nullptr));
        label_17->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label format", nullptr));
        mDDBtnYAxisMajorInterval->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        label_16->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label interval", nullptr));
        mDDBtnYAxisMinorInterval->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        label_11->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Major grid lines", nullptr));
        mYAxisLabelFormatButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Customize", nullptr));
        mYAxisMinorLinesSymbolButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Change\342\200\246", nullptr));
        label_15->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Minor grid lines", nullptr));
        label_14->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Label font", nullptr));
        mYAxisLabelFontButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Font", nullptr));
        groupChartArea->setTitle(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Chart Area", nullptr));
        mSpinLeftMargin->setSuffix(QCoreApplication::translate("QgsBarChartPlotWidgetBase", " mm", nullptr));
        label_3->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Border", nullptr));
        label_24->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Right margin", nullptr));
        mSpinRightMargin->setSuffix(QCoreApplication::translate("QgsBarChartPlotWidgetBase", " mm", nullptr));
        mSpinBottomMargin->setSuffix(QCoreApplication::translate("QgsBarChartPlotWidgetBase", " mm", nullptr));
        label_25->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Bottom margin", nullptr));
        mChartBorderSymbolButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Change\342\200\246", nullptr));
        mDDBtnLeftMargin->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnTopMargin->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        label_23->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Top margin", nullptr));
        label_22->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Left margin", nullptr));
        mSpinTopMargin->setSuffix(QCoreApplication::translate("QgsBarChartPlotWidgetBase", " mm", nullptr));
        mChartBackgroundSymbolButton->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Change\342\200\246", nullptr));
        label_2->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "Background", nullptr));
        mDDBtnRightMargin->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnBottomMargin->setText(QCoreApplication::translate("QgsBarChartPlotWidgetBase", "\342\200\246", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsBarChartPlotWidgetBase: public Ui_QgsBarChartPlotWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSBARCHARTPLOTWIDGETBASE_H
