/********************************************************************************
** Form generated from reading UI file 'qgspiechartplotwidgetbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSPIECHARTPLOTWIDGETBASE_H
#define UI_QGSPIECHARTPLOTWIDGETBASE_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <qgscollapsiblegroupbox.h>
#include "qgsdoublespinbox.h"
#include "qgsfontbutton.h"
#include "qgspanelwidget.h"
#include "qgspropertyoverridebutton.h"
#include "qgsscrollarea.h"
#include "qgssymbolbutton.h"

QT_BEGIN_NAMESPACE

class Ui_QgsPieChartPlotWidgetBase
{
public:
    QVBoxLayout *verticalLayout_2;
    QgsScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *mainLayout;
    QgsCollapsibleGroupBoxBasic *groupSymbolsList;
    QVBoxLayout *verticalBoxLayout;
    QHBoxLayout *symbolsControlsLayout;
    QPushButton *mAddSymbolPushButton;
    QPushButton *mRemoveSymbolPushButton;
    QTableWidget *mSymbolsList;
    QgsCollapsibleGroupBoxBasic *groupChartArea;
    QGridLayout *gridLayout;
    QgsDoubleSpinBox *mSpinLeftMargin;
    QLabel *label_3;
    QLabel *label_24;
    QgsDoubleSpinBox *mSpinRightMargin;
    QgsDoubleSpinBox *mSpinBottomMargin;
    QLabel *label_25;
    QgsFontButton *mLabelFontButton;
    QgsPropertyOverrideButton *mDDBtnLeftMargin;
    QgsPropertyOverrideButton *mDDBtnTopMargin;
    QLabel *label_23;
    QLabel *label_22;
    QgsDoubleSpinBox *mSpinTopMargin;
    QComboBox *mLabelCombo;
    QLabel *label_2;
    QLabel *label_17;
    QPushButton *mLabelFormatButton;
    QgsPropertyOverrideButton *mDDBtnRightMargin;
    QgsPropertyOverrideButton *mDDBtnBottomMargin;

    void setupUi(QgsPanelWidget *QgsPieChartPlotWidgetBase)
    {
        if (QgsPieChartPlotWidgetBase->objectName().isEmpty())
            QgsPieChartPlotWidgetBase->setObjectName("QgsPieChartPlotWidgetBase");
        QgsPieChartPlotWidgetBase->resize(564, 749);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(QgsPieChartPlotWidgetBase->sizePolicy().hasHeightForWidth());
        QgsPieChartPlotWidgetBase->setSizePolicy(sizePolicy);
        verticalLayout_2 = new QVBoxLayout(QgsPieChartPlotWidgetBase);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setContentsMargins(11, 11, 11, 11);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QgsScrollArea(QgsPieChartPlotWidgetBase);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::StyledPanel);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, -127, 548, 1515));
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scrollAreaWidgetContents->sizePolicy().hasHeightForWidth());
        scrollAreaWidgetContents->setSizePolicy(sizePolicy1);
        mainLayout = new QVBoxLayout(scrollAreaWidgetContents);
        mainLayout->setSpacing(6);
        mainLayout->setContentsMargins(11, 11, 11, 11);
        mainLayout->setObjectName("mainLayout");
        groupSymbolsList = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupSymbolsList->setObjectName("groupSymbolsList");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(groupSymbolsList->sizePolicy().hasHeightForWidth());
        groupSymbolsList->setSizePolicy(sizePolicy2);
        groupSymbolsList->setMaximumSize(QSize(16777215, 320));
        verticalBoxLayout = new QVBoxLayout(groupSymbolsList);
        verticalBoxLayout->setSpacing(6);
        verticalBoxLayout->setContentsMargins(11, 11, 11, 11);
        verticalBoxLayout->setObjectName("verticalBoxLayout");
        symbolsControlsLayout = new QHBoxLayout();
        symbolsControlsLayout->setSpacing(6);
        symbolsControlsLayout->setObjectName("symbolsControlsLayout");
        mAddSymbolPushButton = new QPushButton(groupSymbolsList);
        mAddSymbolPushButton->setObjectName("mAddSymbolPushButton");
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/themes/default/symbologyAdd.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mAddSymbolPushButton->setIcon(icon);

        symbolsControlsLayout->addWidget(mAddSymbolPushButton);

        mRemoveSymbolPushButton = new QPushButton(groupSymbolsList);
        mRemoveSymbolPushButton->setObjectName("mRemoveSymbolPushButton");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/themes/default/symbologyRemove.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mRemoveSymbolPushButton->setIcon(icon1);

        symbolsControlsLayout->addWidget(mRemoveSymbolPushButton);


        verticalBoxLayout->addLayout(symbolsControlsLayout);

        mSymbolsList = new QTableWidget(groupSymbolsList);
        mSymbolsList->setObjectName("mSymbolsList");
        sizePolicy2.setHeightForWidth(mSymbolsList->sizePolicy().hasHeightForWidth());
        mSymbolsList->setSizePolicy(sizePolicy2);
        mSymbolsList->setMaximumSize(QSize(16777215, 320));

        verticalBoxLayout->addWidget(mSymbolsList);


        mainLayout->addWidget(groupSymbolsList);

        groupChartArea = new QgsCollapsibleGroupBoxBasic(scrollAreaWidgetContents);
        groupChartArea->setObjectName("groupChartArea");
        gridLayout = new QGridLayout(groupChartArea);
        gridLayout->setSpacing(6);
        gridLayout->setContentsMargins(11, 11, 11, 11);
        gridLayout->setObjectName("gridLayout");
        mSpinLeftMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinLeftMargin->setObjectName("mSpinLeftMargin");
        mSpinLeftMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinLeftMargin, 3, 1, 1, 1);

        label_3 = new QLabel(groupChartArea);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 0, 1, 1);

        label_24 = new QLabel(groupChartArea);
        label_24->setObjectName("label_24");

        gridLayout->addWidget(label_24, 5, 0, 1, 1);

        mSpinRightMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinRightMargin->setObjectName("mSpinRightMargin");
        mSpinRightMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinRightMargin, 5, 1, 1, 1);

        mSpinBottomMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinBottomMargin->setObjectName("mSpinBottomMargin");
        mSpinBottomMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinBottomMargin, 6, 1, 1, 1);

        label_25 = new QLabel(groupChartArea);
        label_25->setObjectName("label_25");

        gridLayout->addWidget(label_25, 6, 0, 1, 1);

        mLabelFontButton = new QgsFontButton(groupChartArea);
        mLabelFontButton->setObjectName("mLabelFontButton");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(mLabelFontButton->sizePolicy().hasHeightForWidth());
        mLabelFontButton->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(mLabelFontButton, 1, 1, 1, 2);

        mDDBtnLeftMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnLeftMargin->setObjectName("mDDBtnLeftMargin");

        gridLayout->addWidget(mDDBtnLeftMargin, 3, 2, 1, 1);

        mDDBtnTopMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnTopMargin->setObjectName("mDDBtnTopMargin");

        gridLayout->addWidget(mDDBtnTopMargin, 4, 2, 1, 1);

        label_23 = new QLabel(groupChartArea);
        label_23->setObjectName("label_23");

        gridLayout->addWidget(label_23, 4, 0, 1, 1);

        label_22 = new QLabel(groupChartArea);
        label_22->setObjectName("label_22");

        gridLayout->addWidget(label_22, 3, 0, 1, 1);

        mSpinTopMargin = new QgsDoubleSpinBox(groupChartArea);
        mSpinTopMargin->setObjectName("mSpinTopMargin");
        mSpinTopMargin->setMaximum(999.990000000000009);

        gridLayout->addWidget(mSpinTopMargin, 4, 1, 1, 1);

        mLabelCombo = new QComboBox(groupChartArea);
        mLabelCombo->setObjectName("mLabelCombo");
        sizePolicy3.setHeightForWidth(mLabelCombo->sizePolicy().hasHeightForWidth());
        mLabelCombo->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(mLabelCombo, 0, 1, 1, 2);

        label_2 = new QLabel(groupChartArea);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        label_17 = new QLabel(groupChartArea);
        label_17->setObjectName("label_17");

        gridLayout->addWidget(label_17, 2, 0, 1, 1);

        mLabelFormatButton = new QPushButton(groupChartArea);
        mLabelFormatButton->setObjectName("mLabelFormatButton");

        gridLayout->addWidget(mLabelFormatButton, 2, 1, 1, 2);

        mDDBtnRightMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnRightMargin->setObjectName("mDDBtnRightMargin");

        gridLayout->addWidget(mDDBtnRightMargin, 5, 2, 1, 1);

        mDDBtnBottomMargin = new QgsPropertyOverrideButton(groupChartArea);
        mDDBtnBottomMargin->setObjectName("mDDBtnBottomMargin");

        gridLayout->addWidget(mDDBtnBottomMargin, 6, 2, 1, 1);

        gridLayout->setColumnStretch(0, 1);
        gridLayout->setColumnStretch(1, 2);

        mainLayout->addWidget(groupChartArea);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_2->addWidget(scrollArea);


        retranslateUi(QgsPieChartPlotWidgetBase);

        QMetaObject::connectSlotsByName(QgsPieChartPlotWidgetBase);
    } // setupUi

    void retranslateUi(QgsPanelWidget *QgsPieChartPlotWidgetBase)
    {
        QgsPieChartPlotWidgetBase->setWindowTitle(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Pie Chart Plot Options", nullptr));
        groupSymbolsList->setTitle(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Symbols list", nullptr));
#if QT_CONFIG(tooltip)
        mAddSymbolPushButton->setToolTip(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Add a series", nullptr));
#endif // QT_CONFIG(tooltip)
        mAddSymbolPushButton->setText(QString());
#if QT_CONFIG(tooltip)
        mRemoveSymbolPushButton->setToolTip(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Remove selected series", nullptr));
#endif // QT_CONFIG(tooltip)
        mRemoveSymbolPushButton->setText(QString());
        groupChartArea->setTitle(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Chart Area", nullptr));
        mSpinLeftMargin->setSuffix(QCoreApplication::translate("QgsPieChartPlotWidgetBase", " mm", nullptr));
        label_3->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Label font", nullptr));
        label_24->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Right margin", nullptr));
        mSpinRightMargin->setSuffix(QCoreApplication::translate("QgsPieChartPlotWidgetBase", " mm", nullptr));
        mSpinBottomMargin->setSuffix(QCoreApplication::translate("QgsPieChartPlotWidgetBase", " mm", nullptr));
        label_25->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Bottom margin", nullptr));
        mLabelFontButton->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Change\342\200\246", nullptr));
        mDDBtnLeftMargin->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnTopMargin->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "\342\200\246", nullptr));
        label_23->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Top margin", nullptr));
        label_22->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Left margin", nullptr));
        mSpinTopMargin->setSuffix(QCoreApplication::translate("QgsPieChartPlotWidgetBase", " mm", nullptr));
        label_2->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Label type", nullptr));
        label_17->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Label numerical format", nullptr));
        mLabelFormatButton->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "Customize", nullptr));
        mDDBtnRightMargin->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "\342\200\246", nullptr));
        mDDBtnBottomMargin->setText(QCoreApplication::translate("QgsPieChartPlotWidgetBase", "\342\200\246", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsPieChartPlotWidgetBase: public Ui_QgsPieChartPlotWidgetBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSPIECHARTPLOTWIDGETBASE_H
