/********************************************************************************
** Form generated from reading UI file 'map3dexportwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MAP3DEXPORTWIDGET_H
#define UI_MAP3DEXPORTWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include "qgsdoublespinbox.h"
#include "qgsfilewidget.h"
#include "qgsspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_Map3DExportWidget
{
public:
    QGridLayout *gridLayout_2;
    QGridLayout *gridLayout;
    QCheckBox *smoothEdgesCheckBox;
    QLabel *folderLAbel;
    QLabel *sceneNameLabel;
    QgsFileWidget *selectFolderWidget;
    QSpacerItem *verticalSpacer;
    QCheckBox *exportTexturesCheckBox;
    QCheckBox *exportNormalsCheckBox;
    QLineEdit *sceneNameLineEdit;
    QgsDoubleSpinBox *scaleSpinBox;
    QLabel *label_3;
    QSpacerItem *fixedSpacer12;
    QGroupBox *terrainGroup;
    QGridLayout *terrainLayout;
    QLabel *terrainTextureResolutionLabel;
    QgsSpinBox *terrainTextureResolutionSpinBox;
    QLabel *terrainResolutionLabel;
    QgsSpinBox *terrainResolutionSpinBox;

    void setupUi(QWidget *Map3DExportWidget)
    {
        if (Map3DExportWidget->objectName().isEmpty())
            Map3DExportWidget->setObjectName("Map3DExportWidget");
        Map3DExportWidget->resize(400, 251);
        gridLayout_2 = new QGridLayout(Map3DExportWidget);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        smoothEdgesCheckBox = new QCheckBox(Map3DExportWidget);
        smoothEdgesCheckBox->setObjectName("smoothEdgesCheckBox");

        gridLayout->addWidget(smoothEdgesCheckBox, 3, 0, 1, 3);

        folderLAbel = new QLabel(Map3DExportWidget);
        folderLAbel->setObjectName("folderLAbel");

        gridLayout->addWidget(folderLAbel, 1, 0, 1, 1);

        sceneNameLabel = new QLabel(Map3DExportWidget);
        sceneNameLabel->setObjectName("sceneNameLabel");

        gridLayout->addWidget(sceneNameLabel, 0, 0, 1, 1);

        selectFolderWidget = new QgsFileWidget(Map3DExportWidget);
        selectFolderWidget->setObjectName("selectFolderWidget");

        gridLayout->addWidget(selectFolderWidget, 1, 1, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 8, 0, 1, 1);

        exportTexturesCheckBox = new QCheckBox(Map3DExportWidget);
        exportTexturesCheckBox->setObjectName("exportTexturesCheckBox");

        gridLayout->addWidget(exportTexturesCheckBox, 5, 0, 1, 3);

        exportNormalsCheckBox = new QCheckBox(Map3DExportWidget);
        exportNormalsCheckBox->setObjectName("exportNormalsCheckBox");
        exportNormalsCheckBox->setChecked(true);
        exportNormalsCheckBox->setAutoRepeat(false);

        gridLayout->addWidget(exportNormalsCheckBox, 4, 0, 1, 3);

        sceneNameLineEdit = new QLineEdit(Map3DExportWidget);
        sceneNameLineEdit->setObjectName("sceneNameLineEdit");

        gridLayout->addWidget(sceneNameLineEdit, 0, 1, 1, 2);

        scaleSpinBox = new QgsDoubleSpinBox(Map3DExportWidget);
        scaleSpinBox->setObjectName("scaleSpinBox");
        scaleSpinBox->setMinimum(0.100000000000000);
        scaleSpinBox->setSingleStep(0.100000000000000);
        scaleSpinBox->setValue(1.000000000000000);

        gridLayout->addWidget(scaleSpinBox, 2, 1, 1, 2);

        label_3 = new QLabel(Map3DExportWidget);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 0, 1, 1);

        fixedSpacer12 = new QSpacerItem(20, 12, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);

        gridLayout->addItem(fixedSpacer12, 6, 0, 1, 3);

        terrainGroup = new QGroupBox(Map3DExportWidget);
        terrainGroup->setObjectName("terrainGroup");
        terrainGroup->setCheckable(true);
        terrainGroup->setChecked(false);
        terrainLayout = new QGridLayout(terrainGroup);
        terrainLayout->setObjectName("terrainLayout");
        terrainTextureResolutionLabel = new QLabel(terrainGroup);
        terrainTextureResolutionLabel->setObjectName("terrainTextureResolutionLabel");

        terrainLayout->addWidget(terrainTextureResolutionLabel, 0, 0, 1, 1);

        terrainTextureResolutionSpinBox = new QgsSpinBox(terrainGroup);
        terrainTextureResolutionSpinBox->setObjectName("terrainTextureResolutionSpinBox");
        terrainTextureResolutionSpinBox->setMinimum(16);
        terrainTextureResolutionSpinBox->setMaximum(4096);
        terrainTextureResolutionSpinBox->setValue(512);

        terrainLayout->addWidget(terrainTextureResolutionSpinBox, 0, 1, 1, 2);

        terrainResolutionLabel = new QLabel(terrainGroup);
        terrainResolutionLabel->setObjectName("terrainResolutionLabel");

        terrainLayout->addWidget(terrainResolutionLabel, 1, 0, 1, 1);

        terrainResolutionSpinBox = new QgsSpinBox(terrainGroup);
        terrainResolutionSpinBox->setObjectName("terrainResolutionSpinBox");
        terrainResolutionSpinBox->setMinimum(1);
        terrainResolutionSpinBox->setMaximum(4096);
        terrainResolutionSpinBox->setValue(1);

        terrainLayout->addWidget(terrainResolutionSpinBox, 1, 1, 1, 2);


        gridLayout->addWidget(terrainGroup, 7, 0, 1, 3);


        gridLayout_2->addLayout(gridLayout, 0, 0, 1, 1);

        QWidget::setTabOrder(sceneNameLineEdit, terrainResolutionSpinBox);
        QWidget::setTabOrder(terrainResolutionSpinBox, terrainTextureResolutionSpinBox);
        QWidget::setTabOrder(terrainTextureResolutionSpinBox, scaleSpinBox);
        QWidget::setTabOrder(scaleSpinBox, smoothEdgesCheckBox);
        QWidget::setTabOrder(smoothEdgesCheckBox, exportNormalsCheckBox);
        QWidget::setTabOrder(exportNormalsCheckBox, exportTexturesCheckBox);

        retranslateUi(Map3DExportWidget);

        QMetaObject::connectSlotsByName(Map3DExportWidget);
    } // setupUi

    void retranslateUi(QWidget *Map3DExportWidget)
    {
        smoothEdgesCheckBox->setText(QCoreApplication::translate("Map3DExportWidget", "Smooth edges", nullptr));
        folderLAbel->setText(QCoreApplication::translate("Map3DExportWidget", "Folder", nullptr));
        sceneNameLabel->setText(QCoreApplication::translate("Map3DExportWidget", "Scene name", nullptr));
        exportTexturesCheckBox->setText(QCoreApplication::translate("Map3DExportWidget", "Export textures", nullptr));
        exportNormalsCheckBox->setText(QCoreApplication::translate("Map3DExportWidget", "Export normals", nullptr));
        label_3->setText(QCoreApplication::translate("Map3DExportWidget", "Model scale", nullptr));
        terrainGroup->setTitle(QCoreApplication::translate("Map3DExportWidget", "Export Terrain", nullptr));
        terrainTextureResolutionLabel->setText(QCoreApplication::translate("Map3DExportWidget", "Terrain texture resolution", nullptr));
        terrainResolutionLabel->setText(QCoreApplication::translate("Map3DExportWidget", "Terrain resolution", nullptr));
        (void)Map3DExportWidget;
    } // retranslateUi

};

namespace Ui {
    class Map3DExportWidget: public Ui_Map3DExportWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MAP3DEXPORTWIDGET_H
