/********************************************************************************
** Form generated from reading UI file 'qgsattributewidgetrelationeditwidget.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSATTRIBUTEWIDGETRELATIONEDITWIDGET_H
#define UI_QGSATTRIBUTEWIDGETRELATIONEDITWIDGET_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qgscollapsiblegroupbox.h"

QT_BEGIN_NAMESPACE

class Ui_QgsAttributeWidgetRelationEditWidget
{
public:
    QFormLayout *formLayout;
    QLabel *mLabelLabel;
    QLineEdit *mRelationLabelEdit;
    QLabel *mCardinalityLabel;
    QComboBox *mRelationCardinalityCombo;
    QCheckBox *mRelationForceSuppressFormPopupCheckBox;
    QgsCollapsibleGroupBox *mWidgetTypeGroupBox;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *mWidgetTypePlaceholderLayout;
    QSpacerItem *mVerticalSpacer;
    QComboBox *mWidgetTypeComboBox;
    QLabel *mCardinalityLabel_2;

    void setupUi(QWidget *QgsAttributeWidgetRelationEditWidget)
    {
        if (QgsAttributeWidgetRelationEditWidget->objectName().isEmpty())
            QgsAttributeWidgetRelationEditWidget->setObjectName("QgsAttributeWidgetRelationEditWidget");
        QgsAttributeWidgetRelationEditWidget->resize(340, 316);
        formLayout = new QFormLayout(QgsAttributeWidgetRelationEditWidget);
        formLayout->setObjectName("formLayout");
        mLabelLabel = new QLabel(QgsAttributeWidgetRelationEditWidget);
        mLabelLabel->setObjectName("mLabelLabel");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, mLabelLabel);

        mRelationLabelEdit = new QLineEdit(QgsAttributeWidgetRelationEditWidget);
        mRelationLabelEdit->setObjectName("mRelationLabelEdit");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(mRelationLabelEdit->sizePolicy().hasHeightForWidth());
        mRelationLabelEdit->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, mRelationLabelEdit);

        mCardinalityLabel = new QLabel(QgsAttributeWidgetRelationEditWidget);
        mCardinalityLabel->setObjectName("mCardinalityLabel");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, mCardinalityLabel);

        mRelationCardinalityCombo = new QComboBox(QgsAttributeWidgetRelationEditWidget);
        mRelationCardinalityCombo->setObjectName("mRelationCardinalityCombo");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, mRelationCardinalityCombo);

        mRelationForceSuppressFormPopupCheckBox = new QCheckBox(QgsAttributeWidgetRelationEditWidget);
        mRelationForceSuppressFormPopupCheckBox->setObjectName("mRelationForceSuppressFormPopupCheckBox");

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, mRelationForceSuppressFormPopupCheckBox);

        mWidgetTypeGroupBox = new QgsCollapsibleGroupBox(QgsAttributeWidgetRelationEditWidget);
        mWidgetTypeGroupBox->setObjectName("mWidgetTypeGroupBox");
        verticalLayout_2 = new QVBoxLayout(mWidgetTypeGroupBox);
        verticalLayout_2->setObjectName("verticalLayout_2");
        mWidgetTypePlaceholderLayout = new QVBoxLayout();
        mWidgetTypePlaceholderLayout->setObjectName("mWidgetTypePlaceholderLayout");

        verticalLayout_2->addLayout(mWidgetTypePlaceholderLayout);


        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, mWidgetTypeGroupBox);

        mVerticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(5, QFormLayout::ItemRole::SpanningRole, mVerticalSpacer);

        mWidgetTypeComboBox = new QComboBox(QgsAttributeWidgetRelationEditWidget);
        mWidgetTypeComboBox->setObjectName("mWidgetTypeComboBox");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, mWidgetTypeComboBox);

        mCardinalityLabel_2 = new QLabel(QgsAttributeWidgetRelationEditWidget);
        mCardinalityLabel_2->setObjectName("mCardinalityLabel_2");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, mCardinalityLabel_2);


        retranslateUi(QgsAttributeWidgetRelationEditWidget);

        QMetaObject::connectSlotsByName(QgsAttributeWidgetRelationEditWidget);
    } // setupUi

    void retranslateUi(QWidget *QgsAttributeWidgetRelationEditWidget)
    {
        QgsAttributeWidgetRelationEditWidget->setWindowTitle(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Attribute Widget Relation Edit Widget", nullptr));
        mLabelLabel->setText(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Label", nullptr));
#if QT_CONFIG(tooltip)
        mRelationLabelEdit->setToolTip(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "If left empty the relation name is used.", nullptr));
#endif // QT_CONFIG(tooltip)
        mCardinalityLabel->setText(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Cardinality", nullptr));
#if QT_CONFIG(statustip)
        mRelationForceSuppressFormPopupCheckBox->setStatusTip(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Do not open a new attribute form after digitizing a new feature, overrides all other options", nullptr));
#endif // QT_CONFIG(statustip)
        mRelationForceSuppressFormPopupCheckBox->setText(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Force hide form on add feature", nullptr));
        mWidgetTypeGroupBox->setTitle(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Widget Configuration", nullptr));
        mCardinalityLabel_2->setText(QCoreApplication::translate("QgsAttributeWidgetRelationEditWidget", "Widget Type", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsAttributeWidgetRelationEditWidget: public Ui_QgsAttributeWidgetRelationEditWidget {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSATTRIBUTEWIDGETRELATIONEDITWIDGET_H
