/********************************************************************************
** Form generated from reading UI file 'qgscustomizationdialogbase.ui'
**
** Created by: Qt User Interface Compiler version 6.11.1
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QGSCUSTOMIZATIONDIALOGBASE_H
#define UI_QGSCUSTOMIZATIONDIALOGBASE_H

#include <QtCore/QVariant>
#include <QtGui/QAction>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QToolBar>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include "qgsfilterlineedit.h"

QT_BEGIN_NAMESPACE

class Ui_QgsCustomizationDialogBase
{
public:
    QAction *actionCatch;
    QAction *actionSave;
    QAction *actionLoad;
    QAction *actionExpandAll;
    QAction *actionCollapseAll;
    QAction *actionSelectAll;
    QAction *mDeleteAction;
    QAction *mAddAction;
    QAction *mListActionsAction;
    QWidget *centralwidget;
    QVBoxLayout *verticalLayout_3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *mCustomizationEnabledCheckBox;
    QSpacerItem *horizontalSpacer;
    QSplitter *mSplitter;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout_2;
    QgsFilterLineEdit *mFilterLe;
    QTreeView *mTreeView;
    QWidget *layoutWidget2;
    QVBoxLayout *verticalLayout;
    QgsFilterLineEdit *mFilterActionsLe;
    QTreeView *mActionsTreeView;
    QDialogButtonBox *buttonBox;
    QToolBar *toolBar;

    void setupUi(QMainWindow *QgsCustomizationDialogBase)
    {
        if (QgsCustomizationDialogBase->objectName().isEmpty())
            QgsCustomizationDialogBase->setObjectName("QgsCustomizationDialogBase");
        QgsCustomizationDialogBase->resize(503, 658);
        actionCatch = new QAction(QgsCustomizationDialogBase);
        actionCatch->setObjectName("actionCatch");
        actionCatch->setCheckable(true);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/images/themes/default/mActionSelect.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionCatch->setIcon(icon);
        actionSave = new QAction(QgsCustomizationDialogBase);
        actionSave->setObjectName("actionSave");
        QIcon icon1;
        icon1.addFile(QString::fromUtf8(":/images/themes/default/mActionFileSave.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionSave->setIcon(icon1);
        actionLoad = new QAction(QgsCustomizationDialogBase);
        actionLoad->setObjectName("actionLoad");
        QIcon icon2;
        icon2.addFile(QString::fromUtf8(":/images/themes/default/mActionFileOpen.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionLoad->setIcon(icon2);
        actionExpandAll = new QAction(QgsCustomizationDialogBase);
        actionExpandAll->setObjectName("actionExpandAll");
        QIcon icon3;
        icon3.addFile(QString::fromUtf8(":/images/themes/default/mActionExpandTree.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionExpandAll->setIcon(icon3);
        actionCollapseAll = new QAction(QgsCustomizationDialogBase);
        actionCollapseAll->setObjectName("actionCollapseAll");
        QIcon icon4;
        icon4.addFile(QString::fromUtf8(":/images/themes/default/mActionCollapseTree.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionCollapseAll->setIcon(icon4);
        actionSelectAll = new QAction(QgsCustomizationDialogBase);
        actionSelectAll->setObjectName("actionSelectAll");
        QIcon icon5;
        icon5.addFile(QString::fromUtf8(":/images/themes/default/mActionSelectAllTree.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        actionSelectAll->setIcon(icon5);
        mDeleteAction = new QAction(QgsCustomizationDialogBase);
        mDeleteAction->setObjectName("mDeleteAction");
        QIcon icon6;
        icon6.addFile(QString::fromUtf8(":/images/themes/default/mActionDeleteSelected.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mDeleteAction->setIcon(icon6);
        mDeleteAction->setMenuRole(QAction::MenuRole::TextHeuristicRole);
        mAddAction = new QAction(QgsCustomizationDialogBase);
        mAddAction->setObjectName("mAddAction");
        QIcon icon7;
        icon7.addFile(QString::fromUtf8(":/images/themes/default/mActionAdd.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mAddAction->setIcon(icon7);
        mAddAction->setMenuRole(QAction::MenuRole::TextHeuristicRole);
        mListActionsAction = new QAction(QgsCustomizationDialogBase);
        mListActionsAction->setObjectName("mListActionsAction");
        mListActionsAction->setCheckable(true);
        QIcon icon8;
        icon8.addFile(QString::fromUtf8(":/images/themes/default/mActionListActions.svg"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        mListActionsAction->setIcon(icon8);
        mListActionsAction->setMenuRole(QAction::MenuRole::NoRole);
        centralwidget = new QWidget(QgsCustomizationDialogBase);
        centralwidget->setObjectName("centralwidget");
        verticalLayout_3 = new QVBoxLayout(centralwidget);
        verticalLayout_3->setObjectName("verticalLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        mCustomizationEnabledCheckBox = new QCheckBox(centralwidget);
        mCustomizationEnabledCheckBox->setObjectName("mCustomizationEnabledCheckBox");

        horizontalLayout->addWidget(mCustomizationEnabledCheckBox);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        verticalLayout_3->addLayout(horizontalLayout);

        mSplitter = new QSplitter(centralwidget);
        mSplitter->setObjectName("mSplitter");
        mSplitter->setOrientation(Qt::Orientation::Horizontal);
        layoutWidget = new QWidget(mSplitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout_2 = new QVBoxLayout(layoutWidget);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        mFilterLe = new QgsFilterLineEdit(layoutWidget);
        mFilterLe->setObjectName("mFilterLe");
        mFilterLe->setProperty("showSearchIcon", QVariant(true));

        verticalLayout_2->addWidget(mFilterLe);

        mTreeView = new QTreeView(layoutWidget);
        mTreeView->setObjectName("mTreeView");
        mTreeView->setDragDropMode(QAbstractItemView::DragDropMode::DragDrop);
        mTreeView->setDefaultDropAction(Qt::DropAction::LinkAction);
        mTreeView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        mTreeView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);

        verticalLayout_2->addWidget(mTreeView);

        mSplitter->addWidget(layoutWidget);
        layoutWidget2 = new QWidget(mSplitter);
        layoutWidget2->setObjectName("layoutWidget2");
        verticalLayout = new QVBoxLayout(layoutWidget2);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        mFilterActionsLe = new QgsFilterLineEdit(layoutWidget2);
        mFilterActionsLe->setObjectName("mFilterActionsLe");
        mFilterActionsLe->setProperty("showSearchIcon", QVariant(true));

        verticalLayout->addWidget(mFilterActionsLe);

        mActionsTreeView = new QTreeView(layoutWidget2);
        mActionsTreeView->setObjectName("mActionsTreeView");
        mActionsTreeView->setDragEnabled(true);
        mActionsTreeView->setDragDropMode(QAbstractItemView::DragDropMode::DragOnly);
        mActionsTreeView->setSelectionMode(QAbstractItemView::SelectionMode::ExtendedSelection);
        mActionsTreeView->setSelectionBehavior(QAbstractItemView::SelectionBehavior::SelectRows);
        mActionsTreeView->setHeaderHidden(false);

        verticalLayout->addWidget(mActionsTreeView);

        mSplitter->addWidget(layoutWidget2);

        verticalLayout_3->addWidget(mSplitter);

        buttonBox = new QDialogButtonBox(centralwidget);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Apply|QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Help|QDialogButtonBox::StandardButton::Ok|QDialogButtonBox::StandardButton::Reset);

        verticalLayout_3->addWidget(buttonBox);

        QgsCustomizationDialogBase->setCentralWidget(centralwidget);
        toolBar = new QToolBar(QgsCustomizationDialogBase);
        toolBar->setObjectName("toolBar");
        toolBar->setMovable(false);
        toolBar->setIconSize(QSize(24, 24));
        QgsCustomizationDialogBase->addToolBar(Qt::ToolBarArea::TopToolBarArea, toolBar);

        toolBar->addAction(actionCatch);
        toolBar->addAction(actionSave);
        toolBar->addAction(actionLoad);
        toolBar->addAction(actionExpandAll);
        toolBar->addAction(actionCollapseAll);
        toolBar->addAction(actionSelectAll);
        toolBar->addAction(mDeleteAction);
        toolBar->addAction(mAddAction);
        toolBar->addAction(mListActionsAction);

        retranslateUi(QgsCustomizationDialogBase);

        QMetaObject::connectSlotsByName(QgsCustomizationDialogBase);
    } // setupUi

    void retranslateUi(QMainWindow *QgsCustomizationDialogBase)
    {
        QgsCustomizationDialogBase->setWindowTitle(QCoreApplication::translate("QgsCustomizationDialogBase", "Interface Customization", nullptr));
        actionCatch->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Catch", nullptr));
#if QT_CONFIG(tooltip)
        actionCatch->setToolTip(QCoreApplication::translate("QgsCustomizationDialogBase", "Switch to catching widgets in main application", nullptr));
#endif // QT_CONFIG(tooltip)
        actionSave->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Save", nullptr));
#if QT_CONFIG(tooltip)
        actionSave->setToolTip(QCoreApplication::translate("QgsCustomizationDialogBase", "Save to file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionLoad->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Load", nullptr));
#if QT_CONFIG(tooltip)
        actionLoad->setToolTip(QCoreApplication::translate("QgsCustomizationDialogBase", "Load from file", nullptr));
#endif // QT_CONFIG(tooltip)
        actionExpandAll->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Expand All", nullptr));
        actionCollapseAll->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Collapse All", nullptr));
        actionSelectAll->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Check All", nullptr));
        mDeleteAction->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Delete user item", nullptr));
        mAddAction->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Add user item", nullptr));
        mListActionsAction->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Display action panel", nullptr));
#if QT_CONFIG(tooltip)
        mListActionsAction->setToolTip(QCoreApplication::translate("QgsCustomizationDialogBase", "<html><head/><body><p>Display action panel from which you can drag and drop existing actions onto user created menu or toolbar in the left panel</p></body></html>", nullptr));
#endif // QT_CONFIG(tooltip)
        mCustomizationEnabledCheckBox->setText(QCoreApplication::translate("QgsCustomizationDialogBase", "Enable customization", nullptr));
        mFilterLe->setPlaceholderText(QCoreApplication::translate("QgsCustomizationDialogBase", "Search\342\200\246", nullptr));
        mFilterActionsLe->setPlaceholderText(QCoreApplication::translate("QgsCustomizationDialogBase", "Search\342\200\246", nullptr));
#if QT_CONFIG(tooltip)
        mActionsTreeView->setToolTip(QCoreApplication::translate("QgsCustomizationDialogBase", "Drag and drop existing actions onto user created menu or toolbar in the left panel", nullptr));
#endif // QT_CONFIG(tooltip)
        toolBar->setWindowTitle(QCoreApplication::translate("QgsCustomizationDialogBase", "toolBar", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QgsCustomizationDialogBase: public Ui_QgsCustomizationDialogBase {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_QGSCUSTOMIZATIONDIALOGBASE_H
