# The PEP 484 type hints stub file for the _core module.
#
# Generated by SIP 6.15.3


import collections, re, typing, enum

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtXml
from PyQt6 import QtNetwork
from PyQt6 import QtGui
from PyQt6 import QtWidgets
from PyQt6 import QtSql
from PyQt6 import QtPrintSupport
from PyQt6 import QtPositioning
from PyQt6 import QtMultimedia
from PyQt6 import QtSerialPort

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]

class QgsCsException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsProcessingException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsProviderConnectionException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsNotSupportedException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsSettingsException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsSfcgalException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsInvalidArgumentException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...

class QgsException(Exception):
    def __init__(self, *args, **kwargs) -> None: ...


class QgsGpsConnection(QtCore.QObject):

    class Status(enum.IntEnum):
        NotConnected = ... # type: QgsGpsConnection.Status
        Connected = ... # type: QgsGpsConnection.Status
        DataReceived = ... # type: QgsGpsConnection.Status
        GPSDataReceived = ... # type: QgsGpsConnection.Status

    def __init__(self, dev: QtCore.QIODevice|None) -> None: ...

    def parseData(self) -> None: ...
    positionChanged: typing.ClassVar[QtCore.pyqtSignal]
    fixStatusChanged: typing.ClassVar[QtCore.pyqtSignal]
    nmeaSentenceReceived: typing.ClassVar[QtCore.pyqtSignal]
    stateChanged: typing.ClassVar[QtCore.pyqtSignal]
    def lastValidLocation(self) -> 'QgsPoint': ...
    def currentGPSInformation(self) -> 'QgsGpsInformation': ...
    def status(self) -> 'QgsGpsConnection.Status': ...
    def setSource(self, source: QtCore.QIODevice|None) -> None: ...
    def close(self) -> bool: ...
    def connect(self) -> bool: ...


class QgsQtLocationConnection(QgsGpsConnection):

    def __init__(self) -> None: ...

    def satellitesInUseUpdated(self, satellites: collections.abc.Iterable[QtPositioning.QGeoSatelliteInfo]) -> None: ...
    def satellitesInViewUpdated(self, satellites: collections.abc.Iterable[QtPositioning.QGeoSatelliteInfo]) -> None: ...
    def parseData(self) -> None: ...
    def broadcastConnectionAvailable(self) -> None: ...


class Qgis(PyQt6.sip.wrapper):

    class TriangulationAlgorithm(enum.IntFlag):
        ConstrainedDelaunay = ... # type: Qgis.TriangulationAlgorithm
        Earcut = ... # type: Qgis.TriangulationAlgorithm

    class ExtrusionFace(enum.IntFlag):
        NoFace = ... # type: Qgis.ExtrusionFace
        Walls = ... # type: Qgis.ExtrusionFace
        Roof = ... # type: Qgis.ExtrusionFace
        Floor = ... # type: Qgis.ExtrusionFace

    class DevToolsNodeRole(enum.Enum):
        Status = ... # type: Qgis.DevToolsNodeRole
        Id = ... # type: Qgis.DevToolsNodeRole
        ElapsedTime = ... # type: Qgis.DevToolsNodeRole
        MaximumTime = ... # type: Qgis.DevToolsNodeRole
        Sort = ... # type: Qgis.DevToolsNodeRole

    class RasterProcessingParameterCapability(enum.IntFlag):
        WmsScale = ... # type: Qgis.RasterProcessingParameterCapability
        WmsDpi = ... # type: Qgis.RasterProcessingParameterCapability

    class StacObjectType(enum.IntEnum):
        Unknown = ... # type: Qgis.StacObjectType
        Catalog = ... # type: Qgis.StacObjectType
        Collection = ... # type: Qgis.StacObjectType
        Item = ... # type: Qgis.StacObjectType

    class SegmentCalculationMethod(enum.IntEnum):
        Standard = ... # type: Qgis.SegmentCalculationMethod
        Adaptive = ... # type: Qgis.SegmentCalculationMethod
        AreaError = ... # type: Qgis.SegmentCalculationMethod
        ConstantDensity = ... # type: Qgis.SegmentCalculationMethod

    class PointCloudZoomOutRenderBehavior(enum.IntEnum):
        RenderExtents = ... # type: Qgis.PointCloudZoomOutRenderBehavior
        RenderOverview = ... # type: Qgis.PointCloudZoomOutRenderBehavior
        RenderOverviewAndExtents = ... # type: Qgis.PointCloudZoomOutRenderBehavior

    class PointCloudAccessType(enum.IntEnum):
        Local = ... # type: Qgis.PointCloudAccessType
        Remote = ... # type: Qgis.PointCloudAccessType

    class MeshRangeExtent(enum.IntEnum):
        WholeMesh = ... # type: Qgis.MeshRangeExtent
        FixedCanvas = ... # type: Qgis.MeshRangeExtent
        UpdatedCanvas = ... # type: Qgis.MeshRangeExtent

    class MeshRangeLimit(enum.IntEnum):
        NotSet = ... # type: Qgis.MeshRangeLimit
        MinimumMaximum = ... # type: Qgis.MeshRangeLimit

    class MouseHandlesAction(enum.IntEnum):
        MoveItem = ... # type: Qgis.MouseHandlesAction
        ResizeUp = ... # type: Qgis.MouseHandlesAction
        ResizeDown = ... # type: Qgis.MouseHandlesAction
        ResizeLeft = ... # type: Qgis.MouseHandlesAction
        ResizeRight = ... # type: Qgis.MouseHandlesAction
        ResizeLeftUp = ... # type: Qgis.MouseHandlesAction
        ResizeRightUp = ... # type: Qgis.MouseHandlesAction
        ResizeLeftDown = ... # type: Qgis.MouseHandlesAction
        ResizeRightDown = ... # type: Qgis.MouseHandlesAction
        RotateTopLeft = ... # type: Qgis.MouseHandlesAction
        RotateTopRight = ... # type: Qgis.MouseHandlesAction
        RotateBottomLeft = ... # type: Qgis.MouseHandlesAction
        RotateBottomRight = ... # type: Qgis.MouseHandlesAction
        SelectItem = ... # type: Qgis.MouseHandlesAction
        NoAction = ... # type: Qgis.MouseHandlesAction

    class DocumentationBrowser(enum.IntEnum):
        DeveloperToolsPanel = ... # type: Qgis.DocumentationBrowser
        SystemWebBrowser = ... # type: Qgis.DocumentationBrowser

    class DocumentationApi(enum.IntEnum):
        PyQgis = ... # type: Qgis.DocumentationApi
        PyQgisSearch = ... # type: Qgis.DocumentationApi
        CppQgis = ... # type: Qgis.DocumentationApi
        Qt = ... # type: Qgis.DocumentationApi

    class ColorModel(enum.IntEnum):
        Rgb = ... # type: Qgis.ColorModel
        Cmyk = ... # type: Qgis.ColorModel

    class SensorThingsEntity(enum.IntEnum):
        Invalid = ... # type: Qgis.SensorThingsEntity
        Thing = ... # type: Qgis.SensorThingsEntity
        Location = ... # type: Qgis.SensorThingsEntity
        HistoricalLocation = ... # type: Qgis.SensorThingsEntity
        Datastream = ... # type: Qgis.SensorThingsEntity
        Sensor = ... # type: Qgis.SensorThingsEntity
        ObservedProperty = ... # type: Qgis.SensorThingsEntity
        Observation = ... # type: Qgis.SensorThingsEntity
        FeatureOfInterest = ... # type: Qgis.SensorThingsEntity
        MultiDatastream = ... # type: Qgis.SensorThingsEntity

    class RasterBandStatistic(enum.IntFlag):
        NoStatistic = ... # type: Qgis.RasterBandStatistic
        Min = ... # type: Qgis.RasterBandStatistic
        Max = ... # type: Qgis.RasterBandStatistic
        Range = ... # type: Qgis.RasterBandStatistic
        Sum = ... # type: Qgis.RasterBandStatistic
        Mean = ... # type: Qgis.RasterBandStatistic
        StdDev = ... # type: Qgis.RasterBandStatistic
        SumOfSquares = ... # type: Qgis.RasterBandStatistic
        All = ... # type: Qgis.RasterBandStatistic

    class StringStatistic(enum.IntFlag):
        Count = ... # type: Qgis.StringStatistic
        CountDistinct = ... # type: Qgis.StringStatistic
        CountMissing = ... # type: Qgis.StringStatistic
        Min = ... # type: Qgis.StringStatistic
        Max = ... # type: Qgis.StringStatistic
        MinimumLength = ... # type: Qgis.StringStatistic
        MaximumLength = ... # type: Qgis.StringStatistic
        MeanLength = ... # type: Qgis.StringStatistic
        Minority = ... # type: Qgis.StringStatistic
        Majority = ... # type: Qgis.StringStatistic
        All = ... # type: Qgis.StringStatistic

    class DateTimeStatistic(enum.IntFlag):
        Count = ... # type: Qgis.DateTimeStatistic
        CountDistinct = ... # type: Qgis.DateTimeStatistic
        CountMissing = ... # type: Qgis.DateTimeStatistic
        Min = ... # type: Qgis.DateTimeStatistic
        Max = ... # type: Qgis.DateTimeStatistic
        Range = ... # type: Qgis.DateTimeStatistic
        All = ... # type: Qgis.DateTimeStatistic

    class Statistic(enum.IntFlag):
        Count = ... # type: Qgis.Statistic
        CountMissing = ... # type: Qgis.Statistic
        Sum = ... # type: Qgis.Statistic
        Mean = ... # type: Qgis.Statistic
        Median = ... # type: Qgis.Statistic
        StDev = ... # type: Qgis.Statistic
        StDevSample = ... # type: Qgis.Statistic
        Min = ... # type: Qgis.Statistic
        Max = ... # type: Qgis.Statistic
        Range = ... # type: Qgis.Statistic
        Minority = ... # type: Qgis.Statistic
        Majority = ... # type: Qgis.Statistic
        Variety = ... # type: Qgis.Statistic
        FirstQuartile = ... # type: Qgis.Statistic
        ThirdQuartile = ... # type: Qgis.Statistic
        InterQuartileRange = ... # type: Qgis.Statistic
        First = ... # type: Qgis.Statistic
        Last = ... # type: Qgis.Statistic
        All = ... # type: Qgis.Statistic

    class Aggregate(enum.IntEnum):
        Count = ... # type: Qgis.Aggregate
        CountDistinct = ... # type: Qgis.Aggregate
        CountMissing = ... # type: Qgis.Aggregate
        Min = ... # type: Qgis.Aggregate
        Max = ... # type: Qgis.Aggregate
        Sum = ... # type: Qgis.Aggregate
        Mean = ... # type: Qgis.Aggregate
        Median = ... # type: Qgis.Aggregate
        StDev = ... # type: Qgis.Aggregate
        StDevSample = ... # type: Qgis.Aggregate
        Range = ... # type: Qgis.Aggregate
        Minority = ... # type: Qgis.Aggregate
        Majority = ... # type: Qgis.Aggregate
        FirstQuartile = ... # type: Qgis.Aggregate
        ThirdQuartile = ... # type: Qgis.Aggregate
        InterQuartileRange = ... # type: Qgis.Aggregate
        StringMinimumLength = ... # type: Qgis.Aggregate
        StringMaximumLength = ... # type: Qgis.Aggregate
        StringConcatenate = ... # type: Qgis.Aggregate
        GeometryCollect = ... # type: Qgis.Aggregate
        ArrayAggregate = ... # type: Qgis.Aggregate
        StringConcatenateUnique = ... # type: Qgis.Aggregate

    class ZonalStatisticResult(enum.IntEnum):
        Success = ... # type: Qgis.ZonalStatisticResult
        LayerTypeWrong = ... # type: Qgis.ZonalStatisticResult
        LayerInvalid = ... # type: Qgis.ZonalStatisticResult
        RasterInvalid = ... # type: Qgis.ZonalStatisticResult
        RasterBandInvalid = ... # type: Qgis.ZonalStatisticResult
        FailedToCreateField = ... # type: Qgis.ZonalStatisticResult
        Canceled = ... # type: Qgis.ZonalStatisticResult

    class ZonalStatistic(enum.IntFlag):
        Count = ... # type: Qgis.ZonalStatistic
        Sum = ... # type: Qgis.ZonalStatistic
        Mean = ... # type: Qgis.ZonalStatistic
        Median = ... # type: Qgis.ZonalStatistic
        StDev = ... # type: Qgis.ZonalStatistic
        Min = ... # type: Qgis.ZonalStatistic
        Max = ... # type: Qgis.ZonalStatistic
        Range = ... # type: Qgis.ZonalStatistic
        Minority = ... # type: Qgis.ZonalStatistic
        Majority = ... # type: Qgis.ZonalStatistic
        Variety = ... # type: Qgis.ZonalStatistic
        Variance = ... # type: Qgis.ZonalStatistic
        MinimumPoint = ... # type: Qgis.ZonalStatistic
        MaximumPoint = ... # type: Qgis.ZonalStatistic
        All = ... # type: Qgis.ZonalStatistic
        AllNumeric = ... # type: Qgis.ZonalStatistic
        Default = ... # type: Qgis.ZonalStatistic

    class VsiHandlerType(enum.IntEnum):
        Invalid = ... # type: Qgis.VsiHandlerType
        Archive = ... # type: Qgis.VsiHandlerType
        Network = ... # type: Qgis.VsiHandlerType
        Cloud = ... # type: Qgis.VsiHandlerType
        Memory = ... # type: Qgis.VsiHandlerType
        Other = ... # type: Qgis.VsiHandlerType

    class GdalResampleAlgorithm(enum.IntEnum):
        RA_NearestNeighbour = ... # type: Qgis.GdalResampleAlgorithm
        RA_Bilinear = ... # type: Qgis.GdalResampleAlgorithm
        RA_Cubic = ... # type: Qgis.GdalResampleAlgorithm
        RA_CubicSpline = ... # type: Qgis.GdalResampleAlgorithm
        RA_Lanczos = ... # type: Qgis.GdalResampleAlgorithm
        RA_Average = ... # type: Qgis.GdalResampleAlgorithm
        RA_Mode = ... # type: Qgis.GdalResampleAlgorithm
        RA_Max = ... # type: Qgis.GdalResampleAlgorithm
        RA_Min = ... # type: Qgis.GdalResampleAlgorithm
        RA_Median = ... # type: Qgis.GdalResampleAlgorithm
        RA_Q1 = ... # type: Qgis.GdalResampleAlgorithm
        RA_Q3 = ... # type: Qgis.GdalResampleAlgorithm

    class TiledSceneRendererFlag(enum.IntFlag):
        RequiresTextures = ... # type: Qgis.TiledSceneRendererFlag
        ForceRasterRender = ... # type: Qgis.TiledSceneRendererFlag
        RendersTriangles = ... # type: Qgis.TiledSceneRendererFlag
        RendersLines = ... # type: Qgis.TiledSceneRendererFlag

    class TiledSceneRequestFlag(enum.IntFlag):
        NoHierarchyFetch = ... # type: Qgis.TiledSceneRequestFlag

    class TileChildrenAvailability(enum.Enum):
        NoChildren = ... # type: Qgis.TileChildrenAvailability
        Available = ... # type: Qgis.TileChildrenAvailability
        NeedFetching = ... # type: Qgis.TileChildrenAvailability

    class TileRefinementProcess(enum.Enum):
        Replacement = ... # type: Qgis.TileRefinementProcess
        Additive = ... # type: Qgis.TileRefinementProcess

    class TiledSceneBoundingVolumeType(enum.Enum):
        Region = ... # type: Qgis.TiledSceneBoundingVolumeType
        OrientedBox = ... # type: Qgis.TiledSceneBoundingVolumeType
        Sphere = ... # type: Qgis.TiledSceneBoundingVolumeType

    class TiledSceneProviderCapability(enum.IntFlag):
        ReadLayerMetadata = ... # type: Qgis.TiledSceneProviderCapability

    class TileAvailability(enum.Enum):
        Available = ... # type: Qgis.TileAvailability
        NotAvailable = ... # type: Qgis.TileAvailability
        AvailableNoChildren = ... # type: Qgis.TileAvailability
        UseLowerZoomLevelTile = ... # type: Qgis.TileAvailability

    class VectorTileProviderCapability(enum.IntFlag):
        ReadLayerMetadata = ... # type: Qgis.VectorTileProviderCapability

    class VectorTileProviderFlag(enum.IntFlag):
        AlwaysUseTileMatrixSetFromProvider = ... # type: Qgis.VectorTileProviderFlag

    class FeatureSymbologyExport(enum.IntEnum):
        NoSymbology = ... # type: Qgis.FeatureSymbologyExport
        PerFeature = ... # type: Qgis.FeatureSymbologyExport
        PerSymbolLayer = ... # type: Qgis.FeatureSymbologyExport

    class ExpressionType(enum.Enum):
        Qgis = ... # type: Qgis.ExpressionType
        PointCloud = ... # type: Qgis.ExpressionType
        RasterCalculator = ... # type: Qgis.ExpressionType

    class AttributeFormReuseLastValuePolicy(enum.IntEnum):
        NotAllowed = ... # type: Qgis.AttributeFormReuseLastValuePolicy
        AllowedDefaultOn = ... # type: Qgis.AttributeFormReuseLastValuePolicy
        AllowedDefaultOff = ... # type: Qgis.AttributeFormReuseLastValuePolicy

    class AttributeFormPythonInitCodeSource(enum.IntEnum):
        NoSource = ... # type: Qgis.AttributeFormPythonInitCodeSource
        File = ... # type: Qgis.AttributeFormPythonInitCodeSource
        Dialog = ... # type: Qgis.AttributeFormPythonInitCodeSource
        Environment = ... # type: Qgis.AttributeFormPythonInitCodeSource

    class AttributeFormSuppression(enum.IntEnum):
        Default = ... # type: Qgis.AttributeFormSuppression
        On = ... # type: Qgis.AttributeFormSuppression
        Off = ... # type: Qgis.AttributeFormSuppression

    class AttributeFormLayout(enum.IntEnum):
        AutoGenerated = ... # type: Qgis.AttributeFormLayout
        DragAndDrop = ... # type: Qgis.AttributeFormLayout
        UiFile = ... # type: Qgis.AttributeFormLayout

    class AttributeEditorContainerType(enum.IntEnum):
        GroupBox = ... # type: Qgis.AttributeEditorContainerType
        Tab = ... # type: Qgis.AttributeEditorContainerType
        Row = ... # type: Qgis.AttributeEditorContainerType

    class AttributeEditorType(enum.IntEnum):
        Container = ... # type: Qgis.AttributeEditorType
        Field = ... # type: Qgis.AttributeEditorType
        Relation = ... # type: Qgis.AttributeEditorType
        QmlElement = ... # type: Qgis.AttributeEditorType
        HtmlElement = ... # type: Qgis.AttributeEditorType
        Action = ... # type: Qgis.AttributeEditorType
        TextElement = ... # type: Qgis.AttributeEditorType
        SpacerElement = ... # type: Qgis.AttributeEditorType
        Invalid = ... # type: Qgis.AttributeEditorType

    class UserProfileSelectionPolicy(enum.IntEnum):
        LastProfile = ... # type: Qgis.UserProfileSelectionPolicy
        DefaultProfile = ... # type: Qgis.UserProfileSelectionPolicy
        AskUser = ... # type: Qgis.UserProfileSelectionPolicy

    class ProviderStyleStorageCapability(enum.IntFlag):
        SaveToDatabase = ... # type: Qgis.ProviderStyleStorageCapability
        LoadFromDatabase = ... # type: Qgis.ProviderStyleStorageCapability
        DeleteFromDatabase = ... # type: Qgis.ProviderStyleStorageCapability

    class DatabaseProviderTableImportCapability(enum.IntFlag):
        SetGeometryColumnName = ... # type: Qgis.DatabaseProviderTableImportCapability
        SetPrimaryKeyName = ... # type: Qgis.DatabaseProviderTableImportCapability

    class DatabaseProviderConnectionCapability2(enum.IntFlag):
        SetFieldComment = ... # type: Qgis.DatabaseProviderConnectionCapability2
        SetFieldAlias = ... # type: Qgis.DatabaseProviderConnectionCapability2
        SetTableComment = ... # type: Qgis.DatabaseProviderConnectionCapability2
        EditFieldDomain = ... # type: Qgis.DatabaseProviderConnectionCapability2
        DeleteFieldDomain = ... # type: Qgis.DatabaseProviderConnectionCapability2

    class PostgresRelKind(enum.Enum):
        NotSet = ... # type: Qgis.PostgresRelKind
        Unknown = ... # type: Qgis.PostgresRelKind
        OrdinaryTable = ... # type: Qgis.PostgresRelKind
        Index = ... # type: Qgis.PostgresRelKind
        Sequence = ... # type: Qgis.PostgresRelKind
        View = ... # type: Qgis.PostgresRelKind
        MaterializedView = ... # type: Qgis.PostgresRelKind
        CompositeType = ... # type: Qgis.PostgresRelKind
        ToastTable = ... # type: Qgis.PostgresRelKind
        ForeignTable = ... # type: Qgis.PostgresRelKind
        PartitionedTable = ... # type: Qgis.PostgresRelKind

    class InputControllerType(enum.IntEnum):
        Map2D = ... # type: Qgis.InputControllerType
        Map3D = ... # type: Qgis.InputControllerType

    class MapGridAnnotationType(enum.IntEnum):
        Longitude = ... # type: Qgis.MapGridAnnotationType
        Latitude = ... # type: Qgis.MapGridAnnotationType

    class MapGridFrameSideFlag(enum.IntFlag):
        Left = ... # type: Qgis.MapGridFrameSideFlag
        Right = ... # type: Qgis.MapGridFrameSideFlag
        Top = ... # type: Qgis.MapGridFrameSideFlag
        Bottom = ... # type: Qgis.MapGridFrameSideFlag

    class MapGridTickLengthMode(enum.IntEnum):
        OrthogonalTicks = ... # type: Qgis.MapGridTickLengthMode
        NormalizedTicks = ... # type: Qgis.MapGridTickLengthMode

    class MapGridFrameStyle(enum.IntEnum):
        NoFrame = ... # type: Qgis.MapGridFrameStyle
        Zebra = ... # type: Qgis.MapGridFrameStyle
        InteriorTicks = ... # type: Qgis.MapGridFrameStyle
        ExteriorTicks = ... # type: Qgis.MapGridFrameStyle
        InteriorExteriorTicks = ... # type: Qgis.MapGridFrameStyle
        LineBorder = ... # type: Qgis.MapGridFrameStyle
        LineBorderNautical = ... # type: Qgis.MapGridFrameStyle
        ZebraNautical = ... # type: Qgis.MapGridFrameStyle

    class MapGridBorderSide(enum.IntEnum):
        Left = ... # type: Qgis.MapGridBorderSide
        Right = ... # type: Qgis.MapGridBorderSide
        Bottom = ... # type: Qgis.MapGridBorderSide
        Top = ... # type: Qgis.MapGridBorderSide

    class MapGridAnnotationFormat(enum.IntEnum):
        Decimal = ... # type: Qgis.MapGridAnnotationFormat
        DegreeMinute = ... # type: Qgis.MapGridAnnotationFormat
        DegreeMinuteSecond = ... # type: Qgis.MapGridAnnotationFormat
        DecimalWithSuffix = ... # type: Qgis.MapGridAnnotationFormat
        DegreeMinuteNoSuffix = ... # type: Qgis.MapGridAnnotationFormat
        DegreeMinutePadded = ... # type: Qgis.MapGridAnnotationFormat
        DegreeMinuteSecondNoSuffix = ... # type: Qgis.MapGridAnnotationFormat
        DegreeMinuteSecondPadded = ... # type: Qgis.MapGridAnnotationFormat
        CustomFormat = ... # type: Qgis.MapGridAnnotationFormat

    class MapGridAnnotationDirection(enum.IntEnum):
        Horizontal = ... # type: Qgis.MapGridAnnotationDirection
        Vertical = ... # type: Qgis.MapGridAnnotationDirection
        VerticalDescending = ... # type: Qgis.MapGridAnnotationDirection
        BoundaryDirection = ... # type: Qgis.MapGridAnnotationDirection
        AboveTick = ... # type: Qgis.MapGridAnnotationDirection
        OnTick = ... # type: Qgis.MapGridAnnotationDirection
        UnderTick = ... # type: Qgis.MapGridAnnotationDirection

    class MapGridAnnotationPosition(enum.IntEnum):
        InsideMapFrame = ... # type: Qgis.MapGridAnnotationPosition
        OutsideMapFrame = ... # type: Qgis.MapGridAnnotationPosition

    class MapGridComponentVisibility(enum.IntEnum):
        ShowAll = ... # type: Qgis.MapGridComponentVisibility
        LatitudeOnly = ... # type: Qgis.MapGridComponentVisibility
        LongitudeOnly = ... # type: Qgis.MapGridComponentVisibility
        HideAll = ... # type: Qgis.MapGridComponentVisibility

    class MapGridStyle(enum.IntEnum):
        Lines = ... # type: Qgis.MapGridStyle
        LineCrosses = ... # type: Qgis.MapGridStyle
        Markers = ... # type: Qgis.MapGridStyle
        FrameAndAnnotationsOnly = ... # type: Qgis.MapGridStyle

    class MapGridUnit(enum.IntEnum):
        MapUnits = ... # type: Qgis.MapGridUnit
        Millimeters = ... # type: Qgis.MapGridUnit
        Centimeters = ... # type: Qgis.MapGridUnit
        DynamicPageSizeBased = ... # type: Qgis.MapGridUnit

    class ScaleBarDistanceLabelHorizontalPlacement(enum.IntEnum):
        CenteredEdge = ... # type: Qgis.ScaleBarDistanceLabelHorizontalPlacement
        CenteredSegment = ... # type: Qgis.ScaleBarDistanceLabelHorizontalPlacement

    class ScaleBarDistanceLabelVerticalPlacement(enum.IntEnum):
        AboveSegment = ... # type: Qgis.ScaleBarDistanceLabelVerticalPlacement
        BelowSegment = ... # type: Qgis.ScaleBarDistanceLabelVerticalPlacement

    class ScaleBarSegmentSizeMode(enum.IntEnum):
        Fixed = ... # type: Qgis.ScaleBarSegmentSizeMode
        FitWidth = ... # type: Qgis.ScaleBarSegmentSizeMode

    class ScaleBarAlignment(enum.IntEnum):
        Left = ... # type: Qgis.ScaleBarAlignment
        Middle = ... # type: Qgis.ScaleBarAlignment
        Right = ... # type: Qgis.ScaleBarAlignment

    class ScaleCalculationMethod(enum.IntEnum):
        HorizontalTop = ... # type: Qgis.ScaleCalculationMethod
        HorizontalMiddle = ... # type: Qgis.ScaleCalculationMethod
        HorizontalBottom = ... # type: Qgis.ScaleCalculationMethod
        HorizontalAverage = ... # type: Qgis.ScaleCalculationMethod
        AtEquator = ... # type: Qgis.ScaleCalculationMethod

    class PictureFormat(enum.IntEnum):
        SVG = ... # type: Qgis.PictureFormat
        Raster = ... # type: Qgis.PictureFormat
        Unknown = ... # type: Qgis.PictureFormat

    class LayoutRenderFlag(enum.IntFlag):
        Debug = ... # type: Qgis.LayoutRenderFlag
        OutlineOnly = ... # type: Qgis.LayoutRenderFlag
        Antialiasing = ... # type: Qgis.LayoutRenderFlag
        UseAdvancedEffects = ... # type: Qgis.LayoutRenderFlag
        ForceVectorOutput = ... # type: Qgis.LayoutRenderFlag
        HideCoverageLayer = ... # type: Qgis.LayoutRenderFlag
        DrawSelection = ... # type: Qgis.LayoutRenderFlag
        DisableTiledRasterLayerRenders = ... # type: Qgis.LayoutRenderFlag
        RenderLabelsByMapLayer = ... # type: Qgis.LayoutRenderFlag
        LosslessImageRendering = ... # type: Qgis.LayoutRenderFlag
        SynchronousLegendGraphics = ... # type: Qgis.LayoutRenderFlag
        AlwaysUseGlobalMasks = ... # type: Qgis.LayoutRenderFlag
        LimitCoverageLayerRenderToCurrentFeature = ... # type: Qgis.LayoutRenderFlag

    class LayoutUnitType(enum.IntEnum):
        PaperUnits = ... # type: Qgis.LayoutUnitType
        ScreenUnits = ... # type: Qgis.LayoutUnitType

    class LayoutUnit(enum.IntEnum):
        Millimeters = ... # type: Qgis.LayoutUnit
        Centimeters = ... # type: Qgis.LayoutUnit
        Meters = ... # type: Qgis.LayoutUnit
        Inches = ... # type: Qgis.LayoutUnit
        Feet = ... # type: Qgis.LayoutUnit
        Points = ... # type: Qgis.LayoutUnit
        Picas = ... # type: Qgis.LayoutUnit
        Pixels = ... # type: Qgis.LayoutUnit

    class RenderUnit(enum.IntEnum):
        Millimeters = ... # type: Qgis.RenderUnit
        MapUnits = ... # type: Qgis.RenderUnit
        Pixels = ... # type: Qgis.RenderUnit
        Percentage = ... # type: Qgis.RenderUnit
        Points = ... # type: Qgis.RenderUnit
        Inches = ... # type: Qgis.RenderUnit
        Unknown = ... # type: Qgis.RenderUnit
        MetersInMapUnits = ... # type: Qgis.RenderUnit

    class TemporalUnit(enum.IntEnum):
        Milliseconds = ... # type: Qgis.TemporalUnit
        Seconds = ... # type: Qgis.TemporalUnit
        Minutes = ... # type: Qgis.TemporalUnit
        Hours = ... # type: Qgis.TemporalUnit
        Days = ... # type: Qgis.TemporalUnit
        Weeks = ... # type: Qgis.TemporalUnit
        Months = ... # type: Qgis.TemporalUnit
        Years = ... # type: Qgis.TemporalUnit
        Decades = ... # type: Qgis.TemporalUnit
        Centuries = ... # type: Qgis.TemporalUnit
        IrregularStep = ... # type: Qgis.TemporalUnit
        Unknown = ... # type: Qgis.TemporalUnit

    class AngleUnit(enum.IntEnum):
        Degrees = ... # type: Qgis.AngleUnit
        Radians = ... # type: Qgis.AngleUnit
        Gon = ... # type: Qgis.AngleUnit
        MinutesOfArc = ... # type: Qgis.AngleUnit
        SecondsOfArc = ... # type: Qgis.AngleUnit
        Turn = ... # type: Qgis.AngleUnit
        MilliradiansSI = ... # type: Qgis.AngleUnit
        MilNATO = ... # type: Qgis.AngleUnit
        Unknown = ... # type: Qgis.AngleUnit

    class VolumeUnit(enum.IntEnum):
        CubicMeters = ... # type: Qgis.VolumeUnit
        CubicFeet = ... # type: Qgis.VolumeUnit
        CubicYards = ... # type: Qgis.VolumeUnit
        Barrel = ... # type: Qgis.VolumeUnit
        CubicDecimeter = ... # type: Qgis.VolumeUnit
        Liters = ... # type: Qgis.VolumeUnit
        GallonUS = ... # type: Qgis.VolumeUnit
        CubicInch = ... # type: Qgis.VolumeUnit
        CubicCentimeter = ... # type: Qgis.VolumeUnit
        CubicDegrees = ... # type: Qgis.VolumeUnit
        Unknown = ... # type: Qgis.VolumeUnit

    class AreaUnit(enum.IntEnum):
        SquareMeters = ... # type: Qgis.AreaUnit
        SquareKilometers = ... # type: Qgis.AreaUnit
        SquareFeet = ... # type: Qgis.AreaUnit
        SquareYards = ... # type: Qgis.AreaUnit
        SquareMiles = ... # type: Qgis.AreaUnit
        Hectares = ... # type: Qgis.AreaUnit
        Acres = ... # type: Qgis.AreaUnit
        SquareNauticalMiles = ... # type: Qgis.AreaUnit
        SquareDegrees = ... # type: Qgis.AreaUnit
        SquareCentimeters = ... # type: Qgis.AreaUnit
        SquareMillimeters = ... # type: Qgis.AreaUnit
        SquareInches = ... # type: Qgis.AreaUnit
        Unknown = ... # type: Qgis.AreaUnit

    class DistanceUnitType(enum.IntEnum):
        Standard = ... # type: Qgis.DistanceUnitType
        Geographic = ... # type: Qgis.DistanceUnitType
        Unknown = ... # type: Qgis.DistanceUnitType

    class DistanceUnit(enum.IntEnum):
        Meters = ... # type: Qgis.DistanceUnit
        Kilometers = ... # type: Qgis.DistanceUnit
        Feet = ... # type: Qgis.DistanceUnit
        NauticalMiles = ... # type: Qgis.DistanceUnit
        Yards = ... # type: Qgis.DistanceUnit
        Miles = ... # type: Qgis.DistanceUnit
        Degrees = ... # type: Qgis.DistanceUnit
        Centimeters = ... # type: Qgis.DistanceUnit
        Millimeters = ... # type: Qgis.DistanceUnit
        Inches = ... # type: Qgis.DistanceUnit
        ChainsInternational = ... # type: Qgis.DistanceUnit
        ChainsBritishBenoit1895A = ... # type: Qgis.DistanceUnit
        ChainsBritishBenoit1895B = ... # type: Qgis.DistanceUnit
        ChainsBritishSears1922Truncated = ... # type: Qgis.DistanceUnit
        ChainsBritishSears1922 = ... # type: Qgis.DistanceUnit
        ChainsClarkes = ... # type: Qgis.DistanceUnit
        ChainsUSSurvey = ... # type: Qgis.DistanceUnit
        FeetBritish1865 = ... # type: Qgis.DistanceUnit
        FeetBritish1936 = ... # type: Qgis.DistanceUnit
        FeetBritishBenoit1895A = ... # type: Qgis.DistanceUnit
        FeetBritishBenoit1895B = ... # type: Qgis.DistanceUnit
        FeetBritishSears1922Truncated = ... # type: Qgis.DistanceUnit
        FeetBritishSears1922 = ... # type: Qgis.DistanceUnit
        FeetClarkes = ... # type: Qgis.DistanceUnit
        FeetGoldCoast = ... # type: Qgis.DistanceUnit
        FeetIndian = ... # type: Qgis.DistanceUnit
        FeetIndian1937 = ... # type: Qgis.DistanceUnit
        FeetIndian1962 = ... # type: Qgis.DistanceUnit
        FeetIndian1975 = ... # type: Qgis.DistanceUnit
        FeetUSSurvey = ... # type: Qgis.DistanceUnit
        LinksInternational = ... # type: Qgis.DistanceUnit
        LinksBritishBenoit1895A = ... # type: Qgis.DistanceUnit
        LinksBritishBenoit1895B = ... # type: Qgis.DistanceUnit
        LinksBritishSears1922Truncated = ... # type: Qgis.DistanceUnit
        LinksBritishSears1922 = ... # type: Qgis.DistanceUnit
        LinksClarkes = ... # type: Qgis.DistanceUnit
        LinksUSSurvey = ... # type: Qgis.DistanceUnit
        YardsBritishBenoit1895A = ... # type: Qgis.DistanceUnit
        YardsBritishBenoit1895B = ... # type: Qgis.DistanceUnit
        YardsBritishSears1922Truncated = ... # type: Qgis.DistanceUnit
        YardsBritishSears1922 = ... # type: Qgis.DistanceUnit
        YardsClarkes = ... # type: Qgis.DistanceUnit
        YardsIndian = ... # type: Qgis.DistanceUnit
        YardsIndian1937 = ... # type: Qgis.DistanceUnit
        YardsIndian1962 = ... # type: Qgis.DistanceUnit
        YardsIndian1975 = ... # type: Qgis.DistanceUnit
        MilesUSSurvey = ... # type: Qgis.DistanceUnit
        Fathoms = ... # type: Qgis.DistanceUnit
        MetersGermanLegal = ... # type: Qgis.DistanceUnit
        Unknown = ... # type: Qgis.DistanceUnit

    class UnitType(enum.IntEnum):
        Distance = ... # type: Qgis.UnitType
        Area = ... # type: Qgis.UnitType
        Volume = ... # type: Qgis.UnitType
        Unknown = ... # type: Qgis.UnitType
        Temporal = ... # type: Qgis.UnitType

    class MapToolUnit(enum.IntEnum):
        Layer = ... # type: Qgis.MapToolUnit
        Pixels = ... # type: Qgis.MapToolUnit
        Project = ... # type: Qgis.MapToolUnit

    class SystemOfMeasurement(enum.IntEnum):
        Unknown = ... # type: Qgis.SystemOfMeasurement
        Metric = ... # type: Qgis.SystemOfMeasurement
        Imperial = ... # type: Qgis.SystemOfMeasurement
        USCS = ... # type: Qgis.SystemOfMeasurement

    class BlendMode(enum.IntEnum):
        Normal = ... # type: Qgis.BlendMode
        Lighten = ... # type: Qgis.BlendMode
        Screen = ... # type: Qgis.BlendMode
        Dodge = ... # type: Qgis.BlendMode
        Addition = ... # type: Qgis.BlendMode
        Darken = ... # type: Qgis.BlendMode
        Multiply = ... # type: Qgis.BlendMode
        Burn = ... # type: Qgis.BlendMode
        Overlay = ... # type: Qgis.BlendMode
        SoftLight = ... # type: Qgis.BlendMode
        HardLight = ... # type: Qgis.BlendMode
        Difference = ... # type: Qgis.BlendMode
        Subtract = ... # type: Qgis.BlendMode
        Source = ... # type: Qgis.BlendMode
        DestinationOver = ... # type: Qgis.BlendMode
        Clear = ... # type: Qgis.BlendMode
        Destination = ... # type: Qgis.BlendMode
        SourceIn = ... # type: Qgis.BlendMode
        DestinationIn = ... # type: Qgis.BlendMode
        SourceOut = ... # type: Qgis.BlendMode
        DestinationOut = ... # type: Qgis.BlendMode
        SourceAtop = ... # type: Qgis.BlendMode
        DestinationAtop = ... # type: Qgis.BlendMode
        Xor = ... # type: Qgis.BlendMode

    class ElevationMapCombineMethod(enum.IntEnum):
        HighestElevation = ... # type: Qgis.ElevationMapCombineMethod
        NewerElevation = ... # type: Qgis.ElevationMapCombineMethod

    class RasterProviderCapability(enum.IntFlag):
        NoProviderCapabilities = ... # type: Qgis.RasterProviderCapability
        ReadLayerMetadata = ... # type: Qgis.RasterProviderCapability
        WriteLayerMetadata = ... # type: Qgis.RasterProviderCapability
        ProviderHintBenefitsFromResampling = ... # type: Qgis.RasterProviderCapability
        ProviderHintCanPerformProviderResampling = ... # type: Qgis.RasterProviderCapability
        ReloadData = ... # type: Qgis.RasterProviderCapability
        DpiDependentData = ... # type: Qgis.RasterProviderCapability
        NativeRasterAttributeTable = ... # type: Qgis.RasterProviderCapability
        BuildPyramids = ... # type: Qgis.RasterProviderCapability

    class RasterInterfaceCapability(enum.IntFlag):
        NoCapabilities = ... # type: Qgis.RasterInterfaceCapability
        Size = ... # type: Qgis.RasterInterfaceCapability
        Create = ... # type: Qgis.RasterInterfaceCapability
        Remove = ... # type: Qgis.RasterInterfaceCapability
        BuildPyramids = ... # type: Qgis.RasterInterfaceCapability
        Identify = ... # type: Qgis.RasterInterfaceCapability
        IdentifyValue = ... # type: Qgis.RasterInterfaceCapability
        IdentifyText = ... # type: Qgis.RasterInterfaceCapability
        IdentifyHtml = ... # type: Qgis.RasterInterfaceCapability
        IdentifyFeature = ... # type: Qgis.RasterInterfaceCapability
        Prefetch = ... # type: Qgis.RasterInterfaceCapability

    class RasterIdentifyFormat(enum.IntFlag):
        Undefined = ... # type: Qgis.RasterIdentifyFormat
        Value = ... # type: Qgis.RasterIdentifyFormat
        Text = ... # type: Qgis.RasterIdentifyFormat
        Html = ... # type: Qgis.RasterIdentifyFormat
        Feature = ... # type: Qgis.RasterIdentifyFormat

    class RasterBuildPyramidOption(enum.IntEnum):
        No = ... # type: Qgis.RasterBuildPyramidOption
        Yes = ... # type: Qgis.RasterBuildPyramidOption
        CopyExisting = ... # type: Qgis.RasterBuildPyramidOption

    class RasterPyramidFormat(enum.IntEnum):
        GeoTiff = ... # type: Qgis.RasterPyramidFormat
        Internal = ... # type: Qgis.RasterPyramidFormat
        Erdas = ... # type: Qgis.RasterPyramidFormat

    class RasterDrawingStyle(enum.IntEnum):
        Undefined = ... # type: Qgis.RasterDrawingStyle
        SingleBandGray = ... # type: Qgis.RasterDrawingStyle
        SingleBandPseudoColor = ... # type: Qgis.RasterDrawingStyle
        PalettedColor = ... # type: Qgis.RasterDrawingStyle
        PalettedSingleBandGray = ... # type: Qgis.RasterDrawingStyle
        PalettedSingleBandPseudoColor = ... # type: Qgis.RasterDrawingStyle
        PalettedMultiBandColor = ... # type: Qgis.RasterDrawingStyle
        MultiBandSingleBandGray = ... # type: Qgis.RasterDrawingStyle
        MultiBandSingleBandPseudoColor = ... # type: Qgis.RasterDrawingStyle
        MultiBandColor = ... # type: Qgis.RasterDrawingStyle
        SingleBandColorData = ... # type: Qgis.RasterDrawingStyle

    class RasterLayerType(enum.IntEnum):
        GrayOrUndefined = ... # type: Qgis.RasterLayerType
        Palette = ... # type: Qgis.RasterLayerType
        MultiBand = ... # type: Qgis.RasterLayerType
        SingleBandColorData = ... # type: Qgis.RasterLayerType

    class RasterColorInterpretation(enum.IntEnum):
        Undefined = ... # type: Qgis.RasterColorInterpretation
        GrayIndex = ... # type: Qgis.RasterColorInterpretation
        PaletteIndex = ... # type: Qgis.RasterColorInterpretation
        RedBand = ... # type: Qgis.RasterColorInterpretation
        GreenBand = ... # type: Qgis.RasterColorInterpretation
        BlueBand = ... # type: Qgis.RasterColorInterpretation
        AlphaBand = ... # type: Qgis.RasterColorInterpretation
        HueBand = ... # type: Qgis.RasterColorInterpretation
        SaturationBand = ... # type: Qgis.RasterColorInterpretation
        LightnessBand = ... # type: Qgis.RasterColorInterpretation
        CyanBand = ... # type: Qgis.RasterColorInterpretation
        MagentaBand = ... # type: Qgis.RasterColorInterpretation
        YellowBand = ... # type: Qgis.RasterColorInterpretation
        BlackBand = ... # type: Qgis.RasterColorInterpretation
        YCbCr_YBand = ... # type: Qgis.RasterColorInterpretation
        YCbCr_CbBand = ... # type: Qgis.RasterColorInterpretation
        YCbCr_CrBand = ... # type: Qgis.RasterColorInterpretation
        ContinuousPalette = ... # type: Qgis.RasterColorInterpretation
        PanBand = ... # type: Qgis.RasterColorInterpretation
        CoastalBand = ... # type: Qgis.RasterColorInterpretation
        RedEdgeBand = ... # type: Qgis.RasterColorInterpretation
        NIRBand = ... # type: Qgis.RasterColorInterpretation
        SWIRBand = ... # type: Qgis.RasterColorInterpretation
        MWIRBand = ... # type: Qgis.RasterColorInterpretation
        LWIRBand = ... # type: Qgis.RasterColorInterpretation
        TIRBand = ... # type: Qgis.RasterColorInterpretation
        OtherIRBand = ... # type: Qgis.RasterColorInterpretation
        SAR_Ka_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_K_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_Ku_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_X_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_C_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_S_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_L_Band = ... # type: Qgis.RasterColorInterpretation
        SAR_P_Band = ... # type: Qgis.RasterColorInterpretation

    class MetadataDateType(enum.Enum):
        Created = ... # type: Qgis.MetadataDateType
        Published = ... # type: Qgis.MetadataDateType
        Revised = ... # type: Qgis.MetadataDateType
        Superseded = ... # type: Qgis.MetadataDateType

    class AttributeActionType(enum.IntEnum):
        Generic = ... # type: Qgis.AttributeActionType
        GenericPython = ... # type: Qgis.AttributeActionType
        Mac = ... # type: Qgis.AttributeActionType
        Windows = ... # type: Qgis.AttributeActionType
        Unix = ... # type: Qgis.AttributeActionType
        OpenUrl = ... # type: Qgis.AttributeActionType
        SubmitUrlEncoded = ... # type: Qgis.AttributeActionType
        SubmitUrlMultipart = ... # type: Qgis.AttributeActionType

    class MapLayerActionFlag(enum.IntFlag):
        EnabledOnlyWhenEditable = ... # type: Qgis.MapLayerActionFlag
        EnableOnlyWhenHasGeometry = ... # type: Qgis.MapLayerActionFlag

    class MapLayerActionTarget(enum.IntFlag):
        Layer = ... # type: Qgis.MapLayerActionTarget
        SingleFeature = ... # type: Qgis.MapLayerActionTarget
        MultipleFeatures = ... # type: Qgis.MapLayerActionTarget
        AllActions = ... # type: Qgis.MapLayerActionTarget

    class ActionType(enum.IntEnum):
        Invalid = ... # type: Qgis.ActionType
        MapLayerAction = ... # type: Qgis.ActionType
        AttributeAction = ... # type: Qgis.ActionType

    class LegendJsonRenderFlag(enum.IntFlag):
        ShowRuleDetails = ... # type: Qgis.LegendJsonRenderFlag

    class LegendSyncMode(enum.IntEnum):
        AllProjectLayers = ... # type: Qgis.LegendSyncMode
        VisibleLayers = ... # type: Qgis.LegendSyncMode
        Manual = ... # type: Qgis.LegendSyncMode

    class LegendComponent(enum.IntEnum):
        Undefined = ... # type: Qgis.LegendComponent
        Hidden = ... # type: Qgis.LegendComponent
        Title = ... # type: Qgis.LegendComponent
        Group = ... # type: Qgis.LegendComponent
        Subgroup = ... # type: Qgis.LegendComponent
        Symbol = ... # type: Qgis.LegendComponent
        SymbolLabel = ... # type: Qgis.LegendComponent

    class MapLayerLegendFlag(enum.IntFlag):
        ExcludeByDefault = ... # type: Qgis.MapLayerLegendFlag

    class LayerTreeFilterFlag(enum.IntFlag):
        SkipVisibilityCheck = ... # type: Qgis.LayerTreeFilterFlag

    class LayerTreeInsertionMethod(enum.IntEnum):
        AboveInsertionPoint = ... # type: Qgis.LayerTreeInsertionMethod
        TopOfTree = ... # type: Qgis.LayerTreeInsertionMethod
        OptimalInInsertionGroup = ... # type: Qgis.LayerTreeInsertionMethod

    class ScriptLanguageCapability(enum.IntFlag):
        Reformat = ... # type: Qgis.ScriptLanguageCapability
        CheckSyntax = ... # type: Qgis.ScriptLanguageCapability
        ToggleComment = ... # type: Qgis.ScriptLanguageCapability

    class ScriptLanguage(enum.IntEnum):
        Css = ... # type: Qgis.ScriptLanguage
        QgisExpression = ... # type: Qgis.ScriptLanguage
        Html = ... # type: Qgis.ScriptLanguage
        JavaScript = ... # type: Qgis.ScriptLanguage
        Json = ... # type: Qgis.ScriptLanguage
        Python = ... # type: Qgis.ScriptLanguage
        R = ... # type: Qgis.ScriptLanguage
        Sql = ... # type: Qgis.ScriptLanguage
        Batch = ... # type: Qgis.ScriptLanguage
        Bash = ... # type: Qgis.ScriptLanguage
        Unknown = ... # type: Qgis.ScriptLanguage

    class SettingsOrigin(enum.IntEnum):
        Any = ... # type: Qgis.SettingsOrigin
        Global = ... # type: Qgis.SettingsOrigin
        Local = ... # type: Qgis.SettingsOrigin

    class CoordinateDisplayType(enum.IntEnum):
        MapCrs = ... # type: Qgis.CoordinateDisplayType
        MapGeographic = ... # type: Qgis.CoordinateDisplayType
        CustomCrs = ... # type: Qgis.CoordinateDisplayType

    class RelationshipCapability(enum.IntFlag):
        MultipleFieldKeys = ... # type: Qgis.RelationshipCapability
        ForwardPathLabel = ... # type: Qgis.RelationshipCapability
        BackwardPathLabel = ... # type: Qgis.RelationshipCapability

    class RelationshipCardinality(enum.IntEnum):
        OneToOne = ... # type: Qgis.RelationshipCardinality
        OneToMany = ... # type: Qgis.RelationshipCardinality
        ManyToOne = ... # type: Qgis.RelationshipCardinality
        ManyToMany = ... # type: Qgis.RelationshipCardinality

    class RelationshipStrength(enum.IntEnum):
        Association = ... # type: Qgis.RelationshipStrength
        Composition = ... # type: Qgis.RelationshipStrength

    class RelationshipType(enum.IntEnum):
        Normal = ... # type: Qgis.RelationshipType
        Generated = ... # type: Qgis.RelationshipType

    class ArcGisRestServiceType(enum.IntEnum):
        FeatureServer = ... # type: Qgis.ArcGisRestServiceType
        MapServer = ... # type: Qgis.ArcGisRestServiceType
        ImageServer = ... # type: Qgis.ArcGisRestServiceType
        GlobeServer = ... # type: Qgis.ArcGisRestServiceType
        GPServer = ... # type: Qgis.ArcGisRestServiceType
        GeocodeServer = ... # type: Qgis.ArcGisRestServiceType
        Unknown = ... # type: Qgis.ArcGisRestServiceType
        SceneServer = ... # type: Qgis.ArcGisRestServiceType

    class MapBoxGlStyleSourceType(enum.IntEnum):
        Vector = ... # type: Qgis.MapBoxGlStyleSourceType
        Raster = ... # type: Qgis.MapBoxGlStyleSourceType
        RasterDem = ... # type: Qgis.MapBoxGlStyleSourceType
        GeoJson = ... # type: Qgis.MapBoxGlStyleSourceType
        Image = ... # type: Qgis.MapBoxGlStyleSourceType
        Video = ... # type: Qgis.MapBoxGlStyleSourceType
        Unknown = ... # type: Qgis.MapBoxGlStyleSourceType

    class ProjectCapability(enum.IntFlag):
        ProjectStyles = ... # type: Qgis.ProjectCapability

    class ProjectReadFlag(enum.IntFlag):
        DontResolveLayers = ... # type: Qgis.ProjectReadFlag
        DontLoadLayouts = ... # type: Qgis.ProjectReadFlag
        TrustLayerMetadata = ... # type: Qgis.ProjectReadFlag
        DontStoreOriginalStyles = ... # type: Qgis.ProjectReadFlag
        DontLoad3DViews = ... # type: Qgis.ProjectReadFlag
        DontLoadProjectStyles = ... # type: Qgis.ProjectReadFlag
        ForceReadOnlyLayers = ... # type: Qgis.ProjectReadFlag
        DontUpgradeAnnotations = ... # type: Qgis.ProjectReadFlag

    class ProjectFileFormat(enum.IntEnum):
        Qgz = ... # type: Qgis.ProjectFileFormat
        Qgs = ... # type: Qgis.ProjectFileFormat

    class AvoidIntersectionsMode(enum.IntEnum):
        AllowIntersections = ... # type: Qgis.AvoidIntersectionsMode
        AvoidIntersectionsCurrentLayer = ... # type: Qgis.AvoidIntersectionsMode
        AvoidIntersectionsLayers = ... # type: Qgis.AvoidIntersectionsMode

    class PointCloudDrawOrder(enum.IntEnum):
        Default = ... # type: Qgis.PointCloudDrawOrder
        BottomToTop = ... # type: Qgis.PointCloudDrawOrder
        TopToBottom = ... # type: Qgis.PointCloudDrawOrder

    class PointCloudSymbol(enum.IntEnum):
        Square = ... # type: Qgis.PointCloudSymbol
        Circle = ... # type: Qgis.PointCloudSymbol

    class ProfileExportType(enum.IntEnum):
        Features3D = ... # type: Qgis.ProfileExportType
        Profile2D = ... # type: Qgis.ProfileExportType
        DistanceVsElevationTable = ... # type: Qgis.ProfileExportType

    class ProfileGeneratorFlag(enum.IntFlag):
        RespectsMaximumErrorMapUnit = ... # type: Qgis.ProfileGeneratorFlag
        RespectsDistanceRange = ... # type: Qgis.ProfileGeneratorFlag
        RespectsElevationRange = ... # type: Qgis.ProfileGeneratorFlag

    class PointCloudProfileType(enum.IntEnum):
        IndividualPoints = ... # type: Qgis.PointCloudProfileType
        TriangulatedSurface = ... # type: Qgis.PointCloudProfileType

    class VectorProfileType(enum.IntEnum):
        IndividualFeatures = ... # type: Qgis.VectorProfileType
        ContinuousSurface = ... # type: Qgis.VectorProfileType

    class ProfileSurfaceSymbology(enum.IntEnum):
        Line = ... # type: Qgis.ProfileSurfaceSymbology
        FillBelow = ... # type: Qgis.ProfileSurfaceSymbology
        FillAbove = ... # type: Qgis.ProfileSurfaceSymbology

    class VerticalAxisInversion(enum.IntEnum):
        Never = ... # type: Qgis.VerticalAxisInversion
        WhenDragging = ... # type: Qgis.VerticalAxisInversion
        Always = ... # type: Qgis.VerticalAxisInversion

    class SceneMode(enum.IntEnum):
        Local = ... # type: Qgis.SceneMode
        Globe = ... # type: Qgis.SceneMode

    class NavigationMode(enum.IntEnum):
        TerrainBased = ... # type: Qgis.NavigationMode
        Walk = ... # type: Qgis.NavigationMode
        GlobeTerrainBased = ... # type: Qgis.NavigationMode

    class LightSourceType(enum.IntEnum):
        Point = ... # type: Qgis.LightSourceType
        Directional = ... # type: Qgis.LightSourceType

    class Point3DShape(enum.IntEnum):
        Cylinder = ... # type: Qgis.Point3DShape
        Sphere = ... # type: Qgis.Point3DShape
        Cone = ... # type: Qgis.Point3DShape
        Cube = ... # type: Qgis.Point3DShape
        Torus = ... # type: Qgis.Point3DShape
        Plane = ... # type: Qgis.Point3DShape
        ExtrudedText = ... # type: Qgis.Point3DShape
        Model = ... # type: Qgis.Point3DShape
        Billboard = ... # type: Qgis.Point3DShape

    class PlotToolFlag(enum.IntFlag):
        ShowContextMenu = ... # type: Qgis.PlotToolFlag

    class ProjectFlag(enum.IntFlag):
        EvaluateDefaultValuesOnProviderSide = ... # type: Qgis.ProjectFlag
        TrustStoredLayerStatistics = ... # type: Qgis.ProjectFlag
        RememberLayerEditStatusBetweenSessions = ... # type: Qgis.ProjectFlag
        RememberAttributeTableWindowsBetweenSessions = ... # type: Qgis.ProjectFlag

    class CadMeasurementDisplayType(enum.IntEnum):
        Hidden = ... # type: Qgis.CadMeasurementDisplayType
        Cartesian = ... # type: Qgis.CadMeasurementDisplayType
        Ellipsoidal = ... # type: Qgis.CadMeasurementDisplayType

    class CadConstraintType(enum.IntEnum):
        Generic = ... # type: Qgis.CadConstraintType
        Angle = ... # type: Qgis.CadConstraintType
        Distance = ... # type: Qgis.CadConstraintType
        XCoordinate = ... # type: Qgis.CadConstraintType
        YCoordinate = ... # type: Qgis.CadConstraintType
        ZValue = ... # type: Qgis.CadConstraintType
        MValue = ... # type: Qgis.CadConstraintType

    class LineExtensionSide(enum.IntEnum):
        BeforeVertex = ... # type: Qgis.LineExtensionSide
        AfterVertex = ... # type: Qgis.LineExtensionSide
        NoVertex = ... # type: Qgis.LineExtensionSide

    class BetweenLineConstraint(enum.IntEnum):
        NoConstraint = ... # type: Qgis.BetweenLineConstraint
        Perpendicular = ... # type: Qgis.BetweenLineConstraint
        Parallel = ... # type: Qgis.BetweenLineConstraint

    class MeshElevationMode(enum.IntEnum):
        FixedElevationRange = ... # type: Qgis.MeshElevationMode
        FromVertices = ... # type: Qgis.MeshElevationMode
        FixedRangePerGroup = ... # type: Qgis.MeshElevationMode

    class RasterElevationMode(enum.IntEnum):
        FixedElevationRange = ... # type: Qgis.RasterElevationMode
        RepresentsElevationSurface = ... # type: Qgis.RasterElevationMode
        FixedRangePerBand = ... # type: Qgis.RasterElevationMode
        DynamicRangePerBand = ... # type: Qgis.RasterElevationMode

    class RangeLimits(enum.IntEnum):
        IncludeBoth = ... # type: Qgis.RangeLimits
        IncludeLowerExcludeUpper = ... # type: Qgis.RangeLimits
        ExcludeLowerIncludeUpper = ... # type: Qgis.RangeLimits
        ExcludeBoth = ... # type: Qgis.RangeLimits

    class AltitudeBinding(enum.IntEnum):
        Vertex = ... # type: Qgis.AltitudeBinding
        Centroid = ... # type: Qgis.AltitudeBinding

    class AltitudeClamping(enum.IntEnum):
        Absolute = ... # type: Qgis.AltitudeClamping
        Relative = ... # type: Qgis.AltitudeClamping
        Terrain = ... # type: Qgis.AltitudeClamping

    class TransactionMode(enum.IntEnum):
        Disabled = ... # type: Qgis.TransactionMode
        AutomaticGroups = ... # type: Qgis.TransactionMode
        BufferedGroups = ... # type: Qgis.TransactionMode

    class FieldDomainType(enum.IntEnum):
        Coded = ... # type: Qgis.FieldDomainType
        Range = ... # type: Qgis.FieldDomainType
        Glob = ... # type: Qgis.FieldDomainType

    class FieldDuplicatePolicy(enum.IntEnum):
        DefaultValue = ... # type: Qgis.FieldDuplicatePolicy
        Duplicate = ... # type: Qgis.FieldDuplicatePolicy
        UnsetField = ... # type: Qgis.FieldDuplicatePolicy

    class FieldDomainMergePolicy(enum.IntEnum):
        DefaultValue = ... # type: Qgis.FieldDomainMergePolicy
        Sum = ... # type: Qgis.FieldDomainMergePolicy
        GeometryWeighted = ... # type: Qgis.FieldDomainMergePolicy
        UnsetField = ... # type: Qgis.FieldDomainMergePolicy
        LargestGeometry = ... # type: Qgis.FieldDomainMergePolicy
        MinimumValue = ... # type: Qgis.FieldDomainMergePolicy
        MaximumValue = ... # type: Qgis.FieldDomainMergePolicy
        SetToNull = ... # type: Qgis.FieldDomainMergePolicy

    class FieldDomainSplitPolicy(enum.IntEnum):
        DefaultValue = ... # type: Qgis.FieldDomainSplitPolicy
        Duplicate = ... # type: Qgis.FieldDomainSplitPolicy
        GeometryRatio = ... # type: Qgis.FieldDomainSplitPolicy
        UnsetField = ... # type: Qgis.FieldDomainSplitPolicy

    class CrsDefinitionFormat(enum.IntEnum):
        Wkt = ... # type: Qgis.CrsDefinitionFormat
        Proj = ... # type: Qgis.CrsDefinitionFormat

    class ProcessingTinInputLayerType(enum.IntEnum):
        Vertices = ... # type: Qgis.ProcessingTinInputLayerType
        StructureLines = ... # type: Qgis.ProcessingTinInputLayerType
        BreakLines = ... # type: Qgis.ProcessingTinInputLayerType

    class ProcessingModelChildAlgorithmExecutionStatus(enum.IntEnum):
        NotExecuted = ... # type: Qgis.ProcessingModelChildAlgorithmExecutionStatus
        Success = ... # type: Qgis.ProcessingModelChildAlgorithmExecutionStatus
        Failed = ... # type: Qgis.ProcessingModelChildAlgorithmExecutionStatus

    class ProcessingModelChildParameterSource(enum.IntEnum):
        ModelParameter = ... # type: Qgis.ProcessingModelChildParameterSource
        ChildOutput = ... # type: Qgis.ProcessingModelChildParameterSource
        StaticValue = ... # type: Qgis.ProcessingModelChildParameterSource
        Expression = ... # type: Qgis.ProcessingModelChildParameterSource
        ExpressionText = ... # type: Qgis.ProcessingModelChildParameterSource
        ModelOutput = ... # type: Qgis.ProcessingModelChildParameterSource

    class ProcessingDateTimeParameterDataType(enum.IntEnum):
        DateTime = ... # type: Qgis.ProcessingDateTimeParameterDataType
        Date = ... # type: Qgis.ProcessingDateTimeParameterDataType
        Time = ... # type: Qgis.ProcessingDateTimeParameterDataType

    class ProcessingFieldParameterDataType(enum.IntEnum):
        Any = ... # type: Qgis.ProcessingFieldParameterDataType
        Numeric = ... # type: Qgis.ProcessingFieldParameterDataType
        String = ... # type: Qgis.ProcessingFieldParameterDataType
        DateTime = ... # type: Qgis.ProcessingFieldParameterDataType
        Binary = ... # type: Qgis.ProcessingFieldParameterDataType
        Boolean = ... # type: Qgis.ProcessingFieldParameterDataType

    class ProcessingNumberParameterType(enum.IntEnum):
        Integer = ... # type: Qgis.ProcessingNumberParameterType
        Double = ... # type: Qgis.ProcessingNumberParameterType

    class ProcessingFileParameterBehavior(enum.IntEnum):
        File = ... # type: Qgis.ProcessingFileParameterBehavior
        Folder = ... # type: Qgis.ProcessingFileParameterBehavior

    class ProcessingParameterFlag(enum.IntFlag):
        Advanced = ... # type: Qgis.ProcessingParameterFlag
        Hidden = ... # type: Qgis.ProcessingParameterFlag
        Optional = ... # type: Qgis.ProcessingParameterFlag
        IsModelOutput = ... # type: Qgis.ProcessingParameterFlag

    class ProcessingParameterTypeFlag(enum.IntFlag):
        ExposeToModeler = ... # type: Qgis.ProcessingParameterTypeFlag

    class ProcessingFeatureSourceFlag(enum.IntFlag):
        SkipGeometryValidityChecks = ... # type: Qgis.ProcessingFeatureSourceFlag

    class ProcessingFeatureSourceDefinitionFlag(enum.IntFlag):
        OverrideDefaultGeometryCheck = ... # type: Qgis.ProcessingFeatureSourceDefinitionFlag
        CreateIndividualOutputPerInputFeature = ... # type: Qgis.ProcessingFeatureSourceDefinitionFlag

    class ProcessingMode(enum.Enum):
        Standard = ... # type: Qgis.ProcessingMode
        Batch = ... # type: Qgis.ProcessingMode
        Modeler = ... # type: Qgis.ProcessingMode

    class ProcessingLogLevel(enum.IntEnum):
        DefaultLevel = ... # type: Qgis.ProcessingLogLevel
        Verbose = ... # type: Qgis.ProcessingLogLevel
        ModelDebug = ... # type: Qgis.ProcessingLogLevel

    class ProcessingPropertyAvailability(enum.IntEnum):
        NotAvailable = ... # type: Qgis.ProcessingPropertyAvailability
        Available = ... # type: Qgis.ProcessingPropertyAvailability

    class ProcessingAlgorithmDocumentationFlag(enum.IntFlag):
        RegeneratesPrimaryKey = ... # type: Qgis.ProcessingAlgorithmDocumentationFlag
        RegeneratesPrimaryKeyInSomeScenarios = ... # type: Qgis.ProcessingAlgorithmDocumentationFlag
        RespectsEllipsoid = ... # type: Qgis.ProcessingAlgorithmDocumentationFlag

    class ProcessingAlgorithmFlag(enum.IntFlag):
        HideFromToolbox = ... # type: Qgis.ProcessingAlgorithmFlag
        HideFromModeler = ... # type: Qgis.ProcessingAlgorithmFlag
        SupportsBatch = ... # type: Qgis.ProcessingAlgorithmFlag
        CanCancel = ... # type: Qgis.ProcessingAlgorithmFlag
        RequiresMatchingCrs = ... # type: Qgis.ProcessingAlgorithmFlag
        NoThreading = ... # type: Qgis.ProcessingAlgorithmFlag
        DisplayNameIsLiteral = ... # type: Qgis.ProcessingAlgorithmFlag
        SupportsInPlaceEdits = ... # type: Qgis.ProcessingAlgorithmFlag
        KnownIssues = ... # type: Qgis.ProcessingAlgorithmFlag
        CustomException = ... # type: Qgis.ProcessingAlgorithmFlag
        PruneModelBranchesBasedOnAlgorithmResults = ... # type: Qgis.ProcessingAlgorithmFlag
        SkipGenericModelLogging = ... # type: Qgis.ProcessingAlgorithmFlag
        NotAvailableInStandaloneTool = ... # type: Qgis.ProcessingAlgorithmFlag
        RequiresProject = ... # type: Qgis.ProcessingAlgorithmFlag
        SecurityRisk = ... # type: Qgis.ProcessingAlgorithmFlag
        Deprecated = ... # type: Qgis.ProcessingAlgorithmFlag

    class ProcessingProviderFlag(enum.IntFlag):
        DeemphasiseSearchResults = ... # type: Qgis.ProcessingProviderFlag
        CompatibleWithVirtualRaster = ... # type: Qgis.ProcessingProviderFlag

    class ProcessingSourceType(enum.IntEnum):
        MapLayer = ... # type: Qgis.ProcessingSourceType
        VectorAnyGeometry = ... # type: Qgis.ProcessingSourceType
        VectorPoint = ... # type: Qgis.ProcessingSourceType
        VectorLine = ... # type: Qgis.ProcessingSourceType
        VectorPolygon = ... # type: Qgis.ProcessingSourceType
        Raster = ... # type: Qgis.ProcessingSourceType
        File = ... # type: Qgis.ProcessingSourceType
        Vector = ... # type: Qgis.ProcessingSourceType
        Mesh = ... # type: Qgis.ProcessingSourceType
        Plugin = ... # type: Qgis.ProcessingSourceType
        PointCloud = ... # type: Qgis.ProcessingSourceType
        Annotation = ... # type: Qgis.ProcessingSourceType
        VectorTile = ... # type: Qgis.ProcessingSourceType
        TiledScene = ... # type: Qgis.ProcessingSourceType

    class QueryStorageBackend(enum.IntEnum):
        LocalProfile = ... # type: Qgis.QueryStorageBackend
        CurrentProject = ... # type: Qgis.QueryStorageBackend

    class HistoryProviderBackend(enum.IntFlag):
        LocalProfile = ... # type: Qgis.HistoryProviderBackend

    class MapRecenteringMode(enum.Enum):
        Always = ... # type: Qgis.MapRecenteringMode
        WhenOutsideVisibleExtent = ... # type: Qgis.MapRecenteringMode
        Never = ... # type: Qgis.MapRecenteringMode

    class ViewSyncModeFlag(enum.IntFlag):
        Sync3DTo2D = ... # type: Qgis.ViewSyncModeFlag
        Sync2DTo3D = ... # type: Qgis.ViewSyncModeFlag

    class MapCanvasFlag(enum.IntFlag):
        ShowMainAnnotationLayer = ... # type: Qgis.MapCanvasFlag

    class RendererUsage(enum.IntEnum):
        View = ... # type: Qgis.RendererUsage
        Export = ... # type: Qgis.RendererUsage
        Unknown = ... # type: Qgis.RendererUsage

    class AngularDirection(enum.IntEnum):
        Clockwise = ... # type: Qgis.AngularDirection
        CounterClockwise = ... # type: Qgis.AngularDirection
        NoOrientation = ... # type: Qgis.AngularDirection

    class ScaleToTileZoomLevelMethod(enum.IntEnum):
        MapBox = ... # type: Qgis.ScaleToTileZoomLevelMethod
        Esri = ... # type: Qgis.ScaleToTileZoomLevelMethod

    class TextRendererFlag(enum.IntFlag):
        WrapLines = ... # type: Qgis.TextRendererFlag

    class Capitalization(enum.IntEnum):
        MixedCase = ... # type: Qgis.Capitalization
        AllUppercase = ... # type: Qgis.Capitalization
        AllLowercase = ... # type: Qgis.Capitalization
        ForceFirstLetterToCapital = ... # type: Qgis.Capitalization
        SmallCaps = ... # type: Qgis.Capitalization
        TitleCase = ... # type: Qgis.Capitalization
        UpperCamelCase = ... # type: Qgis.Capitalization
        AllSmallCaps = ... # type: Qgis.Capitalization

    class TilePixelRatio(enum.Enum):
        Undefined = ... # type: Qgis.TilePixelRatio
        StandardDpi = ... # type: Qgis.TilePixelRatio
        HighDpi = ... # type: Qgis.TilePixelRatio

    class DpiMode(enum.Enum):
        All = ... # type: Qgis.DpiMode
        Off = ... # type: Qgis.DpiMode
        QGIS = ... # type: Qgis.DpiMode
        UMN = ... # type: Qgis.DpiMode
        GeoServer = ... # type: Qgis.DpiMode

    class PieChartLabelType(enum.IntEnum):
        NoLabels = ... # type: Qgis.PieChartLabelType
        Categories = ... # type: Qgis.PieChartLabelType
        Values = ... # type: Qgis.PieChartLabelType

    class PlotAxisType(enum.Enum):
        Interval = ... # type: Qgis.PlotAxisType
        Categorical = ... # type: Qgis.PlotAxisType

    class PlotAxisSuffixPlacement(enum.Enum):
        NoLabels = ... # type: Qgis.PlotAxisSuffixPlacement
        EveryLabel = ... # type: Qgis.PlotAxisSuffixPlacement
        FirstLabel = ... # type: Qgis.PlotAxisSuffixPlacement
        LastLabel = ... # type: Qgis.PlotAxisSuffixPlacement
        FirstAndLastLabels = ... # type: Qgis.PlotAxisSuffixPlacement

    class GraduatedMethod(enum.IntEnum):
        Color = ... # type: Qgis.GraduatedMethod
        Size = ... # type: Qgis.GraduatedMethod

    class DashPatternSizeAdjustment(enum.IntEnum):
        ScaleBothDashAndGap = ... # type: Qgis.DashPatternSizeAdjustment
        ScaleDashOnly = ... # type: Qgis.DashPatternSizeAdjustment
        ScaleGapOnly = ... # type: Qgis.DashPatternSizeAdjustment

    class DashPatternLineEndingRule(enum.IntEnum):
        NoRule = ... # type: Qgis.DashPatternLineEndingRule
        FullDash = ... # type: Qgis.DashPatternLineEndingRule
        HalfDash = ... # type: Qgis.DashPatternLineEndingRule
        FullGap = ... # type: Qgis.DashPatternLineEndingRule
        HalfGap = ... # type: Qgis.DashPatternLineEndingRule

    class LineClipMode(enum.IntEnum):
        ClipPainterOnly = ... # type: Qgis.LineClipMode
        ClipToIntersection = ... # type: Qgis.LineClipMode
        NoClipping = ... # type: Qgis.LineClipMode

    class MarkerClipMode(enum.IntEnum):
        NoClipping = ... # type: Qgis.MarkerClipMode
        Shape = ... # type: Qgis.MarkerClipMode
        CentroidWithin = ... # type: Qgis.MarkerClipMode
        CompletelyWithin = ... # type: Qgis.MarkerClipMode

    class PointCountMethod(enum.IntEnum):
        Absolute = ... # type: Qgis.PointCountMethod
        DensityBased = ... # type: Qgis.PointCountMethod

    class GradientSpread(enum.IntEnum):
        Pad = ... # type: Qgis.GradientSpread
        Reflect = ... # type: Qgis.GradientSpread
        Repeat = ... # type: Qgis.GradientSpread

    class SymbolCoordinateReference(enum.IntEnum):
        Feature = ... # type: Qgis.SymbolCoordinateReference
        Viewport = ... # type: Qgis.SymbolCoordinateReference

    class GradientType(enum.IntEnum):
        Linear = ... # type: Qgis.GradientType
        Radial = ... # type: Qgis.GradientType
        Conical = ... # type: Qgis.GradientType

    class GradientColorSource(enum.IntEnum):
        SimpleTwoColor = ... # type: Qgis.GradientColorSource
        ColorRamp = ... # type: Qgis.GradientColorSource

    class LinearReferencingLabelSource(enum.IntEnum):
        CartesianDistance2D = ... # type: Qgis.LinearReferencingLabelSource
        Z = ... # type: Qgis.LinearReferencingLabelSource
        M = ... # type: Qgis.LinearReferencingLabelSource

    class LinearReferencingPlacement(enum.IntFlag):
        IntervalCartesian2D = ... # type: Qgis.LinearReferencingPlacement
        IntervalZ = ... # type: Qgis.LinearReferencingPlacement
        IntervalM = ... # type: Qgis.LinearReferencingPlacement
        Vertex = ... # type: Qgis.LinearReferencingPlacement

    class MarkerLinePlacement(enum.IntFlag):
        Interval = ... # type: Qgis.MarkerLinePlacement
        Vertex = ... # type: Qgis.MarkerLinePlacement
        LastVertex = ... # type: Qgis.MarkerLinePlacement
        FirstVertex = ... # type: Qgis.MarkerLinePlacement
        CentralPoint = ... # type: Qgis.MarkerLinePlacement
        CurvePoint = ... # type: Qgis.MarkerLinePlacement
        SegmentCenter = ... # type: Qgis.MarkerLinePlacement
        InnerVertices = ... # type: Qgis.MarkerLinePlacement

    class MarkerShape(enum.IntEnum):
        Square = ... # type: Qgis.MarkerShape
        Diamond = ... # type: Qgis.MarkerShape
        Pentagon = ... # type: Qgis.MarkerShape
        Hexagon = ... # type: Qgis.MarkerShape
        Triangle = ... # type: Qgis.MarkerShape
        EquilateralTriangle = ... # type: Qgis.MarkerShape
        Star = ... # type: Qgis.MarkerShape
        Arrow = ... # type: Qgis.MarkerShape
        Circle = ... # type: Qgis.MarkerShape
        Cross = ... # type: Qgis.MarkerShape
        CrossFill = ... # type: Qgis.MarkerShape
        Cross2 = ... # type: Qgis.MarkerShape
        Line = ... # type: Qgis.MarkerShape
        ArrowHead = ... # type: Qgis.MarkerShape
        ArrowHeadFilled = ... # type: Qgis.MarkerShape
        SemiCircle = ... # type: Qgis.MarkerShape
        ThirdCircle = ... # type: Qgis.MarkerShape
        QuarterCircle = ... # type: Qgis.MarkerShape
        QuarterSquare = ... # type: Qgis.MarkerShape
        HalfSquare = ... # type: Qgis.MarkerShape
        DiagonalHalfSquare = ... # type: Qgis.MarkerShape
        RightHalfTriangle = ... # type: Qgis.MarkerShape
        LeftHalfTriangle = ... # type: Qgis.MarkerShape
        Octagon = ... # type: Qgis.MarkerShape
        SquareWithCorners = ... # type: Qgis.MarkerShape
        AsteriskFill = ... # type: Qgis.MarkerShape
        HalfArc = ... # type: Qgis.MarkerShape
        ThirdArc = ... # type: Qgis.MarkerShape
        QuarterArc = ... # type: Qgis.MarkerShape
        ParallelogramRight = ... # type: Qgis.MarkerShape
        ParallelogramLeft = ... # type: Qgis.MarkerShape
        Trapezoid = ... # type: Qgis.MarkerShape
        Shield = ... # type: Qgis.MarkerShape
        DiamondStar = ... # type: Qgis.MarkerShape
        Heart = ... # type: Qgis.MarkerShape
        Decagon = ... # type: Qgis.MarkerShape
        RoundedSquare = ... # type: Qgis.MarkerShape

    class VertexType(enum.IntEnum):
        Segment = ... # type: Qgis.VertexType
        Curve = ... # type: Qgis.VertexType
        ControlPoint = ... # type: Qgis.VertexType

    class SelectiveMaskSourceType(enum.IntEnum):
        SymbolLayer = ... # type: Qgis.SelectiveMaskSourceType
        Label = ... # type: Qgis.SelectiveMaskSourceType

    class RenderSubcomponentProperty(enum.IntEnum):
        Generic = ... # type: Qgis.RenderSubcomponentProperty
        ShadowOffset = ... # type: Qgis.RenderSubcomponentProperty
        BlurSize = ... # type: Qgis.RenderSubcomponentProperty
        GlowSpread = ... # type: Qgis.RenderSubcomponentProperty

    class VectorRenderingSimplificationFlag(enum.IntFlag):
        NoSimplification = ... # type: Qgis.VectorRenderingSimplificationFlag
        GeometrySimplification = ... # type: Qgis.VectorRenderingSimplificationFlag
        AntialiasingSimplification = ... # type: Qgis.VectorRenderingSimplificationFlag
        FullSimplification = ... # type: Qgis.VectorRenderingSimplificationFlag

    class VectorSimplificationAlgorithm(enum.IntEnum):
        Distance = ... # type: Qgis.VectorSimplificationAlgorithm
        SnapToGrid = ... # type: Qgis.VectorSimplificationAlgorithm
        Visvalingam = ... # type: Qgis.VectorSimplificationAlgorithm
        SnappedToGridGlobal = ... # type: Qgis.VectorSimplificationAlgorithm

    class CurvedTextFlag(enum.IntFlag):
        TruncateStringWhenLineIsTooShort = ... # type: Qgis.CurvedTextFlag
        UseBaselinePlacement = ... # type: Qgis.CurvedTextFlag
        UprightCharactersOnly = ... # type: Qgis.CurvedTextFlag
        ExtendLineToFitText = ... # type: Qgis.CurvedTextFlag

    class TextCharacterVerticalAlignment(enum.IntEnum):
        Normal = ... # type: Qgis.TextCharacterVerticalAlignment
        SuperScript = ... # type: Qgis.TextCharacterVerticalAlignment
        SubScript = ... # type: Qgis.TextCharacterVerticalAlignment

    class TextVerticalAlignment(enum.IntEnum):
        Top = ... # type: Qgis.TextVerticalAlignment
        VerticalCenter = ... # type: Qgis.TextVerticalAlignment
        Bottom = ... # type: Qgis.TextVerticalAlignment

    class TextHorizontalAlignment(enum.IntEnum):
        Left = ... # type: Qgis.TextHorizontalAlignment
        Center = ... # type: Qgis.TextHorizontalAlignment
        Right = ... # type: Qgis.TextHorizontalAlignment
        Justify = ... # type: Qgis.TextHorizontalAlignment

    class TextComponent(enum.IntFlag):
        Text = ... # type: Qgis.TextComponent
        Buffer = ... # type: Qgis.TextComponent
        Background = ... # type: Qgis.TextComponent
        Shadow = ... # type: Qgis.TextComponent

    class TextLayoutMode(enum.IntEnum):
        Rectangle = ... # type: Qgis.TextLayoutMode
        Point = ... # type: Qgis.TextLayoutMode
        Labeling = ... # type: Qgis.TextLayoutMode
        RectangleCapHeightBased = ... # type: Qgis.TextLayoutMode
        RectangleAscentBased = ... # type: Qgis.TextLayoutMode

    class TextOrientation(enum.IntEnum):
        Horizontal = ... # type: Qgis.TextOrientation
        Vertical = ... # type: Qgis.TextOrientation
        RotationBased = ... # type: Qgis.TextOrientation

    class LabelPlacementEngineVersion(enum.IntEnum):
        Version1 = ... # type: Qgis.LabelPlacementEngineVersion
        Version2 = ... # type: Qgis.LabelPlacementEngineVersion

    class LabelingFlag(enum.IntFlag):
        UseAllLabels = ... # type: Qgis.LabelingFlag
        UsePartialCandidates = ... # type: Qgis.LabelingFlag
        RenderOutlineLabels = ... # type: Qgis.LabelingFlag
        DrawLabelRectOnly = ... # type: Qgis.LabelingFlag
        DrawCandidates = ... # type: Qgis.LabelingFlag
        DrawUnplacedLabels = ... # type: Qgis.LabelingFlag
        CollectUnplacedLabels = ... # type: Qgis.LabelingFlag
        DrawLabelMetrics = ... # type: Qgis.LabelingFlag

    class TextRenderFormat(enum.IntEnum):
        AlwaysOutlines = ... # type: Qgis.TextRenderFormat
        AlwaysText = ... # type: Qgis.TextRenderFormat
        PreferText = ... # type: Qgis.TextRenderFormat

    class PaintEffectFlag(enum.IntFlag):
        RequiresRasterization = ... # type: Qgis.PaintEffectFlag

    class MapLayerRendererFlag(enum.IntFlag):
        RenderPartialOutputs = ... # type: Qgis.MapLayerRendererFlag
        RenderPartialOutputOverPreviousCachedImage = ... # type: Qgis.MapLayerRendererFlag
        AffectsLabeling = ... # type: Qgis.MapLayerRendererFlag

    class RenderContextFlag(enum.IntFlag):
        DrawEditingInfo = ... # type: Qgis.RenderContextFlag
        ForceVectorOutput = ... # type: Qgis.RenderContextFlag
        UseAdvancedEffects = ... # type: Qgis.RenderContextFlag
        UseRenderingOptimization = ... # type: Qgis.RenderContextFlag
        DrawSelection = ... # type: Qgis.RenderContextFlag
        DrawSymbolBounds = ... # type: Qgis.RenderContextFlag
        RenderMapTile = ... # type: Qgis.RenderContextFlag
        Antialiasing = ... # type: Qgis.RenderContextFlag
        RenderPartialOutput = ... # type: Qgis.RenderContextFlag
        RenderPreviewJob = ... # type: Qgis.RenderContextFlag
        RenderBlocking = ... # type: Qgis.RenderContextFlag
        RenderSymbolPreview = ... # type: Qgis.RenderContextFlag
        LosslessImageRendering = ... # type: Qgis.RenderContextFlag
        ApplyScalingWorkaroundForTextRendering = ... # type: Qgis.RenderContextFlag
        Render3DMap = ... # type: Qgis.RenderContextFlag
        ApplyClipAfterReprojection = ... # type: Qgis.RenderContextFlag
        RenderingSubSymbol = ... # type: Qgis.RenderContextFlag
        HighQualityImageTransforms = ... # type: Qgis.RenderContextFlag
        SkipSymbolRendering = ... # type: Qgis.RenderContextFlag
        RecordProfile = ... # type: Qgis.RenderContextFlag
        AlwaysUseGlobalMasks = ... # type: Qgis.RenderContextFlag
        DisableSymbolClippingToExtent = ... # type: Qgis.RenderContextFlag
        RenderLayerTree = ... # type: Qgis.RenderContextFlag

    class MapSettingsFlag(enum.IntFlag):
        Antialiasing = ... # type: Qgis.MapSettingsFlag
        DrawEditingInfo = ... # type: Qgis.MapSettingsFlag
        ForceVectorOutput = ... # type: Qgis.MapSettingsFlag
        UseAdvancedEffects = ... # type: Qgis.MapSettingsFlag
        DrawLabeling = ... # type: Qgis.MapSettingsFlag
        UseRenderingOptimization = ... # type: Qgis.MapSettingsFlag
        DrawSelection = ... # type: Qgis.MapSettingsFlag
        DrawSymbolBounds = ... # type: Qgis.MapSettingsFlag
        RenderMapTile = ... # type: Qgis.MapSettingsFlag
        RenderPartialOutput = ... # type: Qgis.MapSettingsFlag
        RenderPreviewJob = ... # type: Qgis.MapSettingsFlag
        RenderBlocking = ... # type: Qgis.MapSettingsFlag
        LosslessImageRendering = ... # type: Qgis.MapSettingsFlag
        Render3DMap = ... # type: Qgis.MapSettingsFlag
        HighQualityImageTransforms = ... # type: Qgis.MapSettingsFlag
        SkipSymbolRendering = ... # type: Qgis.MapSettingsFlag
        ForceRasterMasks = ... # type: Qgis.MapSettingsFlag
        RecordProfile = ... # type: Qgis.MapSettingsFlag
        AlwaysUseGlobalMasks = ... # type: Qgis.MapSettingsFlag

    class RasterizedRenderingPolicy(enum.IntEnum):
        Default = ... # type: Qgis.RasterizedRenderingPolicy
        PreferVector = ... # type: Qgis.RasterizedRenderingPolicy
        ForceVector = ... # type: Qgis.RasterizedRenderingPolicy

    class CoordinateTransformationFlag(enum.IntFlag):
        BallparkTransformsAreAppropriate = ... # type: Qgis.CoordinateTransformationFlag
        IgnoreImpossibleTransformations = ... # type: Qgis.CoordinateTransformationFlag

    class TransformDirection(enum.IntEnum):
        Forward = ... # type: Qgis.TransformDirection
        Reverse = ... # type: Qgis.TransformDirection

    class RasterTemporalCapabilityFlag(enum.IntFlag):
        RequestedTimesMustExactlyMatchAllAvailableTemporalRanges = ... # type: Qgis.RasterTemporalCapabilityFlag

    class TemporalIntervalMatchMethod(enum.IntEnum):
        MatchUsingWholeRange = ... # type: Qgis.TemporalIntervalMatchMethod
        MatchExactUsingStartOfRange = ... # type: Qgis.TemporalIntervalMatchMethod
        MatchExactUsingEndOfRange = ... # type: Qgis.TemporalIntervalMatchMethod
        FindClosestMatchToStartOfRange = ... # type: Qgis.TemporalIntervalMatchMethod
        FindClosestMatchToEndOfRange = ... # type: Qgis.TemporalIntervalMatchMethod

    class RasterTemporalMode(enum.IntEnum):
        FixedTemporalRange = ... # type: Qgis.RasterTemporalMode
        TemporalRangeFromDataProvider = ... # type: Qgis.RasterTemporalMode
        RedrawLayerOnly = ... # type: Qgis.RasterTemporalMode
        FixedRangePerBand = ... # type: Qgis.RasterTemporalMode
        RepresentsTemporalValues = ... # type: Qgis.RasterTemporalMode
        FixedDateTime = ... # type: Qgis.RasterTemporalMode

    class VectorDataProviderTemporalMode(enum.IntEnum):
        HasFixedTemporalRange = ... # type: Qgis.VectorDataProviderTemporalMode
        StoresFeatureDateTimeInstantInField = ... # type: Qgis.VectorDataProviderTemporalMode
        StoresFeatureDateTimeStartAndEndInSeparateFields = ... # type: Qgis.VectorDataProviderTemporalMode

    class VectorTemporalLimitMode(enum.IntEnum):
        IncludeBeginExcludeEnd = ... # type: Qgis.VectorTemporalLimitMode
        IncludeBeginIncludeEnd = ... # type: Qgis.VectorTemporalLimitMode

    class VectorTemporalMode(enum.IntEnum):
        FixedTemporalRange = ... # type: Qgis.VectorTemporalMode
        FeatureDateTimeInstantFromField = ... # type: Qgis.VectorTemporalMode
        FeatureDateTimeStartAndEndFromFields = ... # type: Qgis.VectorTemporalMode
        FeatureDateTimeStartAndDurationFromFields = ... # type: Qgis.VectorTemporalMode
        FeatureDateTimeStartAndEndFromExpressions = ... # type: Qgis.VectorTemporalMode
        RedrawLayerOnly = ... # type: Qgis.VectorTemporalMode

    class PlaybackOperation(enum.IntEnum):
        SkipToStart = ... # type: Qgis.PlaybackOperation
        PreviousFrame = ... # type: Qgis.PlaybackOperation
        PlayReverse = ... # type: Qgis.PlaybackOperation
        Pause = ... # type: Qgis.PlaybackOperation
        PlayForward = ... # type: Qgis.PlaybackOperation
        NextFrame = ... # type: Qgis.PlaybackOperation
        SkipToEnd = ... # type: Qgis.PlaybackOperation

    class AnimationState(enum.IntEnum):
        Forward = ... # type: Qgis.AnimationState
        Reverse = ... # type: Qgis.AnimationState
        Idle = ... # type: Qgis.AnimationState

    class TemporalNavigationMode(enum.IntEnum):
        Disabled = ... # type: Qgis.TemporalNavigationMode
        Animated = ... # type: Qgis.TemporalNavigationMode
        FixedRange = ... # type: Qgis.TemporalNavigationMode
        Movie = ... # type: Qgis.TemporalNavigationMode

    class AnnotationItemEditOperationResult(enum.IntEnum):
        Success = ... # type: Qgis.AnnotationItemEditOperationResult
        Invalid = ... # type: Qgis.AnnotationItemEditOperationResult
        ItemCleared = ... # type: Qgis.AnnotationItemEditOperationResult

    class AnnotationItemNodeType(enum.IntEnum):
        VertexHandle = ... # type: Qgis.AnnotationItemNodeType
        CalloutHandle = ... # type: Qgis.AnnotationItemNodeType

    class AnnotationItemGuiFlag(enum.IntFlag):
        FlagNoCreationTools = ... # type: Qgis.AnnotationItemGuiFlag

    class AnnotationPlacementMode(enum.IntEnum):
        SpatialBounds = ... # type: Qgis.AnnotationPlacementMode
        FixedSize = ... # type: Qgis.AnnotationPlacementMode
        RelativeToMapFrame = ... # type: Qgis.AnnotationPlacementMode

    class AnnotationItemFlag(enum.IntFlag):
        ScaleDependentBoundingBox = ... # type: Qgis.AnnotationItemFlag
        SupportsReferenceScale = ... # type: Qgis.AnnotationItemFlag
        SupportsCallouts = ... # type: Qgis.AnnotationItemFlag

    class Axis(enum.IntEnum):
        X = ... # type: Qgis.Axis
        Y = ... # type: Qgis.Axis
        Z = ... # type: Qgis.Axis

    class CrsWktVariant(enum.IntEnum):
        Wkt1Gdal = ... # type: Qgis.CrsWktVariant
        Wkt1Esri = ... # type: Qgis.CrsWktVariant
        Wkt2_2015 = ... # type: Qgis.CrsWktVariant
        Wkt2_2015Simplified = ... # type: Qgis.CrsWktVariant
        Wkt2_2019 = ... # type: Qgis.CrsWktVariant
        Wkt2_2019Simplified = ... # type: Qgis.CrsWktVariant
        Preferred = ... # type: Qgis.CrsWktVariant
        PreferredSimplified = ... # type: Qgis.CrsWktVariant
        PreferredGdal = ... # type: Qgis.CrsWktVariant

    class CrsIdentifierType(enum.IntEnum):
        ShortString = ... # type: Qgis.CrsIdentifierType
        MediumString = ... # type: Qgis.CrsIdentifierType
        FullString = ... # type: Qgis.CrsIdentifierType

    class CoordinateOrder(enum.IntEnum):
        Default = ... # type: Qgis.CoordinateOrder
        XY = ... # type: Qgis.CoordinateOrder
        YX = ... # type: Qgis.CoordinateOrder

    class CrsAxisDirection(enum.IntEnum):
        North = ... # type: Qgis.CrsAxisDirection
        NorthNorthEast = ... # type: Qgis.CrsAxisDirection
        NorthEast = ... # type: Qgis.CrsAxisDirection
        EastNorthEast = ... # type: Qgis.CrsAxisDirection
        East = ... # type: Qgis.CrsAxisDirection
        EastSouthEast = ... # type: Qgis.CrsAxisDirection
        SouthEast = ... # type: Qgis.CrsAxisDirection
        SouthSouthEast = ... # type: Qgis.CrsAxisDirection
        South = ... # type: Qgis.CrsAxisDirection
        SouthSouthWest = ... # type: Qgis.CrsAxisDirection
        SouthWest = ... # type: Qgis.CrsAxisDirection
        WestSouthWest = ... # type: Qgis.CrsAxisDirection
        West = ... # type: Qgis.CrsAxisDirection
        WestNorthWest = ... # type: Qgis.CrsAxisDirection
        NorthWest = ... # type: Qgis.CrsAxisDirection
        NorthNorthWest = ... # type: Qgis.CrsAxisDirection
        GeocentricX = ... # type: Qgis.CrsAxisDirection
        GeocentricY = ... # type: Qgis.CrsAxisDirection
        GeocentricZ = ... # type: Qgis.CrsAxisDirection
        Up = ... # type: Qgis.CrsAxisDirection
        Down = ... # type: Qgis.CrsAxisDirection
        Forward = ... # type: Qgis.CrsAxisDirection
        Aft = ... # type: Qgis.CrsAxisDirection
        Port = ... # type: Qgis.CrsAxisDirection
        Starboard = ... # type: Qgis.CrsAxisDirection
        Clockwise = ... # type: Qgis.CrsAxisDirection
        CounterClockwise = ... # type: Qgis.CrsAxisDirection
        ColumnPositive = ... # type: Qgis.CrsAxisDirection
        ColumnNegative = ... # type: Qgis.CrsAxisDirection
        RowPositive = ... # type: Qgis.CrsAxisDirection
        RowNegative = ... # type: Qgis.CrsAxisDirection
        DisplayRight = ... # type: Qgis.CrsAxisDirection
        DisplayLeft = ... # type: Qgis.CrsAxisDirection
        DisplayUp = ... # type: Qgis.CrsAxisDirection
        DisplayDown = ... # type: Qgis.CrsAxisDirection
        Future = ... # type: Qgis.CrsAxisDirection
        Past = ... # type: Qgis.CrsAxisDirection
        Towards = ... # type: Qgis.CrsAxisDirection
        AwayFrom = ... # type: Qgis.CrsAxisDirection
        Unspecified = ... # type: Qgis.CrsAxisDirection

    class CrsType(enum.IntEnum):
        Unknown = ... # type: Qgis.CrsType
        Geodetic = ... # type: Qgis.CrsType
        Geocentric = ... # type: Qgis.CrsType
        Geographic2d = ... # type: Qgis.CrsType
        Geographic3d = ... # type: Qgis.CrsType
        Vertical = ... # type: Qgis.CrsType
        Projected = ... # type: Qgis.CrsType
        Compound = ... # type: Qgis.CrsType
        Temporal = ... # type: Qgis.CrsType
        Engineering = ... # type: Qgis.CrsType
        Bound = ... # type: Qgis.CrsType
        Other = ... # type: Qgis.CrsType
        DerivedProjected = ... # type: Qgis.CrsType

    class DataProviderFlag(enum.IntFlag):
        IsBasemapSource = ... # type: Qgis.DataProviderFlag
        FastExtent2D = ... # type: Qgis.DataProviderFlag
        FastExtent3D = ... # type: Qgis.DataProviderFlag
        Is3DBasemapSource = ... # type: Qgis.DataProviderFlag

    class AutoRefreshMode(enum.IntEnum):
        Disabled = ... # type: Qgis.AutoRefreshMode
        ReloadData = ... # type: Qgis.AutoRefreshMode
        RedrawOnly = ... # type: Qgis.AutoRefreshMode

    class MapLayerProperty(enum.IntFlag):
        UsersCannotToggleEditing = ... # type: Qgis.MapLayerProperty
        IsBasemapLayer = ... # type: Qgis.MapLayerProperty
        Is3DBasemapLayer = ... # type: Qgis.MapLayerProperty

    class FileOperationFlag(enum.IntFlag):
        IncludeMetadataFile = ... # type: Qgis.FileOperationFlag
        IncludeStyleFile = ... # type: Qgis.FileOperationFlag

    class SpatialFilterType(enum.IntEnum):
        NoFilter = ... # type: Qgis.SpatialFilterType
        BoundingBox = ... # type: Qgis.SpatialFilterType
        DistanceWithin = ... # type: Qgis.SpatialFilterType

    class InvalidGeometryCheck(enum.IntEnum):
        NoCheck = ... # type: Qgis.InvalidGeometryCheck
        SkipInvalid = ... # type: Qgis.InvalidGeometryCheck
        AbortOnInvalid = ... # type: Qgis.InvalidGeometryCheck

    class FeatureRequestFilterType(enum.IntEnum):
        NoFilter = ... # type: Qgis.FeatureRequestFilterType
        Fid = ... # type: Qgis.FeatureRequestFilterType
        Expression = ... # type: Qgis.FeatureRequestFilterType
        Fids = ... # type: Qgis.FeatureRequestFilterType

    class FeatureRequestFlag(enum.IntFlag):
        NoFlags = ... # type: Qgis.FeatureRequestFlag
        NoGeometry = ... # type: Qgis.FeatureRequestFlag
        SubsetOfAttributes = ... # type: Qgis.FeatureRequestFlag
        ExactIntersect = ... # type: Qgis.FeatureRequestFlag
        IgnoreStaticNodesDuringExpressionCompilation = ... # type: Qgis.FeatureRequestFlag
        EmbeddedSymbols = ... # type: Qgis.FeatureRequestFlag

    class MakeValidMethod(enum.IntEnum):
        Linework = ... # type: Qgis.MakeValidMethod
        Structure = ... # type: Qgis.MakeValidMethod

    class CoverageValidityResult(enum.IntEnum):
        Invalid = ... # type: Qgis.CoverageValidityResult
        Valid = ... # type: Qgis.CoverageValidityResult
        Error = ... # type: Qgis.CoverageValidityResult

    class GeosCreationFlag(enum.IntFlag):
        RejectOnInvalidSubGeometry = ... # type: Qgis.GeosCreationFlag
        SkipEmptyInteriorRings = ... # type: Qgis.GeosCreationFlag

    class JoinStyle3D(enum.IntEnum):
        Round = ... # type: Qgis.JoinStyle3D
        Flat = ... # type: Qgis.JoinStyle3D
        CylindersAndSpheres = ... # type: Qgis.JoinStyle3D

    class JoinStyle(enum.IntEnum):
        Round = ... # type: Qgis.JoinStyle
        Miter = ... # type: Qgis.JoinStyle
        Bevel = ... # type: Qgis.JoinStyle

    class EndCapStyle(enum.IntEnum):
        Round = ... # type: Qgis.EndCapStyle
        Flat = ... # type: Qgis.EndCapStyle
        Square = ... # type: Qgis.EndCapStyle

    class BufferSide(enum.IntEnum):
        Left = ... # type: Qgis.BufferSide
        Right = ... # type: Qgis.BufferSide

    class GeometryValidationEngine(enum.IntEnum):
        QgisInternal = ... # type: Qgis.GeometryValidationEngine
        Geos = ... # type: Qgis.GeometryValidationEngine

    class GeometryValidityFlag(enum.IntFlag):
        AllowSelfTouchingHoles = ... # type: Qgis.GeometryValidityFlag

    class GeometryOperationResult(enum.IntEnum):
        Success = ... # type: Qgis.GeometryOperationResult
        NothingHappened = ... # type: Qgis.GeometryOperationResult
        InvalidBaseGeometry = ... # type: Qgis.GeometryOperationResult
        InvalidInputGeometryType = ... # type: Qgis.GeometryOperationResult
        SelectionIsEmpty = ... # type: Qgis.GeometryOperationResult
        SelectionIsGreaterThanOne = ... # type: Qgis.GeometryOperationResult
        GeometryEngineError = ... # type: Qgis.GeometryOperationResult
        LayerNotEditable = ... # type: Qgis.GeometryOperationResult
        AddPartSelectedGeometryNotFound = ... # type: Qgis.GeometryOperationResult
        AddPartNotMultiGeometry = ... # type: Qgis.GeometryOperationResult
        AddRingNotClosed = ... # type: Qgis.GeometryOperationResult
        AddRingNotValid = ... # type: Qgis.GeometryOperationResult
        AddRingCrossesExistingRings = ... # type: Qgis.GeometryOperationResult
        AddRingNotInExistingFeature = ... # type: Qgis.GeometryOperationResult
        SplitCannotSplitPoint = ... # type: Qgis.GeometryOperationResult
        GeometryTypeHasChanged = ... # type: Qgis.GeometryOperationResult

    class GpsFeatureType(enum.IntEnum):
        Waypoint = ... # type: Qgis.GpsFeatureType
        Route = ... # type: Qgis.GpsFeatureType
        Track = ... # type: Qgis.GpsFeatureType

    class BabelCommandFlag(enum.IntFlag):
        QuoteFilePaths = ... # type: Qgis.BabelCommandFlag

    class BabelFormatCapability(enum.IntFlag):
        Import = ... # type: Qgis.BabelFormatCapability
        Export = ... # type: Qgis.BabelFormatCapability
        Waypoints = ... # type: Qgis.BabelFormatCapability
        Routes = ... # type: Qgis.BabelFormatCapability
        Tracks = ... # type: Qgis.BabelFormatCapability

    class GpsInformationComponent(enum.IntFlag):
        Location = ... # type: Qgis.GpsInformationComponent
        Altitude = ... # type: Qgis.GpsInformationComponent
        GroundSpeed = ... # type: Qgis.GpsInformationComponent
        Bearing = ... # type: Qgis.GpsInformationComponent
        TotalTrackLength = ... # type: Qgis.GpsInformationComponent
        TrackDistanceFromStart = ... # type: Qgis.GpsInformationComponent
        Pdop = ... # type: Qgis.GpsInformationComponent
        Hdop = ... # type: Qgis.GpsInformationComponent
        Vdop = ... # type: Qgis.GpsInformationComponent
        HorizontalAccuracy = ... # type: Qgis.GpsInformationComponent
        VerticalAccuracy = ... # type: Qgis.GpsInformationComponent
        HvAccuracy = ... # type: Qgis.GpsInformationComponent
        SatellitesUsed = ... # type: Qgis.GpsInformationComponent
        Timestamp = ... # type: Qgis.GpsInformationComponent
        TrackStartTime = ... # type: Qgis.GpsInformationComponent
        TrackEndTime = ... # type: Qgis.GpsInformationComponent
        TrackDistanceSinceLastPoint = ... # type: Qgis.GpsInformationComponent
        TrackTimeSinceLastPoint = ... # type: Qgis.GpsInformationComponent
        GeoidalSeparation = ... # type: Qgis.GpsInformationComponent
        EllipsoidAltitude = ... # type: Qgis.GpsInformationComponent

    class GpsNavigationStatus(enum.IntEnum):
        NotValid = ... # type: Qgis.GpsNavigationStatus
        Safe = ... # type: Qgis.GpsNavigationStatus
        Caution = ... # type: Qgis.GpsNavigationStatus
        Unsafe = ... # type: Qgis.GpsNavigationStatus

    class GpsQualityIndicator(enum.Enum):
        Unknown = ... # type: Qgis.GpsQualityIndicator
        Invalid = ... # type: Qgis.GpsQualityIndicator
        GPS = ... # type: Qgis.GpsQualityIndicator
        DGPS = ... # type: Qgis.GpsQualityIndicator
        PPS = ... # type: Qgis.GpsQualityIndicator
        RTK = ... # type: Qgis.GpsQualityIndicator
        FloatRTK = ... # type: Qgis.GpsQualityIndicator
        Estimated = ... # type: Qgis.GpsQualityIndicator
        Manual = ... # type: Qgis.GpsQualityIndicator
        Simulation = ... # type: Qgis.GpsQualityIndicator

    class GnssConstellation(enum.Enum):
        Unknown = ... # type: Qgis.GnssConstellation
        Gps = ... # type: Qgis.GnssConstellation
        Glonass = ... # type: Qgis.GnssConstellation
        Galileo = ... # type: Qgis.GnssConstellation
        BeiDou = ... # type: Qgis.GnssConstellation
        Qzss = ... # type: Qgis.GnssConstellation
        Navic = ... # type: Qgis.GnssConstellation
        Sbas = ... # type: Qgis.GnssConstellation

    class GpsFixStatus(enum.IntEnum):
        NoData = ... # type: Qgis.GpsFixStatus
        NoFix = ... # type: Qgis.GpsFixStatus
        Fix2D = ... # type: Qgis.GpsFixStatus
        Fix3D = ... # type: Qgis.GpsFixStatus

    class DeviceConnectionStatus(enum.IntEnum):
        Disconnected = ... # type: Qgis.DeviceConnectionStatus
        Connecting = ... # type: Qgis.DeviceConnectionStatus
        Connected = ... # type: Qgis.DeviceConnectionStatus

    class GpsConnectionType(enum.IntEnum):
        Automatic = ... # type: Qgis.GpsConnectionType
        Internal = ... # type: Qgis.GpsConnectionType
        Serial = ... # type: Qgis.GpsConnectionType
        Gpsd = ... # type: Qgis.GpsConnectionType

    class ContentStatus(enum.IntEnum):
        NotStarted = ... # type: Qgis.ContentStatus
        Running = ... # type: Qgis.ContentStatus
        Finished = ... # type: Qgis.ContentStatus
        Failed = ... # type: Qgis.ContentStatus
        Canceled = ... # type: Qgis.ContentStatus

    class VertexMarkerType(enum.IntEnum):
        SemiTransparentCircle = ... # type: Qgis.VertexMarkerType
        Cross = ... # type: Qgis.VertexMarkerType
        NoMarker = ... # type: Qgis.VertexMarkerType

    class VectorEditResult(enum.IntEnum):
        Success = ... # type: Qgis.VectorEditResult
        EmptyGeometry = ... # type: Qgis.VectorEditResult
        EditFailed = ... # type: Qgis.VectorEditResult
        FetchFeatureFailed = ... # type: Qgis.VectorEditResult
        InvalidLayer = ... # type: Qgis.VectorEditResult

    class SelectionFlag(enum.IntFlag):
        SingleFeatureSelection = ... # type: Qgis.SelectionFlag
        ToggleSelection = ... # type: Qgis.SelectionFlag

    class SelectGeometryRelationship(enum.IntEnum):
        Intersect = ... # type: Qgis.SelectGeometryRelationship
        Within = ... # type: Qgis.SelectGeometryRelationship

    class SelectBehavior(enum.IntEnum):
        SetSelection = ... # type: Qgis.SelectBehavior
        AddToSelection = ... # type: Qgis.SelectBehavior
        IntersectSelection = ... # type: Qgis.SelectBehavior
        RemoveFromSelection = ... # type: Qgis.SelectBehavior

    class SelectionRenderingMode(enum.IntEnum):
        Default = ... # type: Qgis.SelectionRenderingMode
        CustomColor = ... # type: Qgis.SelectionRenderingMode
        CustomSymbol = ... # type: Qgis.SelectionRenderingMode

    class FieldMetadataProperty(enum.IntEnum):
        GeometryCrs = ... # type: Qgis.FieldMetadataProperty
        GeometryWkbType = ... # type: Qgis.FieldMetadataProperty
        CustomProperty = ... # type: Qgis.FieldMetadataProperty

    class FieldConfigurationFlag(enum.IntFlag):
        NoFlag = ... # type: Qgis.FieldConfigurationFlag
        NotSearchable = ... # type: Qgis.FieldConfigurationFlag
        HideFromWms = ... # type: Qgis.FieldConfigurationFlag
        HideFromWfs = ... # type: Qgis.FieldConfigurationFlag

    class FieldOrigin(enum.IntEnum):
        Unknown = ... # type: Qgis.FieldOrigin
        Provider = ... # type: Qgis.FieldOrigin
        Join = ... # type: Qgis.FieldOrigin
        Edit = ... # type: Qgis.FieldOrigin
        Expression = ... # type: Qgis.FieldOrigin

    class SublayerPromptMode(enum.IntEnum):
        AlwaysAsk = ... # type: Qgis.SublayerPromptMode
        AskExcludingRasterBands = ... # type: Qgis.SublayerPromptMode
        NeverAskSkip = ... # type: Qgis.SublayerPromptMode
        NeverAskLoadAll = ... # type: Qgis.SublayerPromptMode

    class FilePathType(enum.IntEnum):
        Absolute = ... # type: Qgis.FilePathType
        Relative = ... # type: Qgis.FilePathType

    class MeshEditingErrorType(enum.IntEnum):
        NoError = ... # type: Qgis.MeshEditingErrorType
        InvalidFace = ... # type: Qgis.MeshEditingErrorType
        TooManyVerticesInFace = ... # type: Qgis.MeshEditingErrorType
        FlatFace = ... # type: Qgis.MeshEditingErrorType
        UniqueSharedVertex = ... # type: Qgis.MeshEditingErrorType
        InvalidVertex = ... # type: Qgis.MeshEditingErrorType
        ManifoldFace = ... # type: Qgis.MeshEditingErrorType

    class RasterFileWriterResult(enum.IntEnum):
        Success = ... # type: Qgis.RasterFileWriterResult
        SourceProviderError = ... # type: Qgis.RasterFileWriterResult
        DestinationProviderError = ... # type: Qgis.RasterFileWriterResult
        CreateDatasourceError = ... # type: Qgis.RasterFileWriterResult
        WriteError = ... # type: Qgis.RasterFileWriterResult
        NoDataConflict = ... # type: Qgis.RasterFileWriterResult
        Canceled = ... # type: Qgis.RasterFileWriterResult

    class RasterExportType(enum.IntEnum):
        Raw = ... # type: Qgis.RasterExportType
        RenderedImage = ... # type: Qgis.RasterExportType

    class RasterAttributeTableType(enum.IntEnum):
        Thematic = ... # type: Qgis.RasterAttributeTableType
        Athematic = ... # type: Qgis.RasterAttributeTableType

    class RasterAttributeTableFieldUsage(enum.IntEnum):
        Generic = ... # type: Qgis.RasterAttributeTableFieldUsage
        PixelCount = ... # type: Qgis.RasterAttributeTableFieldUsage
        Name = ... # type: Qgis.RasterAttributeTableFieldUsage
        Min = ... # type: Qgis.RasterAttributeTableFieldUsage
        Max = ... # type: Qgis.RasterAttributeTableFieldUsage
        MinMax = ... # type: Qgis.RasterAttributeTableFieldUsage
        Red = ... # type: Qgis.RasterAttributeTableFieldUsage
        Green = ... # type: Qgis.RasterAttributeTableFieldUsage
        Blue = ... # type: Qgis.RasterAttributeTableFieldUsage
        Alpha = ... # type: Qgis.RasterAttributeTableFieldUsage
        RedMin = ... # type: Qgis.RasterAttributeTableFieldUsage
        GreenMin = ... # type: Qgis.RasterAttributeTableFieldUsage
        BlueMin = ... # type: Qgis.RasterAttributeTableFieldUsage
        AlphaMin = ... # type: Qgis.RasterAttributeTableFieldUsage
        RedMax = ... # type: Qgis.RasterAttributeTableFieldUsage
        GreenMax = ... # type: Qgis.RasterAttributeTableFieldUsage
        BlueMax = ... # type: Qgis.RasterAttributeTableFieldUsage
        AlphaMax = ... # type: Qgis.RasterAttributeTableFieldUsage
        MaxCount = ... # type: Qgis.RasterAttributeTableFieldUsage

    class RasterRangeAccuracy(enum.IntEnum):
        Exact = ... # type: Qgis.RasterRangeAccuracy
        Estimated = ... # type: Qgis.RasterRangeAccuracy

    class RasterRangeExtent(enum.IntEnum):
        WholeRaster = ... # type: Qgis.RasterRangeExtent
        FixedCanvas = ... # type: Qgis.RasterRangeExtent
        UpdatedCanvas = ... # type: Qgis.RasterRangeExtent

    class RasterRangeLimit(enum.IntEnum):
        NotSet = ... # type: Qgis.RasterRangeLimit
        MinimumMaximum = ... # type: Qgis.RasterRangeLimit
        StdDev = ... # type: Qgis.RasterRangeLimit
        CumulativeCut = ... # type: Qgis.RasterRangeLimit

    class RasterRendererCapability(enum.IntFlag):
        UsesMultipleBands = ... # type: Qgis.RasterRendererCapability

    class RasterRendererFlag(enum.IntFlag):
        InternalLayerOpacityHandling = ... # type: Qgis.RasterRendererFlag
        UseNoDataForOutOfRangePixels = ... # type: Qgis.RasterRendererFlag

    class RasterResamplingMethod(enum.IntEnum):
        Nearest = ... # type: Qgis.RasterResamplingMethod
        Bilinear = ... # type: Qgis.RasterResamplingMethod
        Cubic = ... # type: Qgis.RasterResamplingMethod
        CubicSpline = ... # type: Qgis.RasterResamplingMethod
        Lanczos = ... # type: Qgis.RasterResamplingMethod
        Average = ... # type: Qgis.RasterResamplingMethod
        Mode = ... # type: Qgis.RasterResamplingMethod
        Gauss = ... # type: Qgis.RasterResamplingMethod

    class RasterResamplingStage(enum.IntEnum):
        ResampleFilter = ... # type: Qgis.RasterResamplingStage
        Provider = ... # type: Qgis.RasterResamplingStage

    class RasterPipeInterfaceRole(enum.IntEnum):
        Unknown = ... # type: Qgis.RasterPipeInterfaceRole
        Provider = ... # type: Qgis.RasterPipeInterfaceRole
        Renderer = ... # type: Qgis.RasterPipeInterfaceRole
        Brightness = ... # type: Qgis.RasterPipeInterfaceRole
        Resampler = ... # type: Qgis.RasterPipeInterfaceRole
        Projector = ... # type: Qgis.RasterPipeInterfaceRole
        Nuller = ... # type: Qgis.RasterPipeInterfaceRole
        HueSaturation = ... # type: Qgis.RasterPipeInterfaceRole

    class ShaderClassificationMethod(enum.IntEnum):
        Continuous = ... # type: Qgis.ShaderClassificationMethod
        EqualInterval = ... # type: Qgis.ShaderClassificationMethod
        Quantile = ... # type: Qgis.ShaderClassificationMethod

    class ShaderInterpolationMethod(enum.IntEnum):
        Linear = ... # type: Qgis.ShaderInterpolationMethod
        Discrete = ... # type: Qgis.ShaderInterpolationMethod
        Exact = ... # type: Qgis.ShaderInterpolationMethod

    class SublayerFlag(enum.IntFlag):
        SystemTable = ... # type: Qgis.SublayerFlag

    class SublayerQueryFlag(enum.IntFlag):
        FastScan = ... # type: Qgis.SublayerQueryFlag
        ResolveGeometryType = ... # type: Qgis.SublayerQueryFlag
        CountFeatures = ... # type: Qgis.SublayerQueryFlag
        IncludeSystemTables = ... # type: Qgis.SublayerQueryFlag
        OpenLayersToResolveDescriptions = ... # type: Qgis.SublayerQueryFlag

    class SourceHierarchyLevel(enum.IntEnum):
        Connection = ... # type: Qgis.SourceHierarchyLevel
        Group = ... # type: Qgis.SourceHierarchyLevel
        Object = ... # type: Qgis.SourceHierarchyLevel

    class UriCleaningFlag(enum.IntFlag):
        RemoveCredentials = ... # type: Qgis.UriCleaningFlag
        RedactCredentials = ... # type: Qgis.UriCleaningFlag

    class FileFilterType(enum.IntEnum):
        Vector = ... # type: Qgis.FileFilterType
        Raster = ... # type: Qgis.FileFilterType
        Mesh = ... # type: Qgis.FileFilterType
        MeshDataset = ... # type: Qgis.FileFilterType
        PointCloud = ... # type: Qgis.FileFilterType
        VectorTile = ... # type: Qgis.FileFilterType
        TiledScene = ... # type: Qgis.FileFilterType

    class LabelMultiLineAlignment(enum.IntEnum):
        Left = ... # type: Qgis.LabelMultiLineAlignment
        Center = ... # type: Qgis.LabelMultiLineAlignment
        Right = ... # type: Qgis.LabelMultiLineAlignment
        FollowPlacement = ... # type: Qgis.LabelMultiLineAlignment
        Justify = ... # type: Qgis.LabelMultiLineAlignment

    class UpsideDownLabelHandling(enum.IntEnum):
        FlipUpsideDownLabels = ... # type: Qgis.UpsideDownLabelHandling
        AllowUpsideDownWhenRotationIsDefined = ... # type: Qgis.UpsideDownLabelHandling
        AlwaysAllowUpsideDown = ... # type: Qgis.UpsideDownLabelHandling

    class LabelPolygonPlacementFlag(enum.IntFlag):
        AllowPlacementOutsideOfPolygon = ... # type: Qgis.LabelPolygonPlacementFlag
        AllowPlacementInsideOfPolygon = ... # type: Qgis.LabelPolygonPlacementFlag

    class LabelLinePlacementFlag(enum.IntFlag):
        OnLine = ... # type: Qgis.LabelLinePlacementFlag
        AboveLine = ... # type: Qgis.LabelLinePlacementFlag
        BelowLine = ... # type: Qgis.LabelLinePlacementFlag
        MapOrientation = ... # type: Qgis.LabelLinePlacementFlag

    class LabelQuadrantPosition(enum.IntEnum):
        AboveLeft = ... # type: Qgis.LabelQuadrantPosition
        Above = ... # type: Qgis.LabelQuadrantPosition
        AboveRight = ... # type: Qgis.LabelQuadrantPosition
        Left = ... # type: Qgis.LabelQuadrantPosition
        Over = ... # type: Qgis.LabelQuadrantPosition
        Right = ... # type: Qgis.LabelQuadrantPosition
        BelowLeft = ... # type: Qgis.LabelQuadrantPosition
        Below = ... # type: Qgis.LabelQuadrantPosition
        BelowRight = ... # type: Qgis.LabelQuadrantPosition

    class LabelOffsetType(enum.IntEnum):
        FromPoint = ... # type: Qgis.LabelOffsetType
        FromSymbolBounds = ... # type: Qgis.LabelOffsetType

    class MultiPartLabelingBehavior(enum.IntEnum):
        LabelLargestPartOnly = ... # type: Qgis.MultiPartLabelingBehavior
        LabelEveryPartWithEntireLabel = ... # type: Qgis.MultiPartLabelingBehavior
        SplitLabelTextLinesOverParts = ... # type: Qgis.MultiPartLabelingBehavior

    class LabelPredefinedPointPosition(enum.IntEnum):
        TopLeft = ... # type: Qgis.LabelPredefinedPointPosition
        TopSlightlyLeft = ... # type: Qgis.LabelPredefinedPointPosition
        TopMiddle = ... # type: Qgis.LabelPredefinedPointPosition
        TopSlightlyRight = ... # type: Qgis.LabelPredefinedPointPosition
        TopRight = ... # type: Qgis.LabelPredefinedPointPosition
        MiddleLeft = ... # type: Qgis.LabelPredefinedPointPosition
        MiddleRight = ... # type: Qgis.LabelPredefinedPointPosition
        BottomLeft = ... # type: Qgis.LabelPredefinedPointPosition
        BottomSlightlyLeft = ... # type: Qgis.LabelPredefinedPointPosition
        BottomMiddle = ... # type: Qgis.LabelPredefinedPointPosition
        BottomSlightlyRight = ... # type: Qgis.LabelPredefinedPointPosition
        BottomRight = ... # type: Qgis.LabelPredefinedPointPosition
        OverPoint = ... # type: Qgis.LabelPredefinedPointPosition

    class CurvedLabelMode(enum.IntEnum):
        Default = ... # type: Qgis.CurvedLabelMode
        PlaceCharactersAtVertices = ... # type: Qgis.CurvedLabelMode
        StretchCharacterSpacingToFitLine = ... # type: Qgis.CurvedLabelMode
        StretchWordSpacingToFitLine = ... # type: Qgis.CurvedLabelMode

    class LabelPlacement(enum.IntEnum):
        AroundPoint = ... # type: Qgis.LabelPlacement
        OverPoint = ... # type: Qgis.LabelPlacement
        Line = ... # type: Qgis.LabelPlacement
        Curved = ... # type: Qgis.LabelPlacement
        Horizontal = ... # type: Qgis.LabelPlacement
        Free = ... # type: Qgis.LabelPlacement
        OrderedPositionsAroundPoint = ... # type: Qgis.LabelPlacement
        PerimeterCurved = ... # type: Qgis.LabelPlacement
        OutsidePolygons = ... # type: Qgis.LabelPlacement

    class LabelPrioritization(enum.IntEnum):
        PreferCloser = ... # type: Qgis.LabelPrioritization
        PreferPositionOrdering = ... # type: Qgis.LabelPrioritization

    class LabelWhitespaceCollisionHandling(enum.IntEnum):
        TreatWhitespaceAsCollision = ... # type: Qgis.LabelWhitespaceCollisionHandling
        IgnoreWhitespaceCollisions = ... # type: Qgis.LabelWhitespaceCollisionHandling

    class LabelOverlapHandling(enum.IntEnum):
        PreventOverlap = ... # type: Qgis.LabelOverlapHandling
        AllowOverlapIfRequired = ... # type: Qgis.LabelOverlapHandling
        AllowOverlapAtNoCost = ... # type: Qgis.LabelOverlapHandling

    class UnplacedLabelVisibility(enum.IntEnum):
        FollowEngineSetting = ... # type: Qgis.UnplacedLabelVisibility
        NeverShow = ... # type: Qgis.UnplacedLabelVisibility

    class ActionStart(enum.IntEnum):
        Deferred = ... # type: Qgis.ActionStart
        Immediate = ... # type: Qgis.ActionStart

    class DriveType(enum.IntEnum):
        Unknown = ... # type: Qgis.DriveType
        Invalid = ... # type: Qgis.DriveType
        Removable = ... # type: Qgis.DriveType
        Fixed = ... # type: Qgis.DriveType
        Remote = ... # type: Qgis.DriveType
        CdRom = ... # type: Qgis.DriveType
        RamDisk = ... # type: Qgis.DriveType
        Cloud = ... # type: Qgis.DriveType

    class SqlKeywordCategory(enum.IntEnum):
        Keyword = ... # type: Qgis.SqlKeywordCategory
        Constant = ... # type: Qgis.SqlKeywordCategory
        Function = ... # type: Qgis.SqlKeywordCategory
        Geospatial = ... # type: Qgis.SqlKeywordCategory
        Operator = ... # type: Qgis.SqlKeywordCategory
        Math = ... # type: Qgis.SqlKeywordCategory
        Aggregate = ... # type: Qgis.SqlKeywordCategory
        String = ... # type: Qgis.SqlKeywordCategory
        Identifier = ... # type: Qgis.SqlKeywordCategory

    class SqlLayerDefinitionCapability(enum.IntFlag):
        SubsetStringFilter = ... # type: Qgis.SqlLayerDefinitionCapability
        GeometryColumn = ... # type: Qgis.SqlLayerDefinitionCapability
        PrimaryKeys = ... # type: Qgis.SqlLayerDefinitionCapability
        UnstableFeatureIds = ... # type: Qgis.SqlLayerDefinitionCapability

    class VectorFileWriterCapability(enum.IntFlag):
        FieldAliases = ... # type: Qgis.VectorFileWriterCapability
        FieldComments = ... # type: Qgis.VectorFileWriterCapability

    class VectorExportResult(enum.IntEnum):
        Success = ... # type: Qgis.VectorExportResult
        ErrorCreatingDataSource = ... # type: Qgis.VectorExportResult
        ErrorCreatingLayer = ... # type: Qgis.VectorExportResult
        ErrorAttributeTypeUnsupported = ... # type: Qgis.VectorExportResult
        ErrorAttributeCreationFailed = ... # type: Qgis.VectorExportResult
        ErrorProjectingFeatures = ... # type: Qgis.VectorExportResult
        ErrorFeatureWriteFailed = ... # type: Qgis.VectorExportResult
        ErrorInvalidLayer = ... # type: Qgis.VectorExportResult
        ErrorInvalidProvider = ... # type: Qgis.VectorExportResult
        ErrorProviderUnsupportedFeature = ... # type: Qgis.VectorExportResult
        ErrorConnectionFailed = ... # type: Qgis.VectorExportResult
        UserCanceled = ... # type: Qgis.VectorExportResult

    class HttpMethod(enum.IntEnum):
        Get = ... # type: Qgis.HttpMethod
        Post = ... # type: Qgis.HttpMethod
        Head = ... # type: Qgis.HttpMethod
        Put = ... # type: Qgis.HttpMethod
        Delete = ... # type: Qgis.HttpMethod

    class BrowserDirectoryMonitoring(enum.IntEnum):
        Default = ... # type: Qgis.BrowserDirectoryMonitoring
        NeverMonitor = ... # type: Qgis.BrowserDirectoryMonitoring
        AlwaysMonitor = ... # type: Qgis.BrowserDirectoryMonitoring

    class BrowserLayerType(enum.IntEnum):
        NoType = ... # type: Qgis.BrowserLayerType
        Vector = ... # type: Qgis.BrowserLayerType
        Raster = ... # type: Qgis.BrowserLayerType
        Point = ... # type: Qgis.BrowserLayerType
        Line = ... # type: Qgis.BrowserLayerType
        Polygon = ... # type: Qgis.BrowserLayerType
        TableLayer = ... # type: Qgis.BrowserLayerType
        Database = ... # type: Qgis.BrowserLayerType
        Table = ... # type: Qgis.BrowserLayerType
        Plugin = ... # type: Qgis.BrowserLayerType
        Mesh = ... # type: Qgis.BrowserLayerType
        VectorTile = ... # type: Qgis.BrowserLayerType
        PointCloud = ... # type: Qgis.BrowserLayerType
        TiledScene = ... # type: Qgis.BrowserLayerType

    class DataItemProviderCapability(enum.IntFlag):
        NoCapabilities = ... # type: Qgis.DataItemProviderCapability
        Files = ... # type: Qgis.DataItemProviderCapability
        Directories = ... # type: Qgis.DataItemProviderCapability
        Databases = ... # type: Qgis.DataItemProviderCapability
        NetworkSources = ... # type: Qgis.DataItemProviderCapability

    class BrowserItemCapability(enum.IntFlag):
        NoCapabilities = ... # type: Qgis.BrowserItemCapability
        SetCrs = ... # type: Qgis.BrowserItemCapability
        Fertile = ... # type: Qgis.BrowserItemCapability
        Fast = ... # type: Qgis.BrowserItemCapability
        Collapse = ... # type: Qgis.BrowserItemCapability
        Rename = ... # type: Qgis.BrowserItemCapability
        Delete = ... # type: Qgis.BrowserItemCapability
        ItemRepresentsFile = ... # type: Qgis.BrowserItemCapability
        RefreshChildrenWhenItemIsRefreshed = ... # type: Qgis.BrowserItemCapability
        ReadOnly = ... # type: Qgis.BrowserItemCapability

    class BrowserItemState(enum.IntEnum):
        NotPopulated = ... # type: Qgis.BrowserItemState
        Populating = ... # type: Qgis.BrowserItemState
        Populated = ... # type: Qgis.BrowserItemState

    class BrowserItemType(enum.IntEnum):
        Collection = ... # type: Qgis.BrowserItemType
        Directory = ... # type: Qgis.BrowserItemType
        Layer = ... # type: Qgis.BrowserItemType
        Error = ... # type: Qgis.BrowserItemType
        Favorites = ... # type: Qgis.BrowserItemType
        Project = ... # type: Qgis.BrowserItemType
        Custom = ... # type: Qgis.BrowserItemType
        Fields = ... # type: Qgis.BrowserItemType
        Field = ... # type: Qgis.BrowserItemType

    class SymbolLayerUserFlag(enum.IntFlag):
        DisableSelectionRecoloring = ... # type: Qgis.SymbolLayerUserFlag

    class SymbolLayerFlag(enum.IntFlag):
        DisableFeatureClipping = ... # type: Qgis.SymbolLayerFlag
        CanCalculateMaskGeometryPerFeature = ... # type: Qgis.SymbolLayerFlag
        AffectsLabeling = ... # type: Qgis.SymbolLayerFlag

    class SymbolPreviewFlag(enum.IntFlag):
        FlagIncludeCrosshairsForMarkerSymbols = ... # type: Qgis.SymbolPreviewFlag

    class SymbolFlag(enum.IntFlag):
        RendererShouldUseSymbolLevels = ... # type: Qgis.SymbolFlag
        AffectsLabeling = ... # type: Qgis.SymbolFlag

    class FeatureRendererFlag(enum.IntFlag):
        AffectsLabeling = ... # type: Qgis.FeatureRendererFlag

    class VerticalAnchorPoint(enum.IntEnum):
        Top = ... # type: Qgis.VerticalAnchorPoint
        Center = ... # type: Qgis.VerticalAnchorPoint
        Bottom = ... # type: Qgis.VerticalAnchorPoint
        Baseline = ... # type: Qgis.VerticalAnchorPoint

    class HorizontalAnchorPoint(enum.IntEnum):
        Left = ... # type: Qgis.HorizontalAnchorPoint
        Center = ... # type: Qgis.HorizontalAnchorPoint
        Right = ... # type: Qgis.HorizontalAnchorPoint

    class SymbolRotationMode(enum.IntEnum):
        RespectMapRotation = ... # type: Qgis.SymbolRotationMode
        IgnoreMapRotation = ... # type: Qgis.SymbolRotationMode

    class SymbolRenderHint(enum.IntFlag):
        DynamicRotation = ... # type: Qgis.SymbolRenderHint
        IsSymbolLayerSubSymbol = ... # type: Qgis.SymbolRenderHint
        ForceVectorRendering = ... # type: Qgis.SymbolRenderHint
        ExcludeSymbolBuffers = ... # type: Qgis.SymbolRenderHint

    class SnappingType(enum.IntFlag):
        NoSnap = ... # type: Qgis.SnappingType
        Vertex = ... # type: Qgis.SnappingType
        Segment = ... # type: Qgis.SnappingType
        Area = ... # type: Qgis.SnappingType
        Centroid = ... # type: Qgis.SnappingType
        MiddleOfSegment = ... # type: Qgis.SnappingType
        LineEndpoint = ... # type: Qgis.SnappingType

    class SnappingMode(enum.IntEnum):
        ActiveLayer = ... # type: Qgis.SnappingMode
        AllLayers = ... # type: Qgis.SnappingMode
        AdvancedConfiguration = ... # type: Qgis.SnappingMode

    class SettingsOption(enum.IntFlag):
        SaveFormerValue = ... # type: Qgis.SettingsOption
        SaveEnumFlagAsInt = ... # type: Qgis.SettingsOption

    class SldExportVendorExtension(enum.IntFlag):
        NoVendorExtension = ... # type: Qgis.SldExportVendorExtension
        GeoServerVendorExtension = ... # type: Qgis.SldExportVendorExtension
        DeegreeVendorExtension = ... # type: Qgis.SldExportVendorExtension

    class SldExportOption(enum.IntFlag):
        NoOptions = ... # type: Qgis.SldExportOption
        Svg = ... # type: Qgis.SldExportOption
        Png = ... # type: Qgis.SldExportOption

    class PropertyType(enum.IntEnum):
        Invalid = ... # type: Qgis.PropertyType
        Static = ... # type: Qgis.PropertyType
        Field = ... # type: Qgis.PropertyType
        Expression = ... # type: Qgis.PropertyType

    class SettingsTreeNodeOption(enum.IntFlag):
        NamedListSelectedItemSetting = ... # type: Qgis.SettingsTreeNodeOption

    class SettingsTreeNodeType(enum.Enum):
        Root = ... # type: Qgis.SettingsTreeNodeType
        Standard = ... # type: Qgis.SettingsTreeNodeType
        NamedList = ... # type: Qgis.SettingsTreeNodeType

    class SettingsType(enum.IntEnum):
        Custom = ... # type: Qgis.SettingsType
        Variant = ... # type: Qgis.SettingsType
        String = ... # type: Qgis.SettingsType
        StringList = ... # type: Qgis.SettingsType
        VariantMap = ... # type: Qgis.SettingsType
        Bool = ... # type: Qgis.SettingsType
        Integer = ... # type: Qgis.SettingsType
        Double = ... # type: Qgis.SettingsType
        EnumFlag = ... # type: Qgis.SettingsType
        Color = ... # type: Qgis.SettingsType

    class ScaleMethod(enum.IntEnum):
        ScaleArea = ... # type: Qgis.ScaleMethod
        ScaleDiameter = ... # type: Qgis.ScaleMethod

    class SymbolType(enum.IntEnum):
        Marker = ... # type: Qgis.SymbolType
        Line = ... # type: Qgis.SymbolType
        Fill = ... # type: Qgis.SymbolType
        Hybrid = ... # type: Qgis.SymbolType

    class VectorDataProviderAttributeEditCapability(enum.IntFlag):
        EditAlias = ... # type: Qgis.VectorDataProviderAttributeEditCapability
        EditComment = ... # type: Qgis.VectorDataProviderAttributeEditCapability

    class FeatureAvailability(enum.IntEnum):
        NoFeaturesAvailable = ... # type: Qgis.FeatureAvailability
        FeaturesAvailable = ... # type: Qgis.FeatureAvailability
        FeaturesMaybeAvailable = ... # type: Qgis.FeatureAvailability

    class SpatialIndexPresence(enum.IntEnum):
        Unknown = ... # type: Qgis.SpatialIndexPresence
        NotPresent = ... # type: Qgis.SpatialIndexPresence
        Present = ... # type: Qgis.SpatialIndexPresence

    class FeatureCountState(enum.IntEnum):
        Uncounted = ... # type: Qgis.FeatureCountState
        UnknownCount = ... # type: Qgis.FeatureCountState

    class VectorProviderCapability(enum.IntFlag):
        NoCapabilities = ... # type: Qgis.VectorProviderCapability
        AddFeatures = ... # type: Qgis.VectorProviderCapability
        DeleteFeatures = ... # type: Qgis.VectorProviderCapability
        ChangeAttributeValues = ... # type: Qgis.VectorProviderCapability
        AddAttributes = ... # type: Qgis.VectorProviderCapability
        DeleteAttributes = ... # type: Qgis.VectorProviderCapability
        CreateSpatialIndex = ... # type: Qgis.VectorProviderCapability
        SelectAtId = ... # type: Qgis.VectorProviderCapability
        ChangeGeometries = ... # type: Qgis.VectorProviderCapability
        SelectEncoding = ... # type: Qgis.VectorProviderCapability
        CreateAttributeIndex = ... # type: Qgis.VectorProviderCapability
        SimplifyGeometries = ... # type: Qgis.VectorProviderCapability
        SimplifyGeometriesWithTopologicalValidation = ... # type: Qgis.VectorProviderCapability
        TransactionSupport = ... # type: Qgis.VectorProviderCapability
        CircularGeometries = ... # type: Qgis.VectorProviderCapability
        ChangeFeatures = ... # type: Qgis.VectorProviderCapability
        RenameAttributes = ... # type: Qgis.VectorProviderCapability
        FastTruncate = ... # type: Qgis.VectorProviderCapability
        ReadLayerMetadata = ... # type: Qgis.VectorProviderCapability
        WriteLayerMetadata = ... # type: Qgis.VectorProviderCapability
        CancelSupport = ... # type: Qgis.VectorProviderCapability
        CreateRenderer = ... # type: Qgis.VectorProviderCapability
        CreateLabeling = ... # type: Qgis.VectorProviderCapability
        ReloadData = ... # type: Qgis.VectorProviderCapability
        FeatureSymbology = ... # type: Qgis.VectorProviderCapability
        EditingCapabilities = ... # type: Qgis.VectorProviderCapability

    class DataProviderReadFlag(enum.IntFlag):
        TrustDataSource = ... # type: Qgis.DataProviderReadFlag
        SkipFeatureCount = ... # type: Qgis.DataProviderReadFlag
        LoadDefaultStyle = ... # type: Qgis.DataProviderReadFlag
        SkipGetExtent = ... # type: Qgis.DataProviderReadFlag
        SkipFullScan = ... # type: Qgis.DataProviderReadFlag
        ForceReadOnly = ... # type: Qgis.DataProviderReadFlag
        SkipCredentialsRequest = ... # type: Qgis.DataProviderReadFlag
        ParallelThreadLoading = ... # type: Qgis.DataProviderReadFlag

    class ProjectTrustStatus(enum.IntEnum):
        Undetermined = ... # type: Qgis.ProjectTrustStatus
        Trusted = ... # type: Qgis.ProjectTrustStatus
        Untrusted = ... # type: Qgis.ProjectTrustStatus

    class EmbeddedScriptType(enum.IntEnum):
        Macro = ... # type: Qgis.EmbeddedScriptType
        ExpressionFunction = ... # type: Qgis.EmbeddedScriptType
        Action = ... # type: Qgis.EmbeddedScriptType
        FormInitCode = ... # type: Qgis.EmbeddedScriptType

    class EmbeddedScriptMode(enum.IntEnum):
        Never = ... # type: Qgis.EmbeddedScriptMode
        Ask = ... # type: Qgis.EmbeddedScriptMode
        SessionOnly = ... # type: Qgis.EmbeddedScriptMode
        Always = ... # type: Qgis.EmbeddedScriptMode
        NotForThisSession = ... # type: Qgis.EmbeddedScriptMode
        NeverAsk = ... # type: Qgis.EmbeddedScriptMode

    class VectorLayerTypeFlag(enum.IntFlag):
        SqlQuery = ... # type: Qgis.VectorLayerTypeFlag

    class CaptureTechnique(enum.IntEnum):
        StraightSegments = ... # type: Qgis.CaptureTechnique
        CircularString = ... # type: Qgis.CaptureTechnique
        Streaming = ... # type: Qgis.CaptureTechnique
        Shape = ... # type: Qgis.CaptureTechnique
        PolyBezier = ... # type: Qgis.CaptureTechnique
        NurbsCurve = ... # type: Qgis.CaptureTechnique

    class DataType(enum.IntEnum):
        UnknownDataType = ... # type: Qgis.DataType
        Byte = ... # type: Qgis.DataType
        Int8 = ... # type: Qgis.DataType
        UInt16 = ... # type: Qgis.DataType
        Int16 = ... # type: Qgis.DataType
        UInt32 = ... # type: Qgis.DataType
        Int32 = ... # type: Qgis.DataType
        Float32 = ... # type: Qgis.DataType
        Float64 = ... # type: Qgis.DataType
        CInt16 = ... # type: Qgis.DataType
        CInt32 = ... # type: Qgis.DataType
        CFloat32 = ... # type: Qgis.DataType
        CFloat64 = ... # type: Qgis.DataType
        ARGB32 = ... # type: Qgis.DataType
        ARGB32_Premultiplied = ... # type: Qgis.DataType

    class GeometryType(enum.IntEnum):
        Point = ... # type: Qgis.GeometryType
        Line = ... # type: Qgis.GeometryType
        Polygon = ... # type: Qgis.GeometryType
        Unknown = ... # type: Qgis.GeometryType
        Null = ... # type: Qgis.GeometryType

    class WkbType(enum.IntEnum):
        Unknown = ... # type: Qgis.WkbType
        Point = ... # type: Qgis.WkbType
        LineString = ... # type: Qgis.WkbType
        Polygon = ... # type: Qgis.WkbType
        Triangle = ... # type: Qgis.WkbType
        MultiPoint = ... # type: Qgis.WkbType
        MultiLineString = ... # type: Qgis.WkbType
        MultiPolygon = ... # type: Qgis.WkbType
        GeometryCollection = ... # type: Qgis.WkbType
        CircularString = ... # type: Qgis.WkbType
        CompoundCurve = ... # type: Qgis.WkbType
        CurvePolygon = ... # type: Qgis.WkbType
        MultiCurve = ... # type: Qgis.WkbType
        MultiSurface = ... # type: Qgis.WkbType
        PolyhedralSurface = ... # type: Qgis.WkbType
        TIN = ... # type: Qgis.WkbType
        NurbsCurve = ... # type: Qgis.WkbType
        NoGeometry = ... # type: Qgis.WkbType
        PointZ = ... # type: Qgis.WkbType
        LineStringZ = ... # type: Qgis.WkbType
        PolygonZ = ... # type: Qgis.WkbType
        TriangleZ = ... # type: Qgis.WkbType
        MultiPointZ = ... # type: Qgis.WkbType
        MultiLineStringZ = ... # type: Qgis.WkbType
        MultiPolygonZ = ... # type: Qgis.WkbType
        GeometryCollectionZ = ... # type: Qgis.WkbType
        CircularStringZ = ... # type: Qgis.WkbType
        CompoundCurveZ = ... # type: Qgis.WkbType
        CurvePolygonZ = ... # type: Qgis.WkbType
        MultiCurveZ = ... # type: Qgis.WkbType
        MultiSurfaceZ = ... # type: Qgis.WkbType
        PolyhedralSurfaceZ = ... # type: Qgis.WkbType
        TINZ = ... # type: Qgis.WkbType
        NurbsCurveZ = ... # type: Qgis.WkbType
        PointM = ... # type: Qgis.WkbType
        LineStringM = ... # type: Qgis.WkbType
        PolygonM = ... # type: Qgis.WkbType
        TriangleM = ... # type: Qgis.WkbType
        MultiPointM = ... # type: Qgis.WkbType
        MultiLineStringM = ... # type: Qgis.WkbType
        MultiPolygonM = ... # type: Qgis.WkbType
        GeometryCollectionM = ... # type: Qgis.WkbType
        CircularStringM = ... # type: Qgis.WkbType
        CompoundCurveM = ... # type: Qgis.WkbType
        CurvePolygonM = ... # type: Qgis.WkbType
        MultiCurveM = ... # type: Qgis.WkbType
        MultiSurfaceM = ... # type: Qgis.WkbType
        PolyhedralSurfaceM = ... # type: Qgis.WkbType
        TINM = ... # type: Qgis.WkbType
        NurbsCurveM = ... # type: Qgis.WkbType
        PointZM = ... # type: Qgis.WkbType
        LineStringZM = ... # type: Qgis.WkbType
        PolygonZM = ... # type: Qgis.WkbType
        MultiPointZM = ... # type: Qgis.WkbType
        MultiLineStringZM = ... # type: Qgis.WkbType
        MultiPolygonZM = ... # type: Qgis.WkbType
        GeometryCollectionZM = ... # type: Qgis.WkbType
        CircularStringZM = ... # type: Qgis.WkbType
        CompoundCurveZM = ... # type: Qgis.WkbType
        CurvePolygonZM = ... # type: Qgis.WkbType
        MultiCurveZM = ... # type: Qgis.WkbType
        MultiSurfaceZM = ... # type: Qgis.WkbType
        PolyhedralSurfaceZM = ... # type: Qgis.WkbType
        TINZM = ... # type: Qgis.WkbType
        TriangleZM = ... # type: Qgis.WkbType
        NurbsCurveZM = ... # type: Qgis.WkbType
        Point25D = ... # type: Qgis.WkbType
        LineString25D = ... # type: Qgis.WkbType
        Polygon25D = ... # type: Qgis.WkbType
        MultiPoint25D = ... # type: Qgis.WkbType
        MultiLineString25D = ... # type: Qgis.WkbType
        MultiPolygon25D = ... # type: Qgis.WkbType

    class LoadStyleFlag(enum.IntFlag):
        IgnoreMissingStyleErrors = ... # type: Qgis.LoadStyleFlag

    class LayerFilter(enum.IntFlag):
        RasterLayer = ... # type: Qgis.LayerFilter
        NoGeometry = ... # type: Qgis.LayerFilter
        PointLayer = ... # type: Qgis.LayerFilter
        LineLayer = ... # type: Qgis.LayerFilter
        PolygonLayer = ... # type: Qgis.LayerFilter
        HasGeometry = ... # type: Qgis.LayerFilter
        VectorLayer = ... # type: Qgis.LayerFilter
        PluginLayer = ... # type: Qgis.LayerFilter
        WritableLayer = ... # type: Qgis.LayerFilter
        MeshLayer = ... # type: Qgis.LayerFilter
        VectorTileLayer = ... # type: Qgis.LayerFilter
        PointCloudLayer = ... # type: Qgis.LayerFilter
        AnnotationLayer = ... # type: Qgis.LayerFilter
        TiledSceneLayer = ... # type: Qgis.LayerFilter
        All = ... # type: Qgis.LayerFilter
        SpatialLayer = ... # type: Qgis.LayerFilter

    class LayerType(enum.IntEnum):
        Vector = ... # type: Qgis.LayerType
        Raster = ... # type: Qgis.LayerType
        Plugin = ... # type: Qgis.LayerType
        Mesh = ... # type: Qgis.LayerType
        VectorTile = ... # type: Qgis.LayerType
        Annotation = ... # type: Qgis.LayerType
        PointCloud = ... # type: Qgis.LayerType
        Group = ... # type: Qgis.LayerType
        TiledScene = ... # type: Qgis.LayerType

    class NetworkRequestFlag(enum.IntFlag):
        DisableMessageLogging = ... # type: Qgis.NetworkRequestFlag

    class StringFormat(enum.IntEnum):
        PlainText = ... # type: Qgis.StringFormat
        Html = ... # type: Qgis.StringFormat

    class MessageLevel(enum.IntEnum):
        Info = ... # type: Qgis.MessageLevel
        Warning = ... # type: Qgis.MessageLevel
        Critical = ... # type: Qgis.MessageLevel
        Success = ... # type: Qgis.MessageLevel
        NoLevel = ... # type: Qgis.MessageLevel

    class AuthConfigurationStorageCapability(enum.IntFlag):
        ClearStorage = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadConfiguration = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateConfiguration = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteConfiguration = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateConfiguration = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadCertificateIdentity = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateCertificateIdentity = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteCertificateIdentity = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateCertificateIdentity = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadSslCertificateCustomConfig = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateSslCertificateCustomConfig = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteSslCertificateCustomConfig = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateSslCertificateCustomConfig = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadCertificateAuthority = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateCertificateAuthority = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteCertificateAuthority = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateCertificateAuthority = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadCertificateTrustPolicy = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateCertificateTrustPolicy = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteCertificateTrustPolicy = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateCertificateTrustPolicy = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadMasterPassword = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateMasterPassword = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteMasterPassword = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateMasterPassword = ... # type: Qgis.AuthConfigurationStorageCapability
        ReadSetting = ... # type: Qgis.AuthConfigurationStorageCapability
        UpdateSetting = ... # type: Qgis.AuthConfigurationStorageCapability
        DeleteSetting = ... # type: Qgis.AuthConfigurationStorageCapability
        CreateSetting = ... # type: Qgis.AuthConfigurationStorageCapability

    DEFAULT_HIGHLIGHT_BUFFER_MM = ... # type: float
    DEFAULT_HIGHLIGHT_COLOR = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    DEFAULT_HIGHLIGHT_MIN_WIDTH_MM = ... # type: float
    DEFAULT_LINE_WIDTH = ... # type: float
    DEFAULT_MAPTOPIXEL_THRESHOLD = ... # type: float
    DEFAULT_M_COORDINATE = ... # type: float
    DEFAULT_POINT_SIZE = ... # type: float
    DEFAULT_SEARCH_RADIUS_MM = ... # type: float
    DEFAULT_SEGMENT_EPSILON = ... # type: float
    DEFAULT_SNAP_TOLERANCE = ... # type: float
    DEFAULT_SNAP_UNITS = ... # type: 'Qgis.MapToolUnit'
    DEFAULT_Z_COORDINATE = ... # type: float
    QGIS_DEV_VERSION = ... # type: str
    SCALE_PRECISION = ... # type: float
    UI_SCALE_FACTOR = ... # type: float
    USER_CRS_START_ID = ... # type: int
    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'Qgis') -> None: ...

    @staticmethod
    def geoProj4() -> str: ...
    @staticmethod
    def geoWkt() -> str: ...
    @staticmethod
    def geographicCrsAuthId() -> str: ...
    @staticmethod
    def geoNone() -> str: ...
    @staticmethod
    def hasQtWebkit() -> bool: ...
    @staticmethod
    def geographicLibVersion() -> int: ...
    @staticmethod
    def hasGeographicLib() -> bool: ...
    @staticmethod
    def sfcgalVersionInt() -> int: ...
    @staticmethod
    def hasSfcgal() -> bool: ...
    @staticmethod
    def geosVersion() -> str: ...
    @staticmethod
    def geosVersionPatch() -> int: ...
    @staticmethod
    def geosVersionMinor() -> int: ...
    @staticmethod
    def geosVersionMajor() -> int: ...
    @staticmethod
    def geosVersionInt() -> int: ...
    @staticmethod
    def defaultProjectScales() -> str: ...
    @staticmethod
    def devVersion() -> str: ...
    @staticmethod
    def releaseName() -> str: ...
    @staticmethod
    def versionInt() -> int: ...
    @staticmethod
    def version() -> str: ...


class QgsAbstractContentCacheEntry(PyQt6.sip.wrapper):

    fileModified = ... # type: QtCore.QDateTime|datetime.datetime
    fileModifiedLastCheckTimer = ... # type: QtCore.QElapsedTimer
    mFileModifiedCheckTimeout = ... # type: int
    nextEntry = ... # type: 'QgsAbstractContentCacheEntry'
    path = ... # type: str|None
    previousEntry = ... # type: 'QgsAbstractContentCacheEntry'

    def __init__(self, path: str|None) -> None: ...

    def __ne__(self, other: object): ...
    def isEqual(self, other: 'QgsAbstractContentCacheEntry|None') -> bool: ...
    def dump(self) -> None: ...
    def dataSize(self) -> int: ...
    def __eq__(self, other: object): ...


class QgsAbstractContentCacheBase(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def onRemoteContentFetched(self, url: str|None, success: bool) -> None: ...
    def checkReply(self, reply: QtNetwork.QNetworkReply|None, path: str|None) -> bool: ...
    remoteContentFetched: typing.ClassVar[QtCore.pyqtSignal]
    def invalidateCacheEntry(self, path: str|None) -> bool: ...
    @staticmethod
    def isBase64Data(path: str|None) -> bool: ...
    @staticmethod
    def parseEmbeddedStringData(path: str|None) -> typing.Tuple[bool, str, str]: ...
    @staticmethod
    def parseBase64DataUrl(path: str|None) -> typing.Tuple[bool, str, str]: ...


class QgsAggregateCalculator(PyQt6.sip.wrapper):

    class AggregateInfo(PyQt6.sip.wrapper):

        function = ... # type: str|None
        name = ... # type: str|None
        supportedTypes = ... # type: collections.abc.Iterable[QtCore.QMetaType.Type]

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAggregateCalculator.AggregateInfo') -> None: ...

    class AggregateParameters(PyQt6.sip.wrapper):

        delimiter = ... # type: str|None
        filter = ... # type: str|None
        orderBy = ... # type: 'QgsFeatureRequest.OrderBy'

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAggregateCalculator.AggregateParameters') -> None: ...

    @typing.overload
    def __init__(self, layer: 'QgsVectorLayer|None') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAggregateCalculator') -> None: ...

    @staticmethod
    def aggregates() -> list['QgsAggregateCalculator.AggregateInfo']: ...
    @staticmethod
    def displayName(aggregate: Qgis.Aggregate) -> str: ...
    @staticmethod
    def stringToAggregate(string: str|None) -> typing.Tuple[Qgis.Aggregate, bool]: ...
    def calculate(self, aggregate: Qgis.Aggregate, fieldOrExpression: str|None, context: 'QgsExpressionContext|None' = ..., feedback: 'QgsFeedback|None' = ...) -> typing.Tuple[typing.Any, bool]: ...
    def delimiter(self) -> str: ...
    def setDelimiter(self, delimiter: str|None) -> None: ...
    def filter(self) -> str: ...
    def setFidsFilter(self, fids: typing.Any) -> None: ...
    def setFilter(self, filterExpression: str|None) -> None: ...
    def setParameters(self, parameters: 'QgsAggregateCalculator.AggregateParameters') -> None: ...
    def layer(self) -> 'QgsVectorLayer|None': ...
    def lastError(self) -> str: ...


class QgsAlignRasterData(PyQt6.sip.wrapper):

    class RasterItem(PyQt6.sip.wrapper):

        inputFilename = ... # type: str|None
        outputFilename = ... # type: str|None
        resampleMethod = ... # type: Qgis.GdalResampleAlgorithm
        rescaleValues = ... # type: bool
        srcCellSizeInDestCRS = ... # type: float

        @typing.overload
        def __init__(self, input: str|None, output: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAlignRasterData.RasterItem') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAlignRasterData') -> None: ...


class QgsAnimatedIcon(QtCore.QObject):

    def __init__(self, iconPath: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    frameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def height(self) -> int: ...
    def width(self) -> int: ...
    def disconnectFrameChanged(self, receiver: QtCore.QObject|None, method: str) -> bool: ...
    def connectFrameChanged(self, receiver: QtCore.QObject|None, method: str) -> bool: ...
    def icon(self) -> QtGui.QIcon: ...
    def setIconPath(self, iconPath: str|None) -> None: ...
    def iconPath(self) -> str: ...


class QgsApplication(QtWidgets.QApplication):

    class endian_t(enum.IntEnum):
        XDR = ... # type: QgsApplication.endian_t
        NDR = ... # type: QgsApplication.endian_t

    class Cursor(enum.IntEnum):
        ZoomIn = ... # type: QgsApplication.Cursor
        ZoomOut = ... # type: QgsApplication.Cursor
        Identify = ... # type: QgsApplication.Cursor
        CrossHair = ... # type: QgsApplication.Cursor
        CapturePoint = ... # type: QgsApplication.Cursor
        Select = ... # type: QgsApplication.Cursor
        Sampler = ... # type: QgsApplication.Cursor

    class StyleSheetType(enum.IntEnum):
        Qt = ... # type: QgsApplication.StyleSheetType
        WebBrowser = ... # type: QgsApplication.StyleSheetType

    QGIS_APPLICATION_NAME = ... # type: str
    QGIS_ORGANIZATION_DOMAIN = ... # type: str
    QGIS_ORGANIZATION_NAME = ... # type: str

    def __init__(self, argv: list, GUIenabled: bool, profileFolder: str|None = ..., platformName: str|None = ...) -> None: ...

    themeChanged: typing.ClassVar[QtCore.pyqtSignal]
    localeChanged: typing.ClassVar[QtCore.pyqtSignal]
    requestForTranslatableObjects: typing.ClassVar[QtCore.pyqtSignal]
    nullRepresentationChanged: typing.ClassVar[QtCore.pyqtSignal]
    customVariablesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def collectTranslatableObjects(self, translationContext: 'QgsTranslationContext|None') -> None: ...
    def translation(self) -> str: ...
    @staticmethod
    def setTranslation(translation: str|None) -> None: ...
    def maxConcurrentConnectionsPerPool(self) -> int: ...
    @staticmethod
    def scaleIconSize(standardSize: int, applyDevicePixelRatio: bool = ...) -> int: ...
    @staticmethod
    def setTemporarilyUntrustedProjectsFolders(untrustedProjectsFolders: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def temporarilyUntrustedProjectsFolders() -> list[str]: ...
    @staticmethod
    def setTemporarilyTrustedProjectsFolders(trustedProjectsFolders: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def temporarilyTrustedProjectsFolders() -> list[str]: ...
    @staticmethod
    def setCustomVariable(name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def setCustomVariables(customVariables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def customVariables() -> dict[str, typing.Any]: ...
    @staticmethod
    def setNullRepresentation(nullRepresentation: str|None) -> None: ...
    @staticmethod
    def nullRepresentation() -> str: ...
    @staticmethod
    def localizedDataPathRegistry() -> 'QgsLocalizedDataPathRegistry|None': ...
    @staticmethod
    def profileSourceRegistry() -> 'QgsProfileSourceRegistry|None': ...
    @staticmethod
    def externalStorageRegistry() -> 'QgsExternalStorageRegistry|None': ...
    @staticmethod
    def layerMetadataProviderRegistry() -> 'QgsLayerMetadataProviderRegistry|None': ...
    @staticmethod
    def projectStorageRegistry() -> 'QgsProjectStorageRegistry|None': ...
    @staticmethod
    def labelingEngineRuleRegistry() -> 'QgsLabelingEngineRuleRegistry|None': ...
    @staticmethod
    def scaleBarRendererRegistry() -> 'QgsScaleBarRendererRegistry|None': ...
    @staticmethod
    def symbol3DRegistry() -> 'Qgs3DSymbolRegistry|None': ...
    @staticmethod
    def renderer3DRegistry() -> 'Qgs3DRendererRegistry|None': ...
    @staticmethod
    def fieldFormatterRegistry() -> 'QgsFieldFormatterRegistry|None': ...
    @staticmethod
    def numericFormatRegistry() -> 'QgsNumericFormatRegistry|None': ...
    @staticmethod
    def profiler() -> 'QgsRuntimeProfiler|None': ...
    @staticmethod
    def connectionRegistry() -> 'QgsConnectionRegistry|None': ...
    @staticmethod
    def actionScopeRegistry() -> 'QgsActionScopeRegistry|None': ...
    @staticmethod
    def applicationThemeRegistry() -> 'QgsApplicationThemeRegistry|None': ...
    @staticmethod
    def pageSizeRegistry() -> 'QgsPageSizeRegistry|None': ...
    @staticmethod
    def processingRegistry() -> 'QgsProcessingRegistry|None': ...
    @staticmethod
    def authConfigurationStorageRegistry() -> 'QgsAuthConfigurationStorageRegistry|None': ...
    @staticmethod
    def authManager() -> 'QgsAuthManager|None': ...
    @staticmethod
    def messageLog() -> 'QgsMessageLog|None': ...
    @staticmethod
    def plotRegistry() -> 'QgsPlotRegistry|None': ...
    @staticmethod
    def sensorRegistry() -> 'QgsSensorRegistry|None': ...
    @staticmethod
    def fontManager() -> 'QgsFontManager|None': ...
    @staticmethod
    def defaultStyleModel() -> 'QgsStyleModel|None': ...
    @staticmethod
    def databaseQueryLog() -> 'QgsDatabaseQueryLog|None': ...
    @staticmethod
    def recentStyleHandler() -> 'QgsRecentStyleHandler|None': ...
    @staticmethod
    def bookmarkManager() -> 'QgsBookmarkManager|None': ...
    @staticmethod
    def classificationMethodRegistry() -> 'QgsClassificationMethodRegistry|None': ...
    @staticmethod
    def pluginLayerRegistry() -> 'QgsPluginLayerRegistry|None': ...
    @staticmethod
    def gpsBabelFormatRegistry() -> 'QgsBabelFormatRegistry|None': ...
    @staticmethod
    def gpsConnectionRegistry() -> 'QgsGpsConnectionRegistry|None': ...
    @staticmethod
    def annotationItemRegistry() -> 'QgsAnnotationItemRegistry|None': ...
    @staticmethod
    def layoutItemRegistry() -> 'QgsLayoutItemRegistry|None': ...
    @staticmethod
    def calloutRegistry() -> 'QgsCalloutRegistry|None': ...
    @staticmethod
    def symbolLayerRegistry() -> 'QgsSymbolLayerRegistry|None': ...
    @staticmethod
    def validityCheckRegistry() -> 'QgsValidityCheckRegistry|None': ...
    @staticmethod
    def networkContentFetcherRegistry() -> 'QgsNetworkContentFetcherRegistry|None': ...
    @staticmethod
    def sourceCache() -> 'QgsSourceCache|None': ...
    @staticmethod
    def imageCache() -> 'QgsImageCache|None': ...
    @staticmethod
    def svgCache() -> 'QgsSvgCache|None': ...
    @staticmethod
    def coordinateReferenceSystemRegistry() -> 'QgsCoordinateReferenceSystemRegistry|None': ...
    @staticmethod
    def dataItemProviderRegistry() -> 'QgsDataItemProviderRegistry|None': ...
    @staticmethod
    def tiledSceneRendererRegistry() -> 'QgsTiledSceneRendererRegistry|None': ...
    @staticmethod
    def pointCloudRendererRegistry() -> 'QgsPointCloudRendererRegistry|None': ...
    @staticmethod
    def rendererRegistry() -> 'QgsRendererRegistry|None': ...
    @staticmethod
    def paintEffectRegistry() -> 'QgsPaintEffectRegistry|None': ...
    @staticmethod
    def colorSchemeRegistry() -> 'QgsColorSchemeRegistry|None': ...
    @staticmethod
    @deprecated("""""")
    def settingsRegistryCore() -> 'QgsSettingsRegistryCore|None': ...
    @staticmethod
    def taskManager() -> 'QgsTaskManager|None': ...
    @staticmethod
    def setMaxThreads(maxThreads: int) -> None: ...
    @staticmethod
    def maxThreads() -> int: ...
    @staticmethod
    def setSkippedGdalDrivers(skippedGdalDrivers: collections.abc.Iterable[str|None], deferredSkippedGdalDrivers: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def deferredSkippedGdalDrivers() -> list[str]: ...
    @staticmethod
    def registerGdalDriversFromSettings() -> None: ...
    @staticmethod
    def applyGdalSkippedDrivers() -> None: ...
    @staticmethod
    def skippedGdalDrivers() -> list[str]: ...
    @staticmethod
    def restoreGdalDriver(driver: str|None) -> None: ...
    @staticmethod
    def skipGdalDriver(driver: str|None) -> None: ...
    @staticmethod
    def buildOutputPath() -> str: ...
    @staticmethod
    def buildSourcePath() -> str: ...
    @staticmethod
    def isRunningFromBuildDir() -> bool: ...
    @staticmethod
    def relativePathToAbsolutePath(rpath: str|None, targetPath: str|None) -> str: ...
    @staticmethod
    def absolutePathToRelativePath(apath: str|None, targetPath: str|None) -> str: ...
    @staticmethod
    def registerOgrDrivers() -> None: ...
    @staticmethod
    def showSettings() -> str: ...
    @staticmethod
    def reportStyleSheet(styleSheetType: 'QgsApplication.StyleSheetType' = ...) -> str: ...
    @staticmethod
    def endian() -> 'QgsApplication.endian_t': ...
    @staticmethod
    def appIconPath() -> str: ...
    @staticmethod
    def exitQgis() -> None: ...
    @staticmethod
    def createThemeFolder() -> bool: ...
    @staticmethod
    def createDatabase(errorMessage: str|None = ...) -> bool: ...
    @staticmethod
    def initQgis() -> None: ...
    @staticmethod
    def setAuthDatabaseDirPath(authDbDirPath: str|None) -> None: ...
    @staticmethod
    def setDefaultSvgPaths(pathList: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def setPkgDataPath(pkgDataPath: str|None) -> None: ...
    @staticmethod
    def setPluginPath(pluginPath: str|None) -> None: ...
    @staticmethod
    def setPrefixPath(prefixPath: str|None, useDefaultPaths: bool = ...) -> None: ...
    @staticmethod
    def qmlImportPath() -> str: ...
    @staticmethod
    def libexecPath() -> str: ...
    @staticmethod
    def libraryPath() -> str: ...
    @staticmethod
    def defaultThemesFolder() -> str: ...
    @staticmethod
    def defaultStylePath() -> str: ...
    @staticmethod
    def userThemesFolder() -> str: ...
    @staticmethod
    def setLocale(locale: QtCore.QLocale) -> None: ...
    @staticmethod
    def locale() -> str: ...
    @staticmethod
    def applicationFullName() -> str: ...
    @staticmethod
    def platform() -> str: ...
    @staticmethod
    def systemMemorySizeMb() -> int: ...
    @staticmethod
    def osName() -> str: ...
    @staticmethod
    def userFullName() -> str: ...
    @staticmethod
    def userLoginName() -> str: ...
    @staticmethod
    def shortNameRegularExpression() -> QtCore.QRegularExpression: ...
    @staticmethod
    def userStylePath() -> str: ...
    @staticmethod
    def getThemePixmap(name: str|None, foreColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., backColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., size: int = ...) -> QtGui.QPixmap: ...
    @staticmethod
    def getThemeCursor(cursor: 'QgsApplication.Cursor') -> QtGui.QCursor: ...
    @staticmethod
    def getThemeIcon(name: str|None, fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> QtGui.QIcon: ...
    @staticmethod
    def iconPath(iconFile: str|None) -> str: ...
    @staticmethod
    def defaultThemePath() -> str: ...
    @staticmethod
    def activeThemePath() -> str: ...
    @staticmethod
    def pkgDataPath() -> str: ...
    @staticmethod
    def pluginPath() -> str: ...
    @staticmethod
    def prefixPath() -> str: ...
    @staticmethod
    def systemEnvVars() -> dict[str, str]: ...
    @staticmethod
    def layoutTemplatePaths() -> list[str]: ...
    @staticmethod
    def svgPaths() -> list[str]: ...
    @staticmethod
    def setSvgPaths(svgPaths: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def srsDatabaseFilePath() -> str: ...
    @staticmethod
    def iconsPath() -> str: ...
    @staticmethod
    def splashPath() -> str: ...
    @staticmethod
    def qgisAuthDatabaseUri() -> str: ...
    @staticmethod
    @deprecated("""""")
    def qgisAuthDatabaseFilePath() -> str: ...
    @staticmethod
    def qgisUserDatabaseFilePath() -> str: ...
    @staticmethod
    def qgisSettingsDirPath() -> str: ...
    @staticmethod
    def qgisMasterDatabaseFilePath() -> str: ...
    @staticmethod
    def metadataPath() -> str: ...
    @staticmethod
    def i18nPath() -> str: ...
    @staticmethod
    def licenceFilePath() -> str: ...
    @staticmethod
    def translatorsFilePath() -> str: ...
    @staticmethod
    def serverResourcesPath() -> str: ...
    @staticmethod
    def donorsFilePath() -> str: ...
    @staticmethod
    def sponsorsFilePath() -> str: ...
    @staticmethod
    def contributorsFilePath() -> str: ...
    @staticmethod
    def authorsFilePath() -> str: ...
    @staticmethod
    def uiThemes() -> dict[str, str]: ...
    @staticmethod
    def setUITheme(themeName: str|None) -> None: ...
    @staticmethod
    def themeName() -> str: ...
    @staticmethod
    def resolvePkgPath() -> str: ...
    @staticmethod
    def setThemeName(themeName: str|None) -> None: ...
    @staticmethod
    def setFileOpenEventReceiver(receiver: QtCore.QObject|None) -> None: ...
    def notify(self, receiver: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def event(self, event: QtCore.QEvent|None) -> bool: ...
    @staticmethod
    def instance() -> 'QgsApplication|None': ...


class QgsApplicationThemeRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsApplicationThemeRegistry') -> None: ...

    def themeFolders(self) -> dict[str, str]: ...
    def themeFolder(self, name: str|None) -> str: ...
    def themes(self) -> list[str]: ...
    def removeTheme(self, name: str|None) -> bool: ...
    def addTheme(self, name: str|None, folder: str|None) -> bool: ...


class QgsArchive(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsArchive') -> None: ...

    def exists(self) -> bool: ...
    def dir(self) -> str: ...
    def files(self) -> list[str]: ...
    def removeFile(self, filename: str|None) -> bool: ...
    def addFile(self, filename: str|None) -> None: ...
    def clear(self) -> None: ...
    def unzip(self, zipFilename: str|None) -> bool: ...
    def zip(self, zipFilename: str|None) -> bool: ...


class QgsProjectArchive(QgsArchive):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectArchive') -> None: ...

    def auxiliaryStorageFile(self) -> str: ...
    def clearProjectFile(self) -> bool: ...
    def projectFile(self) -> str: ...
    def unzip(self, zipFilename: str|None) -> bool: ...


class QgsArrowInferSchemaOptions(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsArrowInferSchemaOptions') -> None: ...

    def geometryColumnName(self) -> str: ...
    def setGeometryColumnName(self, geometryColumnName: str|None) -> None: ...


class QgsArrowSchema(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsArrowSchema') -> None: ...

    def setGeometryColumnIndex(self, geometryColumnIndex: int) -> None: ...
    def geometryColumnIndex(self) -> int: ...
    def isValid(self) -> bool: ...
    def exportToAddress(self, otherAddress: int) -> None: ...
    def cSchemaAddress(self) -> int: ...


class QgsArrowArray(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def isValid(self) -> bool: ...
    def exportToAddress(self, otherAddress: int) -> None: ...
    def cArrayAddress(self) -> int: ...


class QgsArrowArrayStream(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def isValid(self) -> bool: ...
    def exportToAddress(self, otherAddress: int) -> None: ...
    def cArrayStreamAddress(self) -> int: ...


class QgsArrowIterator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, featureIterator: 'QgsFeatureIterator') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsArrowIterator') -> None: ...

    @typing.overload
    @staticmethod
    def inferSchema(layer: 'QgsVectorLayer', options: QgsArrowInferSchemaOptions = ...) -> QgsArrowSchema: ...
    @typing.overload
    @staticmethod
    def inferSchema(fields: 'QgsFields', hasGeometry: bool = ..., crs: 'QgsCoordinateReferenceSystem' = ..., options: QgsArrowInferSchemaOptions = ...) -> QgsArrowSchema: ...
    def nextFeatures(self, n: int) -> QgsArrowArray: ...
    def toArrayStream(self, batchSize: int = ...) -> QgsArrowArrayStream: ...
    def setSchema(self, schema: QgsArrowSchema) -> None: ...


class QgsAttributeTableConfig(PyQt6.sip.wrapper):

    class ActionWidgetStyle(enum.IntEnum):
        ButtonList = ... # type: QgsAttributeTableConfig.ActionWidgetStyle
        DropDown = ... # type: QgsAttributeTableConfig.ActionWidgetStyle

    class Type(enum.IntEnum):
        Field = ... # type: QgsAttributeTableConfig.Type
        Action = ... # type: QgsAttributeTableConfig.Type

    class ColumnConfig(PyQt6.sip.wrapper):

        hidden = ... # type: bool
        name = ... # type: str|None
        type = ... # type: 'QgsAttributeTableConfig.Type'
        width = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAttributeTableConfig.ColumnConfig') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeTableConfig') -> None: ...

    def __eq__(self, other: object): ...
    def __ne__(self, other: object): ...
    def hasSameColumns(self, other: 'QgsAttributeTableConfig') -> bool: ...
    def setSortOrder(self, sortOrder: QtCore.Qt.SortOrder) -> None: ...
    def sortOrder(self) -> QtCore.Qt.SortOrder: ...
    def setColumnHidden(self, column: int, hidden: bool) -> None: ...
    def columnHidden(self, column: int) -> bool: ...
    def setColumnWidth(self, column: int, width: int) -> None: ...
    def columnWidth(self, column: int) -> int: ...
    def setSortExpression(self, sortExpression: str|None) -> None: ...
    def sortExpression(self) -> str: ...
    def readXml(self, node: QtXml.QDomNode) -> None: ...
    def writeXml(self, node: QtXml.QDomNode) -> None: ...
    def setActionWidgetStyle(self, actionWidgetStyle: 'QgsAttributeTableConfig.ActionWidgetStyle') -> None: ...
    def actionWidgetStyle(self) -> 'QgsAttributeTableConfig.ActionWidgetStyle': ...
    def setActionWidgetVisible(self, visible: bool) -> None: ...
    def actionWidgetVisible(self) -> bool: ...
    def update(self, fields: 'QgsFields') -> None: ...
    def setColumns(self, columns: collections.abc.Iterable['QgsAttributeTableConfig.ColumnConfig']) -> None: ...
    def mapVisibleColumnToIndex(self, visibleColumn: int) -> int: ...
    def __len__(self) -> int: ...
    def size(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def columns(self) -> list['QgsAttributeTableConfig.ColumnConfig']: ...


class QgsMapLayer(QtCore.QObject):

    class SaveStyleResult(enum.Enum):
        Success = ... # type: QgsMapLayer.SaveStyleResult
        QmlGenerationFailed = ... # type: QgsMapLayer.SaveStyleResult
        SldGenerationFailed = ... # type: QgsMapLayer.SaveStyleResult
        DatabaseWriteFailed = ... # type: QgsMapLayer.SaveStyleResult

    class ReadFlag(enum.IntEnum):
        FlagDontResolveLayers = ... # type: QgsMapLayer.ReadFlag
        FlagTrustLayerMetadata = ... # type: QgsMapLayer.ReadFlag
        FlagReadExtentFromXml = ... # type: QgsMapLayer.ReadFlag
        FlagForceReadOnly = ... # type: QgsMapLayer.ReadFlag

    class StyleCategory(enum.IntEnum):
        LayerConfiguration = ... # type: QgsMapLayer.StyleCategory
        Symbology = ... # type: QgsMapLayer.StyleCategory
        Symbology3D = ... # type: QgsMapLayer.StyleCategory
        Labeling = ... # type: QgsMapLayer.StyleCategory
        Fields = ... # type: QgsMapLayer.StyleCategory
        Forms = ... # type: QgsMapLayer.StyleCategory
        Actions = ... # type: QgsMapLayer.StyleCategory
        MapTips = ... # type: QgsMapLayer.StyleCategory
        Diagrams = ... # type: QgsMapLayer.StyleCategory
        AttributeTable = ... # type: QgsMapLayer.StyleCategory
        Rendering = ... # type: QgsMapLayer.StyleCategory
        CustomProperties = ... # type: QgsMapLayer.StyleCategory
        GeometryOptions = ... # type: QgsMapLayer.StyleCategory
        Relations = ... # type: QgsMapLayer.StyleCategory
        Temporal = ... # type: QgsMapLayer.StyleCategory
        Legend = ... # type: QgsMapLayer.StyleCategory
        Elevation = ... # type: QgsMapLayer.StyleCategory
        Notes = ... # type: QgsMapLayer.StyleCategory
        AllVisualStyleCategories = ... # type: QgsMapLayer.StyleCategory
        AllAttributeCategories = ... # type: QgsMapLayer.StyleCategory
        AllStyleCategories = ... # type: QgsMapLayer.StyleCategory

    class LayerFlag(enum.IntEnum):
        Identifiable = ... # type: QgsMapLayer.LayerFlag
        Removable = ... # type: QgsMapLayer.LayerFlag
        Searchable = ... # type: QgsMapLayer.LayerFlag
        Private = ... # type: QgsMapLayer.LayerFlag

    class PropertyType(enum.IntEnum):
        Style = ... # type: QgsMapLayer.PropertyType
        Metadata = ... # type: QgsMapLayer.PropertyType

    def __init__(self, type: Qgis.LayerType = ..., name: str|None = ..., source: str|None = ...) -> None: ...

    def hasDependencyCycle(self, a0: collections.abc.Iterable['QgsMapLayerDependency']) -> bool: ...
    def invalidateWgs84Extent(self) -> None: ...
    def setError(self, error: 'QgsError') -> None: ...
    def appendError(self, error: 'QgsErrorMessage') -> None: ...
    def setProviderType(self, providerType: str|None) -> None: ...
    def readCommonStyle(self, layerElement: QtXml.QDomElement, context: 'QgsReadWriteContext', categories: 'QgsMapLayer.StyleCategory' = ...) -> None: ...
    def writeCommonStyle(self, layerElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: 'QgsReadWriteContext', categories: 'QgsMapLayer.StyleCategory' = ...) -> None: ...
    def writeStyleManager(self, layerNode: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    def readStyleManager(self, layerNode: QtXml.QDomNode) -> None: ...
    def writeCustomProperties(self, layerNode: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    def readCustomProperties(self, layerNode: QtXml.QDomNode, keyStartsWith: str|None = ...) -> None: ...
    def decodedSource(self, source: str|None, dataProvider: str|None, context: 'QgsReadWriteContext') -> str: ...
    def encodedSource(self, source: str|None, context: 'QgsReadWriteContext') -> str: ...
    def writeXml(self, layer_node: QtXml.QDomNode, document: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readXml(self, layer_node: QtXml.QDomNode, context: 'QgsReadWriteContext') -> bool: ...
    def setValid(self, valid: bool) -> None: ...
    def setExtent3D(self, box: 'QgsBox3D') -> None: ...
    def setExtent(self, rect: 'QgsRectangle') -> None: ...
    mapTipsEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapTipTemplateChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerModified: typing.ClassVar[QtCore.pyqtSignal]
    editingStopped: typing.ClassVar[QtCore.pyqtSignal]
    editingStarted: typing.ClassVar[QtCore.pyqtSignal]
    customPropertyChanged: typing.ClassVar[QtCore.pyqtSignal]
    isValidChanged: typing.ClassVar[QtCore.pyqtSignal]
    styleLoaded: typing.ClassVar[QtCore.pyqtSignal]
    dataSourceChanged: typing.ClassVar[QtCore.pyqtSignal]
    flagsChanged: typing.ClassVar[QtCore.pyqtSignal]
    metadataChanged: typing.ClassVar[QtCore.pyqtSignal]
    autoRefreshIntervalChanged: typing.ClassVar[QtCore.pyqtSignal]
    willBeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    dependenciesChanged: typing.ClassVar[QtCore.pyqtSignal]
    configChanged: typing.ClassVar[QtCore.pyqtSignal]
    request3DUpdate: typing.ClassVar[QtCore.pyqtSignal]
    renderer3DChanged: typing.ClassVar[QtCore.pyqtSignal]
    legendChanged: typing.ClassVar[QtCore.pyqtSignal]
    styleChanged: typing.ClassVar[QtCore.pyqtSignal]
    rendererChanged: typing.ClassVar[QtCore.pyqtSignal]
    opacityChanged: typing.ClassVar[QtCore.pyqtSignal]
    blendModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    dataChanged: typing.ClassVar[QtCore.pyqtSignal]
    recalculateExtents: typing.ClassVar[QtCore.pyqtSignal]
    repaintRequested: typing.ClassVar[QtCore.pyqtSignal]
    verticalCrsChanged: typing.ClassVar[QtCore.pyqtSignal]
    crs3DChanged: typing.ClassVar[QtCore.pyqtSignal]
    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    idChanged: typing.ClassVar[QtCore.pyqtSignal]
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    beforeResolveReferences: typing.ClassVar[QtCore.pyqtSignal]
    def project(self) -> 'QgsProject|None': ...
    def __repr__(self) -> typing.Any: ...
    def setTransformContext(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
    def setRefreshOnNofifyMessage(self, message: str|None) -> None: ...
    def setRefreshOnNotifyEnabled(self, enabled: bool) -> None: ...
    def setDependencies(self, layers: collections.abc.Iterable['QgsMapLayerDependency']) -> bool: ...
    def emitStyleChanged(self) -> None: ...
    def trigger3DUpdate(self) -> None: ...
    def triggerRepaint(self, deferredUpdate: bool = ...) -> None: ...
    def setScaleBasedVisibility(self, enabled: bool) -> None: ...
    def setMaximumScale(self, scale: float) -> None: ...
    def setMinimumScale(self, scale: float) -> None: ...
    @staticmethod
    def providerReadFlags(layerNode: QtXml.QDomNode, layerReadFlags: 'QgsMapLayer.ReadFlag') -> Qgis.DataProviderReadFlag: ...
    def mapTipsEnabled(self) -> bool: ...
    def setMapTipsEnabled(self, enabled: bool) -> None: ...
    def setMapTipTemplate(self, mapTipTemplate: str|None) -> None: ...
    def mapTipTemplate(self) -> str: ...
    def hasMapTips(self) -> bool: ...
    def setLegendPlaceholderImage(self, imgPath: str|None) -> None: ...
    def legendPlaceholderImage(self) -> str: ...
    def profileSource(self) -> 'QgsAbstractProfileSource|None': ...
    def elevationProperties(self) -> 'QgsMapLayerElevationProperties|None': ...
    def temporalProperties(self) -> 'QgsMapLayerTemporalProperties|None': ...
    def selectionProperties(self) -> 'QgsMapLayerSelectionProperties|None': ...
    @typing.overload
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    def accept(self, visitor: 'QgsObjectEntityVisitorInterface|None', context: 'QgsObjectVisitorContext') -> bool: ...
    @staticmethod
    def generateId(layerName: str|None) -> str: ...
    def setOriginalXmlProperties(self, originalXmlProperties: str|None) -> None: ...
    def originalXmlProperties(self) -> str: ...
    def isRefreshOnNotifyEnabled(self) -> bool: ...
    def refreshOnNotifyMessage(self) -> str: ...
    def dependencies(self) -> set['QgsMapLayerDependency']: ...
    def timestamp(self) -> QtCore.QDateTime: ...
    def htmlMetadata(self) -> str: ...
    def setMetadata(self, metadata: 'QgsLayerMetadata') -> None: ...
    def metadata(self) -> 'QgsLayerMetadata': ...
    def setAutoRefreshMode(self, mode: Qgis.AutoRefreshMode) -> None: ...
    @deprecated("""""")
    def setAutoRefreshEnabled(self, enabled: bool) -> None: ...
    def setAutoRefreshInterval(self, interval: int) -> None: ...
    def autoRefreshInterval(self) -> int: ...
    def autoRefreshMode(self) -> Qgis.AutoRefreshMode: ...
    @deprecated("""""")
    def hasAutoRefreshEnabled(self) -> bool: ...
    def hasScaleBasedVisibility(self) -> bool: ...
    def maximumScale(self) -> float: ...
    def minimumScale(self) -> float: ...
    def isInScaleRange(self, scale: float) -> bool: ...
    def renderer3D(self) -> 'QgsAbstract3DRenderer|None': ...
    def setRenderer3D(self, renderer: 'QgsAbstract3DRenderer|None') -> None: ...
    def styleManager(self) -> 'QgsMapLayerStyleManager|None': ...
    def legend(self) -> 'QgsMapLayerLegend|None': ...
    def setLegend(self, legend: 'QgsMapLayerLegend|None') -> None: ...
    @deprecated("""""")
    def legendUrlFormat(self) -> str: ...
    @deprecated("""""")
    def setLegendUrlFormat(self, legendUrlFormat: str|None) -> None: ...
    @deprecated("""""")
    def legendUrl(self) -> str: ...
    @deprecated("""""")
    def setLegendUrl(self, legendUrl: str|None) -> None: ...
    def undoStackStyles(self) -> QtGui.QUndoStack|None: ...
    def undoStack(self) -> QtGui.QUndoStack|None: ...
    def providerType(self) -> str: ...
    @typing.overload
    def setDataSource(self, dataSource: str|None, baseName: str|None = ..., provider: str|None = ..., loadDefaultStyleFlag: bool = ...) -> None: ...
    @typing.overload
    def setDataSource(self, dataSource: str|None, baseName: str|None, provider: str|None, options: 'QgsDataProvider.ProviderOptions', loadDefaultStyleFlag: bool = ...) -> None: ...
    @typing.overload
    def setDataSource(self, dataSource: str|None, baseName: str|None, provider: str|None, options: 'QgsDataProvider.ProviderOptions', flags: Qgis.DataProviderReadFlag) -> None: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: 'QgsReadWriteContext', categories: 'QgsMapLayer.StyleCategory' = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: 'QgsReadWriteContext', categories: 'QgsMapLayer.StyleCategory' = ...) -> bool: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: 'QgsReadWriteContext', categories: 'QgsMapLayer.StyleCategory' = ...) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: 'QgsReadWriteContext', categories: 'QgsMapLayer.StyleCategory' = ...) -> bool: ...
    def readSld(self, node: QtXml.QDomNode, errorMessage: str|None) -> bool: ...
    def loadSldStyle(self, uri: str|None) -> typing.Tuple[str, bool]: ...
    def saveSldStyleV2(self, exportContext: 'QgsSldExportContext') -> typing.Tuple[str, bool]: ...
    def saveSldStyle(self, uri: str|None) -> typing.Tuple[str, bool]: ...
    def saveNamedStyle(self, uri: str|None, categories: 'QgsMapLayer.StyleCategory' = ...) -> typing.Tuple[str, bool]: ...
    @typing.overload
    def saveDefaultStyle(self, categories: 'QgsMapLayer.StyleCategory') -> typing.Tuple[str, bool]: ...
    @typing.overload
    @deprecated("""""")
    def saveDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def exportSldStyleV3(self, exportContext: 'QgsSldExportContext') -> QtXml.QDomDocument: ...
    @deprecated("""""")
    def exportSldStyleV2(self, doc: QtXml.QDomDocument, errorMsg: str|None, exportContext: 'QgsSldExportContext') -> None: ...
    @deprecated("""""")
    def exportSldStyle(self, doc: QtXml.QDomDocument, errorMsg: str|None) -> None: ...
    def exportNamedStyle(self, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext' = ..., categories: 'QgsMapLayer.StyleCategory' = ...) -> str: ...
    def importNamedStyle(self, doc: QtXml.QDomDocument, categories: 'QgsMapLayer.StyleCategory' = ...) -> typing.Tuple[bool, str]: ...
    def loadNamedStyleFromDatabase(self, db: str|None, uri: str|None) -> typing.Tuple[bool, str]: ...
    def loadDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def styleURI(self) -> str: ...
    def importNamedMetadata(self, document: QtXml.QDomDocument, errorMessage: str|None) -> bool: ...
    def loadNamedMetadataFromDatabase(self, db: str|None, uri: str|None, qmd: str|None) -> bool: ...
    def loadDefaultMetadata(self) -> typing.Tuple[str, bool]: ...
    def loadNamedMetadata(self, uri: str|None) -> typing.Tuple[str, bool]: ...
    def saveNamedMetadata(self, uri: str|None) -> typing.Tuple[str, bool]: ...
    def saveDefaultMetadata(self) -> typing.Tuple[str, bool]: ...
    def exportNamedMetadata(self, doc: QtXml.QDomDocument, errorMsg: str|None) -> None: ...
    def metadataUri(self) -> str: ...
    @staticmethod
    def formatLayerName(name: str|None) -> str: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def setVerticalCrs(self, crs: 'QgsCoordinateReferenceSystem') -> typing.Tuple[bool, str]: ...
    def setCrs(self, srs: 'QgsCoordinateReferenceSystem', emitSignal: bool = ...) -> None: ...
    def crs3D(self) -> 'QgsCoordinateReferenceSystem': ...
    def verticalCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def error(self) -> 'QgsError': ...
    def removeCustomProperty(self, key: str|None) -> None: ...
    @typing.overload
    def loadNamedStyle(self, theURI: str|None, loadFromLocalDb: bool, categories: 'QgsMapLayer.StyleCategory' = ..., flags: Qgis.LoadStyleFlag = ...) -> typing.Tuple[str, bool]: ...
    @typing.overload
    def loadNamedStyle(self, uri: str|None, categories: 'QgsMapLayer.StyleCategory' = ..., flags: Qgis.LoadStyleFlag = ...) -> typing.Tuple[str, bool]: ...
    def saveStyleToDatabaseV2(self, name: str|None, description: str|None, useAsDefault: bool, uiFileContent: str|None, categories: 'QgsMapLayer.StyleCategory' = ...) -> typing.Tuple['QgsMapLayer.SaveStyleResult', str]: ...
    @deprecated("""""")
    def saveStyleToDatabase(self, name: str|None, description: str|None, useAsDefault: bool, uiFileContent: str|None, categories: 'QgsMapLayer.StyleCategory' = ...) -> str: ...
    def deleteStyleFromDatabase(self, styleId: str|None) -> typing.Tuple[bool, str]: ...
    def getStyleFromDatabase(self, styleId: str|None) -> typing.Tuple[str, str]: ...
    def listStylesInDatabase(self) -> typing.Tuple[int, list[str], list[str], list[str], str]: ...
    def customProperties(self) -> 'QgsObjectCustomProperties': ...
    def setCustomProperties(self, properties: 'QgsObjectCustomProperties') -> None: ...
    def customProperty(self, value: str|None, defaultValue: typing.Any = ...) -> typing.Any: ...
    def setCustomProperty(self, key: str|None, value: typing.Any) -> None: ...
    def customPropertyKeys(self) -> list[str]: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def writeLayerXml(self, layerElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readLayerXml(self, layerElement: QtXml.QDomElement, context: 'QgsReadWriteContext', flags: 'QgsMapLayer.ReadFlag' = ..., preloadedProvider: 'QgsDataProvider|None' = ...) -> bool: ...
    def isTemporary(self) -> bool: ...
    def isSpatial(self) -> bool: ...
    def isModified(self) -> bool: ...
    def isEditable(self) -> bool: ...
    def supportsEditing(self) -> bool: ...
    def setSubLayerVisibility(self, name: str|None, visible: bool) -> None: ...
    def setLayerOrder(self, layers: collections.abc.Iterable[str|None]) -> None: ...
    def subLayers(self) -> list[str]: ...
    def source(self) -> str: ...
    def publicSource(self, hidePassword: bool = ...) -> str: ...
    def isValid(self) -> bool: ...
    def wgs84Extent(self, forceRecalculate: bool = ...) -> 'QgsRectangle': ...
    def extent3D(self) -> 'QgsBox3D': ...
    def extent(self) -> 'QgsRectangle': ...
    def createMapRenderer(self, rendererContext: 'QgsRenderContext') -> 'QgsMapLayerRenderer|None': ...
    def reload(self) -> None: ...
    def readOnly(self) -> bool: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, blendMode: QtGui.QPainter.CompositionMode) -> None: ...
    @deprecated("""""")
    def metadataUrlFormat(self) -> str: ...
    @deprecated("""""")
    def setMetadataUrlFormat(self, metaUrlFormat: str|None) -> None: ...
    @deprecated("""""")
    def metadataUrlType(self) -> str: ...
    @deprecated("""""")
    def setMetadataUrlType(self, metaUrlType: str|None) -> None: ...
    @deprecated("""""")
    def metadataUrl(self) -> str: ...
    @deprecated("""""")
    def setMetadataUrl(self, metaUrl: str|None) -> None: ...
    def serverProperties(self) -> 'QgsMapLayerServerProperties|None': ...
    @deprecated("""""")
    def attributionUrl(self) -> str: ...
    @deprecated("""""")
    def setAttributionUrl(self, attribUrl: str|None) -> None: ...
    @deprecated("""""")
    def attribution(self) -> str: ...
    @deprecated("""""")
    def setAttribution(self, attrib: str|None) -> None: ...
    @deprecated("""""")
    def dataUrlFormat(self) -> str: ...
    @deprecated("""""")
    def setDataUrlFormat(self, dataUrlFormat: str|None) -> None: ...
    @deprecated("""""")
    def dataUrl(self) -> str: ...
    @deprecated("""""")
    def setDataUrl(self, dataUrl: str|None) -> None: ...
    @deprecated("""""")
    def keywordList(self) -> str: ...
    @deprecated("""""")
    def setKeywordList(self, keywords: str|None) -> None: ...
    @deprecated("""""")
    def abstract(self) -> str: ...
    @deprecated("""""")
    def setAbstract(self, abstract: str|None) -> None: ...
    @deprecated("""""")
    def title(self) -> str: ...
    @deprecated("""""")
    def setTitle(self, title: str|None) -> None: ...
    @deprecated("""""")
    def shortName(self) -> str: ...
    @deprecated("""""")
    def setShortName(self, shortName: str|None) -> None: ...
    def providerMetadata(self) -> 'QgsProviderMetadata|None': ...
    def dataProvider(self) -> 'QgsDataProvider|None': ...
    def name(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def setId(self, id: str|None) -> bool: ...
    def id(self) -> str: ...
    @staticmethod
    def extensionPropertyType(type: 'QgsMapLayer.PropertyType') -> str: ...
    def properties(self) -> Qgis.MapLayerProperty: ...
    def setFlags(self, flags: 'QgsMapLayer.LayerFlag') -> None: ...
    def flags(self) -> 'QgsMapLayer.LayerFlag': ...
    def type(self) -> Qgis.LayerType: ...
    @typing.overload
    def clone(self) -> 'QgsMapLayer|None': ...
    @typing.overload
    def clone(self, layer: 'QgsMapLayer|None') -> None: ...


class QgsExpressionContextGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionContextGenerator') -> None: ...

    def createExpressionContext(self) -> 'QgsExpressionContext': ...


class QgsExpressionContextScopeGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionContextScopeGenerator') -> None: ...

    def createExpressionContextScope(self) -> 'QgsExpressionContextScope|None': ...


class QgsFeatureSink(PyQt6.sip.wrapper):

    class Flag(enum.IntEnum):
        FastInsert = ... # type: QgsFeatureSink.Flag
        RollBackOnErrors = ... # type: QgsFeatureSink.Flag

    class SinkFlag(enum.IntEnum):
        RegeneratePrimaryKey = ... # type: QgsFeatureSink.SinkFlag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureSink') -> None: ...

    def lastError(self) -> str: ...
    def flushBuffer(self) -> bool: ...
    @typing.overload
    def addFeatures(self, features: collections.abc.Iterable['QgsFeature'], flags: 'QgsFeatureSink.Flag' = ...) -> bool: ...
    @typing.overload
    def addFeatures(self, iterator: 'QgsFeatureIterator', flags: 'QgsFeatureSink.Flag' = ...) -> bool: ...
    def addFeature(self, feature: 'QgsFeature', flags: 'QgsFeatureSink.Flag' = ...) -> bool: ...
    def finalize(self) -> None: ...


class QgsFeatureSource(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureSource') -> None: ...

    def hasSpatialIndex(self) -> Qgis.SpatialIndexPresence: ...
    def materialize(self, request: 'QgsFeatureRequest', feedback: 'QgsFeedback|None' = ...) -> 'QgsVectorLayer|None': ...
    def allFeatureIds(self) -> typing.Any: ...
    def sourceExtent3D(self) -> 'QgsBox3D': ...
    def sourceExtent(self) -> 'QgsRectangle': ...
    def maximumValue(self, fieldIndex: int) -> typing.Any: ...
    def minimumValue(self, fieldIndex: int) -> typing.Any: ...
    def uniqueValues(self, fieldIndex: int, limit: int = ...) -> set[typing.Any]: ...
    def hasFeatures(self) -> Qgis.FeatureAvailability: ...
    def featureCount(self) -> int: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def fields(self) -> 'QgsFields': ...
    def sourceCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def sourceName(self) -> str: ...
    def getFeatures(self, request: 'QgsFeatureRequest' = ...) -> 'QgsFeatureIterator': ...


class QgsAbstractProfileSource(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractProfileSource') -> None: ...

    def profileSourceName(self) -> str: ...
    def profileSourceId(self) -> str: ...
    def createProfileGenerator(self, request: 'QgsProfileRequest') -> 'QgsAbstractProfileGenerator|None': ...


class QgsVectorLayer(QgsMapLayer, QgsExpressionContextGenerator, QgsExpressionContextScopeGenerator, QgsFeatureSink, QgsFeatureSource, QgsAbstractProfileSource):

    class LayerOptions(PyQt6.sip.wrapper):

        fallbackCrs = ... # type: 'QgsCoordinateReferenceSystem'
        fallbackWkbType = ... # type: Qgis.WkbType
        forceReadOnly = ... # type: bool
        loadAllStoredStyles = ... # type: bool
        loadDefaultStyle = ... # type: bool
        readExtentFromXml = ... # type: bool
        skipCrsValidation = ... # type: bool
        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, loadDefaultStyle: bool = ..., readExtentFromXml: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, transformContext: 'QgsCoordinateTransformContext', loadDefaultStyle: bool = ..., readExtentFromXml: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayer.LayerOptions') -> None: ...

    class DeleteContext(PyQt6.sip.wrapper):

        cascade = ... # type: bool
        project = ... # type: 'QgsProject'

        @typing.overload
        def __init__(self, cascade: bool = ..., project: 'QgsProject|None' = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayer.DeleteContext') -> None: ...

        def handledFeatures(self, layer: 'QgsVectorLayer|None') -> typing.Any: ...
        def handledLayers(self, includeAuxiliaryLayers: bool = ...) -> list['QgsVectorLayer']: ...

    def __init__(self, path: str|None = ..., baseName: str|None = ..., providerLib: str|None = ..., options: 'QgsVectorLayer.LayerOptions' = ...) -> None: ...

    def setExtent3D(self, rect: 'QgsBox3D') -> None: ...
    def setExtent(self, rect: 'QgsRectangle') -> None: ...
    symbolFeatureCountMapChanged: typing.ClassVar[QtCore.pyqtSignal]
    supportsEditingChanged: typing.ClassVar[QtCore.pyqtSignal]
    readOnlyChanged: typing.ClassVar[QtCore.pyqtSignal]
    editFormConfigChanged: typing.ClassVar[QtCore.pyqtSignal]
    raiseError: typing.ClassVar[QtCore.pyqtSignal]
    displayExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    writeCustomSymbology: typing.ClassVar[QtCore.pyqtSignal]
    readCustomSymbology: typing.ClassVar[QtCore.pyqtSignal]
    editCommandDestroyed: typing.ClassVar[QtCore.pyqtSignal]
    editCommandEnded: typing.ClassVar[QtCore.pyqtSignal]
    editCommandStarted: typing.ClassVar[QtCore.pyqtSignal]
    featureBlendModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    labelingFontNotFound: typing.ClassVar[QtCore.pyqtSignal]
    committedGeometriesChanges: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributeValuesChanges: typing.ClassVar[QtCore.pyqtSignal]
    committedFeaturesRemoved: typing.ClassVar[QtCore.pyqtSignal]
    committedFeaturesAdded: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributesAdded: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributesDeleted: typing.ClassVar[QtCore.pyqtSignal]
    geometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    attributeValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    subsetStringChanged: typing.ClassVar[QtCore.pyqtSignal]
    updatedFields: typing.ClassVar[QtCore.pyqtSignal]
    featuresDeleted: typing.ClassVar[QtCore.pyqtSignal]
    featureDeleted: typing.ClassVar[QtCore.pyqtSignal]
    featureAdded: typing.ClassVar[QtCore.pyqtSignal]
    beforeRemovingExpressionField: typing.ClassVar[QtCore.pyqtSignal]
    attributeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    beforeAddingExpressionField: typing.ClassVar[QtCore.pyqtSignal]
    attributeAdded: typing.ClassVar[QtCore.pyqtSignal]
    afterRollBack: typing.ClassVar[QtCore.pyqtSignal]
    afterCommitChanges: typing.ClassVar[QtCore.pyqtSignal]
    beforeRollBack: typing.ClassVar[QtCore.pyqtSignal]
    beforeCommitChanges: typing.ClassVar[QtCore.pyqtSignal]
    beforeEditingStarted: typing.ClassVar[QtCore.pyqtSignal]
    beforeModifiedCheck: typing.ClassVar[QtCore.pyqtSignal]
    allowCommitChanged: typing.ClassVar[QtCore.pyqtSignal]
    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    @typing.overload
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    def accept(self, visitor: 'QgsObjectEntityVisitorInterface|None', context: 'QgsObjectVisitorContext') -> bool: ...
    def hasSpatialIndex(self) -> Qgis.SpatialIndexPresence: ...
    def setTransformContext(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
    def startEditing(self) -> bool: ...
    def updateExtents(self, force: bool = ...) -> None: ...
    def reselect(self) -> None: ...
    def removeSelection(self) -> None: ...
    @typing.overload
    def deselect(self, featureId: int) -> None: ...
    @typing.overload
    def deselect(self, featureIds: typing.Any) -> None: ...
    @typing.overload
    def select(self, featureId: int) -> None: ...
    @typing.overload
    def select(self, featureIds: typing.Any) -> None: ...
    def storedExpressionManager(self) -> 'QgsStoredExpressionManager|None': ...
    def geometryOptions(self) -> 'QgsGeometryOptions|None': ...
    def isEditCommandActive(self) -> bool: ...
    def readExtentFromXml(self) -> bool: ...
    def setReadExtentFromXml(self, readExtentFromXml: bool) -> None: ...
    def setEditFormConfig(self, editFormConfig: 'QgsEditFormConfig') -> None: ...
    def editFormConfig(self) -> 'QgsEditFormConfig': ...
    def createExpressionContextScope(self) -> 'QgsExpressionContextScope|None': ...
    def createExpressionContext(self) -> 'QgsExpressionContext': ...
    def setAttributeTableConfig(self, attributeTableConfig: QgsAttributeTableConfig) -> None: ...
    def attributeTableConfig(self) -> QgsAttributeTableConfig: ...
    def conditionalStyles(self) -> 'QgsConditionalLayerStyles|None': ...
    def simplifyDrawingCanbeApplied(self, renderContext: 'QgsRenderContext', simplifyHint: Qgis.VectorRenderingSimplificationFlag) -> bool: ...
    def simplifyMethod(self) -> 'QgsVectorSimplifyMethod': ...
    def setSimplifyMethod(self, simplifyMethod: 'QgsVectorSimplifyMethod') -> None: ...
    def htmlMetadata(self) -> str: ...
    def featureBlendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setFeatureBlendMode(self, blendMode: QtGui.QPainter.CompositionMode) -> None: ...
    def aggregate(self, aggregate: Qgis.Aggregate, fieldOrExpression: str|None, parameters: QgsAggregateCalculator.AggregateParameters = ..., context: 'QgsExpressionContext|None' = ..., fids: typing.Any = ..., feedback: 'QgsFeedback|None' = ...) -> typing.Tuple[typing.Any, bool]: ...
    def minimumAndMaximumValue(self, index: int) -> typing.Tuple[typing.Any, typing.Any]: ...
    def maximumValue(self, index: int) -> typing.Any: ...
    def minimumValue(self, index: int) -> typing.Any: ...
    def uniqueStringsMatching(self, index: int, substring: str|None, limit: int = ..., feedback: 'QgsFeedback|None' = ...) -> list[str]: ...
    def uniqueValues(self, fieldIndex: int, limit: int = ...) -> set[typing.Any]: ...
    def editorWidgetSetup(self, index: int) -> 'QgsEditorWidgetSetup': ...
    def setEditorWidgetSetup(self, index: int, setup: 'QgsEditorWidgetSetup') -> None: ...
    def fieldConfigurationFlags(self, index: int) -> Qgis.FieldConfigurationFlag: ...
    def setFieldConfigurationFlag(self, index: int, flag: Qgis.FieldConfigurationFlag, active: bool) -> None: ...
    def setFieldConfigurationFlags(self, index: int, flags: Qgis.FieldConfigurationFlag) -> None: ...
    def setConstraintExpression(self, index: int, expression: str|None, description: str|None = ...) -> None: ...
    def constraintDescription(self, index: int) -> str: ...
    def constraintExpression(self, index: int) -> str: ...
    def removeFieldConstraint(self, index: int, constraint: 'QgsFieldConstraints.Constraint') -> None: ...
    def setFieldConstraint(self, index: int, constraint: 'QgsFieldConstraints.Constraint', strength: 'QgsFieldConstraints.ConstraintStrength' = ...) -> None: ...
    def fieldConstraintsAndStrength(self, fieldIndex: int) -> dict['QgsFieldConstraints.Constraint', 'QgsFieldConstraints.ConstraintStrength']: ...
    def fieldConstraints(self, fieldIndex: int) -> 'QgsFieldConstraints.Constraint': ...
    def defaultValueDefinition(self, index: int) -> 'QgsDefaultValue': ...
    def setDefaultValueDefinition(self, index: int, definition: 'QgsDefaultValue') -> None: ...
    def defaultValue(self, index: int, feature: 'QgsFeature' = ..., context: 'QgsExpressionContext|None' = ...) -> typing.Any: ...
    def updateFields(self) -> None: ...
    @staticmethod
    def drawVertexMarker(x: float, y: float, p: QtGui.QPainter, type: Qgis.VertexMarkerType, vertexSize: int) -> None: ...
    def destroyEditCommand(self) -> None: ...
    def endEditCommand(self) -> None: ...
    def beginEditCommand(self, text: str|None) -> None: ...
    def editBuffer(self) -> 'QgsVectorLayerEditBuffer|None': ...
    def referencingRelations(self, idx: int) -> list['QgsRelation']: ...
    def rollBack(self, deleteBuffer: bool = ...) -> bool: ...
    def commitErrors(self) -> list[str]: ...
    def commitChanges(self, stopEditing: bool = ...) -> bool: ...
    def deleteFeatures(self, fids: typing.Any, context: 'QgsVectorLayer.DeleteContext|None' = ...) -> bool: ...
    def deleteFeature(self, fid: int, context: 'QgsVectorLayer.DeleteContext|None' = ...) -> bool: ...
    def addFeatures(self, features: collections.abc.Iterable['QgsFeature'], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def deleteAttributes(self, attrs: collections.abc.Iterable[int]) -> bool: ...
    def deleteAttribute(self, attr: int) -> bool: ...
    @deprecated("""""")
    def setExcludeAttributesWfs(self, att: collections.abc.Iterable[str|None]) -> None: ...
    @deprecated("""""")
    def excludeAttributesWfs(self) -> set[str]: ...
    @deprecated("""""")
    def setExcludeAttributesWms(self, att: collections.abc.Iterable[str|None]) -> None: ...
    @deprecated("""""")
    def excludeAttributesWms(self) -> set[str]: ...
    def setFieldMergePolicy(self, index: int, policy: Qgis.FieldDomainMergePolicy) -> None: ...
    def setFieldDuplicatePolicy(self, index: int, policy: Qgis.FieldDuplicatePolicy) -> None: ...
    def setFieldSplitPolicy(self, index: int, policy: Qgis.FieldDomainSplitPolicy) -> None: ...
    def attributeAliases(self) -> dict[str, str]: ...
    def attributeDisplayName(self, index: int) -> str: ...
    def attributeAlias(self, index: int) -> str: ...
    def renameAttribute(self, index: int, newName: str|None) -> bool: ...
    def removeFieldAlias(self, index: int) -> None: ...
    def setFieldAlias(self, index: int, aliasString: str|None) -> None: ...
    def addAttribute(self, field: 'QgsField') -> bool: ...
    def changeAttributeValues(self, fid: int, newValues: dict[int, typing.Any], oldValues: dict[int, typing.Any] = ..., skipDefaultValues: bool = ..., context: 'QgsVectorLayerToolsContext|None' = ...) -> bool: ...
    def changeAttributeValue(self, fid: int, field: int, newValue: typing.Any, oldValue: typing.Any = ..., skipDefaultValues: bool = ..., context: 'QgsVectorLayerToolsContext|None' = ...) -> bool: ...
    def changeGeometry(self, fid: int, geometry: 'QgsGeometry', skipDefaultValue: bool = ...) -> bool: ...
    def supportsEditing(self) -> bool: ...
    def setReadOnly(self, readonly: bool = ...) -> bool: ...
    def primaryKeyAttributes(self) -> list[int]: ...
    def attributeList(self) -> list[int]: ...
    def fields(self) -> 'QgsFields': ...
    def sourceExtent3D(self) -> 'QgsBox3D': ...
    def extent3D(self) -> 'QgsBox3D': ...
    def sourceExtent(self) -> 'QgsRectangle': ...
    def extent(self) -> 'QgsRectangle': ...
    def createMapRenderer(self, rendererContext: 'QgsRenderContext') -> 'QgsMapLayerRenderer|None': ...
    def reload(self) -> None: ...
    def isAuxiliaryField(self, index: int) -> typing.Tuple[bool, int]: ...
    def isModified(self) -> bool: ...
    def isSpatial(self) -> bool: ...
    def isEditable(self) -> bool: ...
    def setLabeling(self, labeling: 'QgsAbstractVectorLayerLabeling|None') -> None: ...
    def labeling(self) -> 'QgsAbstractVectorLayerLabeling|None': ...
    @typing.overload
    def addTopologicalPoints(self, geom: 'QgsGeometry') -> int: ...
    @typing.overload
    @deprecated("""""")
    def addTopologicalPoints(self, p: 'QgsPointXY') -> int: ...
    @typing.overload
    def addTopologicalPoints(self, p: 'QgsPoint') -> int: ...
    @typing.overload
    def addTopologicalPoints(self, ps: collections.abc.Iterable['QgsPoint']) -> int: ...
    @typing.overload
    @deprecated("""""")
    def splitFeatures(self, splitLine: collections.abc.Iterable['QgsPointXY'], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitFeatures(self, splitLine: collections.abc.Iterable['QgsPoint'], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitFeatures(self, curve: 'QgsCurve|None', preserveCircular: bool = ..., topologicalEditing: bool = ...) -> typing.Tuple[Qgis.GeometryOperationResult, list['QgsPoint']]: ...
    @typing.overload
    @deprecated("""""")
    def splitParts(self, splitLine: collections.abc.Iterable['QgsPointXY'], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitParts(self, splitLine: collections.abc.Iterable['QgsPoint'], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    def translateFeature(self, featureId: int, dx: float, dy: float) -> int: ...
    def addCurvedPart(self, ring: 'QgsCurve|None') -> Qgis.GeometryOperationResult: ...
    def addPartV2(self, ring: collections.abc.Iterable['QgsPoint']) -> Qgis.GeometryOperationResult: ...
    @deprecated("""""")
    def addPart(self, ring: collections.abc.Iterable['QgsPointXY']) -> Qgis.GeometryOperationResult: ...
    def addCurvedRing(self, ring: 'QgsCurve|None') -> typing.Tuple[Qgis.GeometryOperationResult, int]: ...
    @typing.overload
    @deprecated("""""")
    def addRing(self, ring: collections.abc.Iterable['QgsPointXY']) -> typing.Tuple[Qgis.GeometryOperationResult, int]: ...
    @typing.overload
    def addRing(self, ring: collections.abc.Iterable['QgsPoint']) -> typing.Tuple[Qgis.GeometryOperationResult, int]: ...
    def deleteSelectedFeatures(self, context: 'QgsVectorLayer.DeleteContext|None' = ...) -> typing.Tuple[bool, int]: ...
    def deleteVertex(self, featureId: int, vertex: int) -> Qgis.VectorEditResult: ...
    def moveVertexV2(self, p: 'QgsPoint', atFeatureId: int, atVertex: int) -> bool: ...
    def moveVertex(self, x: float, y: float, atFeatureId: int, atVertex: int) -> bool: ...
    @typing.overload
    def insertVertex(self, x: float, y: float, atFeatureId: int, beforeVertex: int) -> bool: ...
    @typing.overload
    def insertVertex(self, point: 'QgsPoint', atFeatureId: int, beforeVertex: int) -> bool: ...
    def updateFeature(self, feature: 'QgsFeature', skipDefaultValues: bool = ...) -> bool: ...
    def addFeature(self, feature: 'QgsFeature', flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def getGeometry(self, fid: int) -> 'QgsGeometry': ...
    def getFeature(self, fid: int) -> 'QgsFeature': ...
    @typing.overload
    def getFeatures(self, request: 'QgsFeatureRequest' = ...) -> 'QgsFeatureIterator': ...
    @typing.overload
    def getFeatures(self, expression: str|None) -> 'QgsFeatureIterator': ...
    @typing.overload
    def getFeatures(self, fids: typing.Any) -> 'QgsFeatureIterator': ...
    @typing.overload
    def getFeatures(self, rectangle: 'QgsRectangle') -> 'QgsFeatureIterator': ...
    def subsetString(self) -> str: ...
    def setSubsetString(self, subset: str|None) -> bool: ...
    def countSymbolFeatures(self, storeSymbolFids: bool = ...) -> 'QgsVectorLayerFeatureCounter|None': ...
    def loadDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def hasFeatures(self) -> Qgis.FeatureAvailability: ...
    def symbolFeatureIds(self, legendKey: str|None) -> typing.Any: ...
    @typing.overload
    def featureCount(self, legendKey: str|None) -> int: ...
    @typing.overload
    def featureCount(self) -> int: ...
    def readSld(self, node: QtXml.QDomNode, errorMessage: str|None) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def writeSld(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, props: dict[str|None, typing.Any] = ...) -> bool: ...
    @typing.overload
    def writeSld(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: 'QgsSldExportContext') -> bool: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: 'QgsReadWriteContext', categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: 'QgsReadWriteContext', categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: 'QgsReadWriteContext', categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readSymbology(self, layerNode: QtXml.QDomNode, errorMessage: str|None, context: 'QgsReadWriteContext', categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def auxiliaryLayer(self) -> 'QgsAuxiliaryLayer|None': ...
    def setAuxiliaryLayer(self, layer: 'QgsAuxiliaryLayer|None' = ...) -> None: ...
    def loadAuxiliaryLayer(self, storage: 'QgsAuxiliaryStorage', key: str|None = ...) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def decodedSource(self, source: str|None, provider: str|None, context: 'QgsReadWriteContext') -> str: ...
    def encodedSource(self, source: str|None, context: 'QgsReadWriteContext') -> str: ...
    def writeXml(self, layer_node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readXml(self, layer_node: QtXml.QDomNode, context: 'QgsReadWriteContext') -> bool: ...
    def sourceName(self) -> str: ...
    def sourceCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def wkbType(self) -> Qgis.WkbType: ...
    def geometryType(self) -> Qgis.GeometryType: ...
    def featureRendererGenerators(self) -> list['QgsFeatureRendererGenerator']: ...
    def removeFeatureRendererGenerator(self, id: str|None) -> None: ...
    def addFeatureRendererGenerator(self, generator: 'QgsFeatureRendererGenerator|None') -> None: ...
    def setRenderer(self, r: 'QgsFeatureRenderer|None') -> None: ...
    def renderer(self) -> 'QgsFeatureRenderer|None': ...
    def diagramLayerSettings(self) -> 'QgsDiagramLayerSettings|None': ...
    def setDiagramLayerSettings(self, s: 'QgsDiagramLayerSettings') -> None: ...
    def diagramRenderer(self) -> 'QgsDiagramRenderer|None': ...
    def setDiagramRenderer(self, r: 'QgsDiagramRenderer|None') -> None: ...
    def diagramsEnabled(self) -> bool: ...
    def setLabelsEnabled(self, enabled: bool) -> None: ...
    def labelsEnabled(self) -> bool: ...
    def boundingBoxOfSelected(self) -> 'QgsRectangle': ...
    def selectedFeatureIds(self) -> typing.Any: ...
    def getSelectedFeatures(self, request: 'QgsFeatureRequest' = ...) -> 'QgsFeatureIterator': ...
    def selectedFeatures(self) -> list['QgsFeature']: ...
    def invertSelectionInRectangle(self, rect: 'QgsRectangle') -> None: ...
    def selectAll(self) -> None: ...
    def invertSelection(self) -> None: ...
    def modifySelection(self, selectIds: typing.Any, deselectIds: typing.Any) -> None: ...
    def selectByIds(self, ids: typing.Any, behavior: Qgis.SelectBehavior = ..., validateIds: bool = ...) -> None: ...
    def selectByExpression(self, expression: str|None, behavior: Qgis.SelectBehavior = ..., context: 'QgsExpressionContext|None' = ...) -> None: ...
    def selectByRect(self, rect: 'QgsRectangle', behavior: Qgis.SelectBehavior = ...) -> None: ...
    def selectedFeatureCount(self) -> int: ...
    def actions(self) -> 'QgsActionManager|None': ...
    def updateExpressionField(self, index: int, exp: str|None) -> None: ...
    def expressionField(self, index: int) -> str: ...
    def removeExpressionField(self, index: int) -> None: ...
    def addExpressionField(self, exp: str|None, fld: 'QgsField') -> int: ...
    def dependencies(self) -> set['QgsMapLayerDependency']: ...
    def setDependencies(self, layers: collections.abc.Iterable['QgsMapLayerDependency']) -> bool: ...
    def vectorJoins(self) -> list['QgsVectorLayerJoinInfo']: ...
    def joinBuffer(self) -> 'QgsVectorLayerJoinBuffer|None': ...
    def removeJoin(self, joinLayerId: str|None) -> bool: ...
    def addJoin(self, joinInfo: 'QgsVectorLayerJoinInfo') -> bool: ...
    def setCoordinateSystem(self) -> None: ...
    def setProviderEncoding(self, encoding: str|None) -> None: ...
    def createProfileGenerator(self, request: 'QgsProfileRequest') -> 'QgsAbstractProfileGenerator|None': ...
    def profileSourceName(self) -> str: ...
    def profileSourceId(self) -> str: ...
    def profileSource(self) -> QgsAbstractProfileSource|None: ...
    def elevationProperties(self) -> 'QgsMapLayerElevationProperties|None': ...
    def temporalProperties(self) -> 'QgsMapLayerTemporalProperties|None': ...
    def selectionProperties(self) -> 'QgsMapLayerSelectionProperties|None': ...
    def dataProvider(self) -> 'QgsVectorDataProvider|None': ...
    def hasMapTips(self) -> bool: ...
    def displayExpression(self) -> str: ...
    def setDisplayExpression(self, displayExpression: str|None) -> None: ...
    def displayField(self) -> str: ...
    def dataComment(self) -> str: ...
    def vectorLayerTypeFlags(self) -> Qgis.VectorLayerTypeFlag: ...
    def isSqlQuery(self) -> bool: ...
    def capabilitiesString(self) -> str: ...
    def storageType(self) -> str: ...
    def clone(self) -> 'QgsVectorLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsAuxiliaryLayer(QgsVectorLayer):

    def __init__(self, pkField: str|None, filename: str|None, table: str|None, vlayer: QgsVectorLayer|None) -> None: ...

    @staticmethod
    def propertyDefinitionFromField(field: 'QgsField') -> 'QgsPropertyDefinition': ...
    @staticmethod
    def nameFromProperty(def_: 'QgsPropertyDefinition', joined: bool = ...) -> str: ...
    @typing.overload
    @staticmethod
    def createAuxiliaryField(definition: 'QgsPropertyDefinition') -> 'QgsField': ...
    @typing.overload
    @staticmethod
    def createAuxiliaryField(field: 'QgsField') -> 'QgsField': ...
    @typing.overload
    @staticmethod
    def createProperty(property: 'QgsPalLayerSettings.Property', vlayer: QgsVectorLayer|None, overwriteExisting: bool = ...) -> int: ...
    @typing.overload
    @staticmethod
    def createProperty(property: 'QgsDiagramLayerSettings.Property', vlayer: QgsVectorLayer|None, overwriteExisting: bool = ...) -> int: ...
    @typing.overload
    @staticmethod
    def createProperty(property: 'QgsCallout.Property', vlayer: QgsVectorLayer|None, overwriteExisting: bool = ...) -> int: ...
    def propertyDefinitionFromIndex(self, index: int) -> 'QgsPropertyDefinition': ...
    def propertyFromIndex(self, index: int) -> int: ...
    def indexOfPropertyDefinition(self, definition: 'QgsPropertyDefinition') -> int: ...
    def isHiddenProperty(self, index: int) -> bool: ...
    def deleteAttribute(self, attr: int) -> bool: ...
    def save(self) -> bool: ...
    def auxiliaryFields(self) -> 'QgsFields': ...
    def addAuxiliaryField(self, definition: 'QgsPropertyDefinition') -> bool: ...
    def exists(self, definition: 'QgsPropertyDefinition') -> bool: ...
    def joinInfo(self) -> 'QgsVectorLayerJoinInfo': ...
    def clear(self) -> bool: ...
    def toSpatialLayer(self) -> QgsVectorLayer|None: ...
    def clone(self, layer: QgsVectorLayer|None) -> 'QgsAuxiliaryLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsAuxiliaryStorage(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, project: 'QgsProject', copy: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, filename: str|None = ..., copy: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAuxiliaryStorage') -> None: ...

    @staticmethod
    def exists(project: 'QgsProject') -> bool: ...
    @staticmethod
    def extension() -> str: ...
    @staticmethod
    def duplicateTable(uri: 'QgsDataSourceUri', newTable: str|None) -> bool: ...
    @staticmethod
    def deleteTable(uri: 'QgsDataSourceUri') -> bool: ...
    def createAuxiliaryLayer(self, field: 'QgsField', layer: QgsVectorLayer|None) -> QgsAuxiliaryLayer|None: ...
    def save(self) -> bool: ...
    @typing.overload
    def saveAs(self, filename: str|None) -> bool: ...
    @typing.overload
    def saveAs(self, project: 'QgsProject') -> bool: ...
    def errorString(self) -> str: ...
    def currentFileName(self) -> str: ...
    def fileName(self) -> str: ...
    def isValid(self) -> bool: ...


class QgsBearingUtils(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBearingUtils') -> None: ...

    @staticmethod
    def bearingTrueNorth(crs: 'QgsCoordinateReferenceSystem', transformContext: 'QgsCoordinateTransformContext', point: 'QgsPointXY') -> float: ...


class QgsBookmark(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBookmark') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    @staticmethod
    def fromXml(element: QtXml.QDomElement, doc: QtXml.QDomDocument) -> 'QgsBookmark': ...
    def setRotation(self, rotation: float) -> None: ...
    def rotation(self) -> float: ...
    def setExtent(self, extent: 'QgsReferencedRectangle') -> None: ...
    def extent(self) -> 'QgsReferencedRectangle': ...
    def setGroup(self, group: str|None) -> None: ...
    def group(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def setId(self, id: str|None) -> None: ...
    def id(self) -> str: ...


class QgsBookmarkManager(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    bookmarkChanged: typing.ClassVar[QtCore.pyqtSignal]
    bookmarkAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    bookmarkRemoved: typing.ClassVar[QtCore.pyqtSignal]
    bookmarkAdded: typing.ClassVar[QtCore.pyqtSignal]
    bookmarkAboutToBeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def importFromFile(self, path: str|None) -> bool: ...
    @staticmethod
    def exportToFile(path: str|None, managers: collections.abc.Iterable['QgsBookmarkManager'], group: str|None = ...) -> bool: ...
    def moveBookmark(self, id: str|None, destination: 'QgsBookmarkManager|None') -> bool: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...
    def bookmarksByGroup(self, group: str|None) -> list[QgsBookmark]: ...
    def bookmarkById(self, id: str|None) -> QgsBookmark: ...
    def bookmarks(self) -> list[QgsBookmark]: ...
    def renameGroup(self, oldName: str|None, newName: str|None) -> None: ...
    def groups(self) -> list[str]: ...
    def clear(self) -> None: ...
    def updateBookmark(self, bookmark: QgsBookmark) -> bool: ...
    def removeBookmark(self, id: str|None) -> bool: ...
    def addBookmark(self, bookmark: QgsBookmark) -> typing.Tuple[str, bool]: ...
    def initialize(self, filePath: str|None) -> None: ...
    @staticmethod
    def createProjectBasedManager(project: 'QgsProject|None') -> 'QgsBookmarkManager|None': ...


class QgsBookmarkManagerModel(QtCore.QAbstractTableModel):

    class Columns(enum.IntEnum):
        ColumnName = ... # type: QgsBookmarkManagerModel.Columns
        ColumnGroup = ... # type: QgsBookmarkManagerModel.Columns
        ColumnXMin = ... # type: QgsBookmarkManagerModel.Columns
        ColumnYMin = ... # type: QgsBookmarkManagerModel.Columns
        ColumnXMax = ... # type: QgsBookmarkManagerModel.Columns
        ColumnYMax = ... # type: QgsBookmarkManagerModel.Columns
        ColumnRotation = ... # type: QgsBookmarkManagerModel.Columns
        ColumnCrs = ... # type: QgsBookmarkManagerModel.Columns
        ColumnStore = ... # type: QgsBookmarkManagerModel.Columns

    class CustomRole(enum.IntEnum):
        Extent = ... # type: QgsBookmarkManagerModel.CustomRole
        Name = ... # type: QgsBookmarkManagerModel.CustomRole
        Id = ... # type: QgsBookmarkManagerModel.CustomRole
        Group = ... # type: QgsBookmarkManagerModel.CustomRole
        Rotation = ... # type: QgsBookmarkManagerModel.CustomRole

    def __init__(self, manager: QgsBookmarkManager|None, projectManager: QgsBookmarkManager|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def insertRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...


class QgsBookmarkManagerProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, manager: QgsBookmarkManager|None, projectManager: QgsBookmarkManager|None = ..., parent: QtCore.QObject|None = ...) -> None: ...


class QgsAbstractFeatureIterator(PyQt6.sip.wrapper):

    class RequestToSourceCrsResult(enum.IntEnum):
        Success = ... # type: QgsAbstractFeatureIterator.RequestToSourceCrsResult
        DistanceWithinMustBeCheckedManually = ... # type: QgsAbstractFeatureIterator.RequestToSourceCrsResult

    class CompileStatus(enum.IntEnum):
        NoCompilation = ... # type: QgsAbstractFeatureIterator.CompileStatus
        PartiallyCompiled = ... # type: QgsAbstractFeatureIterator.CompileStatus
        Compiled = ... # type: QgsAbstractFeatureIterator.CompileStatus

    @typing.overload
    def __init__(self, request: 'QgsFeatureRequest') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractFeatureIterator') -> None: ...

    def prepareSimplification(self, simplifyMethod: 'QgsSimplifyMethod') -> bool: ...
    def deref(self) -> None: ...
    def ref(self) -> None: ...
    def updateRequestToSourceCrs(self, request: 'QgsFeatureRequest', transform: 'QgsCoordinateTransform') -> 'QgsAbstractFeatureIterator.RequestToSourceCrsResult': ...
    def filterRectToSourceCrs(self, transform: 'QgsCoordinateTransform') -> 'QgsRectangle': ...
    def geometryToDestinationCrs(self, feature: 'QgsFeature', transform: 'QgsCoordinateTransform') -> None: ...
    def nextFeatureFilterFids(self, f: 'QgsFeature') -> bool: ...
    def nextFeatureFilterExpression(self, f: 'QgsFeature') -> bool: ...
    def fetchFeature(self, f: 'QgsFeature') -> bool: ...
    def compileFailed(self) -> bool: ...
    def isValid(self) -> bool: ...
    def compileStatus(self) -> 'QgsAbstractFeatureIterator.CompileStatus': ...
    def close(self) -> bool: ...
    def rewind(self) -> bool: ...
    def nextFeature(self, f: 'QgsFeature') -> bool: ...


class QgsCachedFeatureIterator(QgsAbstractFeatureIterator):

    def __init__(self, vlCache: 'QgsVectorLayerCache|None', featureRequest: 'QgsFeatureRequest') -> None: ...

    def nextFeatureFilterFids(self, f: 'QgsFeature') -> bool: ...
    def fetchFeature(self, f: 'QgsFeature') -> bool: ...
    def close(self) -> bool: ...
    def rewind(self) -> bool: ...


class QgsCachedFeatureWriterIterator(QgsAbstractFeatureIterator):

    @typing.overload
    def __init__(self, vlCache: 'QgsVectorLayerCache|None', featureRequest: 'QgsFeatureRequest') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCachedFeatureWriterIterator') -> None: ...

    def fetchFeature(self, f: 'QgsFeature') -> bool: ...
    def close(self) -> bool: ...
    def rewind(self) -> bool: ...


class QgsAbstractCacheIndex(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractCacheIndex') -> None: ...

    def getCacheIterator(self, featureIterator: 'QgsFeatureIterator', featureRequest: 'QgsFeatureRequest') -> bool: ...
    def requestCompleted(self, featureRequest: 'QgsFeatureRequest', fids: typing.Any) -> None: ...
    def flush(self) -> None: ...
    def flushFeature(self, fid: int) -> None: ...


class QgsCacheIndexFeatureId(QgsAbstractCacheIndex):

    @typing.overload
    def __init__(self, a0: 'QgsVectorLayerCache|None') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCacheIndexFeatureId') -> None: ...

    def getCacheIterator(self, featureIterator: 'QgsFeatureIterator', featureRequest: 'QgsFeatureRequest') -> bool: ...
    def requestCompleted(self, featureRequest: 'QgsFeatureRequest', fids: typing.Any) -> None: ...
    def flush(self) -> None: ...
    def flushFeature(self, fid: int) -> None: ...


class QgsCadUtils(PyQt6.sip.wrapper):

    class AlignMapPointConstraint(PyQt6.sip.wrapper):

        locked = ... # type: bool
        relative = ... # type: bool
        value = ... # type: float

        @typing.overload
        def __init__(self, locked: bool = ..., relative: bool = ..., value: float = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCadUtils.AlignMapPointConstraint') -> None: ...

    class AlignMapPointOutput(PyQt6.sip.wrapper):

        edgeMatch = ... # type: 'QgsPointLocator.Match'
        finalMapPoint = ... # type: 'QgsPointXY'
        snapMatch = ... # type: 'QgsPointLocator.Match'
        softLockCommonAngle = ... # type: float
        softLockLineExtension = ... # type: Qgis.LineExtensionSide
        softLockX = ... # type: float
        softLockY = ... # type: float
        valid = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCadUtils.AlignMapPointOutput') -> None: ...

    class AlignMapPointContext(PyQt6.sip.wrapper):

        angleConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        commonAngleConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        distanceConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        lineExtensionConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        mConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        mapUnitsPerPixel = ... # type: float
        snappingToFeaturesOverridesCommonAngle = ... # type: bool
        snappingUtils = ... # type: 'QgsSnappingUtils'
        xConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        xyVertexConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        yConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'
        zConstraint = ... # type: 'QgsCadUtils.AlignMapPointConstraint'

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCadUtils.AlignMapPointContext') -> None: ...

        def _cadPointList(self) -> list['QgsPointXY']: ...
        def _setCadPointList(self, list: collections.abc.Iterable['QgsPointXY']) -> None: ...
        def cadPoint(self, index: int) -> 'QgsPoint': ...
        def setCadPoint(self, index: int, point: 'QgsPoint') -> None: ...
        def setCadPoints(self, points: collections.abc.Iterable['QgsPoint']) -> None: ...
        def cadPoints(self) -> list['QgsPoint']: ...
        @property
        def cadPointList(self) -> list['QgsPointXY']: ...
        @cadPointList.setter
        def cadPointList(self, list: collections.abc.Iterable['QgsPointXY']) -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCadUtils') -> None: ...

    @staticmethod
    def alignMapPoint(originalMapPoint: 'QgsPointXY', ctx: 'QgsCadUtils.AlignMapPointContext') -> 'QgsCadUtils.AlignMapPointOutput': ...


class QgsClipper(PyQt6.sip.wrapper):

    class Boundary(enum.IntEnum):
        XMax = ... # type: QgsClipper.Boundary
        XMin = ... # type: QgsClipper.Boundary
        YMax = ... # type: QgsClipper.Boundary
        YMin = ... # type: QgsClipper.Boundary
        ZMax = ... # type: QgsClipper.Boundary
        ZMin = ... # type: QgsClipper.Boundary

    MAX_X = ... # type: float
    MAX_Y = ... # type: float
    MIN_X = ... # type: float
    MIN_Y = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClipper') -> None: ...

    @staticmethod
    def clipLineSegment(left: float, right: float, bottom: float, top: float, x0: float, y0: float, x1: float, y1: float) -> typing.Tuple[bool, float, float, float, float]: ...
    @typing.overload
    @staticmethod
    def clippedLine(curve: 'QgsCurve', clipExtent: 'QgsRectangle') -> QtGui.QPolygonF: ...
    @typing.overload
    @staticmethod
    def clippedLine(curve: QtGui.QPolygonF, clipExtent: 'QgsRectangle') -> QtGui.QPolygonF: ...
    @staticmethod
    def trimPolygon(pts: QtGui.QPolygonF, clipRect: 'QgsRectangle') -> None: ...
    @staticmethod
    def trimFeature(x: collections.abc.Iterable[float], y: collections.abc.Iterable[float], shapeOpen: bool) -> None: ...


class QgsCommandLineUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCommandLineUtils') -> None: ...

    @staticmethod
    def allVersions() -> str: ...


class QgsColorRamp(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsColorRamp') -> None: ...

    @staticmethod
    def rampTypes() -> list[tuple[str, str]]: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsColorRamp|None': ...
    def invert(self) -> None: ...
    def type(self) -> str: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def value(self, index: int) -> float: ...
    def count(self) -> int: ...


class QgsGradientStop(PyQt6.sip.wrapper):

    color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    offset = ... # type: float

    @typing.overload
    def __init__(self, offset: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGradientStop') -> None: ...

    def setDirection(self, direction: Qgis.AngularDirection) -> None: ...
    def direction(self) -> Qgis.AngularDirection: ...
    def setColorSpec(self, spec: QtGui.QColor.Spec) -> None: ...
    def colorSpec(self) -> QtGui.QColor.Spec: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsGradientColorRamp(QgsColorRamp):

    @typing.overload
    def __init__(self, color1: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., color2: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., discrete: bool = ..., stops: collections.abc.Iterable[QgsGradientStop] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGradientColorRamp') -> None: ...

    def setDirection(self, direction: Qgis.AngularDirection) -> None: ...
    def direction(self) -> Qgis.AngularDirection: ...
    def setColorSpec(self, spec: QtGui.QColor.Spec) -> None: ...
    def colorSpec(self) -> QtGui.QColor.Spec: ...
    def addStopsToGradient(self, gradient: QtGui.QGradient|None, opacity: float = ...) -> None: ...
    def setInfo(self, info: dict[str|None, str|None]) -> None: ...
    def info(self) -> dict[str, str]: ...
    def stops(self) -> list[QgsGradientStop]: ...
    def setStops(self, stops: collections.abc.Iterable[QgsGradientStop]) -> None: ...
    def convertToDiscrete(self, discrete: bool) -> None: ...
    def setDiscrete(self, discrete: bool) -> None: ...
    def isDiscrete(self) -> bool: ...
    def setColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor1(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color2(self) -> QtGui.QColor: ...
    def color1(self) -> QtGui.QColor: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsGradientColorRamp|None': ...
    def invert(self) -> None: ...
    def type(self) -> str: ...
    @staticmethod
    def typeString() -> str: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def value(self, index: int) -> float: ...
    def count(self) -> int: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsColorRamp|None: ...


class QgsLimitedRandomColorRamp(QgsColorRamp):

    @typing.overload
    def __init__(self, count: int = ..., hueMin: int = ..., hueMax: int = ..., satMin: int = ..., satMax: int = ..., valMin: int = ..., valMax: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLimitedRandomColorRamp') -> None: ...

    def setValMax(self, val: int) -> None: ...
    def setValMin(self, val: int) -> None: ...
    def setSatMax(self, val: int) -> None: ...
    def setSatMin(self, val: int) -> None: ...
    def setHueMax(self, val: int) -> None: ...
    def setHueMin(self, val: int) -> None: ...
    def setCount(self, val: int) -> None: ...
    def valMax(self) -> int: ...
    def valMin(self) -> int: ...
    def satMax(self) -> int: ...
    def satMin(self) -> int: ...
    def hueMax(self) -> int: ...
    def hueMin(self) -> int: ...
    def updateColors(self) -> None: ...
    @staticmethod
    def randomColors(count: int, hueMax: int = ..., hueMin: int = ..., satMax: int = ..., satMin: int = ..., valMax: int = ..., valMin: int = ...) -> list[QtGui.QColor]: ...
    def count(self) -> int: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsLimitedRandomColorRamp|None': ...
    def type(self) -> str: ...
    @staticmethod
    def typeString() -> str: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def value(self, index: int) -> float: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsColorRamp|None: ...


class QgsRandomColorRamp(QgsColorRamp):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRandomColorRamp') -> None: ...

    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsRandomColorRamp|None': ...
    def type(self) -> str: ...
    @staticmethod
    def typeString() -> str: ...
    def setTotalColorCount(self, colorCount: int) -> None: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def value(self, index: int) -> float: ...
    def count(self) -> int: ...


class QgsColorScheme(PyQt6.sip.wrapper):

    class SchemeFlag(enum.IntEnum):
        ShowInColorDialog = ... # type: QgsColorScheme.SchemeFlag
        ShowInColorButtonMenu = ... # type: QgsColorScheme.SchemeFlag
        ShowInAllContexts = ... # type: QgsColorScheme.SchemeFlag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsColorScheme') -> None: ...

    def clone(self) -> 'QgsColorScheme|None': ...
    def setColors(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]], context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> bool: ...
    def isEditable(self) -> bool: ...
    def fetchColors(self, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> list[tuple[QtGui.QColor, str]]: ...
    def flags(self) -> 'QgsColorScheme.SchemeFlag': ...
    def schemeName(self) -> str: ...


class QgsPresetSchemeColorRamp(QgsColorRamp, QgsColorScheme):

    @typing.overload
    def __init__(self, colors: collections.abc.Iterable[QtGui.QColor|QtCore.Qt.GlobalColor|int] = ...) -> None: ...
    @typing.overload
    def __init__(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPresetSchemeColorRamp') -> None: ...

    def isEditable(self) -> bool: ...
    def fetchColors(self, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> list[tuple[QtGui.QColor, str]]: ...
    def schemeName(self) -> str: ...
    def count(self) -> int: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsPresetSchemeColorRamp|None': ...
    def invert(self) -> None: ...
    def type(self) -> str: ...
    @staticmethod
    def typeString() -> str: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def value(self, index: int) -> float: ...
    def colors(self) -> list[QtGui.QColor]: ...
    def setColors(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]], a1: str|None = ..., a2: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> bool: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsColorRamp|None: ...


class QgsColorBrewerColorRamp(QgsColorRamp):

    @typing.overload
    def __init__(self, schemeName: str|None = ..., colors: int = ..., inverted: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsColorBrewerColorRamp') -> None: ...

    def loadPalette(self) -> None: ...
    @staticmethod
    def listSchemeVariants(schemeName: str|None) -> list[int]: ...
    @staticmethod
    def listSchemeNames() -> list[str]: ...
    def setColors(self, colors: int) -> None: ...
    def setSchemeName(self, schemeName: str|None) -> None: ...
    def colors(self) -> int: ...
    def schemeName(self) -> str: ...
    def count(self) -> int: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsColorBrewerColorRamp|None': ...
    def invert(self) -> None: ...
    def type(self) -> str: ...
    @staticmethod
    def typeString() -> str: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def value(self, index: int) -> float: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsColorRamp|None: ...


class QgsCptCityColorRamp(QgsGradientColorRamp):

    @typing.overload
    def __init__(self, schemeName: str|None = ..., variantName: str|None = ..., inverted: bool = ..., doLoadFile: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, schemeName: str|None, variantList: collections.abc.Iterable[str|None], variantName: str|None = ..., inverted: bool = ..., doLoadFile: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCptCityColorRamp') -> None: ...

    def copyingInfo(self) -> dict[str, str]: ...
    def descFileName(self) -> str: ...
    def copyingFileName(self) -> str: ...
    def fileLoaded(self) -> bool: ...
    def loadFile(self) -> bool: ...
    def fileName(self) -> str: ...
    def hasMultiStops(self) -> bool: ...
    def loadPalette(self) -> None: ...
    def setName(self, schemeName: str|None, variantName: str|None = ..., variantList: collections.abc.Iterable[str|None] = ...) -> None: ...
    def setVariantList(self, variantList: collections.abc.Iterable[str|None]) -> None: ...
    def setVariantName(self, variantName: str|None) -> None: ...
    def setSchemeName(self, schemeName: str|None) -> None: ...
    def variantList(self) -> list[str]: ...
    def variantName(self) -> str: ...
    def schemeName(self) -> str: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def cloneGradientRamp(self) -> QgsGradientColorRamp|None: ...
    def copy(self, other: 'QgsCptCityColorRamp|None') -> None: ...
    def clone(self) -> 'QgsCptCityColorRamp|None': ...
    def invert(self) -> None: ...
    def type(self) -> str: ...
    @staticmethod
    def typeString() -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsColorRamp|None: ...


class QgsGplColorScheme(QgsColorScheme):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGplColorScheme') -> None: ...

    def gplFilePath(self) -> str: ...
    def setColors(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]], context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> bool: ...
    def fetchColors(self, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> list[tuple[QtGui.QColor, str]]: ...


class QgsUserColorScheme(QgsGplColorScheme):

    @typing.overload
    def __init__(self, filename: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsUserColorScheme') -> None: ...

    def gplFilePath(self) -> str: ...
    def setShowSchemeInMenu(self, show: bool) -> None: ...
    def erase(self) -> bool: ...
    def setName(self, name: str|None) -> None: ...
    def flags(self) -> QgsColorScheme.SchemeFlag: ...
    def isEditable(self) -> bool: ...
    def clone(self) -> 'QgsUserColorScheme|None': ...
    def schemeName(self) -> str: ...


class QgsRecentColorScheme(QgsColorScheme):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRecentColorScheme') -> None: ...

    @staticmethod
    def lastUsedColor() -> QtGui.QColor: ...
    @staticmethod
    def addRecentColor(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def clone(self) -> 'QgsRecentColorScheme|None': ...
    def fetchColors(self, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> list[tuple[QtGui.QColor, str]]: ...
    def flags(self) -> QgsColorScheme.SchemeFlag: ...
    def schemeName(self) -> str: ...


class QgsCustomColorScheme(QgsColorScheme):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCustomColorScheme') -> None: ...

    def clone(self) -> 'QgsCustomColorScheme|None': ...
    def setColors(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]], context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> bool: ...
    def isEditable(self) -> bool: ...
    def fetchColors(self, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> list[tuple[QtGui.QColor, str]]: ...
    def flags(self) -> QgsColorScheme.SchemeFlag: ...
    def schemeName(self) -> str: ...


class QgsProjectColorScheme(QgsColorScheme):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectColorScheme') -> None: ...

    def clone(self) -> 'QgsProjectColorScheme|None': ...
    def setColors(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]], context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> bool: ...
    def isEditable(self) -> bool: ...
    def fetchColors(self, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> list[tuple[QtGui.QColor, str]]: ...
    def flags(self) -> QgsColorScheme.SchemeFlag: ...
    def schemeName(self) -> str: ...


class QgsColorSchemeRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsColorSchemeRegistry') -> None: ...

    def fetchRandomStyleColor(self) -> QtGui.QColor: ...
    def randomStyleColorScheme(self) -> QgsColorScheme|None: ...
    def setRandomStyleColorScheme(self, scheme: QgsColorScheme|None) -> None: ...
    @typing.overload
    def schemes(self) -> list[QgsColorScheme]: ...
    @typing.overload
    def schemes(self, flag: QgsColorScheme.SchemeFlag) -> list[QgsColorScheme]: ...
    def removeColorScheme(self, scheme: QgsColorScheme|None) -> bool: ...
    def addColorScheme(self, scheme: QgsColorScheme|None) -> None: ...
    def addUserSchemes(self) -> None: ...
    def initStyleScheme(self) -> None: ...
    def addDefaultSchemes(self) -> None: ...
    def populateFromInstance(self) -> None: ...


class QgsColorUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsColorUtils') -> None: ...

    @staticmethod
    def saveIccProfile(colorSpace: QtGui.QColorSpace, iccProfileFilePath: str|None) -> str: ...
    @staticmethod
    def iccProfile(iccProfileFilePath: str|None) -> typing.Tuple[QtGui.QColorSpace, str]: ...
    @staticmethod
    def colorFromString(string: str|None) -> QtGui.QColor: ...
    @staticmethod
    def colorToString(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> str: ...
    @staticmethod
    def readXml(element: QtXml.QDomElement, identifier: str|None, context: 'QgsReadWriteContext') -> QtGui.QColor: ...
    @staticmethod
    def writeXml(color: QtGui.QColor|QtCore.Qt.GlobalColor|int, identifier: str|None, document: QtXml.QDomDocument, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...


class QgsConditionalLayerStyles(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def rulesNeedGeometry(self) -> bool: ...
    def writeXml(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readXml(self, node: QtXml.QDomNode, context: 'QgsReadWriteContext') -> bool: ...
    def fieldStyles(self, fieldName: str|None) -> list['QgsConditionalStyle']: ...
    def setFieldStyles(self, fieldName: str|None, styles: collections.abc.Iterable['QgsConditionalStyle']) -> None: ...
    def constraintFailureStyles(self, strength: 'QgsFieldConstraints.ConstraintStrength') -> 'QgsConditionalStyle': ...
    def setRowStyles(self, styles: collections.abc.Iterable['QgsConditionalStyle']) -> None: ...
    def rowStyles(self) -> list['QgsConditionalStyle']: ...


class QgsConditionalStyle(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsConditionalStyle') -> None: ...
    @typing.overload
    def __init__(self, rule: str|None) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def writeXml(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readXml(self, node: QtXml.QDomNode, context: 'QgsReadWriteContext') -> bool: ...
    @staticmethod
    def compressStyles(styles: collections.abc.Iterable['QgsConditionalStyle']) -> 'QgsConditionalStyle': ...
    @staticmethod
    def matchingConditionalStyle(styles: collections.abc.Iterable['QgsConditionalStyle'], value: typing.Any, context: 'QgsExpressionContext') -> 'QgsConditionalStyle': ...
    @staticmethod
    def matchingConditionalStyles(styles: collections.abc.Iterable['QgsConditionalStyle'], value: typing.Any, context: 'QgsExpressionContext') -> list['QgsConditionalStyle']: ...
    def isValid(self) -> bool: ...
    def rule(self) -> str: ...
    def font(self) -> QtGui.QFont: ...
    def validBackgroundColor(self) -> bool: ...
    def backgroundColor(self) -> QtGui.QColor: ...
    def validTextColor(self) -> bool: ...
    def textColor(self) -> QtGui.QColor: ...
    def symbol(self) -> 'QgsSymbol|None': ...
    def icon(self) -> QtGui.QPixmap: ...
    def name(self) -> str: ...
    def displayText(self) -> str: ...
    def setSymbol(self, value: 'QgsSymbol|None') -> None: ...
    def setFont(self, value: QtGui.QFont) -> None: ...
    def setTextColor(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setBackgroundColor(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setRule(self, value: str|None) -> None: ...
    def setName(self, value: str|None) -> None: ...
    def renderPreview(self, size: QtCore.QSize = ...) -> QtGui.QPixmap: ...
    def matches(self, value: typing.Any, context: 'QgsExpressionContext') -> bool: ...


class QgsConnectionRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def createConnection(self, name: str|None) -> 'QgsAbstractProviderConnection|None': ...


class QgsCoordinateFormatter(PyQt6.sip.wrapper):

    class FormatFlag(enum.IntEnum):
        FlagDegreesUseStringSuffix = ... # type: QgsCoordinateFormatter.FormatFlag
        FlagDegreesPadMinutesSeconds = ... # type: QgsCoordinateFormatter.FormatFlag

    class Format(enum.IntEnum):
        FormatPair = ... # type: QgsCoordinateFormatter.Format
        FormatDegreesMinutesSeconds = ... # type: QgsCoordinateFormatter.Format
        FormatDegreesMinutes = ... # type: QgsCoordinateFormatter.Format
        FormatDecimalDegrees = ... # type: QgsCoordinateFormatter.Format

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCoordinateFormatter') -> None: ...

    @staticmethod
    def separator() -> str: ...
    @staticmethod
    def asPair(x: float, y: float, precision: int = ..., order: Qgis.CoordinateOrder = ...) -> str: ...
    @staticmethod
    def format(point: 'QgsPointXY', format: 'QgsCoordinateFormatter.Format', precision: int = ..., flags: 'QgsCoordinateFormatter.FormatFlag' = ..., order: Qgis.CoordinateOrder = ...) -> str: ...
    @staticmethod
    def formatY(y: float, format: 'QgsCoordinateFormatter.Format', precision: int = ..., flags: 'QgsCoordinateFormatter.FormatFlag' = ...) -> str: ...
    @staticmethod
    def formatX(x: float, format: 'QgsCoordinateFormatter.Format', precision: int = ..., flags: 'QgsCoordinateFormatter.FormatFlag' = ...) -> str: ...


class QgsTask(QtCore.QObject):

    class SubTaskDependency(enum.IntEnum):
        SubTaskIndependent = ... # type: QgsTask.SubTaskDependency
        ParentDependsOnSubTask = ... # type: QgsTask.SubTaskDependency

    class Flag(enum.IntEnum):
        CanCancel = ... # type: QgsTask.Flag
        CancelWithoutPrompt = ... # type: QgsTask.Flag
        Hidden = ... # type: QgsTask.Flag
        Silent = ... # type: QgsTask.Flag
        AllFlags = ... # type: QgsTask.Flag

    class TaskStatus(enum.IntEnum):
        Queued = ... # type: QgsTask.TaskStatus
        OnHold = ... # type: QgsTask.TaskStatus
        Running = ... # type: QgsTask.TaskStatus
        Complete = ... # type: QgsTask.TaskStatus
        Terminated = ... # type: QgsTask.TaskStatus

    def __init__(self, description: str|None = ..., flags: 'QgsTask.Flag' = ...) -> None: ...

    def setProgress(self, progress: float) -> None: ...
    def isCanceled(self) -> bool: ...
    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    taskTerminated: typing.ClassVar[QtCore.pyqtSignal]
    taskCompleted: typing.ClassVar[QtCore.pyqtSignal]
    begun: typing.ClassVar[QtCore.pyqtSignal]
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    progressChanged: typing.ClassVar[QtCore.pyqtSignal]
    def waitForFinished(self, timeout: int = ...) -> bool: ...
    def dependentLayers(self) -> list[QgsMapLayer]: ...
    def setDependentLayers(self, dependentLayers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def addSubTask(self, subTask: 'QgsTask|None', dependencies: collections.abc.Iterable['QgsTask'] = ..., subTaskDependency: 'QgsTask.SubTaskDependency' = ...) -> None: ...
    def unhold(self) -> None: ...
    def hold(self) -> None: ...
    def cancel(self) -> None: ...
    def elapsedTime(self) -> int: ...
    def progress(self) -> float: ...
    def description(self) -> str: ...
    def status(self) -> 'QgsTask.TaskStatus': ...
    def isActive(self) -> bool: ...
    def canCancel(self) -> bool: ...
    def setDescription(self, description: str|None) -> None: ...
    def flags(self) -> 'QgsTask.Flag': ...


class QgsCopyFileTask(QgsTask):

    def __init__(self, source: str|None, destination: str|None) -> None: ...

    def destination(self) -> str: ...
    def errorString(self) -> str: ...
    def run(self) -> bool: ...


class QgsCredentials(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def setInstance(self, instance: 'QgsCredentials|None') -> None: ...
    def requestMasterPassword(self, password: str|None, stored: bool = ...) -> typing.Tuple[bool, str]: ...
    def request(self, realm: str|None, username: str|None, password: str|None, message: str|None = ...) -> typing.Tuple[bool, str, str]: ...
    def mutex(self) -> QtCore.QMutex|None: ...
    def unlock(self) -> None: ...
    def lock(self) -> None: ...
    @staticmethod
    def instance() -> 'QgsCredentials|None': ...
    def getMasterPassword(self, password: str|None, stored: bool = ...) -> typing.Tuple[bool, str]: ...
    def put(self, realm: str|None, username: str|None, password: str|None) -> None: ...
    def get(self, realm: str|None, username: str|None, password: str|None, message: str|None = ..., requestCredentials: bool = ...) -> typing.Tuple[bool, str, str]: ...


class QgsCredentialsNone(QtCore.QObject, QgsCredentials):

    def __init__(self) -> None: ...

    def requestMasterPassword(self, password: str|None, stored: bool = ...) -> typing.Tuple[bool, str]: ...
    def request(self, realm: str|None, username: str|None, password: str|None, message: str|None = ...) -> typing.Tuple[bool, str, str]: ...
    destroyed: typing.ClassVar[QtCore.pyqtSignal]


class QgsCredentialsConsole(QtCore.QObject, QgsCredentials):

    def __init__(self) -> None: ...

    def requestMasterPassword(self, password: str|None, stored: bool = ...) -> typing.Tuple[bool, str]: ...
    def request(self, realm: str|None, username: str|None, password: str|None, message: str|None = ...) -> typing.Tuple[bool, str, str]: ...
    destroyed: typing.ClassVar[QtCore.pyqtSignal]


class QgsDartMeasurement(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        Text = ... # type: QgsDartMeasurement.Type
        ImagePng = ... # type: QgsDartMeasurement.Type
        Integer = ... # type: QgsDartMeasurement.Type

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, type: 'QgsDartMeasurement.Type', value: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDartMeasurement') -> None: ...

    @staticmethod
    def typeToString(type: 'QgsDartMeasurement.Type') -> str: ...
    def send(self) -> None: ...
    def toString(self) -> str: ...


class QgsDatabaseSchemaModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        Empty = ... # type: QgsDatabaseSchemaModel.CustomRole

    @typing.overload
    def __init__(self, provider: str|None, connection: str|None, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, connection: 'QgsAbstractDatabaseProviderConnection|None', parent: QtCore.QObject|None = ...) -> None: ...

    def refresh(self) -> None: ...
    def allowEmptySchema(self) -> bool: ...
    def setAllowEmptySchema(self, allowEmpty: bool) -> None: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...


class QgsDatabaseTableModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        TableName = ... # type: QgsDatabaseTableModel.CustomRole
        Schema = ... # type: QgsDatabaseTableModel.CustomRole
        TableFlags = ... # type: QgsDatabaseTableModel.CustomRole
        Comment = ... # type: QgsDatabaseTableModel.CustomRole
        CustomInfo = ... # type: QgsDatabaseTableModel.CustomRole
        WkbType = ... # type: QgsDatabaseTableModel.CustomRole
        Crs = ... # type: QgsDatabaseTableModel.CustomRole
        Empty = ... # type: QgsDatabaseTableModel.CustomRole

    @typing.overload
    def __init__(self, provider: str|None, connection: str|None, schema: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, connection: 'QgsAbstractDatabaseProviderConnection|None', schema: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def refresh(self) -> None: ...
    def allowEmptyTable(self) -> bool: ...
    def setAllowEmptyTable(self, allowEmpty: bool) -> None: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...


class QgsDataDefinedSizeLegend(PyQt6.sip.wrapper):

    class VerticalAlignment(enum.IntEnum):
        AlignCenter = ... # type: QgsDataDefinedSizeLegend.VerticalAlignment
        AlignBottom = ... # type: QgsDataDefinedSizeLegend.VerticalAlignment

    class LegendType(enum.IntEnum):
        LegendSeparated = ... # type: QgsDataDefinedSizeLegend.LegendType
        LegendCollapsed = ... # type: QgsDataDefinedSizeLegend.LegendType

    class SizeClass(PyQt6.sip.wrapper):

        label = ... # type: str|None
        size = ... # type: float

        @typing.overload
        def __init__(self, size: float, label: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDataDefinedSizeLegend.SizeClass') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsDataDefinedSizeLegend') -> None: ...

    def writeXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    @staticmethod
    def readXml(elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> 'QgsDataDefinedSizeLegend|None': ...
    def collapsedLegendImage(self, context: 'QgsRenderContext', backgroundColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., paddingMM: float = ...) -> QtGui.QImage: ...
    def drawCollapsedLegend(self, context: 'QgsRenderContext') -> typing.Tuple[QtCore.QSizeF|None, float]: ...
    def legendSymbolList(self) -> list['QgsLegendSymbolItem']: ...
    def updateFromSymbolAndProperty(self, symbol: 'QgsMarkerSymbol|None', ddSize: 'QgsProperty') -> None: ...
    def textAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setTextAlignment(self, flag: QtCore.Qt.AlignmentFlag) -> None: ...
    def textColor(self) -> QtGui.QColor: ...
    def setTextColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def font(self) -> QtGui.QFont: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def verticalAlignment(self) -> 'QgsDataDefinedSizeLegend.VerticalAlignment': ...
    def setVerticalAlignment(self, vAlign: 'QgsDataDefinedSizeLegend.VerticalAlignment') -> None: ...
    def title(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    def classes(self) -> list['QgsDataDefinedSizeLegend.SizeClass']: ...
    def setClasses(self, classes: collections.abc.Iterable['QgsDataDefinedSizeLegend.SizeClass']) -> None: ...
    def sizeScaleTransformer(self) -> 'QgsSizeScaleTransformer|None': ...
    def setSizeScaleTransformer(self, transformer: 'QgsSizeScaleTransformer|None') -> None: ...
    def lineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def symbol(self) -> 'QgsMarkerSymbol|None': ...
    def setSymbol(self, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def legendType(self) -> 'QgsDataDefinedSizeLegend.LegendType': ...
    def setLegendType(self, type: 'QgsDataDefinedSizeLegend.LegendType') -> None: ...


class QgsDataProviderElevationProperties(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataProviderElevationProperties') -> None: ...

    def setContainsElevationData(self, contains: bool) -> None: ...
    def containsElevationData(self) -> bool: ...


class QgsDataProviderTemporalCapabilities(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, available: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataProviderTemporalCapabilities') -> None: ...

    def setHasTemporalCapabilities(self, available: bool) -> None: ...
    def hasTemporalCapabilities(self) -> bool: ...


class QgsDataSourceUri(PyQt6.sip.wrapper):

    class SslMode(enum.IntEnum):
        SslPrefer = ... # type: QgsDataSourceUri.SslMode
        SslDisable = ... # type: QgsDataSourceUri.SslMode
        SslAllow = ... # type: QgsDataSourceUri.SslMode
        SslRequire = ... # type: QgsDataSourceUri.SslMode
        SslVerifyCa = ... # type: QgsDataSourceUri.SslMode
        SslVerifyFull = ... # type: QgsDataSourceUri.SslMode

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataSourceUri') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def setHttpHeaders(self, headers: 'QgsHttpHeaders') -> None: ...
    def httpHeader(self, key: str|None) -> str: ...
    def httpHeaders(self) -> 'QgsHttpHeaders': ...
    def parameterKeys(self) -> set[str]: ...
    def setGeometryColumn(self, geometryColumn: str|None) -> None: ...
    def setTable(self, table: str|None) -> None: ...
    @staticmethod
    def encodeSslMode(sslMode: 'QgsDataSourceUri.SslMode') -> str: ...
    @staticmethod
    def decodeSslMode(sslMode: str|None) -> 'QgsDataSourceUri.SslMode': ...
    def setSrid(self, srid: str|None) -> None: ...
    def srid(self) -> str: ...
    def setWkbType(self, type: Qgis.WkbType) -> None: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def setKeyColumn(self, column: str|None) -> None: ...
    def keyColumn(self) -> str: ...
    def service(self) -> str: ...
    def setService(self, service: str|None) -> None: ...
    def sslMode(self) -> 'QgsDataSourceUri.SslMode': ...
    def setSslMode(self, mode: 'QgsDataSourceUri.SslMode') -> None: ...
    def password(self) -> str: ...
    def setDriver(self, driver: str|None) -> None: ...
    def driver(self) -> str: ...
    def port(self) -> str: ...
    def setPort(self, port: str|None) -> None: ...
    def database(self) -> str: ...
    def host(self) -> str: ...
    def setHost(self, host: str|None) -> None: ...
    def setSql(self, sql: str|None) -> None: ...
    def setSchema(self, schema: str|None) -> None: ...
    def clearSchema(self) -> None: ...
    def selectAtIdDisabled(self) -> bool: ...
    def disableSelectAtId(self, flag: bool) -> None: ...
    def useEstimatedMetadata(self) -> bool: ...
    def setUseEstimatedMetadata(self, flag: bool) -> None: ...
    def geometryColumn(self) -> str: ...
    def sql(self) -> str: ...
    def table(self) -> str: ...
    def schema(self) -> str: ...
    def username(self) -> str: ...
    def authConfigId(self) -> str: ...
    @staticmethod
    def removePassword(aUri: str|None, hide: bool = ...) -> str: ...
    def setPassword(self, password: str|None) -> None: ...
    def setUsername(self, username: str|None) -> None: ...
    def setAuthConfigId(self, authcfg: str|None) -> None: ...
    def setDataSource(self, aSchema: str|None, aTable: str|None, aGeometryColumn: str|None, aSql: str|None = ..., aKeyColumn: str|None = ...) -> None: ...
    def setDatabase(self, database: str|None) -> None: ...
    @typing.overload
    def setConnection(self, aHost: str|None, aPort: str|None, aDatabase: str|None, aUsername: str|None, aPassword: str|None, sslmode: 'QgsDataSourceUri.SslMode' = ..., authConfigId: str|None = ...) -> None: ...
    @typing.overload
    def setConnection(self, aService: str|None, aDatabase: str|None, aUsername: str|None, aPassword: str|None, sslmode: 'QgsDataSourceUri.SslMode' = ..., authConfigId: str|None = ...) -> None: ...
    def hasParam(self, key: str|None) -> bool: ...
    def params(self, key: str|None) -> list[str]: ...
    def param(self, key: str|None) -> str: ...
    def removeParam(self, key: str|None) -> int: ...
    def setParamList(self, key: str|None, value: collections.abc.Iterable[str|None]) -> None: ...
    def setParam(self, key: str|None, value: str|None) -> None: ...
    def quotedTablename(self) -> str: ...
    def setEncodedUri(self, uri: str|None) -> None: ...
    def encodedUri(self) -> QtCore.QByteArray: ...
    def uri(self, expandAuthConfig: bool = ...) -> str: ...
    def connectionInfo(self, expandAuthConfig: bool = ...) -> str: ...


class QgsDateTimeStatisticalSummary(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, stats: Qgis.DateTimeStatistic = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDateTimeStatisticalSummary') -> None: ...

    @staticmethod
    def displayName(statistic: Qgis.DateTimeStatistic) -> str: ...
    def range(self) -> 'QgsInterval': ...
    def max(self) -> QtCore.QDateTime: ...
    def min(self) -> QtCore.QDateTime: ...
    def countMissing(self) -> int: ...
    def distinctValues(self) -> set[QtCore.QDateTime]: ...
    def countDistinct(self) -> int: ...
    def count(self) -> int: ...
    def statistic(self, stat: Qgis.DateTimeStatistic) -> typing.Any: ...
    def finalize(self) -> None: ...
    def addValue(self, value: typing.Any) -> None: ...
    def calculate(self, values: collections.abc.Iterable[typing.Any]) -> None: ...
    def reset(self) -> None: ...
    def setStatistics(self, stats: Qgis.DateTimeStatistic) -> None: ...
    def statistics(self) -> Qgis.DateTimeStatistic: ...


@deprecated("")
class QgsDatabaseFilterProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def filterAcceptsRow(self, row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def _setFilterRegExp(self, pattern: str|None) -> None: ...
    def _setFilterWildcard(self, pattern: str|None) -> None: ...


class QgsDatabaseQueryLogEntry(PyQt6.sip.wrapper):

    canceled = ... # type: bool
    error = ... # type: str|None
    fetchedRows = ... # type: int
    finishedTime = ... # type: int
    initiatorClass = ... # type: str|None
    origin = ... # type: str|None
    provider = ... # type: str|None
    query = ... # type: str|None
    queryId = ... # type: int
    startedTime = ... # type: int
    uri = ... # type: str|None

    @typing.overload
    def __init__(self, query: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDatabaseQueryLogEntry') -> None: ...


class QgsDatabaseQueryLog(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    @staticmethod
    def finished(query: QgsDatabaseQueryLogEntry) -> None: ...
    @staticmethod
    def log(query: QgsDatabaseQueryLogEntry) -> None: ...
    @staticmethod
    def enabled() -> bool: ...


class QgsDefaultValue(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, expression: str|None = ..., applyOnUpdate: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDefaultValue') -> None: ...

    def __ne__(self, other: object): ...
    def isValid(self) -> bool: ...
    def setApplyOnUpdate(self, applyOnUpdate: bool) -> None: ...
    def applyOnUpdate(self) -> bool: ...
    def setExpression(self, expression: str|None) -> None: ...
    def expression(self) -> str: ...
    def __repr__(self) -> typing.Any: ...
    def __eq__(self, other: object): ...


class QgsDiagramLayerSettings(PyQt6.sip.wrapper):

    class DiagramType(enum.IntEnum):
        Single = ... # type: QgsDiagramLayerSettings.DiagramType
        Stacked = ... # type: QgsDiagramLayerSettings.DiagramType

    class Property(enum.IntEnum):
        BackgroundColor = ... # type: QgsDiagramLayerSettings.Property
        StrokeColor = ... # type: QgsDiagramLayerSettings.Property
        StrokeWidth = ... # type: QgsDiagramLayerSettings.Property
        PositionX = ... # type: QgsDiagramLayerSettings.Property
        PositionY = ... # type: QgsDiagramLayerSettings.Property
        Distance = ... # type: QgsDiagramLayerSettings.Property
        Priority = ... # type: QgsDiagramLayerSettings.Property
        ZIndex = ... # type: QgsDiagramLayerSettings.Property
        IsObstacle = ... # type: QgsDiagramLayerSettings.Property
        Show = ... # type: QgsDiagramLayerSettings.Property
        AlwaysShow = ... # type: QgsDiagramLayerSettings.Property
        StartAngle = ... # type: QgsDiagramLayerSettings.Property

    class LinePlacementFlag(enum.IntEnum):
        OnLine = ... # type: QgsDiagramLayerSettings.LinePlacementFlag
        AboveLine = ... # type: QgsDiagramLayerSettings.LinePlacementFlag
        BelowLine = ... # type: QgsDiagramLayerSettings.LinePlacementFlag
        MapOrientation = ... # type: QgsDiagramLayerSettings.LinePlacementFlag

    class Placement(enum.IntEnum):
        AroundPoint = ... # type: QgsDiagramLayerSettings.Placement
        OverPoint = ... # type: QgsDiagramLayerSettings.Placement
        Line = ... # type: QgsDiagramLayerSettings.Placement
        Curved = ... # type: QgsDiagramLayerSettings.Placement
        Horizontal = ... # type: QgsDiagramLayerSettings.Placement
        Free = ... # type: QgsDiagramLayerSettings.Placement

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, rh: 'QgsDiagramLayerSettings') -> None: ...

    def setDataDefinedProperties(self, collection: 'QgsPropertyCollection') -> None: ...
    def dataDefinedProperties(self) -> 'QgsPropertyCollection': ...
    def referencedFields(self, context: 'QgsExpressionContext' = ...) -> set[str]: ...
    def prepare(self, context: 'QgsExpressionContext' = ...) -> bool: ...
    def writeXml(self, layerElem: QtXml.QDomElement, doc: QtXml.QDomDocument) -> None: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def setShowAllDiagrams(self, showAllDiagrams: bool) -> None: ...
    def showAllDiagrams(self) -> bool: ...
    def setCoordinateTransform(self, transform: 'QgsCoordinateTransform') -> None: ...
    def coordinateTransform(self) -> 'QgsCoordinateTransform': ...
    def setRenderer(self, diagramRenderer: 'QgsDiagramRenderer|None') -> None: ...
    def renderer(self) -> 'QgsDiagramRenderer|None': ...
    def setDistance(self, distance: float) -> None: ...
    def distance(self) -> float: ...
    def setIsObstacle(self, isObstacle: bool) -> None: ...
    def isObstacle(self) -> bool: ...
    def setZIndex(self, index: float) -> None: ...
    def zIndex(self) -> float: ...
    def setPriority(self, value: int) -> None: ...
    def priority(self) -> int: ...
    def setLinePlacementFlags(self, flags: 'QgsDiagramLayerSettings.LinePlacementFlag') -> None: ...
    def linePlacementFlags(self) -> 'QgsDiagramLayerSettings.LinePlacementFlag': ...
    def setPlacement(self, value: 'QgsDiagramLayerSettings.Placement') -> None: ...
    def placement(self) -> 'QgsDiagramLayerSettings.Placement': ...
    @staticmethod
    def propertyDefinitions() -> dict[int, 'QgsPropertyDefinition']: ...


class QgsDiagramSettings(PyQt6.sip.wrapper):

    class StackedDiagramMode(enum.IntEnum):
        Horizontal = ... # type: QgsDiagramSettings.StackedDiagramMode
        Vertical = ... # type: QgsDiagramSettings.StackedDiagramMode

    class Direction(enum.IntEnum):
        Clockwise = ... # type: QgsDiagramSettings.Direction
        Counterclockwise = ... # type: QgsDiagramSettings.Direction

    class DiagramOrientation(enum.IntEnum):
        Up = ... # type: QgsDiagramSettings.DiagramOrientation
        Down = ... # type: QgsDiagramSettings.DiagramOrientation
        Left = ... # type: QgsDiagramSettings.DiagramOrientation
        Right = ... # type: QgsDiagramSettings.DiagramOrientation

    class LabelPlacementMethod(enum.IntEnum):
        Height = ... # type: QgsDiagramSettings.LabelPlacementMethod
        XHeight = ... # type: QgsDiagramSettings.LabelPlacementMethod

    backgroundColor = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    barWidth = ... # type: float
    categoryAttributes = ... # type: collections.abc.Iterable[str|None]
    categoryColors = ... # type: collections.abc.Iterable[QtGui.QColor|QtCore.Qt.GlobalColor|int]
    categoryLabels = ... # type: collections.abc.Iterable[str|None]
    diagramOrientation = ... # type: 'QgsDiagramSettings.DiagramOrientation'
    enabled = ... # type: bool
    font = ... # type: QtGui.QFont
    labelPlacementMethod = ... # type: 'QgsDiagramSettings.LabelPlacementMethod'
    lineSizeScale = ... # type: 'QgsMapUnitScale'
    lineSizeUnit = ... # type: Qgis.RenderUnit
    maximumScale = ... # type: float
    minimumScale = ... # type: float
    minimumSize = ... # type: float
    opacity = ... # type: float
    penColor = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    penWidth = ... # type: float
    rotationOffset = ... # type: float
    scaleBasedVisibility = ... # type: bool
    scaleByArea = ... # type: bool
    size = ... # type: QtCore.QSizeF
    sizeScale = ... # type: 'QgsMapUnitScale'
    sizeType = ... # type: Qgis.RenderUnit
    stackedDiagramMode = ... # type: 'QgsDiagramSettings.StackedDiagramMode'

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsDiagramSettings') -> None: ...

    def setPaintEffect(self, effect: 'QgsPaintEffect|None') -> None: ...
    def paintEffect(self) -> 'QgsPaintEffect|None': ...
    def setShowAxis(self, showAxis: bool) -> None: ...
    def showAxis(self) -> bool: ...
    def setAxisLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def axisLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def legendItems(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def writeXml(self, rendererElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext' = ...) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext' = ...) -> None: ...
    def setDirection(self, direction: 'QgsDiagramSettings.Direction') -> None: ...
    def direction(self) -> 'QgsDiagramSettings.Direction': ...
    def stackedDiagramSpacingMapUnitScale(self) -> 'QgsMapUnitScale': ...
    def setStackedDiagramSpacingMapUnitScale(self, scale: 'QgsMapUnitScale') -> None: ...
    def stackedDiagramSpacingUnit(self) -> Qgis.RenderUnit: ...
    def setStackedDiagramSpacingUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setStackedDiagramSpacing(self, spacing: float) -> None: ...
    def stackedDiagramSpacing(self) -> float: ...
    def spacingMapUnitScale(self) -> 'QgsMapUnitScale': ...
    def setSpacingMapUnitScale(self, scale: 'QgsMapUnitScale') -> None: ...
    def spacingUnit(self) -> Qgis.RenderUnit: ...
    def setSpacingUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setSpacing(self, spacing: float) -> None: ...
    def spacing(self) -> float: ...


class QgsDiagramInterpolationSettings(PyQt6.sip.wrapper):

    classificationAttributeExpression = ... # type: str|None
    classificationAttributeIsExpression = ... # type: bool
    classificationField = ... # type: str|None
    lowerSize = ... # type: QtCore.QSizeF
    lowerValue = ... # type: float
    upperSize = ... # type: QtCore.QSizeF
    upperValue = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDiagramInterpolationSettings') -> None: ...


class QgsDiagramRenderer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsDiagramRenderer') -> None: ...

    def _writeXml(self, rendererElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    def _readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    @staticmethod
    def dpiPaintDevice(a0: QtGui.QPainter|None) -> int: ...
    def convertSizeToMapUnits(self, size: QtCore.QSizeF, context: 'QgsRenderContext') -> None: ...
    def diagramSize(self, feature: 'QgsFeature', c: 'QgsRenderContext') -> QtCore.QSizeF: ...
    def setAttributeLegend(self, enabled: bool) -> None: ...
    def attributeLegend(self) -> bool: ...
    def legendItems(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def writeXml(self, layerElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    @typing.overload
    def diagramSettings(self) -> list[QgsDiagramSettings]: ...
    @typing.overload
    def diagramSettings(self, feature: 'QgsFeature', c: 'QgsRenderContext', s: QgsDiagramSettings) -> bool: ...
    def diagram(self) -> 'QgsDiagram|None': ...
    def setDiagram(self, d: 'QgsDiagram|None') -> None: ...
    def renderDiagram(self, feature: 'QgsFeature', c: 'QgsRenderContext', pos: QtCore.QPointF, properties: 'QgsPropertyCollection' = ...) -> None: ...
    def referencedFields(self, context: 'QgsExpressionContext' = ...) -> set[str]: ...
    def diagramAttributes(self) -> list[str]: ...
    def rendererName(self) -> str: ...
    def sizeMapUnits(self, feature: 'QgsFeature', c: 'QgsRenderContext') -> QtCore.QSizeF: ...
    def clone(self) -> 'QgsDiagramRenderer|None': ...


class QgsSingleCategoryDiagramRenderer(QgsDiagramRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSingleCategoryDiagramRenderer') -> None: ...

    def diagramSize(self, a0: 'QgsFeature', c: 'QgsRenderContext') -> QtCore.QSizeF: ...
    def legendItems(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def writeXml(self, layerElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    @typing.overload
    def diagramSettings(self) -> list[QgsDiagramSettings]: ...
    @typing.overload
    def diagramSettings(self, feature: 'QgsFeature', c: 'QgsRenderContext', s: QgsDiagramSettings) -> bool: ...
    def setDiagramSettings(self, s: QgsDiagramSettings) -> None: ...
    def diagramAttributes(self) -> list[str]: ...
    def rendererName(self) -> str: ...
    def clone(self) -> 'QgsSingleCategoryDiagramRenderer|None': ...


class QgsLinearlyInterpolatedDiagramRenderer(QgsDiagramRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsLinearlyInterpolatedDiagramRenderer') -> None: ...

    def diagramSize(self, a0: 'QgsFeature', c: 'QgsRenderContext') -> QtCore.QSizeF: ...
    def dataDefinedSizeLegend(self) -> QgsDataDefinedSizeLegend|None: ...
    def setDataDefinedSizeLegend(self, settings: QgsDataDefinedSizeLegend|None) -> None: ...
    def legendItems(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def writeXml(self, layerElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def setClassificationAttributeIsExpression(self, isExpression: bool) -> None: ...
    def classificationAttributeIsExpression(self) -> bool: ...
    def setClassificationAttributeExpression(self, expression: str|None) -> None: ...
    def classificationAttributeExpression(self) -> str: ...
    def setClassificationField(self, field: str|None) -> None: ...
    def classificationField(self) -> str: ...
    def upperSize(self) -> QtCore.QSizeF: ...
    def setUpperSize(self, s: QtCore.QSizeF) -> None: ...
    def lowerSize(self) -> QtCore.QSizeF: ...
    def setLowerSize(self, s: QtCore.QSizeF) -> None: ...
    def upperValue(self) -> float: ...
    def setUpperValue(self, val: float) -> None: ...
    def lowerValue(self) -> float: ...
    def setLowerValue(self, val: float) -> None: ...
    def rendererName(self) -> str: ...
    def referencedFields(self, context: 'QgsExpressionContext' = ...) -> set[str]: ...
    def diagramAttributes(self) -> list[str]: ...
    def setDiagramSettings(self, s: QgsDiagramSettings) -> None: ...
    @typing.overload
    def diagramSettings(self) -> list[QgsDiagramSettings]: ...
    @typing.overload
    def diagramSettings(self, feature: 'QgsFeature', c: 'QgsRenderContext', s: QgsDiagramSettings) -> bool: ...
    def clone(self) -> 'QgsLinearlyInterpolatedDiagramRenderer|None': ...


class QgsStackedDiagramRenderer(QgsDiagramRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsStackedDiagramRenderer') -> None: ...

    def diagramSize(self, a0: 'QgsFeature', c: 'QgsRenderContext') -> QtCore.QSizeF: ...
    def rendererCount(self) -> int: ...
    def renderer(self, index: int) -> QgsDiagramRenderer|None: ...
    def addRenderer(self, renderer: QgsDiagramRenderer|None) -> None: ...
    def renderers(self, sortByDiagramMode: bool = ...) -> list[QgsDiagramRenderer]: ...
    def legendItems(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def _writeXmlSubRenderers(self, rendererElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    def _readXmlSubRenderers(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def writeXml(self, layerElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def rendererName(self) -> str: ...
    def diagramAttributes(self) -> list[str]: ...
    def setDiagramSettings(self, s: QgsDiagramSettings) -> None: ...
    @typing.overload
    def diagramSettings(self) -> list[QgsDiagramSettings]: ...
    @typing.overload
    def diagramSettings(self, feature: 'QgsFeature', c: 'QgsRenderContext', s: QgsDiagramSettings) -> bool: ...
    def renderDiagram(self, feature: 'QgsFeature', c: 'QgsRenderContext', pos: QtCore.QPointF, properties: 'QgsPropertyCollection' = ...) -> None: ...
    def sizeMapUnits(self, feature: 'QgsFeature', c: 'QgsRenderContext') -> QtCore.QSizeF: ...
    def clone(self) -> 'QgsStackedDiagramRenderer|None': ...


class QgsDistanceArea(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsDistanceArea') -> None: ...

    def splitGeometryAtAntimeridian(self, geometry: 'QgsGeometry') -> 'QgsGeometry': ...
    def latitudeGeodesicCrossesAntimeridian(self, p1: 'QgsPointXY', p2: 'QgsPointXY') -> typing.Tuple[float, float]: ...
    def geodesicLine(self, p1: 'QgsPointXY', p2: 'QgsPointXY', interval: float, breakLine: bool = ...) -> typing.Any: ...
    def computeSpheroidProject(self, p1: 'QgsPointXY', distance: float = ..., azimuth: float = ...) -> 'QgsPointXY': ...
    def convertAreaMeasurement(self, area: float, toUnits: Qgis.AreaUnit) -> float: ...
    def convertLengthMeasurement(self, length: float, toUnits: Qgis.DistanceUnit) -> float: ...
    @staticmethod
    def formatArea(area: float, decimals: int, unit: Qgis.AreaUnit, keepBaseUnit: bool = ...) -> str: ...
    @staticmethod
    def formatDistance(distance: float, decimals: int, unit: Qgis.DistanceUnit, keepBaseUnit: bool = ...) -> str: ...
    def bearing(self, p1: 'QgsPointXY', p2: 'QgsPointXY') -> float: ...
    def measurePolygon(self, points: collections.abc.Iterable['QgsPointXY']) -> float: ...
    def areaUnits(self) -> Qgis.AreaUnit: ...
    def lengthUnits(self) -> Qgis.DistanceUnit: ...
    def measureLineProjected(self, p1: 'QgsPointXY', distance: float = ..., azimuth: float = ...) -> typing.Tuple[float, 'QgsPointXY|None']: ...
    @typing.overload
    def measureLine(self, points: collections.abc.Iterable['QgsPointXY']) -> float: ...
    @typing.overload
    def measureLine(self, p1: 'QgsPointXY', p2: 'QgsPointXY') -> float: ...
    def measurePerimeter(self, geometry: 'QgsGeometry') -> float: ...
    def measureLength(self, geometry: 'QgsGeometry') -> float: ...
    def measureArea(self, geometry: 'QgsGeometry') -> float: ...
    def ellipsoidInverseFlattening(self) -> float: ...
    def ellipsoidSemiMinor(self) -> float: ...
    def ellipsoidSemiMajor(self) -> float: ...
    def ellipsoid(self) -> str: ...
    @typing.overload
    def setEllipsoid(self, ellipsoid: str|None) -> bool: ...
    @typing.overload
    def setEllipsoid(self, semiMajor: float, semiMinor: float) -> bool: ...
    def ellipsoidCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def sourceCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setSourceCrs(self, crs: 'QgsCoordinateReferenceSystem', context: 'QgsCoordinateTransformContext') -> None: ...
    def willUseEllipsoid(self) -> bool: ...


class QgsEditorWidgetSetup(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, config: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEditorWidgetSetup') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def isNull(self) -> bool: ...
    def config(self) -> dict[str, typing.Any]: ...
    def type(self) -> str: ...


class QgsElevationMap(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, size: QtCore.QSize, devicePixelRatio: float = ...) -> None: ...
    @typing.overload
    def __init__(self, image: QtGui.QImage) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsElevationMap') -> None: ...

    def noDataValue(self) -> float: ...
    def isNoData(self, colorRaw: int) -> bool: ...
    @staticmethod
    def decodeElevation(colorRaw: int) -> float: ...
    @staticmethod
    def encodeElevation(z: float) -> int: ...
    def isValid(self) -> bool: ...
    def combine(self, otherElevationMap: 'QgsElevationMap', method: Qgis.ElevationMapCombineMethod) -> None: ...
    def painter(self) -> QtGui.QPainter|None: ...
    def rawElevationImage(self) -> QtGui.QImage: ...
    def applyHillshading(self, image: QtGui.QImage, multiDirectional: bool, altitude: float, azimuth: float, zFactor: float, cellSizeX: float, cellSizeY: float) -> None: ...
    def applyEyeDomeLighting(self, image: QtGui.QImage, distance: int, strength: float, rendererScale: float) -> None: ...


class QgsElevationShadingRenderer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsElevationShadingRenderer') -> None: ...

    def setCombinedElevationMethod(self, method: Qgis.ElevationMapCombineMethod) -> None: ...
    def combinedElevationMethod(self) -> Qgis.ElevationMapCombineMethod: ...
    def readXml(self, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def setLightAzimuth(self, lightAzimuth: float) -> None: ...
    def lightAzimuth(self) -> float: ...
    def setLightAltitude(self, lightAltitude: float) -> None: ...
    def lightAltitude(self) -> float: ...
    def setHillshadingMultidirectional(self, multiDirectional: bool) -> None: ...
    def isHillshadingMultidirectional(self) -> bool: ...
    def setHillshadingZFactor(self, zFactor: float) -> None: ...
    def hillshadingZFactor(self) -> float: ...
    def isActiveHillshading(self) -> bool: ...
    def setActiveHillshading(self, active: bool) -> None: ...
    def setEyeDomeLightingDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def eyeDomeLightingDistanceUnit(self) -> Qgis.RenderUnit: ...
    def setEyeDomeLightingDistance(self, distance: float) -> None: ...
    def eyeDomeLightingDistance(self) -> float: ...
    def setEyeDomeLightingStrength(self, strength: float) -> None: ...
    def eyeDomeLightingStrength(self) -> float: ...
    def isActiveEyeDomeLighting(self) -> bool: ...
    def setActiveEyeDomeLighting(self, active: bool) -> None: ...
    def isActive(self) -> bool: ...
    def setActive(self, active: bool) -> None: ...
    def renderShading(self, elevation: QgsElevationMap, image: QtGui.QImage, context: 'QgsRenderContext') -> None: ...


class QgsElevationUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsElevationUtils') -> None: ...

    @staticmethod
    def enableElevationForLayer(layer: QgsMapLayer|None) -> bool: ...
    @staticmethod
    def canEnableElevationForLayer(layer: QgsMapLayer|None) -> bool: ...
    @staticmethod
    def significantZValuesForLayers(layers: collections.abc.Iterable[QgsMapLayer]) -> list[float]: ...
    @staticmethod
    def significantZValuesForProject(project: 'QgsProject|None') -> list[float]: ...
    @staticmethod
    def calculateZRangeForProject(project: 'QgsProject|None') -> 'QgsDoubleRange': ...


class QgsErrorMessage(PyQt6.sip.wrapper):

    class Format(enum.IntEnum):
        Text = ... # type: QgsErrorMessage.Format
        Html = ... # type: QgsErrorMessage.Format

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str|None, tag: str|None = ..., file: str|None = ..., function: str|None = ..., line: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsErrorMessage') -> None: ...

    def line(self) -> int: ...
    def function(self) -> str: ...
    def file(self) -> str: ...
    def tag(self) -> str: ...
    def message(self) -> str: ...


class QgsError(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, message: str|None, tag: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsError') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def messageList(self) -> list[QgsErrorMessage]: ...
    def clear(self) -> None: ...
    def summary(self) -> str: ...
    def message(self, format: QgsErrorMessage.Format = ...) -> str: ...
    def isEmpty(self) -> bool: ...
    @typing.overload
    def append(self, message: str|None, tag: str|None) -> None: ...
    @typing.overload
    def append(self, message: QgsErrorMessage) -> None: ...


class QgsExpressionFunction(PyQt6.sip.wrapper):

    class Parameter(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, name: str|None, optional: bool = ..., defaultValue: typing.Any = ..., isSubExpression: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpressionFunction.Parameter') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def isSubExpression(self) -> bool: ...
        def defaultValue(self) -> typing.Any: ...
        def optional(self) -> bool: ...
        def name(self) -> str: ...

    @typing.overload
    def __init__(self, fnname: str|None, params: int, group: str|None, helpText: str|None = ..., lazyEval: bool = ..., handlesNull: bool = ..., isContextual: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, fnname: str|None, params: int, groups: collections.abc.Iterable[str|None], helpText: str|None = ..., lazyEval: bool = ..., handlesNull: bool = ..., isContextual: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, fnname: str|None, params: collections.abc.Iterable['QgsExpressionFunction.Parameter'], group: str|None, helpText: str|None = ..., lazyEval: bool = ..., handlesNull: bool = ..., isContextual: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, fnname: str|None, params: collections.abc.Iterable['QgsExpressionFunction.Parameter'], groups: collections.abc.Iterable[str|None], helpText: str|None = ..., lazyEval: bool = ..., handlesNull: bool = ..., isContextual: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionFunction') -> None: ...

    def __ne__(self, other: object): ...
    @staticmethod
    def allParamsStatic(node: 'QgsExpressionNodeFunction|None', parent: 'QgsExpression|None', context: 'QgsExpressionContext|None') -> bool: ...
    def handlesNull(self) -> bool: ...
    def __eq__(self, other: object): ...
    def run(self, args: 'QgsExpressionNode.NodeList|None', context: 'QgsExpressionContext|None', parent: 'QgsExpression|None', node: 'QgsExpressionNodeFunction|None') -> typing.Any: ...
    def func(self, values: collections.abc.Iterable[typing.Any], context: 'QgsExpressionContext|None', parent: 'QgsExpression|None', node: 'QgsExpressionNodeFunction|None') -> typing.Any: ...
    def helpText(self) -> str: ...
    def groups(self) -> list[str]: ...
    def group(self) -> str: ...
    def isDeprecated(self) -> bool: ...
    def isContextual(self) -> bool: ...
    def referencedColumns(self, node: 'QgsExpressionNodeFunction|None') -> set[str]: ...
    def prepare(self, node: 'QgsExpressionNodeFunction|None', parent: 'QgsExpression|None', context: 'QgsExpressionContext|None') -> bool: ...
    def isStatic(self, node: 'QgsExpressionNodeFunction|None', parent: 'QgsExpression|None', context: 'QgsExpressionContext|None') -> bool: ...
    def lazyEval(self) -> bool: ...
    def aliases(self) -> list[str]: ...
    def usesGeometry(self, node: 'QgsExpressionNodeFunction|None') -> bool: ...
    def parameters(self) -> list['QgsExpressionFunction.Parameter']: ...
    def minParams(self) -> int: ...
    def params(self) -> int: ...
    def name(self) -> str: ...


class QgsScopedExpressionFunction(QgsExpressionFunction):

    @typing.overload
    def __init__(self, fnname: str|None, params: int, group: str|None, helpText: str|None = ..., usesGeometry: bool = ..., referencedColumns: collections.abc.Iterable[str|None] = ..., lazyEval: bool = ..., handlesNull: bool = ..., isContextual: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, fnname: str|None, params: collections.abc.Iterable[QgsExpressionFunction.Parameter], group: str|None, helpText: str|None = ..., usesGeometry: bool = ..., referencedColumns: collections.abc.Iterable[str|None] = ..., lazyEval: bool = ..., handlesNull: bool = ..., isContextual: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScopedExpressionFunction') -> None: ...

    def isStatic(self, node: 'QgsExpressionNodeFunction|None', parent: 'QgsExpression|None', context: 'QgsExpressionContext|None') -> bool: ...
    def referencedColumns(self, node: 'QgsExpressionNodeFunction|None') -> set[str]: ...
    def usesGeometry(self, node: 'QgsExpressionNodeFunction|None') -> bool: ...
    def clone(self) -> 'QgsScopedExpressionFunction|None': ...
    def func(self, values: collections.abc.Iterable[typing.Any], context: 'QgsExpressionContext|None', parent: 'QgsExpression|None', node: 'QgsExpressionNodeFunction|None') -> typing.Any: ...


class QgsExpressionContextScope(PyQt6.sip.wrapper):

    class StaticVariable(PyQt6.sip.wrapper):

        description = ... # type: str|None
        isStatic = ... # type: bool
        name = ... # type: str|None
        readOnly = ... # type: bool
        value = ... # type: typing.Any

        @typing.overload
        def __init__(self, name: str|None = ..., value: typing.Any = ..., readOnly: bool = ..., isStatic: bool = ..., description: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpressionContextScope.StaticVariable') -> None: ...

    @typing.overload
    def __init__(self, name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsExpressionContextScope') -> None: ...

    def layerStores(self) -> list['QgsMapLayerStore']: ...
    def addLayerStore(self, store: 'QgsMapLayerStore|None') -> None: ...
    def removeHiddenVariable(self, hiddenVariable: str|None) -> None: ...
    def addHiddenVariable(self, hiddenVariable: str|None) -> None: ...
    def setHiddenVariables(self, hiddenVariables: collections.abc.Iterable[str|None]) -> None: ...
    def hiddenVariables(self) -> list[str]: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readXml(self, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def setFields(self, fields: 'QgsFields') -> None: ...
    def removeGeometry(self) -> None: ...
    def setGeometry(self, geometry: 'QgsGeometry') -> None: ...
    def geometry(self) -> 'QgsGeometry': ...
    def hasGeometry(self) -> bool: ...
    def removeFeature(self) -> None: ...
    def setFeature(self, feature: 'QgsFeature') -> None: ...
    def feature(self) -> 'QgsFeature': ...
    def hasFeature(self) -> bool: ...
    def addFunction(self, name: str|None, function: QgsScopedExpressionFunction|None) -> None: ...
    def functionNames(self) -> list[str]: ...
    def function(self, name: str|None) -> QgsExpressionFunction|None: ...
    def hasFunction(self, name: str|None) -> bool: ...
    def variableCount(self) -> int: ...
    def description(self, name: str|None) -> str: ...
    def isStatic(self, name: str|None) -> bool: ...
    def isReadOnly(self, name: str|None) -> bool: ...
    def filteredVariableNames(self) -> list[str]: ...
    def variableNames(self) -> list[str]: ...
    def variable(self, name: str|None) -> typing.Any: ...
    def hasVariable(self, name: str|None) -> bool: ...
    def removeVariable(self, name: str|None) -> bool: ...
    def addVariable(self, variable: 'QgsExpressionContextScope.StaticVariable') -> None: ...
    def setVariable(self, name: str|None, value: typing.Any, isStatic: bool = ...) -> None: ...
    def name(self) -> str: ...


class QgsExpressionContext(PyQt6.sip.wrapper):

    EXPR_CLUSTER_COLOR = ... # type: str|None
    EXPR_CLUSTER_SIZE = ... # type: str|None
    EXPR_FIELDS = ... # type: str|None
    EXPR_GEOMETRY_PART_COUNT = ... # type: str|None
    EXPR_GEOMETRY_PART_NUM = ... # type: str|None
    EXPR_GEOMETRY_POINT_COUNT = ... # type: str|None
    EXPR_GEOMETRY_POINT_NUM = ... # type: str|None
    EXPR_GEOMETRY_RING_NUM = ... # type: str|None
    EXPR_ORIGINAL_VALUE = ... # type: str|None
    EXPR_SYMBOL_ANGLE = ... # type: str|None
    EXPR_SYMBOL_COLOR = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, scopes: collections.abc.Iterable[QgsExpressionContextScope]) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsExpressionContext') -> None: ...

    def uniqueHash(self, variables: collections.abc.Iterable[str|None] = ...) -> typing.Tuple[str, bool]: ...
    def feedback(self) -> 'QgsFeedback|None': ...
    def setFeedback(self, feedback: 'QgsFeedback|None') -> None: ...
    def loadedLayerStore(self) -> 'QgsMapLayerStore|None': ...
    def setLoadedLayerStore(self, store: 'QgsMapLayerStore|None') -> None: ...
    def layerStores(self) -> list['QgsMapLayerStore']: ...
    def clearCachedValues(self) -> None: ...
    def cachedValue(self, key: str|None) -> typing.Any: ...
    def hasCachedValue(self, key: str|None) -> bool: ...
    def setCachedValue(self, key: str|None, value: typing.Any) -> None: ...
    def setOriginalValueVariable(self, value: typing.Any) -> None: ...
    def fields(self) -> 'QgsFields': ...
    def setFields(self, fields: 'QgsFields') -> None: ...
    def geometry(self) -> 'QgsGeometry': ...
    def hasGeometry(self) -> bool: ...
    def setGeometry(self, geometry: 'QgsGeometry') -> None: ...
    def feature(self) -> 'QgsFeature': ...
    def hasFeature(self) -> bool: ...
    def setFeature(self, feature: 'QgsFeature') -> None: ...
    def popScope(self) -> QgsExpressionContextScope|None: ...
    def appendScopes(self, scopes: collections.abc.Iterable[QgsExpressionContextScope]) -> None: ...
    def appendScope(self, scope: QgsExpressionContextScope|None) -> None: ...
    def scopeCount(self) -> int: ...
    def function(self, name: str|None) -> QgsExpressionFunction|None: ...
    def functionNames(self) -> list[str]: ...
    def hasFunction(self, name: str|None) -> bool: ...
    def description(self, name: str|None) -> str: ...
    def isReadOnly(self, name: str|None) -> bool: ...
    def filteredVariableNames(self) -> list[str]: ...
    def variableNames(self) -> list[str]: ...
    @typing.overload
    def indexOfScope(self, scope: QgsExpressionContextScope|None) -> int: ...
    @typing.overload
    def indexOfScope(self, scopeName: str|None) -> int: ...
    def scopes(self) -> list[QgsExpressionContextScope]: ...
    def lastScope(self) -> QgsExpressionContextScope|None: ...
    def scope(self, index: int) -> QgsExpressionContextScope|None: ...
    def activeScopeForVariable(self, name: str|None) -> QgsExpressionContextScope|None: ...
    def setHighlightedFunctions(self, names: collections.abc.Iterable[str|None]) -> None: ...
    def isHighlightedFunction(self, name: str|None) -> bool: ...
    def setHighlightedVariables(self, variableNames: collections.abc.Iterable[str|None]) -> None: ...
    def highlightedVariables(self) -> list[str]: ...
    def isHighlightedVariable(self, name: str|None) -> bool: ...
    def variablesToMap(self) -> dict[str, typing.Any]: ...
    def variable(self, name: str|None) -> typing.Any: ...
    def hasVariable(self, name: str|None) -> bool: ...


class QgsExpressionFieldBuffer(PyQt6.sip.wrapper):

    class ExpressionField(PyQt6.sip.wrapper):

        cachedExpression = ... # type: 'QgsExpression'
        field = ... # type: 'QgsField'

        @typing.overload
        def __init__(self, exp: str|None, fld: 'QgsField') -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpressionFieldBuffer.ExpressionField') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionFieldBuffer') -> None: ...

    def expressions(self) -> list['QgsExpressionFieldBuffer.ExpressionField']: ...
    def updateFields(self, flds: 'QgsFields') -> None: ...
    def readXml(self, layer_node: QtXml.QDomNode) -> None: ...
    def writeXml(self, layer_node: QtXml.QDomNode, document: QtXml.QDomDocument) -> None: ...
    def updateExpression(self, index: int, exp: str|None) -> None: ...
    def renameExpression(self, index: int, name: str|None) -> None: ...
    def removeExpression(self, index: int) -> None: ...
    def addExpression(self, exp: str|None, fld: 'QgsField') -> None: ...


class QgsFeature(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, id: int = ...) -> None: ...
    @typing.overload
    def __init__(self, fields: 'QgsFields', id: int = ...) -> None: ...
    @typing.overload
    def __init__(self, rhs: 'QgsFeature') -> None: ...

    def approximateMemoryUsage(self) -> int: ...
    def fieldNameIndex(self, fieldName: str|None) -> int: ...
    def setEmbeddedSymbol(self, symbol: 'QgsSymbol|None') -> None: ...
    def embeddedSymbol(self) -> 'QgsSymbol|None': ...
    def isUnsetValue(self, fieldIdx: int) -> bool: ...
    @typing.overload
    def attribute(self, name: str|None) -> typing.Any: ...
    @typing.overload
    def attribute(self, fieldIdx: int) -> typing.Any: ...
    def fields(self) -> 'QgsFields': ...
    def setFields(self, fields: 'QgsFields', initAttributes: bool = ...) -> None: ...
    def clearGeometry(self) -> None: ...
    @typing.overload
    def setGeometry(self, geometry: 'QgsGeometry') -> None: ...
    @typing.overload
    def setGeometry(self, geometry: 'QgsAbstractGeometry|None') -> None: ...
    def geometry(self) -> 'QgsGeometry': ...
    def hasGeometry(self) -> bool: ...
    def setValid(self, validity: bool) -> None: ...
    def isValid(self) -> bool: ...
    @typing.overload
    def deleteAttribute(self, field: int) -> None: ...
    @typing.overload
    def deleteAttribute(self, name: str|None) -> bool: ...
    def padAttributes(self, count: int) -> None: ...
    def resizeAttributes(self, fieldCount: int) -> None: ...
    def initAttributes(self, fieldCount: int) -> None: ...
    @typing.overload
    def setAttribute(self, field: int, attr: bool|int|float|str|typing.Any|None) -> bool: ...
    @typing.overload
    def setAttribute(self, name: str|None, value: bool|int|float|str|typing.Any|None) -> None: ...
    def setAttributes(self, attrs: typing.Any) -> None: ...
    def attributeCount(self) -> int: ...
    def attributeMap(self) -> dict[str, object|None]: ...
    def attributes(self) -> typing.Any: ...
    def setId(self, id: int) -> None: ...
    def id(self) -> int: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __hash__(self) -> int: ...
    @typing.overload
    def __delitem__(self, key: int) -> None: ...
    @typing.overload
    def __delitem__(self, name: str|None) -> None: ...
    @typing.overload
    def __setitem__(self, key: int, value: bool|int|float|str|typing.Any|None) -> None: ...
    @typing.overload
    def __setitem__(self, key: str|None, value: bool|int|float|str|typing.Any|None) -> None: ...
    @typing.overload
    def __getitem__(self, key: int) -> typing.Any: ...
    @typing.overload
    def __getitem__(self, name: str|None) -> typing.Any: ...
    def __iter__(self) -> typing.Any: ...


class QgsFeatureFilterProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureFilterProvider') -> None: ...

    def clone(self) -> 'QgsFeatureFilterProvider|None': ...
    def layerAttributes(self, layer: QgsVectorLayer|None, attributes: collections.abc.Iterable[str|None]) -> list[str]: ...
    @typing.overload
    @deprecated("""""")
    def filterFeatures(self, layer: QgsVectorLayer|None, featureRequest: 'QgsFeatureRequest') -> None: ...
    @typing.overload
    def filterFeatures(self, layerId: str|None, featureRequest: 'QgsFeatureRequest') -> None: ...
    @deprecated("""""")
    def isFilterThreadSafe(self) -> bool: ...


class QgsFeatureExpressionFilterProvider(QgsFeatureFilterProvider):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureExpressionFilterProvider') -> None: ...

    def setFilter(self, layerId: str|None, expression: 'QgsExpression') -> None: ...
    def clone(self) -> 'QgsFeatureExpressionFilterProvider|None': ...
    def layerAttributes(self, layer: QgsVectorLayer|None, attributes: collections.abc.Iterable[str|None]) -> list[str]: ...
    @typing.overload
    @deprecated("""""")
    def filterFeatures(self, layer: QgsVectorLayer|None, filterFeatures: 'QgsFeatureRequest') -> None: ...
    @typing.overload
    def filterFeatures(self, layerId: str|None, filterFeatures: 'QgsFeatureRequest') -> None: ...


class QgsFeaturePickerModelBase(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        IdentifierValue = ... # type: QgsFeaturePickerModelBase.CustomRole
        IdentifierValues = ... # type: QgsFeaturePickerModelBase.CustomRole
        Value = ... # type: QgsFeaturePickerModelBase.CustomRole
        Feature = ... # type: QgsFeaturePickerModelBase.CustomRole
        FeatureId = ... # type: QgsFeaturePickerModelBase.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def setExtraIdentifierValueUnguarded(self, identifierValue: typing.Any) -> None: ...
    def requestToReloadCurrentFeature(self, request: 'QgsFeatureRequest') -> None: ...
    def setExtraIdentifierValue(self, extraIdentifierValue: typing.Any) -> None: ...
    def extraIdentifierValue(self) -> typing.Any: ...
    fetchLimitChanged: typing.ClassVar[QtCore.pyqtSignal]
    fetchGeometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    allowNullChanged: typing.ClassVar[QtCore.pyqtSignal]
    endUpdate: typing.ClassVar[QtCore.pyqtSignal]
    beginUpdate: typing.ClassVar[QtCore.pyqtSignal]
    extraValueDoesNotExistChanged: typing.ClassVar[QtCore.pyqtSignal]
    extraIdentifierValueIndexChanged: typing.ClassVar[QtCore.pyqtSignal]
    extraIdentifierValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterJobCompleted: typing.ClassVar[QtCore.pyqtSignal]
    isLoadingChanged: typing.ClassVar[QtCore.pyqtSignal]
    parentFormFeatureChanged: typing.ClassVar[QtCore.pyqtSignal]
    formFeatureChanged: typing.ClassVar[QtCore.pyqtSignal]
    sortOrderChanged: typing.ClassVar[QtCore.pyqtSignal]
    orderExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    displayExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    currentFeatureChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setFetchLimit(self, fetchLimit: int) -> None: ...
    def fetchLimit(self) -> int: ...
    def setFetchGeometry(self, fetchGeometry: bool) -> None: ...
    def fetchGeometry(self) -> bool: ...
    def setAllowNull(self, allowNull: bool) -> None: ...
    def allowNull(self) -> bool: ...
    def extraValueDoesNotExist(self) -> bool: ...
    def extraIdentifierValueIndex(self) -> int: ...
    def setExtraIdentifierValueToNull(self) -> None: ...
    def isLoading(self) -> bool: ...
    def setParentFormFeature(self, feature: QgsFeature) -> None: ...
    def parentFormFeature(self) -> QgsFeature: ...
    def setFormFeature(self, feature: QgsFeature) -> None: ...
    def formFeature(self) -> QgsFeature: ...
    def setSortOrder(self, sortOrder: QtCore.Qt.SortOrder) -> None: ...
    def sortOrder(self) -> QtCore.Qt.SortOrder: ...
    def setOrderExpression(self, orderExpression: str|None) -> None: ...
    def orderExpression(self) -> str: ...
    def setFilterExpression(self, filterExpression: str|None) -> None: ...
    def filterExpression(self) -> str: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def setFilterValue(self, filterValue: str|None) -> None: ...
    def filterValue(self) -> str: ...
    def setDisplayExpression(self, displayExpression: str|None) -> None: ...
    def displayExpression(self) -> str: ...
    def setSourceLayer(self, sourceLayer: QgsVectorLayer|None) -> None: ...
    def sourceLayer(self) -> QgsVectorLayer|None: ...


class QgsFeaturePickerModel(QgsFeaturePickerModelBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    featureChanged: typing.ClassVar[QtCore.pyqtSignal]
    def feature(self) -> QgsFeature: ...
    def setFeature(self, fid: int) -> None: ...
    def setExtraIdentifierValueToNull(self) -> None: ...


class QgsFeatureFilterModel(QgsFeaturePickerModelBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    extraIdentifierValuesChanged: typing.ClassVar[QtCore.pyqtSignal]
    identifierFieldsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setExtraIdentifierValues(self, extraIdentifierValues: collections.abc.Iterable[typing.Any]) -> None: ...
    def extraIdentifierValues(self) -> list[typing.Any]: ...
    def setExtraIdentifierValueToNull(self) -> None: ...
    def setIdentifierFields(self, identifierFields: collections.abc.Iterable[str|None]) -> None: ...
    def identifierFields(self) -> list[str]: ...
    def identifierField(self) -> str: ...


class QgsFeatureIterator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, iter: QgsAbstractFeatureIterator|None) -> None: ...
    @typing.overload
    def __init__(self, fi: 'QgsFeatureIterator') -> None: ...

    def compileFailed(self) -> bool: ...
    def compileStatus(self) -> QgsAbstractFeatureIterator.CompileStatus: ...
    def isClosed(self) -> bool: ...
    def isValid(self) -> bool: ...
    def close(self) -> bool: ...
    def rewind(self) -> bool: ...
    def nextFeature(self, f: QgsFeature) -> bool: ...
    def __next__(self) -> QgsFeature: ...
    def __iter__(self) -> 'QgsFeatureIterator|None': ...


class QgsFeatureRequest(PyQt6.sip.wrapper):

    class OrderByClause(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, expression: str|None, ascending: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, expression: str|None, ascending: bool, nullsfirst: bool) -> None: ...
        @typing.overload
        def __init__(self, expression: 'QgsExpression', ascending: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, expression: 'QgsExpression', ascending: bool, nullsfirst: bool) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsFeatureRequest.OrderByClause') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def dump(self) -> str: ...
        def setNullsFirst(self, nullsFirst: bool) -> None: ...
        def nullsFirst(self) -> bool: ...
        def setAscending(self, ascending: bool) -> None: ...
        def ascending(self) -> bool: ...
        def prepare(self, context: QgsExpressionContext|None) -> bool: ...
        def expression(self) -> 'QgsExpression': ...

    class OrderBy(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, other: collections.abc.Iterable['QgsFeatureRequest.OrderByClause']) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsFeatureRequest.OrderBy') -> None: ...

        def dump(self) -> str: ...
        def usedAttributeIndices(self, fields: 'QgsFields') -> typing.Any: ...
        def usedAttributes(self) -> set[str]: ...
        def load(self, elem: QtXml.QDomElement) -> None: ...
        def save(self, elem: QtXml.QDomElement) -> None: ...
        def list(self) -> list['QgsFeatureRequest.OrderByClause']: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    ALL_ATTRIBUTES = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, fid: int) -> None: ...
    @typing.overload
    def __init__(self, fids: typing.Any) -> None: ...
    @typing.overload
    def __init__(self, rectangle: 'QgsRectangle') -> None: ...
    @typing.overload
    def __init__(self, expr: 'QgsExpression', context: QgsExpressionContext = ...) -> None: ...
    @typing.overload
    def __init__(self, rh: 'QgsFeatureRequest') -> None: ...

    def feedback(self) -> 'QgsFeedback|None': ...
    def setFeedback(self, feedback: 'QgsFeedback|None') -> None: ...
    def setRequestMayBeNested(self, requestMayBeNested: bool) -> 'QgsFeatureRequest': ...
    def requestMayBeNested(self) -> bool: ...
    def setTimeout(self, timeout: int) -> 'QgsFeatureRequest': ...
    def timeout(self) -> int: ...
    @deprecated("""""")
    def setConnectionTimeout(self, connectionTimeout: int) -> 'QgsFeatureRequest': ...
    @deprecated("""""")
    def connectionTimeout(self) -> int: ...
    def acceptFeature(self, feature: QgsFeature) -> bool: ...
    def setTransformErrorCallback(self, a0: typing.Callable[..., None]) -> 'QgsFeatureRequest': ...
    def setDestinationCrs(self, crs: 'QgsCoordinateReferenceSystem', context: 'QgsCoordinateTransformContext') -> 'QgsFeatureRequest': ...
    def setCoordinateTransform(self, transform: 'QgsCoordinateTransform') -> 'QgsFeatureRequest': ...
    def calculateTransform(self, sourceCrs: 'QgsCoordinateReferenceSystem') -> 'QgsCoordinateTransform': ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def destinationCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def coordinateTransform(self) -> 'QgsCoordinateTransform': ...
    def simplifyMethod(self) -> 'QgsSimplifyMethod': ...
    def setSimplifyMethod(self, simplifyMethod: 'QgsSimplifyMethod') -> 'QgsFeatureRequest': ...
    def subsetOfAttributes(self) -> list[int]: ...
    def setNoAttributes(self) -> 'QgsFeatureRequest': ...
    @typing.overload
    def setSubsetOfAttributes(self, attrs: collections.abc.Iterable[int]) -> 'QgsFeatureRequest': ...
    @typing.overload
    def setSubsetOfAttributes(self, attrNames: collections.abc.Iterable[str|None], fields: 'QgsFields') -> 'QgsFeatureRequest': ...
    @typing.overload
    def setSubsetOfAttributes(self, attrNames: collections.abc.Iterable[str|None], fields: 'QgsFields') -> 'QgsFeatureRequest': ...
    def flags(self) -> Qgis.FeatureRequestFlag: ...
    def setFlags(self, flags: Qgis.FeatureRequestFlag) -> 'QgsFeatureRequest': ...
    def limit(self) -> int: ...
    def setLimit(self, limit: int) -> 'QgsFeatureRequest': ...
    def setOrderBy(self, orderBy: 'QgsFeatureRequest.OrderBy') -> 'QgsFeatureRequest': ...
    def orderBy(self) -> 'QgsFeatureRequest.OrderBy': ...
    @typing.overload
    def addOrderBy(self, expression: str|None, ascending: bool = ...) -> 'QgsFeatureRequest': ...
    @typing.overload
    def addOrderBy(self, expression: str|None, ascending: bool, nullsfirst: bool) -> 'QgsFeatureRequest': ...
    def disableFilter(self) -> 'QgsFeatureRequest': ...
    def setExpressionContext(self, context: QgsExpressionContext) -> 'QgsFeatureRequest': ...
    def expressionContext(self) -> QgsExpressionContext|None: ...
    def combineFilterExpression(self, expression: str|None) -> 'QgsFeatureRequest': ...
    def filterExpression(self) -> 'QgsExpression|None': ...
    def setFilterExpression(self, expression: str|None) -> 'QgsFeatureRequest': ...
    def setInvalidGeometryCallback(self, a0: typing.Callable[..., None]) -> 'QgsFeatureRequest': ...
    def invalidGeometryCheck(self) -> Qgis.InvalidGeometryCheck: ...
    def setInvalidGeometryCheck(self, check: Qgis.InvalidGeometryCheck) -> 'QgsFeatureRequest': ...
    def filterFids(self) -> typing.Any: ...
    def setFilterFids(self, fids: typing.Any) -> 'QgsFeatureRequest': ...
    def filterFid(self) -> int: ...
    def setFilterFid(self, fid: int) -> 'QgsFeatureRequest': ...
    def distanceWithin(self) -> float: ...
    def referenceGeometry(self) -> 'QgsGeometry': ...
    def setDistanceWithin(self, geometry: 'QgsGeometry', distance: float) -> 'QgsFeatureRequest': ...
    def filterRect(self) -> 'QgsRectangle': ...
    def setFilterRect(self, rectangle: 'QgsRectangle') -> 'QgsFeatureRequest': ...
    def spatialFilterType(self) -> Qgis.SpatialFilterType: ...
    def filterType(self) -> Qgis.FeatureRequestFilterType: ...
    def compare(self, other: 'QgsFeatureRequest') -> bool: ...


class QgsAbstractFeatureSource(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractFeatureSource') -> None: ...

    def iteratorClosed(self, it: QgsAbstractFeatureIterator|None) -> None: ...
    def iteratorOpened(self, it: QgsAbstractFeatureIterator|None) -> None: ...
    def getFeatures(self, request: QgsFeatureRequest = ...) -> QgsFeatureIterator: ...


class QgsFeatureStore(QgsFeatureSink):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, fields: 'QgsFields', crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureStore') -> None: ...

    def params(self) -> dict[str, typing.Any]: ...
    def setParams(self, parameters: dict[str|None, typing.Any]) -> None: ...
    def features(self) -> list[QgsFeature]: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def count(self) -> int: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def addFeature(self, feature: QgsFeature, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setFields(self, fields: 'QgsFields') -> None: ...
    def fields(self) -> 'QgsFields': ...


class QgsFeedback(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    processedCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    progressChanged: typing.ClassVar[QtCore.pyqtSignal]
    canceled: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    @staticmethod
    def createScaledFeedback(parentFeedback: 'QgsFeedback|None', startPercentage: float, endPercentage: float) -> 'QgsFeedback'|None: ...
    def setProcessedCount(self, processedCount: int) -> None: ...
    def processedCount(self) -> int: ...
    def progress(self) -> float: ...
    def setProgress(self, progress: float) -> None: ...
    def isCanceled(self) -> bool: ...


class QgsField(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, name: str|None = ..., type: QtCore.QMetaType.Type = ..., typeName: str|None = ..., len: int = ..., prec: int = ..., comment: str|None = ..., subType: QtCore.QMetaType.Type = ...) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, name: str|None, type: typing.Any, typeName: str|None = ..., len: int = ..., prec: int = ..., comment: str|None = ..., subType: typing.Any = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsField') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def setMergePolicy(self, policy: Qgis.FieldDomainMergePolicy) -> None: ...
    def mergePolicy(self) -> Qgis.FieldDomainMergePolicy: ...
    def setDuplicatePolicy(self, policy: Qgis.FieldDuplicatePolicy) -> None: ...
    def duplicatePolicy(self) -> Qgis.FieldDuplicatePolicy: ...
    def setSplitPolicy(self, policy: Qgis.FieldDomainSplitPolicy) -> None: ...
    def splitPolicy(self) -> Qgis.FieldDomainSplitPolicy: ...
    def isReadOnly(self) -> bool: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def editorWidgetSetup(self) -> QgsEditorWidgetSetup: ...
    def setEditorWidgetSetup(self, v: QgsEditorWidgetSetup) -> None: ...
    def convertCompatible(self, v: typing.Any) -> bool: ...
    @staticmethod
    def readableConfigurationFlag(flag: Qgis.FieldConfigurationFlag) -> str: ...
    def displayString(self, v: typing.Any) -> str: ...
    def setConfigurationFlags(self, flags: Qgis.FieldConfigurationFlag) -> None: ...
    def configurationFlags(self) -> Qgis.FieldConfigurationFlag: ...
    def setAlias(self, alias: str|None) -> None: ...
    def alias(self) -> str: ...
    def setConstraints(self, constraints: 'QgsFieldConstraints') -> None: ...
    def constraints(self) -> 'QgsFieldConstraints': ...
    def setDefaultValueDefinition(self, defaultValueDefinition: QgsDefaultValue) -> None: ...
    def defaultValueDefinition(self) -> QgsDefaultValue: ...
    def setComment(self, comment: str|None) -> None: ...
    def setPrecision(self, precision: int) -> None: ...
    def setLength(self, len: int) -> None: ...
    def setTypeName(self, typeName: str|None) -> None: ...
    @typing.overload
    def setSubType(self, subType: QtCore.QMetaType.Type) -> None: ...
    @typing.overload
    @deprecated("""""")
    def setSubType(self, subType: typing.Any) -> None: ...
    @typing.overload
    def setType(self, type: QtCore.QMetaType.Type) -> None: ...
    @typing.overload
    @deprecated("""""")
    def setType(self, type: typing.Any) -> None: ...
    def setName(self, name: str|None) -> None: ...
    def isDateOrTime(self) -> bool: ...
    def isNumeric(self) -> bool: ...
    @typing.overload
    def setMetadata(self, metadata: dict[int, typing.Any]) -> None: ...
    @typing.overload
    def setMetadata(self, property: int, value: typing.Any) -> None: ...
    @typing.overload
    def metadata(self) -> dict[int, typing.Any]: ...
    @typing.overload
    def metadata(self, property: int) -> typing.Any: ...
    def comment(self) -> str: ...
    def precision(self) -> int: ...
    def length(self) -> int: ...
    def typeName(self) -> str: ...
    def subType(self) -> QtCore.QMetaType.Type: ...
    def type(self) -> QtCore.QMetaType.Type: ...
    def friendlyTypeString(self) -> str: ...
    def displayType(self, showConstraints: bool = ...) -> str: ...
    def displayNameWithAlias(self) -> str: ...
    def displayName(self) -> str: ...
    def name(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsFieldConstraints(PyQt6.sip.wrapper):

    class ConstraintStrength(enum.IntEnum):
        ConstraintStrengthNotSet = ... # type: QgsFieldConstraints.ConstraintStrength
        ConstraintStrengthHard = ... # type: QgsFieldConstraints.ConstraintStrength
        ConstraintStrengthSoft = ... # type: QgsFieldConstraints.ConstraintStrength

    class ConstraintOrigin(enum.IntEnum):
        ConstraintOriginNotSet = ... # type: QgsFieldConstraints.ConstraintOrigin
        ConstraintOriginProvider = ... # type: QgsFieldConstraints.ConstraintOrigin
        ConstraintOriginLayer = ... # type: QgsFieldConstraints.ConstraintOrigin

    class Constraint(enum.IntEnum):
        ConstraintNotNull = ... # type: QgsFieldConstraints.Constraint
        ConstraintUnique = ... # type: QgsFieldConstraints.Constraint
        ConstraintExpression = ... # type: QgsFieldConstraints.Constraint

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFieldConstraints') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def setDomainName(self, domain: str|None) -> None: ...
    def domainName(self) -> str: ...
    def setConstraintExpression(self, expression: str|None, description: str|None = ...) -> None: ...
    def constraintDescription(self) -> str: ...
    def constraintExpression(self) -> str: ...
    def removeConstraint(self, constraint: 'QgsFieldConstraints.Constraint') -> None: ...
    def setConstraint(self, constraint: 'QgsFieldConstraints.Constraint', origin: 'QgsFieldConstraints.ConstraintOrigin' = ...) -> None: ...
    def setConstraintStrength(self, constraint: 'QgsFieldConstraints.Constraint', strength: 'QgsFieldConstraints.ConstraintStrength') -> None: ...
    def constraintStrength(self, constraint: 'QgsFieldConstraints.Constraint') -> 'QgsFieldConstraints.ConstraintStrength': ...
    def constraintOrigin(self, constraint: 'QgsFieldConstraints.Constraint') -> 'QgsFieldConstraints.ConstraintOrigin': ...
    def constraints(self) -> 'QgsFieldConstraints.Constraint': ...


class QgsFieldFormatterContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFieldFormatterContext') -> None: ...

    def setProject(self, project: 'QgsProject|None') -> None: ...
    def project(self) -> 'QgsProject|None': ...


class QgsFieldFormatter(PyQt6.sip.wrapper):

    class Flag(enum.IntEnum):
        CanProvideAvailableValues = ... # type: QgsFieldFormatter.Flag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFieldFormatter') -> None: ...

    def setFlags(self, flags: 'QgsFieldFormatter.Flag') -> None: ...
    def flags(self) -> 'QgsFieldFormatter.Flag': ...
    def availableValues(self, config: dict[str|None, typing.Any], countLimit: int, context: QgsFieldFormatterContext) -> list[typing.Any]: ...
    def createCache(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any]) -> typing.Any: ...
    def alignmentFlag(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any]) -> QtCore.Qt.AlignmentFlag: ...
    def sortValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> typing.Any: ...
    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsFieldFormatterRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    fieldFormatterRemoved: typing.ClassVar[QtCore.pyqtSignal]
    fieldFormatterAdded: typing.ClassVar[QtCore.pyqtSignal]
    def fallbackFieldFormatter(self) -> QgsFieldFormatter|None: ...
    def fieldFormatter(self, id: str|None) -> QgsFieldFormatter|None: ...
    @typing.overload
    def removeFieldFormatter(self, formatter: QgsFieldFormatter|None) -> None: ...
    @typing.overload
    def removeFieldFormatter(self, id: str|None) -> None: ...
    def addFieldFormatter(self, formatter: QgsFieldFormatter|None) -> None: ...


class QgsFieldModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        FieldName = ... # type: QgsFieldModel.CustomRole
        FieldIndex = ... # type: QgsFieldModel.CustomRole
        Expression = ... # type: QgsFieldModel.CustomRole
        IsExpression = ... # type: QgsFieldModel.CustomRole
        ExpressionValidity = ... # type: QgsFieldModel.CustomRole
        FieldType = ... # type: QgsFieldModel.CustomRole
        FieldOrigin = ... # type: QgsFieldModel.CustomRole
        IsEmpty = ... # type: QgsFieldModel.CustomRole
        EditorWidgetType = ... # type: QgsFieldModel.CustomRole
        JoinedFieldIsEditable = ... # type: QgsFieldModel.CustomRole
        FieldIsWidgetEditable = ... # type: QgsFieldModel.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def updateModel(self) -> None: ...
    def setLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def fields(self) -> 'QgsFields': ...
    def setFields(self, fields: 'QgsFields') -> None: ...
    @staticmethod
    def fieldToolTipExtended(field: QgsField, layer: QgsVectorLayer|None) -> str: ...
    @staticmethod
    def fieldToolTip(field: QgsField) -> str: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def layer(self) -> QgsVectorLayer|None: ...
    def removeExpression(self) -> None: ...
    def setExpression(self, expression: str|None) -> None: ...
    def isField(self, expression: str|None) -> bool: ...
    def allowEmptyFieldName(self) -> bool: ...
    def setAllowEmptyFieldName(self, allowEmpty: bool) -> None: ...
    def allowExpression(self) -> bool: ...
    def setAllowExpression(self, allowExpression: bool) -> None: ...
    def indexFromName(self, fieldName: str|None) -> QtCore.QModelIndex: ...


class QgsFieldProxyModel(QtCore.QSortFilterProxyModel):

    class Filter(enum.IntEnum):
        String = ... # type: QgsFieldProxyModel.Filter
        Int = ... # type: QgsFieldProxyModel.Filter
        LongLong = ... # type: QgsFieldProxyModel.Filter
        Double = ... # type: QgsFieldProxyModel.Filter
        Numeric = ... # type: QgsFieldProxyModel.Filter
        Date = ... # type: QgsFieldProxyModel.Filter
        Time = ... # type: QgsFieldProxyModel.Filter
        HideReadOnly = ... # type: QgsFieldProxyModel.Filter
        DateTime = ... # type: QgsFieldProxyModel.Filter
        Binary = ... # type: QgsFieldProxyModel.Filter
        Boolean = ... # type: QgsFieldProxyModel.Filter
        OriginProvider = ... # type: QgsFieldProxyModel.Filter
        AllTypes = ... # type: QgsFieldProxyModel.Filter

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def filters(self) -> 'QgsFieldProxyModel.Filter': ...
    def setFilters(self, filters: 'QgsFieldProxyModel.Filter') -> 'QgsFieldProxyModel|None': ...
    def sourceFieldModel(self) -> QgsFieldModel|None: ...


class QgsFields(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsFields') -> None: ...
    @typing.overload
    def __init__(self, fields: typing.Any) -> None: ...

    def __setitem__(self, key: int, field: QgsField) -> None: ...
    @typing.overload
    @staticmethod
    def iconForFieldType(type: QtCore.QMetaType.Type, subType: QtCore.QMetaType.Type = ..., typeString: str|None = ...) -> QtGui.QIcon: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def iconForFieldType(type: typing.Any, subType: typing.Any, typeString: str|None = ...) -> QtGui.QIcon: ...
    def iconForField(self, fieldIdx: int, considerOrigin: bool = ...) -> QtGui.QIcon: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def toList(self) -> typing.Any: ...
    def allAttributesList(self) -> list[int]: ...
    def lookupField(self, fieldName: str|None) -> int: ...
    def indexOf(self, fieldName: str|None) -> int: ...
    def indexFromName(self, fieldName: str|None) -> int: ...
    def fieldOriginIndex(self, fieldIdx: int) -> int: ...
    def fieldOrigin(self, fieldIdx: int) -> Qgis.FieldOrigin: ...
    @typing.overload
    def field(self, fieldIdx: int) -> QgsField: ...
    @typing.overload
    def field(self, name: str|None) -> QgsField: ...
    def at(self, i: int) -> QgsField: ...
    @typing.overload
    def __getitem__(self, i: int) -> QgsField: ...
    @typing.overload
    def __getitem__(self, name: str|None) -> QgsField: ...
    def exists(self, i: int) -> bool: ...
    def names(self) -> list[str]: ...
    def size(self) -> int: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def count(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def extend(self, other: 'QgsFields') -> None: ...
    def remove(self, fieldIdx: int) -> None: ...
    def appendExpressionField(self, field: QgsField, originIndex: int) -> bool: ...
    def rename(self, fieldIdx: int, name: str|None) -> bool: ...
    @typing.overload
    def append(self, field: QgsField, origin: Qgis.FieldOrigin = ..., originIndex: int = ...) -> bool: ...
    @typing.overload
    def append(self, fields: typing.Any, origin: Qgis.FieldOrigin = ...) -> bool: ...
    @typing.overload
    def append(self, fields: 'QgsFields') -> bool: ...
    def clear(self) -> None: ...


class QgsFileFilterGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFileFilterGenerator') -> None: ...

    def createFileFilter(self) -> str: ...


class QgsFileUtils(PyQt6.sip.wrapper):

    class CopyFlag(enum.IntFlag):
        NoSymLinks = ... # type: QgsFileUtils.CopyFlag

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFileUtils') -> None: ...

    @staticmethod
    def replaceTextInFile(path: str|None, searchString: str|None, replacement: str|None) -> bool: ...
    @staticmethod
    def copyDirectory(source: str|None, destination: str|None, flags: 'QgsFileUtils.CopyFlag' = ..., excludePatterns: collections.abc.Iterable[str|None] = ...) -> bool: ...
    @staticmethod
    def uniquePath(path: str|None) -> str: ...
    @staticmethod
    def splitPathToComponents(path: str|None) -> list[str]: ...
    @staticmethod
    def renameDataset(oldPath: str|None, newPath: str|None, flags: Qgis.FileOperationFlag = ...) -> typing.Tuple[bool, str]: ...
    @staticmethod
    def sidecarFilesForPath(path: str|None) -> set[str]: ...
    @staticmethod
    def pathIsSlowDevice(path: str|None) -> bool: ...
    @staticmethod
    def driveType(path: str|None) -> Qgis.DriveType: ...
    @staticmethod
    def findFile(file: str|None, basepath: str|None = ..., maxClimbs: int = ..., searchCeiling: int = ..., currentDir: str|None = ...) -> list[str]: ...
    @staticmethod
    def findClosestExistingPath(path: str|None) -> str: ...
    @staticmethod
    def stringToSafeFilename(string: str|None) -> str: ...
    @staticmethod
    def addExtensionFromFilter(fileName: str|None, filter: str|None) -> str: ...
    @staticmethod
    def ensureFileNameHasExtension(fileName: str|None, extensions: collections.abc.Iterable[str|None]) -> str: ...
    @staticmethod
    def fileMatchesFilter(fileName: str|None, filter: str|None) -> bool: ...
    @staticmethod
    def wildcardsFromFilter(filter: str|None) -> str: ...
    @staticmethod
    def extensionsFromFilter(filter: str|None) -> list[str]: ...
    @staticmethod
    def representFileSize(bytes: int) -> str: ...


class QgsFontUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFontUtils') -> None: ...

    @staticmethod
    def createFont(family: str|None, pointSize: int = ..., weight: int = ..., italic: bool = ...) -> QtGui.QFont: ...
    @staticmethod
    def setFontFamily(font: QtGui.QFont, family: str|None) -> None: ...
    @staticmethod
    def recentFontFamilies() -> list[str]: ...
    @staticmethod
    def addRecentFontFamily(family: str|None) -> None: ...
    @staticmethod
    def asCSS(font: QtGui.QFont, pointToPixelMultiplier: float = ...) -> str: ...
    @staticmethod
    def untranslateNamedStyle(namedStyle: str|None) -> str: ...
    @staticmethod
    def translateNamedStyle(namedStyle: str|None) -> str: ...
    @staticmethod
    def fromMimeData(data: QtCore.QMimeData|None) -> typing.Tuple[QtGui.QFont, bool]: ...
    @staticmethod
    def toMimeData(font: QtGui.QFont) -> QtCore.QMimeData|None: ...
    @staticmethod
    def setFromXmlChildNode(font: QtGui.QFont, element: QtXml.QDomElement, childNode: str|None) -> bool: ...
    @staticmethod
    def setFromXmlElement(font: QtGui.QFont, element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def toXmlElement(font: QtGui.QFont, document: QtXml.QDomDocument, elementName: str|None) -> QtXml.QDomElement: ...
    @staticmethod
    def getStandardTestFont(style: str|None = ..., pointsize: int = ...) -> QtGui.QFont: ...
    @staticmethod
    def loadStandardTestFonts(loadstyles: collections.abc.Iterable[str|None]) -> bool: ...
    @staticmethod
    def standardTestFontFamily() -> str: ...
    @staticmethod
    def updateFontViaStyle(f: QtGui.QFont, fontstyle: str|None, fallback: bool = ...) -> bool: ...
    @staticmethod
    def fontFamilyMatchOnSystem(family: str|None, chosen: str|None = ...) -> typing.Tuple[bool, bool]: ...
    @staticmethod
    def resolveFontStyleName(font: QtGui.QFont) -> str: ...
    @staticmethod
    def fontFamilyHasStyle(family: str|None, style: str|None) -> bool: ...
    @staticmethod
    def fontFamilyOnSystem(family: str|None) -> bool: ...
    @staticmethod
    def fontMatchOnSystem(f: QtGui.QFont) -> bool: ...


class QgsGeometryOptions(QtCore.QObject):

    def __init__(self) -> None: ...

    geometryPrecisionChanged: typing.ClassVar[QtCore.pyqtSignal]
    removeDuplicateNodesChanged: typing.ClassVar[QtCore.pyqtSignal]
    geometryChecksChanged: typing.ClassVar[QtCore.pyqtSignal]
    checkConfigurationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def readXml(self, node: QtXml.QDomNode) -> None: ...
    def writeXml(self, node: QtXml.QDomNode) -> None: ...
    def setCheckConfiguration(self, checkId: str|None, checkConfiguration: dict[str|None, typing.Any]) -> None: ...
    def checkConfiguration(self, checkId: str|None) -> dict[str, typing.Any]: ...
    def setGeometryChecks(self, geometryChecks: collections.abc.Iterable[str|None]) -> None: ...
    def geometryChecks(self) -> list[str]: ...
    def apply(self, geometry: 'QgsGeometry') -> None: ...
    def isActive(self) -> bool: ...
    def setGeometryPrecision(self, value: float) -> None: ...
    def geometryPrecision(self) -> float: ...
    def setRemoveDuplicateNodes(self, value: bool) -> None: ...
    def removeDuplicateNodes(self) -> bool: ...


class QgsAbstractGeometrySimplifier(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractGeometrySimplifier') -> None: ...

    @typing.overload
    @staticmethod
    def isGeneralizableByDeviceBoundingBox(envelope: 'QgsRectangle', mapToPixelTol: float = ...) -> bool: ...
    @typing.overload
    @staticmethod
    def isGeneralizableByDeviceBoundingBox(points: collections.abc.Iterable[QtCore.QPointF], mapToPixelTol: float = ...) -> bool: ...
    @typing.overload
    def simplify(self, geometry: 'QgsGeometry') -> 'QgsGeometry': ...
    @typing.overload
    def simplify(self, geometry: 'QgsAbstractGeometry|None') -> 'QgsAbstractGeometry|None': ...


class QgsTopologyPreservingSimplifier(QgsAbstractGeometrySimplifier):

    @typing.overload
    def __init__(self, tolerance: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTopologyPreservingSimplifier') -> None: ...

    @typing.overload
    def simplify(self, geometry: 'QgsGeometry') -> 'QgsGeometry': ...
    @typing.overload
    def simplify(self, geometry: 'QgsAbstractGeometry|None') -> 'QgsAbstractGeometry|None': ...


class QgsGeometryValidator(QtCore.QThread):

    def __init__(self, geometry: 'QgsGeometry', errors: collections.abc.Iterable['QgsGeometry.Error'] = ..., method: Qgis.GeometryValidationEngine = ...) -> None: ...

    def addError(self, a0: 'QgsGeometry.Error') -> None: ...
    validationFinished: typing.ClassVar[QtCore.pyqtSignal]
    errorFound: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def validateGeometry(geometry: 'QgsGeometry', method: Qgis.GeometryValidationEngine = ...) -> list['QgsGeometry.Error']: ...
    def stop(self) -> None: ...
    def run(self) -> None: ...


class QgsGml(QtCore.QObject):

    def __init__(self, typeName: str|None, geometryAttribute: str|None, fields: QgsFields) -> None: ...

    dataProgressAndSteps: typing.ClassVar[QtCore.pyqtSignal]
    totalStepsUpdate: typing.ClassVar[QtCore.pyqtSignal]
    dataReadProgress: typing.ClassVar[QtCore.pyqtSignal]
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def idsMap(self) -> typing.Any: ...
    def featuresMap(self) -> typing.Any: ...
    def getFeatures(self, data: QtCore.QByteArray|bytes|bytearray|memoryview, extent: 'QgsRectangle|None' = ...) -> typing.Tuple[int, Qgis.WkbType|None]: ...
    def getFeaturesUri(self, uri: str|None, extent: 'QgsRectangle|None' = ..., userName: str|None = ..., password: str|None = ..., authcfg: str|None = ...) -> typing.Tuple[int, Qgis.WkbType|None]: ...


class QgsGmlFeatureClass(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, path: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGmlFeatureClass') -> None: ...

    def geometryAttributes(self) -> list[str]: ...
    def path(self) -> str: ...
    def fieldIndex(self, name: str|None) -> int: ...
    def fields(self) -> typing.Any: ...


class QgsGmlSchema(QtCore.QObject):

    def __init__(self) -> None: ...

    def error(self) -> QgsError: ...
    def geometryAttributes(self, typeName: str|None) -> list[str]: ...
    def fields(self, typeName: str|None) -> typing.Any: ...
    def typeNames(self) -> list[str]: ...
    def guessSchema(self, data: QtCore.QByteArray|bytes|bytearray|memoryview) -> bool: ...
    def parseXSD(self, xml: QtCore.QByteArray|bytes|bytearray|memoryview) -> bool: ...


class QgsGroupedFeatureFilterProvider(QgsFeatureFilterProvider):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGroupedFeatureFilterProvider') -> None: ...

    def addProvider(self, provider: QgsFeatureFilterProvider|None) -> 'QgsGroupedFeatureFilterProvider': ...
    def clone(self) -> 'QgsGroupedFeatureFilterProvider|None': ...
    def layerAttributes(self, layer: QgsVectorLayer|None, attributes: collections.abc.Iterable[str|None]) -> list[str]: ...
    @typing.overload
    @deprecated("""""")
    def filterFeatures(self, layer: QgsVectorLayer|None, filterFeatures: QgsFeatureRequest) -> None: ...
    @typing.overload
    def filterFeatures(self, layerId: str|None, filterFeatures: QgsFeatureRequest) -> None: ...
    @deprecated("""""")
    def isFilterThreadSafe(self) -> bool: ...


class QgsGroupLayer(QgsMapLayer):

    class LayerOptions(PyQt6.sip.wrapper):

        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsGroupLayer.LayerOptions') -> None: ...

    def __init__(self, name: str|None, options: 'QgsGroupLayer.LayerOptions') -> None: ...

    def prepareLayersForRemovalFromGroup(self) -> None: ...
    def setPaintEffect(self, effect: 'QgsPaintEffect|None') -> None: ...
    def paintEffect(self) -> 'QgsPaintEffect|None': ...
    def childLayers(self) -> list[QgsMapLayer]: ...
    def setChildLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def htmlMetadata(self) -> str: ...
    def dataProvider(self) -> 'QgsDataProvider|None': ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: 'QgsReadWriteContext', categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, a3: 'QgsReadWriteContext', categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeXml(self, layer_node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> bool: ...
    def readXml(self, layerNode: QtXml.QDomNode, context: 'QgsReadWriteContext') -> bool: ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def extent(self) -> 'QgsRectangle': ...
    def createMapRenderer(self, rendererContext: 'QgsRenderContext') -> 'QgsMapLayerRenderer|None': ...
    def clone(self) -> 'QgsGroupLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsHistogram(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHistogram') -> None: ...

    def counts(self, bins: int) -> list[int]: ...
    def binEdges(self, bins: int) -> list[float]: ...
    def optimalNumberBins(self) -> int: ...
    def optimalBinWidth(self) -> float: ...
    @typing.overload
    def setValues(self, values: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def setValues(self, layer: QgsVectorLayer|None, fieldOrExpression: str|None, feedback: QgsFeedback|None = ...) -> bool: ...


class QgsHstoreUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHstoreUtils') -> None: ...

    @staticmethod
    def build(map: dict[str|None, typing.Any]) -> str: ...
    @staticmethod
    def parse(string: str|None) -> dict[str, typing.Any]: ...


class QgsHtmlUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHtmlUtils') -> None: ...

    @staticmethod
    def buildBulletList(values: collections.abc.Iterable[str|None]) -> str: ...


class QgsIconUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsIconUtils') -> None: ...

    @staticmethod
    def iconForLayerType(type: Qgis.LayerType) -> QtGui.QIcon: ...
    @staticmethod
    def iconForLayer(layer: QgsMapLayer|None) -> QtGui.QIcon: ...
    @staticmethod
    def iconTiledScene() -> QtGui.QIcon: ...
    @staticmethod
    def iconPointCloud() -> QtGui.QIcon: ...
    @staticmethod
    def iconVectorTile() -> QtGui.QIcon: ...
    @staticmethod
    def iconMesh() -> QtGui.QIcon: ...
    @staticmethod
    def iconDefaultLayer() -> QtGui.QIcon: ...
    @staticmethod
    def iconRaster() -> QtGui.QIcon: ...
    @staticmethod
    def iconTable() -> QtGui.QIcon: ...
    @staticmethod
    def iconGeometryCollection() -> QtGui.QIcon: ...
    @staticmethod
    def iconPolygon() -> QtGui.QIcon: ...
    @staticmethod
    def iconLine() -> QtGui.QIcon: ...
    @staticmethod
    def iconPoint() -> QtGui.QIcon: ...
    @staticmethod
    def iconForGeometryType(typeGroup: Qgis.GeometryType) -> QtGui.QIcon: ...
    @staticmethod
    def iconForWkbType(type: Qgis.WkbType) -> QtGui.QIcon: ...


class QgsIdentifyContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsIdentifyContext') -> None: ...

    def setZRange(self, range: 'QgsDoubleRange') -> None: ...
    def zRange(self) -> 'QgsDoubleRange': ...
    def isTemporal(self) -> bool: ...
    def temporalRange(self) -> 'QgsDateTimeRange': ...
    def setTemporalRange(self, range: 'QgsDateTimeRange') -> None: ...


class QgsImageCache(QgsAbstractContentCacheBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    remoteImageFetched: typing.ClassVar[QtCore.pyqtSignal]
    def prepareAnimation(self, path: str|None) -> None: ...
    def nextFrameDelay(self, path: str|None, currentFrame: int = ..., blocking: bool = ...) -> int: ...
    def totalFrameCount(self, path: str|None, blocking: bool = ...) -> int: ...
    def originalSize(self, path: str|None, blocking: bool = ...) -> QtCore.QSize: ...
    def pathAsImage(self, path: str|None, size: QtCore.QSize, keepAspectRatio: bool, opacity: float, blocking: bool = ..., targetDpi: float = ..., frameNumber: int = ...) -> typing.Tuple[QtGui.QImage, bool]: ...
    def maximumSize(self) -> int: ...


class QgsInterval(PyQt6.sip.wrapper):

    DAY = ... # type: int
    HOUR = ... # type: int
    MINUTE = ... # type: int
    MONTHS = ... # type: int
    WEEKS = ... # type: int
    YEARS = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, seconds: float) -> None: ...
    @typing.overload
    def __init__(self, duration: float, unit: Qgis.TemporalUnit) -> None: ...
    @typing.overload
    def __init__(self, years: float, months: float, weeks: float, days: float, hours: float, minutes: float, seconds: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsInterval') -> None: ...

    @staticmethod
    def fromString(string: str|None) -> 'QgsInterval': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def originalUnit(self) -> Qgis.TemporalUnit: ...
    def originalDuration(self) -> float: ...
    def setValid(self, valid: bool) -> None: ...
    def isValid(self) -> bool: ...
    def setSeconds(self, seconds: float) -> None: ...
    def seconds(self) -> float: ...
    def setMinutes(self, minutes: float) -> None: ...
    def minutes(self) -> float: ...
    def setHours(self, hours: float) -> None: ...
    def hours(self) -> float: ...
    def setDays(self, days: float) -> None: ...
    def days(self) -> float: ...
    def setWeeks(self, weeks: float) -> None: ...
    def weeks(self) -> float: ...
    def setMonths(self, months: float) -> None: ...
    def months(self) -> float: ...
    def setYears(self, years: float) -> None: ...
    def years(self) -> float: ...
    def __repr__(self) -> typing.Any: ...


class QgsJsonExporter(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, vectorLayer: QgsVectorLayer|None = ..., precision: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsJsonExporter') -> None: ...

    def setDestinationCrs(self, destinationCrs: 'QgsCoordinateReferenceSystem') -> None: ...
    def exportFeatures(self, features: collections.abc.Iterable[QgsFeature], indent: int = ...) -> str: ...
    def exportFeature(self, feature: QgsFeature, extraProperties: dict[str|None, typing.Any] = ..., id: typing.Any = ..., indent: int = ...) -> str: ...
    def useFieldFormatters(self) -> bool: ...
    def setUseFieldFormatters(self, useFieldFormatters: bool) -> None: ...
    def excludedAttributes(self) -> list[int]: ...
    def setExcludedAttributes(self, attributes: collections.abc.Iterable[int]) -> None: ...
    def attributes(self) -> list[int]: ...
    def setAttributes(self, attributes: collections.abc.Iterable[int]) -> None: ...
    def setTransformGeometries(self, activate: bool) -> None: ...
    def sourceCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setSourceCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def vectorLayer(self) -> QgsVectorLayer|None: ...
    def setVectorLayer(self, vectorLayer: QgsVectorLayer|None) -> None: ...
    def attributeDisplayName(self) -> bool: ...
    def setAttributeDisplayName(self, displayName: bool) -> None: ...
    def includeRelated(self) -> bool: ...
    def setIncludeRelated(self, includeRelated: bool) -> None: ...
    def includeAttributes(self) -> bool: ...
    def setIncludeAttributes(self, includeAttributes: bool) -> None: ...
    def includeGeometry(self) -> bool: ...
    def setIncludeGeometry(self, includeGeometry: bool) -> None: ...
    def precision(self) -> int: ...
    def setPrecision(self, precision: int) -> None: ...


class QgsJsonUtils(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsJsonUtils') -> None: ...

    @staticmethod
    def geometryFromGeoJson(geometry: str|None) -> 'QgsGeometry': ...
    @typing.overload
    @staticmethod
    def parseArray(json: str|None, type: QtCore.QMetaType.Type = ...) -> list[typing.Any]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def parseArray(json: str|None, type: typing.Any) -> list[typing.Any]: ...
    @staticmethod
    def exportAttributes(feature: QgsFeature, layer: QgsVectorLayer|None = ..., attributeWidgetCaches: collections.abc.Iterable[typing.Any] = ...) -> str: ...
    @staticmethod
    def encodeValue(value: typing.Any) -> str: ...
    @staticmethod
    def stringToFields(string: str|None) -> QgsFields: ...
    @staticmethod
    def stringToFeatureList(string: str|None, fields: QgsFields = ...) -> list[QgsFeature]: ...


class QgsLayerDefinition(PyQt6.sip.wrapper):

    class DependencySorter(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, doc: QtXml.QDomDocument) -> None: ...
        @typing.overload
        def __init__(self, fileName: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerDefinition.DependencySorter') -> None: ...

        def isLayerDependent(self, layerId: str|None) -> bool: ...
        def hasMissingDependency(self) -> bool: ...
        def hasCycle(self) -> bool: ...
        def sortedLayerIds(self) -> list[str]: ...
        def sortedLayerNodes(self) -> list[QtXml.QDomNode]: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerDefinition') -> None: ...

    @typing.overload
    @staticmethod
    def loadLayerDefinitionLayers(document: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> list[QgsMapLayer]: ...
    @typing.overload
    @staticmethod
    def loadLayerDefinitionLayers(qlrfile: str|None) -> list[QgsMapLayer]: ...
    @staticmethod
    def exportLayerDefinitionLayers(layers: collections.abc.Iterable[QgsMapLayer], context: 'QgsReadWriteContext') -> QtXml.QDomDocument: ...
    @typing.overload
    @staticmethod
    def exportLayerDefinition(path: str|None, selectedTreeNodes: collections.abc.Iterable['QgsLayerTreeNode']) -> typing.Tuple[bool, str]: ...
    @typing.overload
    @staticmethod
    def exportLayerDefinition(path: str|None, selectedTreeNodes: collections.abc.Iterable['QgsLayerTreeNode'], pathType: Qgis.FilePathType) -> typing.Tuple[bool, str]: ...
    @typing.overload
    @staticmethod
    def exportLayerDefinition(doc: QtXml.QDomDocument, selectedTreeNodes: collections.abc.Iterable['QgsLayerTreeNode'], context: 'QgsReadWriteContext') -> typing.Tuple[bool, str]: ...
    @typing.overload
    @staticmethod
    def loadLayerDefinition(path: str|None, project: 'QgsProject|None', rootGroup: 'QgsLayerTreeGroup|None', insertMethod: Qgis.LayerTreeInsertionMethod = ..., insertPoint: 'QgsLayerTreeRegistryBridge.InsertionPoint|None' = ...) -> typing.Tuple[bool, str]: ...
    @typing.overload
    @staticmethod
    def loadLayerDefinition(doc: QtXml.QDomDocument, project: 'QgsProject|None', rootGroup: 'QgsLayerTreeGroup|None', context: 'QgsReadWriteContext', insertMethod: Qgis.LayerTreeInsertionMethod = ..., insertPoint: 'QgsLayerTreeRegistryBridge.InsertionPoint|None' = ...) -> typing.Tuple[bool, str]: ...


class QgsLayerNotesUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerNotesUtils') -> None: ...

    @staticmethod
    def removeNotes(layer: QgsMapLayer|None) -> None: ...
    @staticmethod
    def layerHasNotes(layer: QgsMapLayer|None) -> bool: ...
    @staticmethod
    def setLayerNotes(layer: QgsMapLayer|None, notes: str|None) -> None: ...
    @staticmethod
    def layerNotes(layer: QgsMapLayer|None) -> str: ...


class QgsLegendRenderer(PyQt6.sip.wrapper):

    def __init__(self, legendModel: 'QgsLayerTreeModel|None', settings: 'QgsLegendSettings') -> None: ...

    @staticmethod
    def nodeLegendStyle(node: 'QgsLayerTreeNode|None', model: 'QgsLayerTreeModel|None') -> Qgis.LegendComponent: ...
    @staticmethod
    def setNodeLegendStyle(node: 'QgsLayerTreeNode|None', style: Qgis.LegendComponent) -> None: ...
    def exportLegendToJson(self, context: 'QgsRenderContext') -> dict[str, QtCore.QJsonValue]: ...
    @typing.overload
    @deprecated("""""")
    def drawLegend(self, painter: QtGui.QPainter|None) -> None: ...
    @typing.overload
    def drawLegend(self, context: 'QgsRenderContext') -> None: ...
    def legendSize(self) -> QtCore.QSizeF: ...
    def setLegendSize(self, s: QtCore.QSizeF) -> None: ...
    def minimumSize(self, renderContext: 'QgsRenderContext|None' = ...) -> QtCore.QSizeF: ...
    def proxyModel(self) -> 'QgsLayerTreeFilterProxyModel|None': ...
    def setProxyModel(self, model: 'QgsLayerTreeFilterProxyModel|None') -> None: ...


class QgsLegendSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLegendSettings') -> None: ...

    def setAutoWrapLinesAfter(self, length: float) -> None: ...
    def autoWrapLinesAfter(self) -> float: ...
    def setJsonRenderFlags(self, jsonRenderFlags: Qgis.LegendJsonRenderFlag) -> None: ...
    def jsonRenderFlags(self) -> Qgis.LegendJsonRenderFlag: ...
    def fontDescentMillimeters(self, font: QtGui.QFont) -> float: ...
    def fontAscentMillimeters(self, font: QtGui.QFont) -> float: ...
    def fontHeightCharacterMM(self, font: QtGui.QFont, c: str) -> float: ...
    def textWidthMillimeters(self, font: QtGui.QFont, text: str|None) -> float: ...
    def pixelFontSize(self, pointSize: float) -> float: ...
    def scaledFontPixelSize(self, font: QtGui.QFont) -> QtGui.QFont: ...
    @typing.overload
    def drawText(self, p: QtGui.QPainter|None, x: float, y: float, text: str|None, font: QtGui.QFont) -> None: ...
    @typing.overload
    def drawText(self, p: QtGui.QPainter|None, rect: QtCore.QRectF, text: str|None, font: QtGui.QFont, halignment: QtCore.Qt.AlignmentFlag = ..., valignment: QtCore.Qt.AlignmentFlag = ..., flags: int = ...) -> None: ...
    def splitStringForWrapping(self, stringToSplt: str|None) -> list[str]: ...
    def evaluateItemText(self, text: str|None, context: QgsExpressionContext) -> list[str]: ...
    @deprecated("""""")
    def setDpi(self, dpi: int) -> None: ...
    @deprecated("""""")
    def dpi(self) -> int: ...
    @deprecated("""""")
    def setMapUnitsPerPixel(self, mapUnitsPerPixel: float) -> None: ...
    @deprecated("""""")
    def mapUnitsPerPixel(self) -> float: ...
    @deprecated("""""")
    def setMapScale(self, scale: float) -> None: ...
    @deprecated("""""")
    def mapScale(self) -> float: ...
    @deprecated("""""")
    def setUseAdvancedEffects(self, use: bool) -> None: ...
    @deprecated("""""")
    def useAdvancedEffects(self) -> bool: ...
    @deprecated("""""")
    def setMmPerMapUnit(self, mmPerMapUnit: float) -> None: ...
    @deprecated("""""")
    def mmPerMapUnit(self) -> float: ...
    def setLineSpacing(self, s: float) -> None: ...
    @deprecated("""""")
    def lineSpacing(self) -> float: ...
    def synchronousLegendRequests(self) -> bool: ...
    def setSynchronousLegendRequests(self, b: bool) -> None: ...
    def setWmsLegendSize(self, s: QtCore.QSizeF) -> None: ...
    def wmsLegendSize(self) -> QtCore.QSizeF: ...
    def setRasterStrokeWidth(self, width: float) -> None: ...
    def rasterStrokeWidth(self) -> float: ...
    def setRasterStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def rasterStrokeColor(self) -> QtGui.QColor: ...
    def setDrawRasterStroke(self, enabled: bool) -> None: ...
    def drawRasterStroke(self) -> bool: ...
    def symbolAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setSymbolAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def setMinimumSymbolSize(self, size: float) -> None: ...
    def minimumSymbolSize(self) -> float: ...
    def setMaximumSymbolSize(self, size: float) -> None: ...
    def maximumSymbolSize(self) -> float: ...
    def setSymbolSize(self, s: QtCore.QSizeF) -> None: ...
    def symbolSize(self) -> QtCore.QSizeF: ...
    @deprecated("""""")
    def setLayerFontColor(self, fontColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def layerFontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFontColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fontColor(self) -> QtGui.QColor: ...
    def setEqualColumnWidth(self, s: bool) -> None: ...
    def equalColumnWidth(self) -> bool: ...
    def setSplitLayer(self, s: bool) -> None: ...
    def splitLayer(self) -> bool: ...
    def setColumnCount(self, c: int) -> None: ...
    def columnCount(self) -> int: ...
    def setColumnSpace(self, s: float) -> None: ...
    def columnSpace(self) -> float: ...
    def wrapChar(self) -> str: ...
    def setWrapChar(self, t: str|None) -> None: ...
    def setBoxSpace(self, s: float) -> None: ...
    def boxSpace(self) -> float: ...
    def setStyle(self, s: Qgis.LegendComponent, style: 'QgsLegendStyle') -> None: ...
    def style(self, s: Qgis.LegendComponent) -> 'QgsLegendStyle': ...
    def setTitleAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def titleAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def title(self) -> str: ...
    def setTitle(self, t: str|None) -> None: ...
    def updateDataDefinedProperties(self, context: 'QgsRenderContext') -> None: ...


class QgsLegendStyle(PyQt6.sip.wrapper):

    class Side(enum.IntEnum):
        Top = ... # type: QgsLegendStyle.Side
        Bottom = ... # type: QgsLegendStyle.Side
        Left = ... # type: QgsLegendStyle.Side
        Right = ... # type: QgsLegendStyle.Side

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLegendStyle') -> None: ...

    @staticmethod
    def styleLabel(s: Qgis.LegendComponent) -> str: ...
    @staticmethod
    def styleFromName(styleName: str|None) -> Qgis.LegendComponent: ...
    @staticmethod
    def styleName(s: Qgis.LegendComponent) -> str: ...
    def updateDataDefinedProperties(self, context: 'QgsRenderContext') -> None: ...
    def readXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext' = ...) -> None: ...
    def writeXml(self, name: str|None, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext' = ...) -> None: ...
    def setIndent(self, indent: float) -> None: ...
    def indent(self) -> float: ...
    def setAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def alignment(self) -> QtCore.Qt.AlignmentFlag: ...
    @typing.overload
    def setMargin(self, side: 'QgsLegendStyle.Side', margin: float) -> None: ...
    @typing.overload
    def setMargin(self, margin: float) -> None: ...
    def margin(self, side: 'QgsLegendStyle.Side') -> float: ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    @deprecated("""""")
    def setFont(self, font: QtGui.QFont) -> None: ...
    @deprecated("""""")
    def font(self) -> QtGui.QFont: ...


class QgsLocalDefaultSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLocalDefaultSettings') -> None: ...

    @staticmethod
    def geographicCoordinateFormat() -> 'QgsGeographicCoordinateNumericFormat|None': ...
    @staticmethod
    def setGeographicCoordinateFormat(format: 'QgsGeographicCoordinateNumericFormat|None') -> None: ...
    @staticmethod
    def bearingFormat() -> 'QgsBearingNumericFormat|None': ...
    @staticmethod
    def setBearingFormat(format: 'QgsBearingNumericFormat|None') -> None: ...


class QgsLocalizedDataPathRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def unregisterPath(self, path: str|None) -> None: ...
    def registerPath(self, path: str|None, position: int = ...) -> None: ...
    def paths(self) -> list[str]: ...
    def localizedPath(self, globalPath: str|None) -> str: ...
    def globalPath(self, localizedPath: str|None) -> str: ...


class QgsLogger(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLogger') -> None: ...

    @staticmethod
    def logFile() -> str: ...
    @staticmethod
    def logMessageToFile(message: str|None) -> None: ...
    @staticmethod
    def debugLevel() -> int: ...
    @staticmethod
    def fatal(msg: str|None) -> None: ...
    @staticmethod
    def critical(msg: str|None) -> None: ...
    @staticmethod
    def warning(msg: str|None) -> None: ...
    @typing.overload
    @staticmethod
    def debug(msg: str|None, debuglevel: int = ..., file: str = ..., function: str = ..., line: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def debug(var: str|None, val: int, debuglevel: int = ..., file: str = ..., function: str = ..., line: int = ...) -> None: ...


class QgsScopeLogger(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, file: str, func: str, line: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScopeLogger') -> None: ...


class QgsMagneticModel(PyQt6.sip.wrapper):

    def __init__(self, name: str|None, path: str|None = ..., maxDegree: int = ..., maxOrder: int = ...) -> None: ...

    @staticmethod
    def fieldComponentsWithTimeDerivatives(Bx: float, By: float, Bz: float, Bxt: float, Byt: float, Bzt: float) -> typing.Tuple[bool, float, float, float, float, float, float, float, float]: ...
    @staticmethod
    def fieldComponents(Bx: float, By: float, Bz: float) -> typing.Tuple[bool, float, float, float, float]: ...
    def getComponentsWithTimeDerivatives(self, years: float, latitude: float, longitude: float, height: float) -> typing.Tuple[bool, float, float, float, float, float, float]: ...
    def getComponents(self, years: float, latitude: float, longitude: float, height: float) -> typing.Tuple[bool, float, float, float]: ...
    def inclination(self, years: float, latitude: float, longitude: float, height: float) -> typing.Tuple[bool, float]: ...
    def declination(self, years: float, latitude: float, longitude: float, height: float) -> typing.Tuple[bool, float]: ...
    def order(self) -> int: ...
    def degree(self) -> int: ...
    def maximumYear(self) -> float: ...
    def minimumYear(self) -> float: ...
    def maximumHeight(self) -> float: ...
    def minimumHeight(self) -> float: ...
    def error(self) -> str: ...
    def name(self) -> str: ...
    def directory(self) -> str: ...
    def file(self) -> str: ...
    def dateTime(self) -> QtCore.QDateTime: ...
    def description(self) -> str: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def defaultModelName() -> str: ...
    @staticmethod
    def defaultFilePath() -> str: ...


class QgsMapClippingRegion(PyQt6.sip.wrapper):

    class FeatureClippingType(enum.IntEnum):
        ClipToIntersection = ... # type: QgsMapClippingRegion.FeatureClippingType
        ClipPainterOnly = ... # type: QgsMapClippingRegion.FeatureClippingType
        NoClipping = ... # type: QgsMapClippingRegion.FeatureClippingType

    @typing.overload
    def __init__(self, geometry: 'QgsGeometry') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapClippingRegion') -> None: ...

    def appliesToLayer(self, layer: QgsMapLayer|None) -> bool: ...
    def restrictedLayers(self) -> list[QgsMapLayer]: ...
    def setRestrictedLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def setRestrictToLayers(self, enabled: bool) -> None: ...
    def restrictToLayers(self) -> bool: ...
    def setFeatureClip(self, type: 'QgsMapClippingRegion.FeatureClippingType') -> None: ...
    def featureClip(self) -> 'QgsMapClippingRegion.FeatureClippingType': ...
    def setGeometry(self, geometry: 'QgsGeometry') -> None: ...
    def geometry(self) -> 'QgsGeometry': ...


class QgsMapClippingUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapClippingUtils') -> None: ...

    @staticmethod
    def calculateLabelIntersectionGeometry(regions: collections.abc.Iterable[QgsMapClippingRegion], context: 'QgsRenderContext') -> typing.Tuple['QgsGeometry', bool]: ...
    @staticmethod
    def calculatePainterClipRegion(regions: collections.abc.Iterable[QgsMapClippingRegion], context: 'QgsRenderContext', layerType: Qgis.LayerType) -> typing.Tuple[QtGui.QPainterPath, bool]: ...
    @staticmethod
    def calculateFeatureIntersectionGeometry(regions: collections.abc.Iterable[QgsMapClippingRegion], context: 'QgsRenderContext') -> typing.Tuple['QgsGeometry', bool]: ...
    @staticmethod
    def calculateFeatureRequestGeometry(regions: collections.abc.Iterable[QgsMapClippingRegion], context: 'QgsRenderContext') -> typing.Tuple['QgsGeometry', bool]: ...
    @staticmethod
    def collectClippingRegionsForLayer(context: 'QgsRenderContext', layer: QgsMapLayer|None) -> list[QgsMapClippingRegion]: ...


class QgsMapDecoration(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapDecoration') -> None: ...

    def setDisplayName(self, name: str|None) -> None: ...
    def hasFixedMapPosition(self) -> bool: ...
    def displayName(self) -> str: ...
    def render(self, mapSettings: 'QgsMapSettings', context: 'QgsRenderContext') -> None: ...


class QgsMapHitTest(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, settings: 'QgsMapSettings', polygon: 'QgsGeometry' = ..., layerFilterExpression: dict[str|None, str|None] = ...) -> None: ...
    @typing.overload
    def __init__(self, settings: 'QgsMapSettings', layerFilterExpression: dict[str|None, str|None]) -> None: ...
    @typing.overload
    def __init__(self, settings: 'QgsLayerTreeFilterSettings') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapHitTest') -> None: ...

    def legendKeyVisible(self, ruleKey: str|None, layer: QgsVectorLayer|None) -> bool: ...
    def symbolVisible(self, symbol: 'QgsSymbol|None', layer: QgsVectorLayer|None) -> bool: ...
    def resultsRenderersUpdatedCanvas(self) -> dict[str, tuple[float, float]]: ...
    def results(self) -> typing.Any: ...
    def run(self) -> None: ...


class QgsMapHitTestTask(QgsTask):

    def __init__(self, settings: 'QgsLayerTreeFilterSettings') -> None: ...

    def run(self) -> bool: ...
    def resultsRenderersUpdatedCanvas(self) -> dict[str, tuple[float, float]]: ...
    def cancel(self) -> None: ...
    def results(self) -> typing.Any: ...


class QgsMapLayerDependency(PyQt6.sip.wrapper):

    class Origin(enum.IntEnum):
        FromProvider = ... # type: QgsMapLayerDependency.Origin
        FromUser = ... # type: QgsMapLayerDependency.Origin

    class Type(enum.IntEnum):
        PresenceDependency = ... # type: QgsMapLayerDependency.Type
        DataDependency = ... # type: QgsMapLayerDependency.Type

    @typing.overload
    def __init__(self, layerId: str|None, type: 'QgsMapLayerDependency.Type' = ..., origin: 'QgsMapLayerDependency.Origin' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerDependency') -> None: ...

    def __ne__(self, other: object): ...
    def __hash__(self) -> int: ...
    def __eq__(self, other: object): ...
    def layerId(self) -> str: ...
    def origin(self) -> 'QgsMapLayerDependency.Origin': ...
    def type(self) -> 'QgsMapLayerDependency.Type': ...


class QgsMapLayerFactory(PyQt6.sip.wrapper):

    class LayerOptions(PyQt6.sip.wrapper):

        loadAllStoredStyles = ... # type: bool
        loadDefaultStyle = ... # type: bool
        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMapLayerFactory.LayerOptions') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerFactory') -> None: ...

    @staticmethod
    def createLayer(uri: str|None, name: str|None, type: Qgis.LayerType, options: 'QgsMapLayerFactory.LayerOptions', provider: str|None = ...) -> QgsMapLayer|None: ...
    @staticmethod
    def typeToString(type: Qgis.LayerType) -> str: ...
    @staticmethod
    def typeFromString(string: str|None) -> typing.Tuple[Qgis.LayerType, bool]: ...


class QgsMapLayerLegend(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    itemsChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def defaultPointCloudLegend(layer: 'QgsPointCloudLayer|None') -> 'QgsMapLayerLegend|None': ...
    @staticmethod
    def defaultMeshLegend(ml: 'QgsMeshLayer|None') -> 'QgsMapLayerLegend|None': ...
    @staticmethod
    def defaultRasterLegend(rl: 'QgsRasterLayer|None') -> 'QgsMapLayerLegend|None': ...
    @staticmethod
    def defaultVectorLegend(vl: QgsVectorLayer|None) -> 'QgsMapLayerLegend|None': ...
    def createLayerTreeModelLegendNodes(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def setFlags(self, flags: Qgis.MapLayerLegendFlag) -> None: ...
    def setFlag(self, flag: Qgis.MapLayerLegendFlag, on: bool = ...) -> None: ...
    def flags(self) -> Qgis.MapLayerLegendFlag: ...


class QgsMapLayerLegendUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerLegendUtils') -> None: ...

    @staticmethod
    def applyLayerNodeProperties(nodeLayer: 'QgsLayerTreeLayer|None', nodes: collections.abc.Iterable['QgsLayerTreeModelLegendNode']) -> None: ...
    @staticmethod
    def legendNodeColumnBreak(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> bool: ...
    @staticmethod
    def setLegendNodeColumnBreak(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int, columnBreakBeforeNode: bool) -> None: ...
    @staticmethod
    def legendNodeColorRampSettings(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> 'QgsColorRampLegendNodeSettings|None': ...
    @staticmethod
    def setLegendNodeColorRampSettings(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int, settings: 'QgsColorRampLegendNodeSettings|None') -> None: ...
    @staticmethod
    def legendNodeCustomSymbol(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> 'QgsSymbol'|None: ...
    @staticmethod
    def setLegendNodeCustomSymbol(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int, symbol: 'QgsSymbol|None') -> None: ...
    @staticmethod
    def legendNodeSymbolSize(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> QtCore.QSizeF: ...
    @staticmethod
    def setLegendNodeSymbolSize(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int, size: QtCore.QSizeF) -> None: ...
    @staticmethod
    def legendNodePatchShape(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> 'QgsLegendPatchShape': ...
    @staticmethod
    def setLegendNodePatchShape(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int, shape: 'QgsLegendPatchShape') -> None: ...
    @staticmethod
    def hasLegendNodeUserLabel(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> bool: ...
    @staticmethod
    def legendNodeUserLabel(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int) -> str: ...
    @staticmethod
    def setLegendNodeUserLabel(nodeLayer: 'QgsLayerTreeLayer|None', originalIndex: int, newLabel: str|None) -> None: ...
    @staticmethod
    def hasLegendNodeOrder(nodeLayer: 'QgsLayerTreeLayer|None') -> bool: ...
    @staticmethod
    def legendNodeOrder(nodeLayer: 'QgsLayerTreeLayer|None') -> list[int]: ...
    @staticmethod
    def setLegendNodeOrder(nodeLayer: 'QgsLayerTreeLayer|None', order: collections.abc.Iterable[int]) -> None: ...


class QgsDefaultVectorLayerLegend(QgsMapLayerLegend):

    def __init__(self, vl: QgsVectorLayer|None) -> None: ...

    def writeXml(self, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def createLayerTreeModelLegendNodes(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...
    def setTextOnSymbolContent(self, content: dict[str|None, str|None]) -> None: ...
    def textOnSymbolContent(self) -> dict[str, str]: ...
    def setTextOnSymbolTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textOnSymbolTextFormat(self) -> 'QgsTextFormat': ...
    def setShowLabelLegend(self, enabled: bool) -> None: ...
    def showLabelLegend(self) -> bool: ...
    def setTextOnSymbolEnabled(self, enabled: bool) -> None: ...
    def textOnSymbolEnabled(self) -> bool: ...


class QgsDefaultRasterLayerLegend(QgsMapLayerLegend):

    def __init__(self, rl: 'QgsRasterLayer|None') -> None: ...

    def createLayerTreeModelLegendNodes(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...


class QgsDefaultMeshLayerLegend(QgsMapLayerLegend):

    def __init__(self, ml: 'QgsMeshLayer|None') -> None: ...

    def createLayerTreeModelLegendNodes(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...


class QgsDefaultPointCloudLayerLegend(QgsMapLayerLegend):

    def __init__(self, layer: 'QgsPointCloudLayer|None') -> None: ...

    def createLayerTreeModelLegendNodes(self, nodeLayer: 'QgsLayerTreeLayer|None') -> list['QgsLayerTreeModelLegendNode']: ...


class QgsMapLayerModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        LayerId = ... # type: QgsMapLayerModel.CustomRole
        Layer = ... # type: QgsMapLayerModel.CustomRole
        Empty = ... # type: QgsMapLayerModel.CustomRole
        Additional = ... # type: QgsMapLayerModel.CustomRole

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ..., project: 'QgsProject|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, layers: collections.abc.Iterable[QgsMapLayer], parent: QtCore.QObject|None = ..., project: 'QgsProject|None' = ...) -> None: ...

    def addLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def removeLayers(self, layerIds: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def iconForLayer(layer: QgsMapLayer|None) -> QtGui.QIcon: ...
    def supportedDropActions(self) -> QtCore.Qt.DropAction: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def canDropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeTypes(self) -> list[str]: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def insertRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def additionalLayers(self) -> list[QgsMapLayer]: ...
    def setAdditionalLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def additionalItems(self) -> list[str]: ...
    def setAdditionalItems(self, items: collections.abc.Iterable[str|None]) -> None: ...
    def layerFromIndex(self, index: QtCore.QModelIndex) -> QgsMapLayer|None: ...
    def indexFromLayer(self, layer: QgsMapLayer|None) -> QtCore.QModelIndex: ...
    def itemsCheckable(self) -> bool: ...
    def setLayersChecked(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def layersChecked(self, checkState: QtCore.Qt.CheckState = ...) -> list[QgsMapLayer]: ...
    def showCrs(self) -> bool: ...
    def setShowCrs(self, showCrs: bool) -> None: ...
    def allowEmptyLayer(self) -> bool: ...
    def setAllowEmptyLayer(self, allowEmpty: bool, text: str|None = ..., icon: QtGui.QIcon = ...) -> None: ...
    def checkAll(self, checkState: QtCore.Qt.CheckState) -> None: ...
    def itemsCanBeReordered(self) -> bool: ...
    def setItemsCanBeReordered(self, allow: bool) -> None: ...
    def setProject(self, project: 'QgsProject|None') -> None: ...
    def setItemsCheckable(self, checkable: bool) -> None: ...


class QgsMapLayerProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def setFilterString(self, filter: str|None) -> None: ...
    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def acceptsLayer(self, layer: QgsMapLayer|None) -> bool: ...
    def filterString(self) -> str: ...
    def excludedProviders(self) -> list[str]: ...
    def setExcludedProviders(self, providers: collections.abc.Iterable[str|None]) -> None: ...
    def exceptedLayerIds(self) -> list[str]: ...
    def setExceptedLayerIds(self, ids: collections.abc.Iterable[str|None]) -> None: ...
    def exceptedLayerList(self) -> list[QgsMapLayer]: ...
    def setExceptedLayerList(self, exceptList: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def layerAllowlist(self) -> list[QgsMapLayer]: ...
    @deprecated("""""")
    def layerWhitelist(self) -> list[QgsMapLayer]: ...
    def setLayerAllowlist(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    @deprecated("""""")
    def setLayerWhitelist(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    @staticmethod
    def layerMatchesFilters(layer: QgsMapLayer|None, filters: Qgis.LayerFilter) -> bool: ...
    def setProject(self, project: 'QgsProject|None') -> None: ...
    def filters(self) -> Qgis.LayerFilter: ...
    @typing.overload
    def setFilters(self, filters: Qgis.LayerFilter) -> 'QgsMapLayerProxyModel|None': ...
    @typing.overload
    @deprecated("""""")
    def setFilters(self, filters: int) -> None: ...
    def sourceLayerModel(self) -> QgsMapLayerModel|None: ...


class QgsMapLayerRenderer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, layerID: str|None, context: 'QgsRenderContext|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerRenderer') -> None: ...

    def appendRenderedItemDetails(self, details: 'QgsRenderedItemDetails|None') -> None: ...
    def takeRenderedItemDetails(self) -> list['QgsRenderedItemDetails']: ...
    def isReadyToCompose(self) -> bool: ...
    def renderContext(self) -> 'QgsRenderContext|None': ...
    def layerId(self) -> str: ...
    def errors(self) -> list[str]: ...
    def feedback(self) -> QgsFeedback|None: ...
    def flags(self) -> Qgis.MapLayerRendererFlag: ...
    def forceRasterRender(self) -> bool: ...
    def render(self) -> bool: ...


class QgsServerMetadataUrlProperties(PyQt6.sip.wrapper):

    class MetadataUrl(PyQt6.sip.wrapper):

        format = ... # type: str|None
        type = ... # type: str|None
        url = ... # type: str|None

        @typing.overload
        def __init__(self, url: str|None = ..., type: str|None = ..., format: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsServerMetadataUrlProperties.MetadataUrl') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsServerMetadataUrlProperties') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def layer(self) -> QgsMapLayer|None: ...
    def addMetadataUrl(self, metaUrl: 'QgsServerMetadataUrlProperties.MetadataUrl') -> None: ...
    def setMetadataUrls(self, metaUrls: collections.abc.Iterable['QgsServerMetadataUrlProperties.MetadataUrl']) -> None: ...
    def metadataUrls(self) -> list['QgsServerMetadataUrlProperties.MetadataUrl']: ...


class QgsServerWmsDimensionProperties(PyQt6.sip.wrapper):

    class PredefinedWmsDimensionName(enum.IntEnum):
        TIME = ... # type: QgsServerWmsDimensionProperties.PredefinedWmsDimensionName
        DATE = ... # type: QgsServerWmsDimensionProperties.PredefinedWmsDimensionName
        ELEVATION = ... # type: QgsServerWmsDimensionProperties.PredefinedWmsDimensionName

    class WmsDimensionInfo(PyQt6.sip.wrapper):

        class DefaultDisplay(enum.IntEnum):
            AllValues = ... # type: QgsServerWmsDimensionProperties.WmsDimensionInfo.DefaultDisplay
            MinValue = ... # type: QgsServerWmsDimensionProperties.WmsDimensionInfo.DefaultDisplay
            MaxValue = ... # type: QgsServerWmsDimensionProperties.WmsDimensionInfo.DefaultDisplay
            ReferenceValue = ... # type: QgsServerWmsDimensionProperties.WmsDimensionInfo.DefaultDisplay

        defaultDisplayType = ... # type: int
        endFieldName = ... # type: str|None
        fieldName = ... # type: str|None
        name = ... # type: str|None
        referenceValue = ... # type: typing.Any
        unitSymbol = ... # type: str|None
        units = ... # type: str|None

        @typing.overload
        def __init__(self, dimName: str|None, dimFieldName: str|None, dimEndFieldName: str|None = ..., dimUnits: str|None = ..., dimUnitSymbol: str|None = ..., dimDefaultDisplayType: int = ..., dimReferenceValue: typing.Any = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsServerWmsDimensionProperties.WmsDimensionInfo') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsServerWmsDimensionProperties') -> None: ...

    def layer(self) -> QgsMapLayer|None: ...
    def wmsDimensions(self) -> list['QgsServerWmsDimensionProperties.WmsDimensionInfo']: ...
    def setWmsDimensions(self, dimensions: collections.abc.Iterable['QgsServerWmsDimensionProperties.WmsDimensionInfo']) -> None: ...
    def removeWmsDimension(self, wmsDimName: str|None) -> bool: ...
    def addWmsDimension(self, wmsDimInfo: 'QgsServerWmsDimensionProperties.WmsDimensionInfo') -> bool: ...
    @staticmethod
    def wmsDimensionDefaultDisplayLabels() -> dict[int, str]: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsMapLayerServerProperties(QgsServerMetadataUrlProperties, QgsServerWmsDimensionProperties):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, layer: QgsMapLayer|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerServerProperties') -> None: ...

    def layer(self) -> QgsMapLayer|None: ...
    def legendUrlFormat(self) -> str: ...
    def setLegendUrlFormat(self, legendUrlFormat: str|None) -> None: ...
    def legendUrl(self) -> str: ...
    def setLegendUrl(self, legendUrl: str|None) -> None: ...
    def attributionUrl(self) -> str: ...
    def setAttributionUrl(self, url: str|None) -> None: ...
    def attribution(self) -> str: ...
    def setAttribution(self, attrib: str|None) -> None: ...
    def dataUrlFormat(self) -> str: ...
    def setDataUrlFormat(self, dataUrlFormat: str|None) -> None: ...
    def dataUrl(self) -> str: ...
    def setDataUrl(self, dataUrl: str|None) -> None: ...
    def keywordList(self) -> str: ...
    def setKeywordList(self, keywords: str|None) -> None: ...
    def abstract(self) -> str: ...
    def setAbstract(self, abstract: str|None) -> None: ...
    def wfsTitle(self) -> str: ...
    def title(self) -> str: ...
    def setWfsTitle(self, title: str|None) -> None: ...
    def setTitle(self, title: str|None) -> None: ...
    def wfsTypeName(self) -> str: ...
    def shortName(self) -> str: ...
    def setShortName(self, name: str|None) -> None: ...
    def reset(self) -> None: ...
    def readXml(self, layer_node: QtXml.QDomNode) -> None: ...
    def writeXml(self, layer_node: QtXml.QDomNode, document: QtXml.QDomDocument) -> None: ...
    def copyTo(self, properties: 'QgsMapLayerServerProperties|None') -> None: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsVectorLayerServerProperties(QgsMapLayerServerProperties):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorLayerServerProperties') -> None: ...


class QgsMapLayerStore(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    layerWasAdded: typing.ClassVar[QtCore.pyqtSignal]
    layersAdded: typing.ClassVar[QtCore.pyqtSignal]
    allLayersRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layerRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layersRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layerWillBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layersWillBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    def transferLayersFromStore(self, other: 'QgsMapLayerStore|None') -> None: ...
    def removeAllMapLayers(self) -> None: ...
    def takeMapLayer(self, layer: QgsMapLayer|None) -> QgsMapLayer|None: ...
    @typing.overload
    def removeMapLayer(self, id: str|None) -> None: ...
    @typing.overload
    def removeMapLayer(self, layer: QgsMapLayer|None) -> None: ...
    def removeMapLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def removeMapLayersById(self, layerIds: collections.abc.Iterable[str|None]) -> None: ...
    def addMapLayer(self, layer: QgsMapLayer|None) -> QgsMapLayer|None: ...
    def addMapLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> list[QgsMapLayer]: ...
    def validMapLayers(self) -> typing.Any: ...
    def mapLayers(self) -> typing.Any: ...
    def mapLayersByName(self, name: str|None) -> list[QgsMapLayer]: ...
    def mapLayer(self, id: str|None) -> QgsMapLayer|None: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def validCount(self) -> int: ...
    def count(self) -> int: ...


class QgsMapLayerStyle(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, xmlData: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerStyle') -> None: ...

    def writeXml(self, styleElement: QtXml.QDomElement) -> None: ...
    def readXml(self, styleElement: QtXml.QDomElement) -> None: ...
    def writeToLayer(self, layer: QgsMapLayer|None) -> None: ...
    def readFromLayer(self, layer: QgsMapLayer|None) -> None: ...
    def xmlData(self) -> str: ...
    def clear(self) -> None: ...
    def isValid(self) -> bool: ...


class QgsMapLayerStyleOverride(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, layer: QgsMapLayer|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerStyleOverride') -> None: ...

    def setOverrideStyle(self, style: str|None) -> None: ...


class QgsMapLayerStyleManager(QtCore.QObject):

    def __init__(self, layer: QgsMapLayer|None) -> None: ...

    currentStyleChanged: typing.ClassVar[QtCore.pyqtSignal]
    styleRenamed: typing.ClassVar[QtCore.pyqtSignal]
    styleRemoved: typing.ClassVar[QtCore.pyqtSignal]
    styleAdded: typing.ClassVar[QtCore.pyqtSignal]
    def copyStylesFrom(self, other: 'QgsMapLayerStyleManager|None') -> None: ...
    @staticmethod
    def isDefault(styleName: str|None) -> bool: ...
    def restoreOverrideStyle(self) -> bool: ...
    def setOverrideStyle(self, styleDef: str|None) -> bool: ...
    def setCurrentStyle(self, name: str|None) -> bool: ...
    def currentStyle(self) -> str: ...
    def renameStyle(self, name: str|None, newName: str|None) -> bool: ...
    def removeStyle(self, name: str|None) -> bool: ...
    def addStyleFromLayer(self, name: str|None) -> bool: ...
    def addStyle(self, name: str|None, style: QgsMapLayerStyle) -> bool: ...
    def style(self, name: str|None) -> QgsMapLayerStyle: ...
    def mapLayerStyles(self) -> dict[str, QgsMapLayerStyle]: ...
    def styles(self) -> list[str]: ...
    def writeXml(self, mgrElement: QtXml.QDomElement) -> None: ...
    def readXml(self, mgrElement: QtXml.QDomElement) -> None: ...
    def reset(self) -> None: ...
    def layer(self) -> QgsMapLayer|None: ...


class QgsMapLayerElevationProperties(QtCore.QObject):

    class Flag(enum.IntEnum):
        FlagDontInvalidateCachedRendersWhenRangeChanges = ... # type: QgsMapLayerElevationProperties.Flag

    class Property(enum.IntEnum):
        ZOffset = ... # type: QgsMapLayerElevationProperties.Property
        ExtrusionHeight = ... # type: QgsMapLayerElevationProperties.Property
        RasterPerBandLowerElevation = ... # type: QgsMapLayerElevationProperties.Property
        RasterPerBandUpperElevation = ... # type: QgsMapLayerElevationProperties.Property

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def copyCommonProperties(self, other: 'QgsMapLayerElevationProperties|None') -> None: ...
    def readCommonProperties(self, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> None: ...
    def writeCommonProperties(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> None: ...
    profileGenerationPropertyChanged: typing.ClassVar[QtCore.pyqtSignal]
    profileRenderingPropertyChanged: typing.ClassVar[QtCore.pyqtSignal]
    zScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    zOffsetChanged: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def propertyDefinitions() -> dict[int, 'QgsPropertyDefinition']: ...
    def setDataDefinedProperties(self, collection: 'QgsPropertyCollection') -> None: ...
    def dataDefinedProperties(self) -> 'QgsPropertyCollection': ...
    def setZScale(self, scale: float) -> None: ...
    def zScale(self) -> float: ...
    def setZOffset(self, offset: float) -> None: ...
    def zOffset(self) -> float: ...
    def showByDefaultInElevationProfilePlots(self) -> bool: ...
    def significantZValues(self, layer: QgsMapLayer|None) -> list[float]: ...
    def calculateZRange(self, layer: QgsMapLayer|None) -> 'QgsDoubleRange': ...
    def flags(self) -> 'QgsMapLayerElevationProperties.Flag': ...
    def isVisibleInZRange(self, range: 'QgsDoubleRange', layer: QgsMapLayer|None = ...) -> bool: ...
    def clone(self) -> 'QgsMapLayerElevationProperties|None': ...
    def htmlSummary(self) -> str: ...
    def setDefaultsFromLayer(self, layer: QgsMapLayer|None) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> QtXml.QDomElement: ...
    def hasElevation(self) -> bool: ...


class QgsMapLayerSelectionProperties(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def clone(self) -> 'QgsMapLayerSelectionProperties|None': ...
    def readXml(self, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> QtXml.QDomElement: ...


class QgsTemporalProperty(QtCore.QObject):

    class Flag(enum.IntEnum):
        FlagDontInvalidateCachedRendersWhenRangeChanges = ... # type: QgsTemporalProperty.Flag

    def __init__(self, parent: QtCore.QObject|None = ..., enabled: bool = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def flags(self) -> 'QgsTemporalProperty.Flag': ...
    def isActive(self) -> bool: ...
    def setIsActive(self, active: bool) -> None: ...


class QgsMapLayerTemporalProperties(QgsTemporalProperty):

    def __init__(self, parent: QtCore.QObject|None, enabled: bool = ...) -> None: ...

    def allTemporalRanges(self, layer: QgsMapLayer|None) -> list['QgsDateTimeRange']: ...
    def setDefaultsFromDataProviderTemporalCapabilities(self, capabilities: QgsDataProviderTemporalCapabilities|None) -> None: ...
    def isVisibleInTemporalRange(self, range: 'QgsDateTimeRange') -> bool: ...
    def readXml(self, element: QtXml.QDomElement, context: 'QgsReadWriteContext') -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: 'QgsReadWriteContext') -> QtXml.QDomElement: ...


class QgsMapLayerUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerUtils') -> None: ...

    @staticmethod
    def layerTypeToString(type: Qgis.LayerType) -> str: ...
    @staticmethod
    def isOpenStreetMapLayer(layer: QgsMapLayer|None) -> bool: ...
    @staticmethod
    def launderLayerName(name: str|None) -> str: ...
    @staticmethod
    def sortLayersByType(layers: collections.abc.Iterable[QgsMapLayer], order: collections.abc.Iterable[Qgis.LayerType]) -> list[QgsMapLayer]: ...
    @staticmethod
    def updateLayerSourcePath(layer: QgsMapLayer|None, newPath: str|None) -> bool: ...
    @staticmethod
    def layerRefersToUri(layer: QgsMapLayer|None, uri: str|None, level: Qgis.SourceHierarchyLevel = ...) -> bool: ...
    @staticmethod
    def layerSourceMatchesPath(layer: QgsMapLayer|None, path: str|None) -> bool: ...
    @staticmethod
    def databaseConnection(layer: QgsMapLayer|None) -> 'QgsAbstractDatabaseProviderConnection|None': ...
    @staticmethod
    def combinedExtent(layers: collections.abc.Iterable[QgsMapLayer], crs: 'QgsCoordinateReferenceSystem', transformContext: 'QgsCoordinateTransformContext') -> 'QgsRectangle': ...


class QgsLabelBlockingRegion(PyQt6.sip.wrapper):

    geometry = ... # type: 'QgsGeometry'

    @typing.overload
    def __init__(self, geometry: 'QgsGeometry') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelBlockingRegion') -> None: ...


class QgsTemporalRangeObject(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, enabled: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTemporalRangeObject') -> None: ...

    def temporalRange(self) -> 'QgsDateTimeRange': ...
    def setTemporalRange(self, range: 'QgsDateTimeRange') -> None: ...
    def isTemporal(self) -> bool: ...
    def setIsTemporal(self, enabled: bool) -> None: ...


class QgsMapSettings(QgsTemporalRangeObject):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapSettings') -> None: ...

    def updateDerived(self) -> None: ...
    def setSelectiveMaskingSourceSets(self, sets: collections.abc.Iterable['QgsSelectiveMaskingSourceSet']) -> None: ...
    def selectiveMaskingSourceSets(self) -> dict[str, 'QgsSelectiveMaskingSourceSet']: ...
    def setRasterizedRenderingPolicy(self, policy: Qgis.RasterizedRenderingPolicy) -> None: ...
    def rasterizedRenderingPolicy(self) -> Qgis.RasterizedRenderingPolicy: ...
    def setElevationShadingRenderer(self, renderer: QgsElevationShadingRenderer) -> None: ...
    def elevationShadingRenderer(self) -> QgsElevationShadingRenderer: ...
    def setCurrentFrame(self, frame: int) -> None: ...
    def currentFrame(self) -> int: ...
    def setFrameRate(self, rate: float) -> None: ...
    def frameRate(self) -> float: ...
    def setRendererUsage(self, rendererUsage: Qgis.RendererUsage) -> None: ...
    def rendererUsage(self) -> Qgis.RendererUsage: ...
    def setZRange(self, range: 'QgsDoubleRange') -> None: ...
    def zRange(self) -> 'QgsDoubleRange': ...
    def renderedFeatureHandlers(self) -> list['QgsRenderedFeatureHandlerInterface']: ...
    def addRenderedFeatureHandler(self, handler: 'QgsRenderedFeatureHandlerInterface|None') -> None: ...
    def setMaskSettings(self, settings: 'QgsMaskRenderSettings') -> None: ...
    def maskSettings(self) -> 'QgsMaskRenderSettings': ...
    def simplifyMethod(self) -> 'QgsVectorSimplifyMethod': ...
    def setSimplifyMethod(self, method: 'QgsVectorSimplifyMethod') -> None: ...
    def clippingRegions(self) -> list[QgsMapClippingRegion]: ...
    def setClippingRegions(self, regions: collections.abc.Iterable[QgsMapClippingRegion]) -> None: ...
    def addClippingRegion(self, region: QgsMapClippingRegion) -> None: ...
    def labelBlockingRegions(self) -> list[QgsLabelBlockingRegion]: ...
    def setLabelBlockingRegions(self, regions: collections.abc.Iterable[QgsLabelBlockingRegion]) -> None: ...
    def setLabelBoundaryGeometry(self, boundary: 'QgsGeometry') -> None: ...
    def labelBoundaryGeometry(self) -> 'QgsGeometry': ...
    def labelingEngineSettings(self) -> 'QgsLabelingEngineSettings': ...
    def setLabelingEngineSettings(self, settings: 'QgsLabelingEngineSettings') -> None: ...
    def segmentationToleranceType(self) -> 'QgsAbstractGeometry.SegmentationToleranceType': ...
    def setSegmentationToleranceType(self, type: 'QgsAbstractGeometry.SegmentationToleranceType') -> None: ...
    def segmentationTolerance(self) -> float: ...
    def setSegmentationTolerance(self, tolerance: float) -> None: ...
    def writeXml(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    def readXml(self, node: QtXml.QDomNode) -> None: ...
    def fullExtent(self) -> 'QgsRectangle': ...
    def computeScaleForExtent(self, extent: 'QgsRectangle') -> float: ...
    def computeExtentForScale(self, center: 'QgsPointXY', scale: float) -> 'QgsRectangle': ...
    def layerTransform(self, layer: QgsMapLayer|None) -> 'QgsCoordinateTransform': ...
    @typing.overload
    def mapToLayerCoordinates(self, layer: QgsMapLayer|None, point: 'QgsPointXY') -> 'QgsPointXY': ...
    @typing.overload
    def mapToLayerCoordinates(self, layer: QgsMapLayer|None, point: 'QgsPoint') -> 'QgsPoint': ...
    @typing.overload
    def mapToLayerCoordinates(self, layer: QgsMapLayer|None, rect: 'QgsRectangle') -> 'QgsRectangle': ...
    @typing.overload
    def layerToMapCoordinates(self, layer: QgsMapLayer|None, point: 'QgsPointXY') -> 'QgsPointXY': ...
    @typing.overload
    def layerToMapCoordinates(self, layer: QgsMapLayer|None, point: 'QgsPoint') -> 'QgsPoint': ...
    @typing.overload
    def layerToMapCoordinates(self, layer: QgsMapLayer|None, rect: 'QgsRectangle') -> 'QgsRectangle': ...
    def outputExtentToLayerExtent(self, layer: QgsMapLayer|None, extent: 'QgsRectangle') -> 'QgsRectangle': ...
    def layerExtentToOutputExtent(self, layer: QgsMapLayer|None, extent: 'QgsRectangle') -> 'QgsRectangle': ...
    def layerToMapUnits(self, layer: QgsMapLayer|None, referenceExtent: 'QgsRectangle' = ...) -> float: ...
    def mapToPixel(self) -> 'QgsMapToPixel': ...
    def setPathResolver(self, resolver: 'QgsPathResolver') -> None: ...
    def pathResolver(self) -> 'QgsPathResolver': ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def expressionContext(self) -> QgsExpressionContext: ...
    def setExpressionContext(self, context: QgsExpressionContext) -> None: ...
    def scale(self) -> float: ...
    def mapUnitsPerPixel(self) -> float: ...
    def visiblePolygonWithBuffer(self) -> QtGui.QPolygonF: ...
    def visiblePolygon(self) -> QtGui.QPolygonF: ...
    def visibleExtent(self) -> 'QgsRectangle': ...
    def hasValidSettings(self) -> bool: ...
    def outputImageFormat(self) -> QtGui.QImage.Format: ...
    def setOutputImageFormat(self, format: QtGui.QImage.Format) -> None: ...
    def setTextRenderFormat(self, format: Qgis.TextRenderFormat) -> None: ...
    def textRenderFormat(self) -> Qgis.TextRenderFormat: ...
    def testFlag(self, flag: Qgis.MapSettingsFlag) -> bool: ...
    def flags(self) -> Qgis.MapSettingsFlag: ...
    def setFlag(self, flag: Qgis.MapSettingsFlag, on: bool = ...) -> None: ...
    def setFlags(self, flags: Qgis.MapSettingsFlag) -> None: ...
    def selectionColor(self) -> QtGui.QColor: ...
    def setSelectionColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def backgroundColor(self) -> QtGui.QColor: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def ellipsoid(self) -> str: ...
    def setEllipsoid(self, ellipsoid: str|None) -> bool: ...
    def setScaleMethod(self, method: Qgis.ScaleCalculationMethod) -> None: ...
    def scaleMethod(self) -> Qgis.ScaleCalculationMethod: ...
    def mapUnits(self) -> Qgis.DistanceUnit: ...
    def destinationCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setDestinationCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def clearCustomRenderingFlag(self, flag: str|None) -> None: ...
    def setCustomRenderingFlag(self, flag: str|None, value: typing.Any) -> None: ...
    def customRenderingFlags(self) -> dict[str, typing.Any]: ...
    def setCustomRenderFlags(self, customRenderFlags: str|None) -> None: ...
    def customRenderFlags(self) -> str: ...
    def setLayerStyleOverrides(self, overrides: dict[str|None, str|None]) -> None: ...
    def layerStyleOverrides(self) -> dict[str, str]: ...
    def setLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def layers(self, expandGroupLayers: bool = ...) -> list[QgsMapLayer]: ...
    def layerIds(self, expandGroupLayers: bool = ...) -> list[str]: ...
    def magnificationFactor(self) -> float: ...
    def setMagnificationFactor(self, factor: float, center: 'QgsPointXY|None' = ...) -> None: ...
    def setDpiTarget(self, dpi: float) -> None: ...
    def dpiTarget(self) -> float: ...
    def setOutputDpi(self, dpi: float) -> None: ...
    def outputDpi(self) -> float: ...
    def setRotation(self, rotation: float) -> None: ...
    def rotation(self) -> float: ...
    def deviceOutputSize(self) -> QtCore.QSize: ...
    def setDevicePixelRatio(self, dpr: float) -> None: ...
    def devicePixelRatio(self) -> float: ...
    def setOutputSize(self, size: QtCore.QSize) -> None: ...
    def outputSize(self) -> QtCore.QSize: ...
    def setExtentBuffer(self, buffer: float) -> None: ...
    def extentBuffer(self) -> float: ...
    def setExtent(self, rect: 'QgsRectangle', magnified: bool = ...) -> None: ...
    def extent(self) -> 'QgsRectangle': ...


class QgsMapSettingsUtils(PyQt6.sip.wrapper):

    class EffectsCheckFlag(enum.IntFlag):
        IgnoreGeoPdfSupportedEffects = ... # type: QgsMapSettingsUtils.EffectsCheckFlag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapSettingsUtils') -> None: ...

    @staticmethod
    def isValidExtent(extent: 'QgsRectangle') -> bool: ...
    @staticmethod
    def worldFileContent(mapSettings: QgsMapSettings) -> str: ...
    @staticmethod
    def worldFileParameters(mapSettings: QgsMapSettings) -> typing.Tuple[float, float, float, float, float, float]: ...
    @staticmethod
    def containsAdvancedEffects(mapSettings: QgsMapSettings, flags: 'QgsMapSettingsUtils.EffectsCheckFlag' = ...) -> list[str]: ...


class QgsMapThemeCollection(QtCore.QObject):

    class MapThemeLayerRecord(PyQt6.sip.wrapper):

        checkedLegendItems = ... # type: collections.abc.Iterable[str|None]
        currentStyle = ... # type: str|None
        expandedLayerNode = ... # type: bool
        expandedLegendItems = ... # type: collections.abc.Iterable[str|None]
        isVisible = ... # type: bool
        usingCurrentStyle = ... # type: bool
        usingLegendItems = ... # type: bool

        @typing.overload
        def __init__(self, l: QgsMapLayer|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMapThemeCollection.MapThemeLayerRecord') -> None: ...

        def setLayer(self, layer: QgsMapLayer|None) -> None: ...
        def layer(self) -> QgsMapLayer|None: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    class MapThemeRecord(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMapThemeCollection.MapThemeRecord') -> None: ...

        def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> None: ...
        @staticmethod
        def readXml(element: QtXml.QDomElement, project: 'QgsProject|None') -> 'QgsMapThemeCollection.MapThemeRecord': ...
        def setCheckedGroupNodes(self, checkedGroupNodes: collections.abc.Iterable[str|None]) -> None: ...
        def setExpandedGroupNodes(self, expandedGroupNodes: collections.abc.Iterable[str|None]) -> None: ...
        def checkedGroupNodes(self) -> set[str]: ...
        def expandedGroupNodes(self) -> set[str]: ...
        def setHasCheckedStateInfo(self, hasInfo: bool) -> None: ...
        def setHasExpandedStateInfo(self, hasInfo: bool) -> None: ...
        def hasCheckedStateInfo(self) -> bool: ...
        def hasExpandedStateInfo(self) -> bool: ...
        def addLayerRecord(self, record: 'QgsMapThemeCollection.MapThemeLayerRecord') -> None: ...
        def removeLayerRecord(self, layer: QgsMapLayer|None) -> None: ...
        def setLayerRecords(self, records: collections.abc.Iterable['QgsMapThemeCollection.MapThemeLayerRecord']) -> None: ...
        def layerRecords(self) -> list['QgsMapThemeCollection.MapThemeLayerRecord']: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...

    projectChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapThemeRenamed: typing.ClassVar[QtCore.pyqtSignal]
    mapThemeChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapThemesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def masterVisibleLayers(self) -> list[QgsMapLayer]: ...
    def masterLayerOrder(self) -> list[QgsMapLayer]: ...
    def setProject(self, project: 'QgsProject|None') -> None: ...
    def project(self) -> 'QgsProject|None': ...
    def applyTheme(self, name: str|None, root: 'QgsLayerTreeGroup|None', model: 'QgsLayerTreeModel|None') -> None: ...
    @staticmethod
    def createThemeFromCurrentState(root: 'QgsLayerTreeGroup|None', model: 'QgsLayerTreeModel|None') -> 'QgsMapThemeCollection.MapThemeRecord': ...
    def writeXml(self, doc: QtXml.QDomDocument) -> None: ...
    def readXml(self, doc: QtXml.QDomDocument) -> None: ...
    def mapThemeStyleOverrides(self, name: str|None) -> dict[str, str]: ...
    def mapThemeVisibleLayers(self, name: str|None) -> list[QgsMapLayer]: ...
    def mapThemeVisibleLayerIds(self, name: str|None) -> list[str]: ...
    def mapThemeState(self, name: str|None) -> 'QgsMapThemeCollection.MapThemeRecord': ...
    def mapThemes(self) -> list[str]: ...
    def clear(self) -> None: ...
    def renameMapTheme(self, name: str|None, newName: str|None) -> bool: ...
    def removeMapTheme(self, name: str|None) -> None: ...
    def update(self, name: str|None, state: 'QgsMapThemeCollection.MapThemeRecord') -> None: ...
    def insert(self, name: str|None, state: 'QgsMapThemeCollection.MapThemeRecord') -> None: ...
    def hasMapTheme(self, name: str|None) -> bool: ...


class QgsMapToPixel(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, mapUnitsPerPixel: float, centerX: float, centerY: float, widthPixels: int, heightPixels: int, rotation: float) -> None: ...
    @typing.overload
    def __init__(self, mapUnitsPerPixel: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapToPixel') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def yCenter(self) -> float: ...
    def xCenter(self) -> float: ...
    def showParameters(self) -> str: ...
    def setParameters(self, mapUnitsPerPixel: float, centerX: float, centerY: float, widthPixels: int, heightPixels: int, rotation: float) -> None: ...
    def mapRotation(self) -> float: ...
    def setMapRotation(self, degrees: float, cx: float, cy: float) -> None: ...
    def mapHeight(self) -> int: ...
    def mapWidth(self) -> int: ...
    def mapUnitsPerPixel(self) -> float: ...
    def setMapUnitsPerPixel(self, mapUnitsPerPixel: float) -> None: ...
    @deprecated("""""")
    def toMapPoint(self, x: float, y: float) -> 'QgsPointXY': ...
    def toMapCoordinatesF(self, x: float, y: float) -> 'QgsPointXY': ...
    @typing.overload
    def toMapCoordinates(self, x: int, y: int) -> 'QgsPointXY': ...
    @typing.overload
    def toMapCoordinates(self, p: QtCore.QPoint) -> 'QgsPointXY': ...
    def transformBounds(self, bounds: QtCore.QRectF) -> QtCore.QRectF: ...
    def transformInPlace(self) -> typing.Tuple[float, float]: ...
    @typing.overload
    def transform(self, p: 'QgsPointXY') -> 'QgsPointXY': ...
    @typing.overload
    def transform(self, p: 'QgsPointXY|None') -> None: ...
    @typing.overload
    def transform(self, x: float, y: float) -> 'QgsPointXY': ...
    @typing.overload
    def transform(self) -> QtGui.QTransform: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def fromScale(scale: float, mapUnits: Qgis.DistanceUnit, dpi: float = ...) -> 'QgsMapToPixel': ...


class QgsMapToPixelSimplifier(QgsAbstractGeometrySimplifier):

    class SimplifyFlag(enum.IntEnum):
        NoFlags = ... # type: QgsMapToPixelSimplifier.SimplifyFlag
        SimplifyGeometry = ... # type: QgsMapToPixelSimplifier.SimplifyFlag
        SimplifyEnvelope = ... # type: QgsMapToPixelSimplifier.SimplifyFlag

    @typing.overload
    def __init__(self, simplifyFlags: int, tolerance: float, simplifyAlgorithm: Qgis.VectorSimplificationAlgorithm = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapToPixelSimplifier') -> None: ...

    @typing.overload
    @staticmethod
    def isGeneralizableByMapBoundingBox(envelope: 'QgsRectangle', map2pixelTol: float) -> bool: ...
    @typing.overload
    def isGeneralizableByMapBoundingBox(self, envelope: 'QgsRectangle') -> bool: ...
    def setTolerance(self, value: float) -> None: ...
    @typing.overload
    def simplify(self, geometry: 'QgsGeometry') -> 'QgsGeometry': ...
    @typing.overload
    def simplify(self, geometry: 'QgsAbstractGeometry|None') -> 'QgsAbstractGeometry|None': ...
    def setSimplifyAlgorithm(self, simplifyAlgorithm: Qgis.VectorSimplificationAlgorithm) -> None: ...
    def simplifyAlgorithm(self) -> Qgis.VectorSimplificationAlgorithm: ...
    def setSimplifyFlags(self, simplifyFlags: int) -> None: ...
    def simplifyFlags(self) -> int: ...
    @staticmethod
    def equalSnapToGrid(x1: float, y1: float, x2: float, y2: float, gridOriginX: float, gridOriginY: float, gridInverseSizeXY: float) -> bool: ...
    @staticmethod
    def calculateLengthSquared2D(x1: float, y1: float, x2: float, y2: float) -> float: ...


class QgsMapUnitScale(PyQt6.sip.wrapper):

    maxScale = ... # type: float
    maxSizeMM = ... # type: float
    maxSizeMMEnabled = ... # type: bool
    minScale = ... # type: float
    minSizeMM = ... # type: float
    minSizeMMEnabled = ... # type: bool

    @typing.overload
    def __init__(self, minScale: float = ..., maxScale: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapUnitScale') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def computeMapUnitsPerPixel(self, c: 'QgsRenderContext') -> float: ...
    def isNull(self) -> bool: ...


class QgsMargins(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, left: float, top: float, right: float, bottom: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMargins') -> None: ...

    def __eq__(self, other: object): ...
    def __ne__(self, other: object): ...
    @typing.overload
    def __add__(self, m2: 'QgsMargins') -> 'QgsMargins': ...
    @typing.overload
    def __add__(self, rhs: float) -> 'QgsMargins': ...
    def __radd__(self, lhs: float) -> 'QgsMargins': ...
    @typing.overload
    def __sub__(self, m2: 'QgsMargins') -> 'QgsMargins': ...
    @typing.overload
    def __sub__(self, rhs: float) -> 'QgsMargins': ...
    def __mul__(self, factor: float) -> 'QgsMargins': ...
    def __rmul__(self, factor: float) -> 'QgsMargins': ...
    def __truediv__(self, divisor: float) -> 'QgsMargins': ...
    def __pos__(self) -> 'QgsMargins': ...
    def __neg__(self) -> 'QgsMargins': ...
    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def fromString(string: str|None) -> 'QgsMargins': ...
    def toString(self) -> str: ...
    def __itruediv__(self, divisor: float) -> 'QgsMargins': ...
    def __imul__(self, factor: float) -> 'QgsMargins': ...
    @typing.overload
    def __isub__(self, margins: 'QgsMargins') -> 'QgsMargins': ...
    @typing.overload
    def __isub__(self, subtrahend: float) -> 'QgsMargins': ...
    @typing.overload
    def __iadd__(self, margins: 'QgsMargins') -> 'QgsMargins': ...
    @typing.overload
    def __iadd__(self, addend: float) -> 'QgsMargins': ...
    def setBottom(self, bottom: float) -> None: ...
    def setRight(self, right: float) -> None: ...
    def setTop(self, top: float) -> None: ...
    def setLeft(self, left: float) -> None: ...
    def bottom(self) -> float: ...
    def right(self) -> float: ...
    def top(self) -> float: ...
    def left(self) -> float: ...
    def isNull(self) -> bool: ...


class QgsMaskIdProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMaskIdProvider') -> None: ...

    def size(self) -> int: ...
    def maskId(self, labelLayerId: str|None = ..., labelRuleId: str|None = ...) -> int: ...
    def insertLabelLayer(self, layerId: str|None, ruleId: str|None, maskedSymbolLayers: collections.abc.Iterable['QgsSymbolLayerReference']) -> int: ...


class QgsMaskRenderSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMaskRenderSettings') -> None: ...

    def setSimplificationTolerance(self, tolerance: float) -> None: ...
    def simplifyTolerance(self) -> float: ...


class QgsMathUtils(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMathUtils') -> None: ...

    @staticmethod
    def doubleToRational(value: float, tolerance: float = ..., maxIterations: int = ...) -> typing.Tuple[int, int]: ...


class QgsMatrix4x4(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, m11: float, m12: float, m13: float, m14: float, m21: float, m22: float, m23: float, m24: float, m31: float, m32: float, m33: float, m34: float, m41: float, m42: float, m43: float, m44: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMatrix4x4') -> None: ...

    @typing.overload
    def __mul__(self, vector: 'QgsVector3D') -> 'QgsVector3D': ...
    @typing.overload
    def __mul__(self, m2: 'QgsMatrix4x4') -> 'QgsMatrix4x4': ...
    def __repr__(self) -> typing.Any: ...
    def setToIdentity(self) -> None: ...
    def isIdentity(self) -> bool: ...
    def map(self, vector: 'QgsVector3D') -> 'QgsVector3D': ...
    def translate(self, vector: 'QgsVector3D') -> None: ...
    def data(self) -> list[float]: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsMeasureUtils(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeasureUtils') -> None: ...

    @staticmethod
    def formatDistanceForProject(project: 'QgsProject|None', distance: float, unit: Qgis.DistanceUnit) -> str: ...
    @staticmethod
    def formatAreaForProject(project: 'QgsProject|None', area: float, unit: Qgis.AreaUnit) -> str: ...


class QgsMessageLog(QtCore.QObject):

    def __init__(self) -> None: ...

    messageReceivedWithFormat: typing.ClassVar[QtCore.pyqtSignal]
    messageReceived: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def logMessage(message: str|None, tag: str|None = ..., level: Qgis.MessageLevel = ..., notifyUser: bool = ..., file: str = ..., function: str = ..., line: int = ..., format: Qgis.StringFormat = ...) -> None: ...


class QgsMessageLogNotifyBlocker(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...


class QgsMessageLogConsole(QtCore.QObject):

    def __init__(self) -> None: ...

    @typing.overload
    def logMessage(self, message: str|None, tag: str|None, level: Qgis.MessageLevel) -> None: ...
    @typing.overload
    def logMessage(self, message: str|None, tag: str|None, level: Qgis.MessageLevel, format: Qgis.StringFormat) -> None: ...
    def formatLogMessage(self, message: str|None, tag: str|None, level: Qgis.MessageLevel = ...) -> str: ...


class QgsMessageOutput(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMessageOutput') -> None: ...

    @staticmethod
    def createMessageOutput() -> 'QgsMessageOutput|None': ...
    @typing.overload
    def showMessage(self, blocking: bool = ...) -> None: ...
    @typing.overload
    @staticmethod
    def showMessage(title: str|None, message: str|None, format: Qgis.StringFormat) -> None: ...
    def setTitle(self, title: str|None) -> None: ...
    def appendMessage(self, message: str|None) -> None: ...
    def setMessage(self, message: str|None, format: Qgis.StringFormat) -> None: ...


class QgsMessageOutputConsole(QtCore.QObject, QgsMessageOutput):

    def __init__(self) -> None: ...

    destroyed: typing.ClassVar[QtCore.pyqtSignal]
    def showMessage(self, blocking: bool = ...) -> None: ...
    def setTitle(self, title: str|None) -> None: ...
    def appendMessage(self, message: str|None) -> None: ...
    def setMessage(self, message: str|None, format: Qgis.StringFormat) -> None: ...


class QgsMimeDataUtils(PyQt6.sip.wrapper):

    class Uri(PyQt6.sip.wrapper):

        filePath = ... # type: str|None
        layerId = ... # type: str|None
        layerType = ... # type: str|None
        name = ... # type: str|None
        pId = ... # type: str|None
        providerKey = ... # type: str|None
        supportedCrs = ... # type: collections.abc.Iterable[str|None]
        supportedFormats = ... # type: collections.abc.Iterable[str|None]
        uri = ... # type: str|None
        wkbType = ... # type: Qgis.WkbType

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, encData: str|None) -> None: ...
        @typing.overload
        def __init__(self, layer: QgsMapLayer|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMimeDataUtils.Uri') -> None: ...

        def __repr__(self) -> typing.Any: ...
        def mapLayer(self) -> QgsMapLayer|None: ...
        def meshLayer(self, error: str|None) -> typing.Tuple['QgsMeshLayer|None', bool]: ...
        def rasterLayer(self, error: str|None) -> typing.Tuple['QgsRasterLayer|None', bool]: ...
        def vectorLayer(self, error: str|None) -> typing.Tuple[QgsVectorLayer|None, bool]: ...
        def data(self) -> str: ...
        def isValid(self) -> bool: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMimeDataUtils') -> None: ...

    @staticmethod
    def hasOriginatedFromCurrentAppInstance(uri: 'QgsMimeDataUtils.Uri') -> bool: ...
    @staticmethod
    def layerTreeNodesToUriList(nodes: collections.abc.Iterable['QgsLayerTreeNode']) -> QtCore.QByteArray: ...
    @staticmethod
    def decodeUriList(data: QtCore.QMimeData|None) -> list['QgsMimeDataUtils.Uri']: ...
    @staticmethod
    def isUriList(data: QtCore.QMimeData|None) -> bool: ...
    @staticmethod
    def encodeUriList(layers: collections.abc.Iterable['QgsMimeDataUtils.Uri']) -> QtCore.QMimeData|None: ...


class QgsMultiRenderChecker(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMultiRenderChecker') -> None: ...

    @staticmethod
    def drawBackground(image: QtGui.QImage|None) -> None: ...
    def controlImagePath(self) -> str: ...
    def markdownReport(self) -> str: ...
    def report(self) -> str: ...
    def runTest(self, testName: str|None, mismatchCount: int = ...) -> bool: ...
    def setSizeTolerance(self, xTolerance: int, yTolerance: int) -> None: ...
    def setColorTolerance(self, colorTolerance: int) -> None: ...
    def setMapSettings(self, mapSettings: QgsMapSettings) -> None: ...
    def setExpectFail(self, expectFail: bool) -> None: ...
    def setRenderedImage(self, renderedImagePath: str|None) -> None: ...
    def setControlPathPrefix(self, prefix: str|None) -> None: ...
    def setFileFunctionLine(self, file: str|None, function: str|None, line: int) -> None: ...
    def setControlName(self, name: str|None) -> None: ...


class QgsLayoutChecker(QgsMultiRenderChecker):

    @typing.overload
    def __init__(self, testName: str|None, layout: 'QgsLayout|None') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutChecker') -> None: ...

    def testLayout(self, page: int = ..., pixelDiff: int = ..., createReferenceImage: bool = ...) -> typing.Tuple[bool, str]: ...
    def setSize(self, size: QtCore.QSize) -> None: ...


class QgsObjectCustomProperties(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsObjectCustomProperties') -> None: ...

    def writeXml(self, parentNode: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    def readXml(self, parentNode: QtXml.QDomNode, keyStartsWith: str|None = ...) -> None: ...
    def contains(self, key: str|None) -> bool: ...
    def remove(self, key: str|None) -> None: ...
    def value(self, key: str|None, defaultValue: typing.Any = ...) -> typing.Any: ...
    def setValue(self, key: str|None, value: typing.Any) -> None: ...
    def keys(self) -> list[str]: ...


class QgsEmbeddedScriptEntity(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: Qgis.EmbeddedScriptType, name: str|None, script: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEmbeddedScriptEntity') -> None: ...

    def script(self) -> str: ...
    def name(self) -> str: ...
    def type(self) -> Qgis.EmbeddedScriptType: ...


class QgsObjectVisitorContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsObjectVisitorContext') -> None: ...


class QgsObjectEntityVisitorInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsObjectEntityVisitorInterface') -> None: ...

    def visitEmbeddedScript(self, entity: QgsEmbeddedScriptEntity, context: QgsObjectVisitorContext) -> bool: ...


class QgsEmbeddedScriptVisitor(QgsObjectEntityVisitorInterface):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEmbeddedScriptVisitor') -> None: ...

    def embeddedScripts(self) -> list[QgsEmbeddedScriptEntity]: ...
    def visitEmbeddedScript(self, entity: QgsEmbeddedScriptEntity, a1: QgsObjectVisitorContext) -> bool: ...


class QgsOfflineEditing(QtCore.QObject):

    class ContainerType(enum.IntEnum):
        SpatiaLite = ... # type: QgsOfflineEditing.ContainerType
        GPKG = ... # type: QgsOfflineEditing.ContainerType

    class ProgressMode(enum.IntEnum):
        CopyFeatures = ... # type: QgsOfflineEditing.ProgressMode
        ProcessFeatures = ... # type: QgsOfflineEditing.ProgressMode
        AddFields = ... # type: QgsOfflineEditing.ProgressMode
        AddFeatures = ... # type: QgsOfflineEditing.ProgressMode
        RemoveFeatures = ... # type: QgsOfflineEditing.ProgressMode
        UpdateFeatures = ... # type: QgsOfflineEditing.ProgressMode
        UpdateGeometries = ... # type: QgsOfflineEditing.ProgressMode

    def __init__(self) -> None: ...

    warning: typing.ClassVar[QtCore.pyqtSignal]
    progressStopped: typing.ClassVar[QtCore.pyqtSignal]
    progressUpdated: typing.ClassVar[QtCore.pyqtSignal]
    progressModeSet: typing.ClassVar[QtCore.pyqtSignal]
    layerProgressUpdated: typing.ClassVar[QtCore.pyqtSignal]
    progressStarted: typing.ClassVar[QtCore.pyqtSignal]
    def synchronize(self, useTransaction: bool = ...) -> None: ...
    def isOfflineProject(self) -> bool: ...
    def convertToOfflineProject(self, offlineDataPath: str|None, offlineDbFile: str|None, layerIds: collections.abc.Iterable[str|None], onlySelected: bool = ..., containerType: 'QgsOfflineEditing.ContainerType' = ..., layerNameSuffix: str|None = ...) -> bool: ...


class QgsOgcUtils(PyQt6.sip.wrapper):

    class FilterVersion(enum.IntEnum):
        FILTER_OGC_1_0 = ... # type: QgsOgcUtils.FilterVersion
        FILTER_OGC_1_1 = ... # type: QgsOgcUtils.FilterVersion
        FILTER_FES_2_0 = ... # type: QgsOgcUtils.FilterVersion

    class GMLVersion(enum.IntEnum):
        GML_2_1_2 = ... # type: QgsOgcUtils.GMLVersion
        GML_3_1_0 = ... # type: QgsOgcUtils.GMLVersion
        GML_3_2_1 = ... # type: QgsOgcUtils.GMLVersion

    class Context(PyQt6.sip.wrapper):

        layer = ... # type: QgsMapLayer
        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, layer: QgsMapLayer|None = ..., transformContext: 'QgsCoordinateTransformContext' = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsOgcUtils.Context') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOgcUtils') -> None: ...

    @staticmethod
    def elseFilterExpression(doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def expressionToOgcExpression(exp: 'QgsExpression', doc: QtXml.QDomDocument, errorMessage: str|None = ..., requiresFilterElement: bool = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def expressionToOgcExpression(exp: 'QgsExpression', doc: QtXml.QDomDocument, gmlVersion: 'QgsOgcUtils.GMLVersion', filterVersion: 'QgsOgcUtils.FilterVersion', geometryName: str|None, srsName: str|None, honourAxisOrientation: bool, invertAxisOrientation: bool, errorMessage: str|None = ..., requiresFilterElement: bool = ..., fieldNameToXPathMap: dict[str|None, str|None] = ..., namespacePrefixToUriMap: dict[str|None, str|None] = ...) -> QtXml.QDomElement: ...
    @staticmethod
    def expressionToOgcFilter(exp: 'QgsExpression', doc: QtXml.QDomDocument, errorMessage: str|None = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def expressionFromOgcFilter(element: QtXml.QDomElement, layer: QgsVectorLayer|None = ...) -> 'QgsExpression|None': ...
    @typing.overload
    @staticmethod
    def expressionFromOgcFilter(element: QtXml.QDomElement, version: 'QgsOgcUtils.FilterVersion', layer: QgsVectorLayer|None = ...) -> 'QgsExpression|None': ...
    @staticmethod
    def colorFromOgcFill(fillElement: QtXml.QDomElement) -> QtGui.QColor: ...
    @typing.overload
    @staticmethod
    def rectangleToGMLEnvelope(env: 'QgsRectangle|None', doc: QtXml.QDomDocument, precision: int = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def rectangleToGMLEnvelope(env: 'QgsRectangle|None', doc: QtXml.QDomDocument, srsName: str|None, invertAxisOrientation: bool, precision: int = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def rectangleToGMLBox(box: 'QgsRectangle|None', doc: QtXml.QDomDocument, precision: int = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def rectangleToGMLBox(box: 'QgsRectangle|None', doc: QtXml.QDomDocument, srsName: str|None, invertAxisOrientation: bool, precision: int = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def geometryToGML(geometry: 'QgsGeometry', doc: QtXml.QDomDocument, gmlVersion: 'QgsOgcUtils.GMLVersion', srsName: str|None, invertAxisOrientation: bool, gmlIdBase: str|None, precision: int = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def geometryToGML(geometry: 'QgsGeometry', doc: QtXml.QDomDocument, format: str|None, precision: int = ...) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def geometryToGML(geometry: 'QgsGeometry', doc: QtXml.QDomDocument, precision: int = ...) -> QtXml.QDomElement: ...
    @staticmethod
    def rectangleFromGMLEnvelope(envelopeNode: QtXml.QDomNode) -> 'QgsRectangle': ...
    @staticmethod
    def rectangleFromGMLBox(boxNode: QtXml.QDomNode) -> 'QgsRectangle': ...
    @typing.overload
    @staticmethod
    def geometryFromGML(xmlString: str|None, context: 'QgsOgcUtils.Context' = ...) -> 'QgsGeometry': ...
    @typing.overload
    @staticmethod
    def geometryFromGML(geometryNode: QtXml.QDomNode, context: 'QgsOgcUtils.Context' = ...) -> 'QgsGeometry': ...


class QgsOptionalQgsExpressionBase(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, data: 'QgsExpression') -> None: ...
    @typing.overload
    def __init__(self, data: 'QgsExpression', enabled: bool) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionalQgsExpressionBase') -> None: ...

    def __ne__(self, other: object): ...
    def setData(self, data: 'QgsExpression') -> None: ...
    def data(self) -> 'QgsExpression': ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def __eq__(self, other: object): ...


class QgsOptionalExpression(QgsOptionalQgsExpressionBase):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, expression: 'QgsExpression') -> None: ...
    @typing.overload
    def __init__(self, expression: 'QgsExpression', enabled: bool) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionalExpression') -> None: ...

    def readXml(self, element: QtXml.QDomElement) -> None: ...
    def writeXml(self, element: QtXml.QDomElement) -> None: ...


class QgsOwsConnection(QtCore.QObject):

    def __init__(self, service: str|None, connName: str|None) -> None: ...

    @staticmethod
    def setSelectedConnection(service: str|None, name: str|None) -> None: ...
    @staticmethod
    def selectedConnection(service: str|None) -> str: ...
    @staticmethod
    def deleteConnection(service: str|None, name: str|None) -> None: ...
    @staticmethod
    def connectionList(service: str|None) -> list[str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def addWfsConnectionSettings(uri: QgsDataSourceUri, settingsKey: str|None) -> QgsDataSourceUri: ...
    @typing.overload
    @staticmethod
    def addWfsConnectionSettings(uri: QgsDataSourceUri, service: str|None, connName: str|None) -> QgsDataSourceUri: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def addWmsWcsConnectionSettings(uri: QgsDataSourceUri, settingsKey: str|None) -> QgsDataSourceUri: ...
    @typing.overload
    @staticmethod
    def addWmsWcsConnectionSettings(uri: QgsDataSourceUri, service: str|None, connName: str|None) -> QgsDataSourceUri: ...
    def uri(self) -> QgsDataSourceUri: ...
    def service(self) -> str: ...
    def connectionInfo(self) -> str: ...
    def connectionName(self) -> str: ...


class QgsPathResolver(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, baseFileName: str|None = ..., attachmentDir: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPathResolver') -> None: ...

    @staticmethod
    def removePathWriter(id: str|None) -> None: ...
    @staticmethod
    def setPathWriter(a0: typing.Callable[..., None]) -> str: ...
    @staticmethod
    def removePathPreprocessor(id: str|None) -> None: ...
    @staticmethod
    def setPathPreprocessor(a0: typing.Callable[..., None]) -> str: ...
    def readPath(self, filename: str|None) -> str: ...
    def writePath(self, filename: str|None) -> str: ...


class QgsPluginLayer(QgsMapLayer):

    def __init__(self, layerType: str|None, layerName: str|None = ...) -> None: ...

    def icon(self) -> QtGui.QIcon: ...
    def dataProvider(self) -> 'QgsDataProvider|None': ...
    def setSource(self, source: str|None) -> None: ...
    def setExtent(self, extent: 'QgsRectangle') -> None: ...
    def pluginLayerType(self) -> str: ...
    def clone(self) -> 'QgsPluginLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsPluginLayerType(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPluginLayerType') -> None: ...

    def showLayerProperties(self, layer: QgsPluginLayer|None) -> bool: ...
    @typing.overload
    def createLayer(self) -> QgsPluginLayer|None: ...
    @typing.overload
    def createLayer(self, uri: str|None) -> QgsPluginLayer|None: ...
    def name(self) -> str: ...


class QgsPluginLayerRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def createLayer(self, typeName: str|None, uri: str|None = ...) -> QgsPluginLayer|None: ...
    def pluginLayerType(self, typeName: str|None) -> QgsPluginLayerType|None: ...
    def removePluginLayerType(self, typeName: str|None) -> bool: ...
    def addPluginLayerType(self, pluginLayerType: QgsPluginLayerType|None) -> bool: ...
    def pluginLayerTypes(self) -> list[str]: ...


class QgsPointLocator(QtCore.QObject):

    class Type(enum.IntEnum):
        Invalid = ... # type: QgsPointLocator.Type
        Vertex = ... # type: QgsPointLocator.Type
        Edge = ... # type: QgsPointLocator.Type
        Area = ... # type: QgsPointLocator.Type
        Centroid = ... # type: QgsPointLocator.Type
        MiddleOfSegment = ... # type: QgsPointLocator.Type
        LineEndpoint = ... # type: QgsPointLocator.Type
        All = ... # type: QgsPointLocator.Type

    class Match(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, t: 'QgsPointLocator.Type', vl: QgsVectorLayer|None, fid: int, dist: float, pt: 'QgsPointXY', vertexIndex: int = ..., edgePoints: 'QgsPointXY|None' = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsPointLocator.Match') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def interpolatedPoint(self, destinationCrs: 'QgsCoordinateReferenceSystem' = ...) -> 'QgsPoint': ...
        def edgePoints(self) -> typing.Tuple['QgsPointXY', 'QgsPointXY']: ...
        def featureId(self) -> int: ...
        def layer(self) -> QgsVectorLayer|None: ...
        def vertexIndex(self) -> int: ...
        def point(self) -> 'QgsPointXY': ...
        def distance(self) -> float: ...
        def hasLineEndpoint(self) -> bool: ...
        def hasMiddleSegment(self) -> bool: ...
        def hasArea(self) -> bool: ...
        def hasCentroid(self) -> bool: ...
        def hasEdge(self) -> bool: ...
        def hasVertex(self) -> bool: ...
        def isValid(self) -> bool: ...
        def type(self) -> 'QgsPointLocator.Type': ...

    class MatchFilter(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsPointLocator.MatchFilter') -> None: ...

        def acceptMatch(self, match: 'QgsPointLocator.Match') -> bool: ...

    def __init__(self, layer: QgsVectorLayer|None, destinationCrs: 'QgsCoordinateReferenceSystem' = ..., transformContext: 'QgsCoordinateTransformContext' = ..., extent: 'QgsRectangle|None' = ...) -> None: ...

    def destroyIndex(self) -> None: ...
    def rebuildIndex(self, maxFeaturesToIndex: int = ...) -> bool: ...
    initFinished: typing.ClassVar[QtCore.pyqtSignal]
    def waitForIndexingFinished(self) -> None: ...
    def isIndexing(self) -> bool: ...
    def cachedGeometryCount(self) -> int: ...
    def pointInPolygon(self, point: 'QgsPointXY', relaxed: bool = ..., filter: 'QgsPointLocator.MatchFilter|None' = ...) -> list['QgsPointLocator.Match']: ...
    @typing.overload
    def verticesInRect(self, rect: 'QgsRectangle', filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> list['QgsPointLocator.Match']: ...
    @typing.overload
    def verticesInRect(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> list['QgsPointLocator.Match']: ...
    @typing.overload
    def edgesInRect(self, rect: 'QgsRectangle', filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> list['QgsPointLocator.Match']: ...
    @typing.overload
    def edgesInRect(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> list['QgsPointLocator.Match']: ...
    def nearestArea(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> 'QgsPointLocator.Match': ...
    def nearestEdge(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> 'QgsPointLocator.Match': ...
    def nearestLineEndpoints(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> 'QgsPointLocator.Match': ...
    def nearestMiddleOfSegment(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> 'QgsPointLocator.Match': ...
    def nearestCentroid(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> 'QgsPointLocator.Match': ...
    def nearestVertex(self, point: 'QgsPointXY', tolerance: float, filter: 'QgsPointLocator.MatchFilter|None' = ..., relaxed: bool = ...) -> 'QgsPointLocator.Match': ...
    def hasIndex(self) -> bool: ...
    def init(self, maxFeaturesToIndex: int = ..., relaxed: bool = ...) -> bool: ...
    def setRenderContext(self, context: 'QgsRenderContext|None') -> None: ...
    def setExtent(self, extent: 'QgsRectangle|None') -> None: ...
    def extent(self) -> 'QgsRectangle|None': ...
    def destinationCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def layer(self) -> QgsVectorLayer|None: ...


class QgsPointXY(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p: 'QgsPointXY') -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float) -> None: ...
    @typing.overload
    def __init__(self, point: QtCore.QPointF) -> None: ...
    @typing.overload
    def __init__(self, point: QtCore.QPoint) -> None: ...
    @typing.overload
    def __init__(self, point: 'QgsPoint') -> None: ...

    def __hash__(self) -> int: ...
    def __getitem__(self, a0: int) -> typing.Any: ...
    def __len__(self) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def __itruediv__(self, scalar: float) -> 'QgsPointXY': ...
    def __imul__(self, scalar: float) -> 'QgsPointXY': ...
    def __truediv__(self, scalar: float) -> 'QgsPointXY': ...
    def __mul__(self, scalar: float) -> 'QgsPointXY': ...
    def __add__(self, v: 'QgsVector') -> 'QgsPointXY': ...
    def __isub__(self, v: 'QgsVector') -> 'QgsPointXY': ...
    def __iadd__(self, v: 'QgsVector') -> 'QgsPointXY': ...
    @typing.overload
    def __sub__(self, p: 'QgsPointXY') -> 'QgsVector': ...
    @typing.overload
    def __sub__(self, v: 'QgsVector') -> 'QgsPointXY': ...
    def multiply(self, scalar: float) -> None: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def distanceCompare(self, other: 'QgsPointXY', epsilon: float = ...) -> bool: ...
    def compare(self, other: 'QgsPointXY', epsilon: float = ...) -> bool: ...
    def isEmpty(self) -> bool: ...
    def project(self, distance: float, bearing: float) -> 'QgsPointXY': ...
    def azimuth(self, other: 'QgsPointXY') -> float: ...
    def sqrDistToSegment(self, x1: float, y1: float, x2: float, y2: float, epsilon: float = ...) -> typing.Tuple[float, 'QgsPointXY']: ...
    @typing.overload
    def distance(self, x: float, y: float) -> float: ...
    @typing.overload
    def distance(self, other: 'QgsPointXY') -> float: ...
    @typing.overload
    def sqrDist(self, x: float, y: float) -> float: ...
    @typing.overload
    def sqrDist(self, other: 'QgsPointXY') -> float: ...
    def asWkt(self) -> str: ...
    def toString(self, precision: int = ...) -> str: ...
    def toQPointF(self) -> QtCore.QPointF: ...
    def y(self) -> float: ...
    def x(self) -> float: ...
    def set(self, x: float, y: float) -> None: ...
    def setY(self, y: float) -> None: ...
    def setX(self, x: float) -> None: ...


class QgsPostgresStringUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPostgresStringUtils') -> None: ...

    @staticmethod
    def buildArray(list: collections.abc.Iterable[typing.Any]) -> str: ...
    @staticmethod
    def parseArray(string: str|None) -> list[typing.Any]: ...


class QgsPropertyDefinition(PyQt6.sip.wrapper):

    class DataType(enum.IntEnum):
        DataTypeString = ... # type: QgsPropertyDefinition.DataType
        DataTypeNumeric = ... # type: QgsPropertyDefinition.DataType
        DataTypeBoolean = ... # type: QgsPropertyDefinition.DataType

    class StandardPropertyTemplate(enum.IntEnum):
        Boolean = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Integer = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        IntegerPositive = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        IntegerPositiveGreaterZero = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Double = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        DoublePositive = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Double0To1 = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Rotation = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        String = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Opacity = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        RenderUnits = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        ColorWithAlpha = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        ColorNoAlpha = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        PenJoinStyle = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        BlendMode = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Point = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Size = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Size2D = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        LineStyle = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        StrokeWidth = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        FillStyle = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        CapStyle = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        HorizontalAnchor = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        VerticalAnchor = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        SvgPath = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Offset = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        DateTime = ... # type: QgsPropertyDefinition.StandardPropertyTemplate
        Custom = ... # type: QgsPropertyDefinition.StandardPropertyTemplate

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, description: str|None, type: 'QgsPropertyDefinition.StandardPropertyTemplate', origin: str|None = ..., comment: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, dataType: 'QgsPropertyDefinition.DataType', description: str|None, helpText: str|None, origin: str|None = ..., comment: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPropertyDefinition') -> None: ...

    def supportsAssistant(self) -> bool: ...
    def standardTemplate(self) -> 'QgsPropertyDefinition.StandardPropertyTemplate': ...
    def dataType(self) -> 'QgsPropertyDefinition.DataType': ...
    def setDataType(self, type: 'QgsPropertyDefinition.DataType') -> None: ...
    def helpText(self) -> str: ...
    def setComment(self, comment: str|None) -> None: ...
    def comment(self) -> str: ...
    def description(self) -> str: ...
    def setOrigin(self, origin: str|None) -> None: ...
    def origin(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...


class QgsProperty(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsProperty') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def convertToTransformer(self) -> bool: ...
    def transformer(self) -> 'QgsPropertyTransformer|None': ...
    def setTransformer(self, transformer: 'QgsPropertyTransformer|None') -> None: ...
    def loadVariant(self, property: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def valueAsBool(self, context: QgsExpressionContext, defaultValue: bool = ...) -> typing.Tuple[bool, bool]: ...
    def valueAsInt(self, context: QgsExpressionContext, defaultValue: int = ...) -> typing.Tuple[int, bool]: ...
    def valueAsDouble(self, context: QgsExpressionContext, defaultValue: float = ...) -> typing.Tuple[float, bool]: ...
    def valueAsColor(self, context: QgsExpressionContext, defaultColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> typing.Tuple[QtGui.QColor, bool]: ...
    def valueAsString(self, context: QgsExpressionContext, defaultString: str|None = ...) -> typing.Tuple[str, bool]: ...
    def valueAsDateTime(self, context: QgsExpressionContext, defaultDateTime: QtCore.QDateTime|datetime.datetime = ...) -> typing.Tuple[QtCore.QDateTime, bool]: ...
    def value(self, context: QgsExpressionContext, defaultValue: typing.Any = ...) -> typing.Tuple[typing.Any, bool]: ...
    def isProjectColor(self) -> bool: ...
    def referencedFields(self, context: QgsExpressionContext = ..., ignoreContext: bool = ...) -> set[str]: ...
    def prepare(self, context: QgsExpressionContext = ...) -> bool: ...
    def asExpression(self) -> str: ...
    def expressionString(self) -> str: ...
    def setExpressionString(self, expression: str|None) -> None: ...
    def field(self) -> str: ...
    def setField(self, field: str|None) -> None: ...
    def staticValue(self) -> typing.Any: ...
    def setStaticValue(self, value: typing.Any) -> None: ...
    def setActive(self, active: bool) -> None: ...
    def isStaticValueInContext(self, context: QgsExpressionContext) -> typing.Tuple[bool, typing.Any]: ...
    def isActive(self) -> bool: ...
    def propertyType(self) -> Qgis.PropertyType: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def fromValue(value: typing.Any, isActive: bool = ...) -> 'QgsProperty': ...
    @staticmethod
    def fromField(fieldName: str|None, isActive: bool = ...) -> 'QgsProperty': ...
    @staticmethod
    def fromExpression(expression: str|None, isActive: bool = ...) -> 'QgsProperty': ...
    @staticmethod
    def variantMapToPropertyMap(variantMap: dict[str|None, typing.Any]) -> dict[str, 'QgsProperty']: ...
    @staticmethod
    def propertyMapToVariantMap(propertyMap: dict[str|None, 'QgsProperty']) -> dict[str, typing.Any]: ...


class QgsAbstractPropertyCollection(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractPropertyCollection') -> None: ...

    def loadVariant(self, configuration: typing.Any, definitions: dict[int, QgsPropertyDefinition]) -> bool: ...
    def toVariant(self, definitions: dict[int, QgsPropertyDefinition]) -> typing.Any: ...
    def readXml(self, collectionElem: QtXml.QDomElement, definitions: dict[int, QgsPropertyDefinition]) -> bool: ...
    def writeXml(self, collectionElem: QtXml.QDomElement, definitions: dict[int, QgsPropertyDefinition]) -> bool: ...
    def hasDynamicProperties(self) -> bool: ...
    def hasActiveProperties(self) -> bool: ...
    def isActive(self, key: int) -> bool: ...
    def referencedFields(self, context: QgsExpressionContext = ..., ignoreContext: bool = ...) -> set[str]: ...
    def prepare(self, context: QgsExpressionContext = ...) -> bool: ...
    def valueAsBool(self, key: int, context: QgsExpressionContext, defaultValue: bool = ...) -> typing.Tuple[bool, bool]: ...
    def valueAsInt(self, key: int, context: QgsExpressionContext, defaultValue: int = ...) -> typing.Tuple[int, bool]: ...
    def valueAsDouble(self, key: int, context: QgsExpressionContext, defaultValue: float = ...) -> typing.Tuple[float, bool]: ...
    def valueAsColor(self, key: int, context: QgsExpressionContext, defaultColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> typing.Tuple[QtGui.QColor, bool]: ...
    def valueAsString(self, key: int, context: QgsExpressionContext, defaultString: str|None = ...) -> typing.Tuple[str, bool]: ...
    def valueAsDateTime(self, key: int, context: QgsExpressionContext, defaultDateTime: QtCore.QDateTime|datetime.datetime = ...) -> typing.Tuple[QtCore.QDateTime, bool]: ...
    def value(self, key: int, context: QgsExpressionContext, defaultValue: typing.Any = ...) -> typing.Any: ...
    def property(self, key: int) -> QgsProperty: ...
    def hasProperty(self, key: int) -> bool: ...
    def clear(self) -> None: ...
    def propertyKeys(self) -> typing.Any: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...


class QgsPropertyCollection(QgsAbstractPropertyCollection):

    @typing.overload
    def __init__(self, name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsPropertyCollection') -> None: ...

    @typing.overload
    def setProperty(self, key: int, property: QgsProperty) -> None: ...
    @typing.overload
    def setProperty(self, key: int, value: typing.Any) -> None: ...
    def loadVariant(self, configuration: typing.Any, definitions: dict[int, QgsPropertyDefinition]) -> bool: ...
    def toVariant(self, definitions: dict[int, QgsPropertyDefinition]) -> typing.Any: ...
    def hasDynamicProperties(self) -> bool: ...
    def hasActiveProperties(self) -> bool: ...
    def isActive(self, key: int) -> bool: ...
    def referencedFields(self, context: QgsExpressionContext = ..., ignoreContext: bool = ...) -> set[str]: ...
    def prepare(self, context: QgsExpressionContext = ...) -> bool: ...
    def value(self, key: int, context: QgsExpressionContext, defaultValue: typing.Any = ...) -> typing.Any: ...
    def property(self, key: int) -> QgsProperty: ...
    def hasProperty(self, key: int) -> bool: ...
    def clear(self) -> None: ...
    def propertyKeys(self) -> typing.Any: ...
    def count(self) -> int: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsPropertyCollectionStack(QgsAbstractPropertyCollection):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsPropertyCollectionStack') -> None: ...

    def loadVariant(self, collection: typing.Any, definitions: dict[int, QgsPropertyDefinition]) -> bool: ...
    def toVariant(self, definitions: dict[int, QgsPropertyDefinition]) -> typing.Any: ...
    def hasProperty(self, key: int) -> bool: ...
    def propertyKeys(self) -> typing.Any: ...
    def prepare(self, context: QgsExpressionContext = ...) -> bool: ...
    def referencedFields(self, context: QgsExpressionContext = ..., ignoreContext: bool = ...) -> set[str]: ...
    def value(self, key: int, context: QgsExpressionContext, defaultValue: typing.Any = ...) -> typing.Any: ...
    def property(self, key: int) -> QgsProperty: ...
    def isActive(self, key: int) -> bool: ...
    def hasDynamicProperties(self) -> bool: ...
    def hasActiveProperties(self) -> bool: ...
    def collection(self, name: str|None) -> QgsPropertyCollection|None: ...
    def at(self, index: int) -> QgsPropertyCollection|None: ...
    def appendCollection(self, collection: QgsPropertyCollection|None) -> None: ...
    def clear(self) -> None: ...
    def count(self) -> int: ...


class QgsCurveTransform(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, controlPoints: collections.abc.Iterable[QgsPointXY]) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsCurveTransform') -> None: ...

    def loadVariant(self, transformer: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def writeXml(self, transformElem: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...
    def readXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...
    @typing.overload
    def y(self, x: float) -> float: ...
    @typing.overload
    def y(self, x: collections.abc.Iterable[float]) -> list[float]: ...
    def removeControlPoint(self, x: float, y: float) -> None: ...
    def addControlPoint(self, x: float, y: float) -> None: ...
    def setControlPoints(self, points: collections.abc.Iterable[QgsPointXY]) -> None: ...
    def controlPoints(self) -> list[QgsPointXY]: ...


class QgsPropertyTransformer(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        GenericNumericTransformer = ... # type: QgsPropertyTransformer.Type
        SizeScaleTransformer = ... # type: QgsPropertyTransformer.Type
        ColorRampTransformer = ... # type: QgsPropertyTransformer.Type

    @typing.overload
    def __init__(self, minValue: float = ..., maxValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsPropertyTransformer') -> None: ...

    def transformNumeric(self, input: float) -> float: ...
    @staticmethod
    def fromExpression(expression: str|None) -> typing.Tuple['QgsPropertyTransformer|None', str, str]: ...
    def toExpression(self, baseExpression: str|None) -> str: ...
    def transform(self, context: QgsExpressionContext, value: typing.Any) -> typing.Any: ...
    def setCurveTransform(self, transform: QgsCurveTransform|None) -> None: ...
    def curveTransform(self) -> QgsCurveTransform|None: ...
    def setMaxValue(self, max: float) -> None: ...
    def maxValue(self) -> float: ...
    def setMinValue(self, min: float) -> None: ...
    def minValue(self) -> float: ...
    def toVariant(self) -> typing.Any: ...
    def loadVariant(self, transformer: typing.Any) -> bool: ...
    def clone(self) -> 'QgsPropertyTransformer|None': ...
    def transformerType(self) -> 'QgsPropertyTransformer.Type': ...
    @staticmethod
    def create(type: 'QgsPropertyTransformer.Type') -> 'QgsPropertyTransformer|None': ...


class QgsGenericNumericTransformer(QgsPropertyTransformer):

    @typing.overload
    def __init__(self, minValue: float = ..., maxValue: float = ..., minOutput: float = ..., maxOutput: float = ..., nullOutput: float = ..., exponent: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGenericNumericTransformer') -> None: ...

    def setExponent(self, exponent: float) -> None: ...
    def exponent(self) -> float: ...
    def setNullOutputValue(self, size: float) -> None: ...
    def nullOutputValue(self) -> float: ...
    def setMaxOutputValue(self, size: float) -> None: ...
    def maxOutputValue(self) -> float: ...
    def setMinOutputValue(self, size: float) -> None: ...
    def minOutputValue(self) -> float: ...
    def value(self, input: float) -> float: ...
    @staticmethod
    def fromExpression(expression: str|None) -> typing.Tuple['QgsGenericNumericTransformer|None', str, str]: ...
    def toExpression(self, baseExpression: str|None) -> str: ...
    def transform(self, context: QgsExpressionContext, value: typing.Any) -> typing.Any: ...
    def loadVariant(self, definition: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def clone(self) -> 'QgsGenericNumericTransformer|None': ...
    def transformerType(self) -> QgsPropertyTransformer.Type: ...


class QgsSizeScaleTransformer(QgsPropertyTransformer):

    class ScaleType(enum.IntEnum):
        Linear = ... # type: QgsSizeScaleTransformer.ScaleType
        Area = ... # type: QgsSizeScaleTransformer.ScaleType
        Flannery = ... # type: QgsSizeScaleTransformer.ScaleType
        Exponential = ... # type: QgsSizeScaleTransformer.ScaleType

    @typing.overload
    def __init__(self, type: 'QgsSizeScaleTransformer.ScaleType' = ..., minValue: float = ..., maxValue: float = ..., minSize: float = ..., maxSize: float = ..., nullSize: float = ..., exponent: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSizeScaleTransformer') -> None: ...

    def setType(self, type: 'QgsSizeScaleTransformer.ScaleType') -> None: ...
    def type(self) -> 'QgsSizeScaleTransformer.ScaleType': ...
    def setExponent(self, exponent: float) -> None: ...
    def exponent(self) -> float: ...
    def setNullSize(self, size: float) -> None: ...
    def nullSize(self) -> float: ...
    def setMaxSize(self, size: float) -> None: ...
    def maxSize(self) -> float: ...
    def setMinSize(self, size: float) -> None: ...
    def minSize(self) -> float: ...
    def size(self, value: float) -> float: ...
    @staticmethod
    def fromExpression(expression: str|None) -> typing.Tuple['QgsSizeScaleTransformer|None', str, str]: ...
    def toExpression(self, baseExpression: str|None) -> str: ...
    def transform(self, context: QgsExpressionContext, value: typing.Any) -> typing.Any: ...
    def loadVariant(self, definition: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def clone(self) -> 'QgsSizeScaleTransformer|None': ...
    def transformerType(self) -> QgsPropertyTransformer.Type: ...


class QgsColorRampTransformer(QgsPropertyTransformer):

    @typing.overload
    def __init__(self, minValue: float = ..., maxValue: float = ..., ramp: QgsColorRamp|None = ..., nullColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., rampName: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsColorRampTransformer') -> None: ...

    def setRampName(self, name: str|None) -> None: ...
    def rampName(self) -> str: ...
    def setNullColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def nullColor(self) -> QtGui.QColor: ...
    def setColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def colorRamp(self) -> QgsColorRamp|None: ...
    def color(self, value: float) -> QtGui.QColor: ...
    def toExpression(self, baseExpression: str|None) -> str: ...
    def transform(self, context: QgsExpressionContext, value: typing.Any) -> typing.Any: ...
    def loadVariant(self, definition: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def clone(self) -> 'QgsColorRampTransformer|None': ...
    def transformerType(self) -> QgsPropertyTransformer.Type: ...


class QgsProviderConnectionModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        ConnectionName = ... # type: QgsProviderConnectionModel.CustomRole
        Uri = ... # type: QgsProviderConnectionModel.CustomRole
        Configuration = ... # type: QgsProviderConnectionModel.CustomRole
        Empty = ... # type: QgsProviderConnectionModel.CustomRole

    def __init__(self, provider: str|None, parent: QtCore.QObject|None = ...) -> None: ...

    def index(self, row: int, column: int, parent: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def allowEmptyConnection(self) -> bool: ...
    def setAllowEmptyConnection(self, allowEmpty: bool) -> None: ...


class QgsProxyFeatureSink(QgsFeatureSink):

    @typing.overload
    def __init__(self, sink: QgsFeatureSink|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProxyFeatureSink') -> None: ...

    def destinationSink(self) -> QgsFeatureSink|None: ...
    def finalize(self) -> None: ...
    def flushBuffer(self) -> bool: ...
    def lastError(self) -> str: ...
    @typing.overload
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    @typing.overload
    def addFeatures(self, iterator: QgsFeatureIterator, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def addFeature(self, feature: QgsFeature, flags: QgsFeatureSink.Flag = ...) -> bool: ...


class QgsProxyProgressTask(QgsTask):

    def __init__(self, description: str|None, canCancel: bool = ...) -> None: ...

    canceled: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    def setProxyProgress(self, progress: float) -> None: ...
    def run(self) -> bool: ...
    def finalize(self, result: bool) -> None: ...


class QgsScopedProxyProgressTask(PyQt6.sip.wrapper):

    def __init__(self, description: str|None) -> None: ...

    def setProgress(self, progress: float) -> None: ...


class QgsPythonRunner(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPythonRunner') -> None: ...

    def setArgvCommand(self, arguments: collections.abc.Iterable[str|None], messageOnError: str|None = ...) -> bool: ...
    def evalCommand(self, command: str|None, result: str|None) -> bool: ...
    def runFileCommand(self, filename: str|None, messageOnError: str|None = ...) -> bool: ...
    def runCommand(self, command: str|None, messageOnError: str|None = ...) -> bool: ...
    @staticmethod
    def setInstance(runner: 'QgsPythonRunner|None') -> None: ...
    @staticmethod
    def setArgv(arguments: collections.abc.Iterable[str|None], messageOnError: str|None = ...) -> bool: ...
    @staticmethod
    def eval(command: str|None) -> typing.Tuple[bool, str]: ...
    @staticmethod
    def runFile(filename: str|None, messageOnError: str|None = ...) -> bool: ...
    @staticmethod
    def run(command: str|None, messageOnError: str|None = ...) -> bool: ...
    @staticmethod
    def isValid() -> bool: ...


class QgsQueryResultModel(QtCore.QAbstractTableModel):

    def __init__(self, queryResult: 'QgsAbstractDatabaseProviderConnection.QueryResult', parent: QtCore.QObject|None = ...) -> None: ...

    fetchingStarted: typing.ClassVar[QtCore.pyqtSignal]
    fetchMoreRows: typing.ClassVar[QtCore.pyqtSignal]
    fetchingComplete: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    def rowsReady(self, rows: typing.Any) -> None: ...
    def queryResult(self) -> 'QgsAbstractDatabaseProviderConnection.QueryResult': ...
    def columns(self) -> list[str]: ...
    def canFetchMore(self, parent: QtCore.QModelIndex) -> bool: ...
    def fetchMore(self, parent: QtCore.QModelIndex) -> None: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...


class QgsRangedoubleBase(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, lower: float, upper: float, includeLower: bool = ..., includeUpper: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, lower: float, upper: float, limits: Qgis.RangeLimits) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRangedoubleBase') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def overlaps(self, other: 'QgsRangedoubleBase') -> bool: ...
    @typing.overload
    def contains(self, other: 'QgsRangedoubleBase') -> bool: ...
    @typing.overload
    def contains(self, element: float) -> bool: ...
    def isSingleton(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def rangeLimits(self) -> Qgis.RangeLimits: ...
    def includeUpper(self) -> bool: ...
    def includeLower(self) -> bool: ...
    def upper(self) -> float: ...
    def lower(self) -> float: ...


class QgsDoubleRange(QgsRangedoubleBase):

    @typing.overload
    def __init__(self, lower: float, upper: float, limits: Qgis.RangeLimits) -> None: ...
    @typing.overload
    def __init__(self, lower: float, upper: float, includeLower: bool = ..., includeUpper: bool = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDoubleRange') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def isInfinite(self) -> bool: ...


class QgsRangeintBase(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, lower: int, upper: int, includeLower: bool = ..., includeUpper: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, lower: int, upper: int, limits: Qgis.RangeLimits) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRangeintBase') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def overlaps(self, other: 'QgsRangeintBase') -> bool: ...
    @typing.overload
    def contains(self, other: 'QgsRangeintBase') -> bool: ...
    @typing.overload
    def contains(self, element: int) -> bool: ...
    def isSingleton(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def rangeLimits(self) -> Qgis.RangeLimits: ...
    def includeUpper(self) -> bool: ...
    def includeLower(self) -> bool: ...
    def upper(self) -> int: ...
    def lower(self) -> int: ...


class QgsIntRange(QgsRangeintBase):

    @typing.overload
    def __init__(self, lower: int, upper: int, limits: Qgis.RangeLimits) -> None: ...
    @typing.overload
    def __init__(self, lower: int, upper: int, includeLower: bool = ..., includeUpper: bool = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsIntRange') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def isInfinite(self) -> bool: ...


class QgsDateRange(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, begin: QtCore.QDate|datetime.date, end: QtCore.QDate|datetime.date, includeBeginning: bool = ..., includeEnd: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDateRange') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def extend(self, other: 'QgsDateRange') -> bool: ...
    def overlaps(self, other: 'QgsDateRange') -> bool: ...
    @typing.overload
    def contains(self, other: 'QgsDateRange') -> bool: ...
    @typing.overload
    def contains(self, element: QtCore.QDate|datetime.date) -> bool: ...
    def isEmpty(self) -> bool: ...
    def isInfinite(self) -> bool: ...
    def isInstant(self) -> bool: ...
    def includeEnd(self) -> bool: ...
    def includeBeginning(self) -> bool: ...
    def end(self) -> QtCore.QDate: ...
    def begin(self) -> QtCore.QDate: ...


class QgsDateTimeRange(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, begin: QtCore.QDateTime|datetime.datetime, end: QtCore.QDateTime|datetime.datetime, includeBeginning: bool = ..., includeEnd: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDateTimeRange') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def extend(self, other: 'QgsDateTimeRange') -> bool: ...
    def overlaps(self, other: 'QgsDateTimeRange') -> bool: ...
    @typing.overload
    def contains(self, other: 'QgsDateTimeRange') -> bool: ...
    @typing.overload
    def contains(self, element: QtCore.QDateTime|datetime.datetime) -> bool: ...
    def isEmpty(self) -> bool: ...
    def isInfinite(self) -> bool: ...
    def isInstant(self) -> bool: ...
    def includeEnd(self) -> bool: ...
    def includeBeginning(self) -> bool: ...
    def end(self) -> QtCore.QDateTime: ...
    def begin(self) -> QtCore.QDateTime: ...


class QgsReadWriteContext(PyQt6.sip.wrapper):

    class ReadWriteMessage(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, message: str|None = ..., level: Qgis.MessageLevel = ..., categories: collections.abc.Iterable[str|None] = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsReadWriteContext.ReadWriteMessage') -> None: ...

        def __repr__(self) -> typing.Any: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def categories(self) -> list[str]: ...
        def level(self) -> Qgis.MessageLevel: ...
        def message(self) -> str: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReadWriteContext') -> None: ...

    def setCurrentLayerId(self, layerId: str|None) -> None: ...
    def currentLayerId(self) -> str: ...
    def setTransformContext(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def setProjectTranslator(self, projectTranslator: 'QgsProjectTranslator|None') -> None: ...
    def projectTranslator(self) -> 'QgsProjectTranslator|None': ...
    def takeMessages(self) -> list['QgsReadWriteContext.ReadWriteMessage']: ...
    def _enterCategory(self, category: str|None, details: str|None = ...) -> 'QgsReadWriteContextCategoryPopper': ...
    def pushMessage(self, message: str|None, level: Qgis.MessageLevel = ...) -> None: ...
    def setPathResolver(self, resolver: QgsPathResolver) -> None: ...
    def pathResolver(self) -> QgsPathResolver: ...


class QgsReadWriteContextCategoryPopper(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, context: QgsReadWriteContext) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReadWriteContextCategoryPopper') -> None: ...


class QgsReadWriteLocker(PyQt6.sip.wrapper):

    class Mode(enum.IntEnum):
        Read = ... # type: QgsReadWriteLocker.Mode
        Write = ... # type: QgsReadWriteLocker.Mode
        Unlocked = ... # type: QgsReadWriteLocker.Mode

    @typing.overload
    def __init__(self, lock: QtCore.QReadWriteLock, mode: 'QgsReadWriteLocker.Mode') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReadWriteLocker') -> None: ...

    def unlock(self) -> None: ...
    def changeMode(self, mode: 'QgsReadWriteLocker.Mode') -> None: ...


class QgsRecentStyleHandler(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def recentSymbol(self, identifier: str|None) -> 'QgsSymbol|None': ...
    def pushRecentSymbol(self, identifier: str|None, symbol: 'QgsSymbol|None') -> None: ...


class QgsRelation(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: 'QgsRelationContext') -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsRelation') -> None: ...

    @staticmethod
    def strengthToDisplayString(strength: Qgis.RelationshipStrength) -> str: ...
    @staticmethod
    def cardinalityToDisplayString(cardinality: Qgis.RelationshipCardinality) -> str: ...
    def type(self) -> Qgis.RelationshipType: ...
    def polymorphicRelation(self) -> 'QgsPolymorphicRelation': ...
    def polymorphicRelationId(self) -> str: ...
    def setPolymorphicRelationId(self, polymorphicRelationId: str|None) -> None: ...
    def updateRelationStatus(self) -> None: ...
    def resolveReferencingField(self, referencedField: str|None) -> str: ...
    def resolveReferencedField(self, referencingField: str|None) -> str: ...
    def hasEqualDefinition(self, other: 'QgsRelation') -> bool: ...
    def validationError(self) -> str: ...
    def isValid(self) -> bool: ...
    def referencingFieldsAllowNull(self) -> bool: ...
    def referencingFields(self) -> list[int]: ...
    def referencedFields(self) -> list[int]: ...
    def fieldPairs(self) -> dict[str, str]: ...
    def referencedLayer(self) -> QgsVectorLayer|None: ...
    def referencedLayerId(self) -> str: ...
    def referencingLayer(self) -> QgsVectorLayer|None: ...
    def referencingLayerId(self) -> str: ...
    def generateId(self) -> None: ...
    def id(self) -> str: ...
    def strength(self) -> Qgis.RelationshipStrength: ...
    def name(self) -> str: ...
    def getReferencedFeature(self, feature: QgsFeature) -> QgsFeature: ...
    @typing.overload
    def getReferencedFeatureRequest(self, attributes: typing.Any) -> QgsFeatureRequest: ...
    @typing.overload
    def getReferencedFeatureRequest(self, feature: QgsFeature) -> QgsFeatureRequest: ...
    def getRelatedFeaturesFilter(self, feature: QgsFeature) -> str: ...
    def getRelatedFeaturesRequest(self, feature: QgsFeature) -> QgsFeatureRequest: ...
    def getRelatedFeatures(self, feature: QgsFeature) -> QgsFeatureIterator: ...
    def addFieldPair(self, referencingField: str|None, referencedField: str|None) -> None: ...
    def setReferencedLayer(self, id: str|None) -> None: ...
    def setReferencingLayer(self, id: str|None) -> None: ...
    def setStrength(self, strength: Qgis.RelationshipStrength) -> None: ...
    def setName(self, name: str|None) -> None: ...
    def setId(self, id: str|None) -> None: ...
    def writeXml(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    @staticmethod
    def createFromXml(node: QtXml.QDomNode, context: QgsReadWriteContext, relationContext: 'QgsRelationContext' = ...) -> 'QgsRelation': ...


class QgsPolymorphicRelation(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, context: 'QgsRelationContext') -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsPolymorphicRelation') -> None: ...

    def setRelationStrength(self, relationStrength: Qgis.RelationshipStrength) -> None: ...
    def strength(self) -> Qgis.RelationshipStrength: ...
    def layerRepresentation(self, layer: QgsVectorLayer|None) -> str: ...
    def generateRelations(self) -> list[QgsRelation]: ...
    def referencedLayerIds(self) -> list[str]: ...
    def setReferencedLayerIds(self, childRelationIds: collections.abc.Iterable[str|None]) -> None: ...
    def referencedLayerExpression(self) -> str: ...
    def setReferencedLayerExpression(self, expression: str|None) -> None: ...
    def referencedLayerField(self) -> str: ...
    def setReferencedLayerField(self, referencedLayerField: str|None) -> None: ...
    def updateRelationStatus(self) -> None: ...
    def hasEqualDefinition(self, other: 'QgsPolymorphicRelation') -> bool: ...
    def isValid(self) -> bool: ...
    def referencingFields(self) -> list[int]: ...
    def referencedFields(self, layerId: str|None) -> list[int]: ...
    def fieldPairs(self) -> dict[str, str]: ...
    def referencingLayer(self) -> QgsVectorLayer|None: ...
    def referencingLayerId(self) -> str: ...
    def generateId(self) -> None: ...
    def id(self) -> str: ...
    def name(self) -> str: ...
    def addFieldPair(self, referencingField: str|None, referencedField: str|None) -> None: ...
    def setReferencingLayer(self, id: str|None) -> None: ...
    def setName(self, name: str|None) -> None: ...
    def setId(self, id: str|None) -> None: ...
    def writeXml(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    @staticmethod
    def createFromXml(node: QtXml.QDomNode, context: QgsReadWriteContext, relationContext: 'QgsRelationContext' = ...) -> 'QgsPolymorphicRelation': ...


class QgsRelationContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRelationContext') -> None: ...

    def project(self) -> 'QgsProject|None': ...


class QgsRemappingSinkDefinition(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRemappingSinkDefinition') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def setDestinationFields(self, fields: QgsFields) -> None: ...
    def destinationFields(self) -> QgsFields: ...
    def setDestinationWkbType(self, type: Qgis.WkbType) -> None: ...
    def destinationWkbType(self) -> Qgis.WkbType: ...
    def setDestinationCrs(self, destination: 'QgsCoordinateReferenceSystem') -> None: ...
    def destinationCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setSourceCrs(self, source: 'QgsCoordinateReferenceSystem') -> None: ...
    def sourceCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def addMappedField(self, destinationField: str|None, property: QgsProperty) -> None: ...
    def setFieldMap(self, map: dict[str|None, QgsProperty]) -> None: ...
    def fieldMap(self) -> dict[str, QgsProperty]: ...


class QgsRemappingProxyFeatureSink(QgsFeatureSink):

    @typing.overload
    def __init__(self, mappingDefinition: QgsRemappingSinkDefinition, sink: QgsFeatureSink|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRemappingProxyFeatureSink') -> None: ...

    def destinationSink(self) -> QgsFeatureSink|None: ...
    def lastError(self) -> str: ...
    @typing.overload
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    @typing.overload
    def addFeatures(self, iterator: QgsFeatureIterator, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def addFeature(self, feature: QgsFeature, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def remapFeature(self, feature: QgsFeature) -> list[QgsFeature]: ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def setExpressionContext(self, context: QgsExpressionContext) -> None: ...


class QgsWeakRelation(PyQt6.sip.wrapper):

    class WeakRelationType(enum.IntEnum):
        Referencing = ... # type: QgsWeakRelation.WeakRelationType
        Referenced = ... # type: QgsWeakRelation.WeakRelationType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, relationId: str|None, relationName: str|None, strength: Qgis.RelationshipStrength, referencingLayerId: str|None, referencingLayerName: str|None, referencingLayerSource: str|None, referencingLayerProviderKey: str|None, referencedLayerId: str|None, referencedLayerName: str|None, referencedLayerSource: str|None, referencedLayerProviderKey: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsWeakRelation') -> None: ...

    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def writeXml(layer: QgsVectorLayer|None, type: 'QgsWeakRelation.WeakRelationType', relation: QgsRelation, node: QtXml.QDomNode, doc: QtXml.QDomDocument) -> None: ...
    @staticmethod
    def readXml(layer: QgsVectorLayer|None, type: 'QgsWeakRelation.WeakRelationType', node: QtXml.QDomNode, resolver: QgsPathResolver) -> 'QgsWeakRelation': ...
    def setRelatedTableType(self, type: str|None) -> None: ...
    def relatedTableType(self) -> str: ...
    def setBackwardPathLabel(self, label: str|None) -> None: ...
    def setForwardPathLabel(self, label: str|None) -> None: ...
    def backwardPathLabel(self) -> str: ...
    def forwardPathLabel(self) -> str: ...
    def setCardinality(self, cardinality: Qgis.RelationshipCardinality) -> None: ...
    def cardinality(self) -> Qgis.RelationshipCardinality: ...
    def strength(self) -> Qgis.RelationshipStrength: ...
    def setMappingReferencedLayerFields(self, fields: collections.abc.Iterable[str|None]) -> None: ...
    def mappingReferencedLayerFields(self) -> list[str]: ...
    def setReferencedLayerFields(self, fields: collections.abc.Iterable[str|None]) -> None: ...
    def referencedLayerFields(self) -> list[str]: ...
    def setMappingReferencingLayerFields(self, fields: collections.abc.Iterable[str|None]) -> None: ...
    def mappingReferencingLayerFields(self) -> list[str]: ...
    def setReferencingLayerFields(self, fields: collections.abc.Iterable[str|None]) -> None: ...
    def referencingLayerFields(self) -> list[str]: ...
    def setMappingTable(self, sourceUri: str|None, provider: str|None) -> None: ...
    def mappingTableName(self) -> str: ...
    def mappingTableProvider(self) -> str: ...
    def mappingTableSource(self) -> str: ...
    def setReferencedLayer(self, sourceUri: str|None, provider: str|None) -> None: ...
    def referencedLayerName(self) -> str: ...
    def referencedLayerProvider(self) -> str: ...
    def referencedLayerSource(self) -> str: ...
    def setReferencingLayer(self, sourceUri: str|None, provider: str|None) -> None: ...
    def referencingLayerName(self) -> str: ...
    def referencingLayerProvider(self) -> str: ...
    def referencingLayerSource(self) -> str: ...
    def name(self) -> str: ...
    def id(self) -> str: ...
    def resolvedRelations(self, project: 'QgsProject|None') -> list[QgsRelation]: ...


class QgsRelationManager(QtCore.QObject):

    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...

    def updateRelationsStatus(self) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    relationsLoaded: typing.ClassVar[QtCore.pyqtSignal]
    def setPolymorphicRelations(self, relations: collections.abc.Iterable[QgsPolymorphicRelation]) -> None: ...
    def removePolymorphicRelation(self, polymorphicRelationId: str|None) -> None: ...
    def addPolymorphicRelation(self, polymorphicRelation: QgsPolymorphicRelation) -> None: ...
    def polymorphicRelation(self, polymorphicRelationId: str|None) -> QgsPolymorphicRelation: ...
    def polymorphicRelations(self) -> dict[str, QgsPolymorphicRelation]: ...
    @staticmethod
    def discoverRelations(existingRelations: collections.abc.Iterable[QgsRelation], layers: collections.abc.Iterable[QgsVectorLayer]) -> list[QgsRelation]: ...
    def referencedRelations(self, layer: QgsVectorLayer|None = ...) -> list[QgsRelation]: ...
    def referencingRelations(self, layer: QgsVectorLayer|None = ..., fieldIdx: int = ...) -> list[QgsRelation]: ...
    def clear(self) -> None: ...
    def relationsByName(self, name: str|None) -> list[QgsRelation]: ...
    def relation(self, id: str|None) -> QgsRelation: ...
    @typing.overload
    def removeRelation(self, id: str|None) -> None: ...
    @typing.overload
    def removeRelation(self, relation: QgsRelation) -> None: ...
    def addRelation(self, relation: QgsRelation) -> None: ...
    def relations(self) -> dict[str, QgsRelation]: ...
    def setRelations(self, relations: collections.abc.Iterable[QgsRelation]) -> None: ...
    def context(self) -> QgsRelationContext: ...


class QgsRenderChecker(PyQt6.sip.wrapper):

    class Flag(enum.IntFlag):
        AvoidExportingRenderedImage = ... # type: QgsRenderChecker.Flag
        Silent = ... # type: QgsRenderChecker.Flag

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRenderChecker') -> None: ...

    @staticmethod
    def sourcePath() -> str: ...
    def dartMeasurements(self) -> list[QgsDartMeasurement]: ...
    def enableDashBuffering(self, enable: bool) -> None: ...
    def expectedImageFile(self) -> str: ...
    @staticmethod
    def drawBackground(image: QtGui.QImage|None) -> None: ...
    @deprecated("""""")
    def isKnownAnomaly(self, diffImageFile: str|None) -> bool: ...
    @typing.overload
    def compareImages(self, testName: str|None, mismatchCount: int = ..., renderedImageFile: str|None = ..., flags: 'QgsRenderChecker.Flag' = ...) -> bool: ...
    @typing.overload
    def compareImages(self, testName: str|None, referenceImageFile: str|None, renderedImageFile: str|None, mismatchCount: int = ..., flags: 'QgsRenderChecker.Flag' = ...) -> bool: ...
    def runTest(self, testName: str|None, mismatchCount: int = ..., flags: 'QgsRenderChecker.Flag' = ...) -> bool: ...
    def setSizeTolerance(self, xTolerance: int, yTolerance: int) -> None: ...
    def setColorTolerance(self, colorTolerance: int) -> None: ...
    def setMapSettings(self, mapSettings: QgsMapSettings) -> None: ...
    def renderedImage(self) -> str: ...
    def setExpectFail(self, expectFail: bool) -> None: ...
    def setRenderedImage(self, imageFileName: str|None) -> None: ...
    def imageToHash(self, imageFile: str|None) -> str: ...
    def setControlPathSuffix(self, name: str|None) -> None: ...
    def setControlPathPrefix(self, name: str|None) -> None: ...
    def setControlExtension(self, extension: str|None) -> None: ...
    def setControlName(self, name: str|None) -> None: ...
    def setElapsedTimeTarget(self, target: int) -> None: ...
    def elapsedTime(self) -> int: ...
    def matchTarget(self) -> int: ...
    def mismatchCount(self) -> int: ...
    def matchPercent(self) -> float: ...
    def markdownReport(self, ignoreSuccess: bool = ...) -> str: ...
    def report(self, ignoreSuccess: bool = ...) -> str: ...
    def setControlImagePath(self, path: str|None) -> None: ...
    def controlImagePath(self) -> str: ...
    @staticmethod
    def shouldGenerateReport() -> bool: ...
    @staticmethod
    def testReportDir() -> QtCore.QDir: ...


class QgsRenderContext(QgsTemporalRangeObject):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, rh: 'QgsRenderContext') -> None: ...

    def setElevationMap(self, map: QgsElevationMap|None) -> None: ...
    def elevationMap(self) -> QgsElevationMap|None: ...
    def setCurrentFrame(self, frame: int) -> None: ...
    def currentFrame(self) -> int: ...
    def setFrameRate(self, rate: float) -> None: ...
    def frameRate(self) -> float: ...
    def setRendererUsage(self, usage: Qgis.RendererUsage) -> None: ...
    def rendererUsage(self) -> Qgis.RendererUsage: ...
    def setRasterizedRenderingPolicy(self, policy: Qgis.RasterizedRenderingPolicy) -> None: ...
    def rasterizedRenderingPolicy(self) -> Qgis.RasterizedRenderingPolicy: ...
    def imageFormat(self) -> QtGui.QImage.Format: ...
    def setImageFormat(self, format: QtGui.QImage.Format) -> None: ...
    def deviceOutputSize(self) -> QtCore.QSize: ...
    def setDevicePixelRatio(self, ratio: float) -> None: ...
    def devicePixelRatio(self) -> float: ...
    def setOutputSize(self, size: QtCore.QSize) -> None: ...
    def outputSize(self) -> QtCore.QSize: ...
    def setZRange(self, range: QgsDoubleRange) -> None: ...
    def zRange(self) -> QgsDoubleRange: ...
    def symbolLayerClipGeometries(self, symbolLayerId: str|None) -> list['QgsGeometry']: ...
    def symbolLayerHasClipGeometries(self, symbolLayerId: str|None) -> bool: ...
    def addSymbolLayerClipGeometry(self, symbolLayerId: str|None, geometry: 'QgsGeometry') -> None: ...
    @deprecated("""""")
    def symbolLayerClipPaths(self, symbolLayerId: str|None) -> list[QtGui.QPainterPath]: ...
    @deprecated("""""")
    def addSymbolLayerClipPath(self, symbolLayerId: str|None, path: QtGui.QPainterPath) -> None: ...
    def setMaskSettings(self, settings: QgsMaskRenderSettings) -> None: ...
    def maskSettings(self) -> QgsMaskRenderSettings: ...
    def setTextureOrigin(self, origin: QtCore.QPointF) -> None: ...
    def textureOrigin(self) -> QtCore.QPointF: ...
    def setFeatureClipGeometry(self, geometry: 'QgsGeometry') -> None: ...
    def featureClipGeometry(self) -> 'QgsGeometry': ...
    def clippingRegions(self) -> list[QgsMapClippingRegion]: ...
    def clearCustomProperty(self, property: str|None) -> None: ...
    @deprecated("""""")
    def clearCustomRenderingFlag(self, flag: str|None) -> None: ...
    def setCustomProperty(self, property: str|None, value: typing.Any) -> None: ...
    @deprecated("""""")
    def setCustomRenderingFlag(self, flag: str|None, value: typing.Any) -> None: ...
    def customProperties(self) -> dict[str, typing.Any]: ...
    @deprecated("""""")
    def customRenderingFlags(self) -> dict[str, typing.Any]: ...
    def isGuiPreview(self) -> bool: ...
    def setIsGuiPreview(self, preview: bool) -> None: ...
    def currentMaskId(self) -> int: ...
    def setCurrentMaskId(self, id: int) -> None: ...
    def maskIdProvider(self) -> QgsMaskIdProvider|None: ...
    def setMaskIdProvider(self, provider: QgsMaskIdProvider|None) -> None: ...
    def hasRenderedFeatureHandlers(self) -> bool: ...
    def renderedFeatureHandlers(self) -> list['QgsRenderedFeatureHandlerInterface']: ...
    def setTextRenderFormat(self, format: Qgis.TextRenderFormat) -> None: ...
    def textRenderFormat(self) -> Qgis.TextRenderFormat: ...
    def convertMetersToMapUnits(self, meters: float) -> float: ...
    def convertFromMapUnits(self, sizeInMapUnits: float, outputUnit: Qgis.RenderUnit) -> float: ...
    def convertToMapUnits(self, size: float, unit: Qgis.RenderUnit, scale: QgsMapUnitScale = ...) -> float: ...
    def convertFromPainterUnits(self, size: float, unit: Qgis.RenderUnit) -> float: ...
    def convertToPainterUnits(self, size: float, unit: Qgis.RenderUnit, scale: QgsMapUnitScale = ..., property: Qgis.RenderSubcomponentProperty = ...) -> float: ...
    def segmentationToleranceType(self) -> 'QgsAbstractGeometry.SegmentationToleranceType': ...
    def setSegmentationToleranceType(self, type: 'QgsAbstractGeometry.SegmentationToleranceType') -> None: ...
    def segmentationTolerance(self) -> float: ...
    def setSegmentationTolerance(self, tolerance: float) -> None: ...
    def featureFilterProvider(self) -> QgsFeatureFilterProvider|None: ...
    def setFeatureFilterProvider(self, ffp: QgsFeatureFilterProvider|None) -> None: ...
    def setGeometry(self, geometry: 'QgsAbstractGeometry|None') -> None: ...
    def geometry(self) -> 'QgsAbstractGeometry|None': ...
    def expressionContext(self) -> QgsExpressionContext: ...
    def setExpressionContext(self, context: QgsExpressionContext) -> None: ...
    def setVectorSimplifyMethod(self, simplifyMethod: 'QgsVectorSimplifyMethod') -> None: ...
    def vectorSimplifyMethod(self) -> 'QgsVectorSimplifyMethod': ...
    def setUseRenderingOptimization(self, enabled: bool) -> None: ...
    def useRenderingOptimization(self) -> bool: ...
    def setShowSelection(self, showSelection: bool) -> None: ...
    def setSelectionColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def setForceVectorOutput(self, force: bool) -> None: ...
    def setMaskPainter(self, p: QtGui.QPainter|None, id: int = ...) -> None: ...
    def setPreviewRenderPainter(self, painter: QtGui.QPainter|None) -> None: ...
    def setPainter(self, p: QtGui.QPainter|None) -> None: ...
    def setSymbologyReferenceScale(self, scale: float) -> None: ...
    def setRendererScale(self, scale: float) -> None: ...
    def setDpiTarget(self, dpi: float) -> None: ...
    def setScaleFactor(self, factor: float) -> None: ...
    def setDistanceArea(self, distanceArea: QgsDistanceArea) -> None: ...
    def setRenderingStopped(self, stopped: bool) -> None: ...
    def setDrawEditingInformation(self, b: bool) -> None: ...
    def setMapExtent(self, extent: 'QgsRectangle') -> None: ...
    def setExtent(self, extent: 'QgsRectangle') -> None: ...
    def setMapToPixel(self, mtp: QgsMapToPixel) -> None: ...
    def setCoordinateTransform(self, t: 'QgsCoordinateTransform') -> None: ...
    def showSelection(self) -> bool: ...
    def selectionColor(self) -> QtGui.QColor: ...
    def symbologyReferenceScale(self) -> float: ...
    def rendererScale(self) -> float: ...
    def drawEditingInformation(self) -> bool: ...
    @deprecated("""""")
    def setUseAdvancedEffects(self, enabled: bool) -> None: ...
    @deprecated("""""")
    def useAdvancedEffects(self) -> bool: ...
    @deprecated("""""")
    def forceVectorOutput(self) -> bool: ...
    def feedback(self) -> QgsFeedback|None: ...
    def setFeedback(self, feedback: QgsFeedback|None) -> None: ...
    def renderingStopped(self) -> bool: ...
    def dpiTarget(self) -> float: ...
    def scaleFactor(self) -> float: ...
    def mapToPixel(self) -> QgsMapToPixel: ...
    def mapExtent(self) -> 'QgsRectangle': ...
    def extent(self) -> 'QgsRectangle': ...
    def setPathResolver(self, resolver: QgsPathResolver) -> None: ...
    def pathResolver(self) -> QgsPathResolver: ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def distanceArea(self) -> QgsDistanceArea: ...
    def coordinateTransform(self) -> 'QgsCoordinateTransform': ...
    def isSymbolLayerEnabled(self, layer: 'QgsSymbolLayer|None') -> bool: ...
    def disabledSymbolLayersV2(self) -> set[str]: ...
    @deprecated("""""")
    def disabledSymbolLayers(self) -> set['QgsSymbolLayer']: ...
    def setDisabledSymbolLayersV2(self, symbolLayers: collections.abc.Iterable[str|None]) -> None: ...
    @deprecated("""""")
    def setDisabledSymbolLayers(self, symbolLayers: collections.abc.Iterable['QgsSymbolLayer']) -> None: ...
    def maskPainter(self, id: int = ...) -> QtGui.QPainter|None: ...
    def setPainterFlagsUsingContext(self, painter: QtGui.QPainter|None = ...) -> None: ...
    def previewRenderPainter(self) -> QtGui.QPainter|None: ...
    def painter(self) -> QtGui.QPainter|None: ...
    @staticmethod
    def fromQPainter(painter: QtGui.QPainter|None) -> 'QgsRenderContext': ...
    @staticmethod
    def fromMapSettings(mapSettings: QgsMapSettings) -> 'QgsRenderContext': ...
    def testFlag(self, flag: Qgis.RenderContextFlag) -> bool: ...
    def flags(self) -> Qgis.RenderContextFlag: ...
    def setFlag(self, flag: Qgis.RenderContextFlag, on: bool = ...) -> None: ...
    def setFlags(self, flags: Qgis.RenderContextFlag) -> None: ...


class QgsRenderedFeatureHandlerInterface(PyQt6.sip.wrapper):

    class RenderedFeatureContext(PyQt6.sip.wrapper):

        renderContext = ... # type: QgsRenderContext

        @typing.overload
        def __init__(self, renderContext: QgsRenderContext) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRenderedFeatureHandlerInterface.RenderedFeatureContext') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRenderedFeatureHandlerInterface') -> None: ...

    def usedAttributes(self, layer: QgsVectorLayer|None, context: QgsRenderContext) -> set[str]: ...
    def handleRenderedFeature(self, feature: QgsFeature, renderedBounds: 'QgsGeometry', context: 'QgsRenderedFeatureHandlerInterface.RenderedFeatureContext') -> None: ...


class QgsRenderedItemDetails(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, layerId: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRenderedItemDetails') -> None: ...

    def setBoundingBox(self, bounds: 'QgsRectangle') -> None: ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def layerId(self) -> str: ...


class QgsRenderedLayerStatistics(QgsRenderedItemDetails):

    @typing.overload
    def __init__(self, layerId: str|None, minimum: collections.abc.Iterable[float], maximum: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def __init__(self, layerId: str|None, minimum: float|None = ..., maximum: float|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRenderedLayerStatistics') -> None: ...

    @typing.overload
    def setMaximum(self, maximum: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def setMaximum(self, index: int, maximum: float) -> bool: ...
    @typing.overload
    def setMinimum(self, minimum: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def setMinimum(self, index: int, minimum: float) -> bool: ...
    @typing.overload
    def maximum(self) -> list[float]: ...
    @typing.overload
    def maximum(self, index: int) -> float: ...
    @typing.overload
    def minimum(self) -> list[float]: ...
    @typing.overload
    def minimum(self, index: int) -> float: ...
    def __repr__(self) -> typing.Any: ...


class QgsRunProcess(QtCore.QObject):

    def dialogGone(self) -> None: ...
    def processExit(self, a0: int, a1: QtCore.QProcess.ExitStatus) -> None: ...
    def processError(self, a0: QtCore.QProcess.ProcessError) -> None: ...
    def stderrAvailable(self) -> None: ...
    def stdoutAvailable(self) -> None: ...
    @staticmethod
    def splitCommand(command: str|None) -> list[str]: ...
    @staticmethod
    def create(action: str|None, capture: bool) -> 'QgsRunProcess|None': ...


class QgsBlockingProcess(QtCore.QObject):

    def __init__(self, program: str|None, arguments: collections.abc.Iterable[str|None]) -> None: ...

    def processError(self) -> QtCore.QProcess.ProcessError: ...
    def exitStatus(self) -> QtCore.QProcess.ExitStatus: ...
    def run(self, feedback: QgsFeedback|None = ...) -> int: ...
    def setStdErrHandler(self, a0: typing.Callable[..., None]) -> None: ...
    def setStdOutHandler(self, a0: typing.Callable[..., None]) -> None: ...


class QgsRuntimeProfiler(QtCore.QAbstractItemModel):

    def __init__(self) -> None: ...

    def groupAdded(self, group: str|None) -> None: ...
    def asText(self, group: str|None = ...) -> str: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    @staticmethod
    def translateGroupName(group: str|None) -> str: ...
    def groupIsActive(self, group: str|None) -> bool: ...
    def groups(self) -> set[str]: ...
    def totalTime(self, group: str|None = ...) -> float: ...
    def clear(self, group: str|None = ...) -> None: ...
    def profileTime(self, name: str|None, group: str|None = ...) -> float: ...
    def record(self, name: str|None, time: float, group: str|None = ..., id: str|None = ...) -> None: ...
    def end(self, group: str|None = ...) -> None: ...
    def start(self, name: str|None, group: str|None = ..., id: str|None = ...) -> None: ...
    def childGroups(self, parent: str|None = ..., group: str|None = ...) -> list[str]: ...
    @deprecated("""""")
    def endGroup(self) -> None: ...
    @deprecated("""""")
    def beginGroup(self, name: str|None) -> None: ...


class QgsScopedRuntimeProfile(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, group: str|None = ..., id: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScopedRuntimeProfile') -> None: ...

    def switchTask(self, name: str|None) -> None: ...


class QgsScaleCalculator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, dpi: float = ..., mapUnits: Qgis.DistanceUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScaleCalculator') -> None: ...

    def calculateGeographicDistanceAtLatitude(self, latitude: float, longitude1: float, longitude2: float) -> float: ...
    def calculateGeographicDistance(self, mapExtent: 'QgsRectangle') -> float: ...
    def calculateImageSize(self, mapExtent: 'QgsRectangle', scale: float) -> QtCore.QSizeF: ...
    def calculate(self, mapExtent: 'QgsRectangle', canvasWidth: float) -> float: ...
    def mapUnits(self) -> Qgis.DistanceUnit: ...
    def setMapUnits(self, mapUnits: Qgis.DistanceUnit) -> None: ...
    def dpi(self) -> float: ...
    def setDpi(self, dpi: float) -> None: ...
    def setMethod(self, method: Qgis.ScaleCalculationMethod) -> None: ...
    def method(self) -> Qgis.ScaleCalculationMethod: ...


class QgsScaleUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScaleUtils') -> None: ...

    @staticmethod
    def lessThanMaximumScale(scale: float, maxScale: float) -> bool: ...
    @staticmethod
    def equalToOrGreaterThanMinimumScale(scale: float, minScale: float) -> bool: ...
    @staticmethod
    def loadScaleList(fileName: str|None, scales: collections.abc.Iterable[str|None], errorMessage: str|None) -> bool: ...
    @staticmethod
    def saveScaleList(fileName: str|None, scales: collections.abc.Iterable[str|None], errorMessage: str|None) -> bool: ...


class QgsScreenProperties(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, screen: QtGui.QScreen|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScreenProperties') -> None: ...

    def updateRenderContextForScreen(self, context: QgsRenderContext) -> None: ...
    def setPhysicalDpi(self, dpi: float) -> None: ...
    def physicalDpi(self) -> float: ...
    def setDevicePixelRatio(self, ratio: float) -> None: ...
    def devicePixelRatio(self) -> float: ...
    def isValid(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsSelectionContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSelectionContext') -> None: ...

    def setScale(self, scale: float) -> None: ...
    def scale(self) -> float: ...


class QgsSimplifyMethod(PyQt6.sip.wrapper):

    class MethodType(enum.IntEnum):
        NoSimplification = ... # type: QgsSimplifyMethod.MethodType
        OptimizeForRendering = ... # type: QgsSimplifyMethod.MethodType
        PreserveTopology = ... # type: QgsSimplifyMethod.MethodType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSimplifyMethod') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def createGeometrySimplifier(simplifyMethod: 'QgsSimplifyMethod') -> QgsAbstractGeometrySimplifier|None: ...
    def forceLocalOptimization(self) -> bool: ...
    def setForceLocalOptimization(self, localOptimization: bool) -> None: ...
    def threshold(self) -> float: ...
    def setThreshold(self, threshold: float) -> None: ...
    def tolerance(self) -> float: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def methodType(self) -> 'QgsSimplifyMethod.MethodType': ...
    def setMethodType(self, methodType: 'QgsSimplifyMethod.MethodType') -> None: ...


class QgsSingleItemModel(QtCore.QAbstractItemModel):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ..., text: str|None = ..., data: dict[int, typing.Any] = ..., flags: QtCore.Qt.ItemFlag = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtCore.QObject|None, columnData: typing.Any, flags: QtCore.Qt.ItemFlag = ...) -> None: ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...


class QgsSipUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSipUtils') -> None: ...

    @staticmethod
    def isPyOwned(a0: typing.Any) -> bool: ...


class QgsSldExportContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSldExportContext') -> None: ...
    @typing.overload
    def __init__(self, options: Qgis.SldExportOption, vendorExtension: Qgis.SldExportVendorExtension, filePath: str|None) -> None: ...

    def setExtraProperties(self, properties: dict[str|None, typing.Any]) -> None: ...
    def extraProperties(self) -> dict[str, typing.Any]: ...
    def pushWarning(self, warning: str|None) -> None: ...
    def warnings(self) -> list[str]: ...
    def pushError(self, error: str|None) -> None: ...
    def errors(self) -> list[str]: ...
    def setExportFilePath(self, exportFilePath: str|None) -> None: ...
    def exportFilePath(self) -> str: ...
    def setVendorExtension(self, vendorExtension: Qgis.SldExportVendorExtension) -> None: ...
    def vendorExtensions(self) -> Qgis.SldExportVendorExtension: ...
    def setExportOptions(self, exportOptions: Qgis.SldExportOption) -> None: ...
    def exportOptions(self) -> Qgis.SldExportOption: ...


class QgsSnappingConfig(PyQt6.sip.wrapper):

    class ScaleDependencyMode(enum.IntEnum):
        Disabled = ... # type: QgsSnappingConfig.ScaleDependencyMode
        Global = ... # type: QgsSnappingConfig.ScaleDependencyMode
        PerLayer = ... # type: QgsSnappingConfig.ScaleDependencyMode

    class SnappingType(enum.IntEnum):
        Vertex = ... # type: QgsSnappingConfig.SnappingType
        VertexAndSegment = ... # type: QgsSnappingConfig.SnappingType
        Segment = ... # type: QgsSnappingConfig.SnappingType

    class IndividualLayerSettings(PyQt6.sip.wrapper):

        @typing.overload
        @deprecated("""""")
        def __init__(self, enabled: bool, type: 'QgsSnappingConfig.SnappingType', tolerance: float, units: Qgis.MapToolUnit) -> None: ...
        @typing.overload
        def __init__(self, enabled: bool, type: Qgis.SnappingType, tolerance: float, units: Qgis.MapToolUnit, minScale: float = ..., maxScale: float = ...) -> None: ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSnappingConfig.IndividualLayerSettings') -> None: ...

        def __eq__(self, other: object): ...
        def __ne__(self, other: object): ...
        def setMaximumScale(self, maxScale: float) -> None: ...
        def maximumScale(self) -> float: ...
        def setMinimumScale(self, minScale: float) -> None: ...
        def minimumScale(self) -> float: ...
        def setUnits(self, units: Qgis.MapToolUnit) -> None: ...
        def units(self) -> Qgis.MapToolUnit: ...
        def setTolerance(self, tolerance: float) -> None: ...
        def tolerance(self) -> float: ...
        def setTypeFlag(self, type: Qgis.SnappingType) -> None: ...
        @deprecated("""""")
        def setType(self, type: 'QgsSnappingConfig.SnappingType') -> None: ...
        @deprecated("""""")
        def type(self) -> 'QgsSnappingConfig.SnappingType': ...
        def typeFlag(self) -> Qgis.SnappingType: ...
        def setEnabled(self, enabled: bool) -> None: ...
        def enabled(self) -> bool: ...
        def valid(self) -> bool: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSnappingConfig') -> None: ...

    def setProject(self, project: 'QgsProject|None') -> None: ...
    def project(self) -> 'QgsProject|None': ...
    def removeLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> bool: ...
    def addLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> bool: ...
    def writeProject(self, doc: QtXml.QDomDocument) -> None: ...
    def readProject(self, doc: QtXml.QDomDocument) -> None: ...
    def __ne__(self, other: object): ...
    def clearIndividualLayerSettings(self) -> None: ...
    def setIndividualLayerSettings(self, vl: QgsVectorLayer|None, individualLayerSettings: 'QgsSnappingConfig.IndividualLayerSettings') -> None: ...
    @typing.overload
    def individualLayerSettings(self) -> dict: ...
    @typing.overload
    def individualLayerSettings(self, vl: QgsVectorLayer|None) -> 'QgsSnappingConfig.IndividualLayerSettings': ...
    def setSelfSnapping(self, enabled: bool) -> None: ...
    def selfSnapping(self) -> bool: ...
    def setIntersectionSnapping(self, enabled: bool) -> None: ...
    def intersectionSnapping(self) -> bool: ...
    def setUnits(self, units: Qgis.MapToolUnit) -> None: ...
    def units(self) -> Qgis.MapToolUnit: ...
    def scaleDependencyMode(self) -> 'QgsSnappingConfig.ScaleDependencyMode': ...
    def setScaleDependencyMode(self, mode: 'QgsSnappingConfig.ScaleDependencyMode') -> None: ...
    def setMaximumScale(self, maxScale: float) -> None: ...
    def maximumScale(self) -> float: ...
    def setMinimumScale(self, minScale: float) -> None: ...
    def minimumScale(self) -> float: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def tolerance(self) -> float: ...
    def setTypeFlag(self, type: Qgis.SnappingType) -> None: ...
    def setType(self, type: 'QgsSnappingConfig.SnappingType') -> None: ...
    @deprecated("""""")
    def type(self) -> 'QgsSnappingConfig.SnappingType': ...
    def typeFlag(self) -> Qgis.SnappingType: ...
    def setMode(self, mode: Qgis.SnappingMode) -> None: ...
    def mode(self) -> Qgis.SnappingMode: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def reset(self) -> None: ...
    def __eq__(self, other: object): ...
    @staticmethod
    @deprecated("""""")
    def snappingTypeFlagToIcon(type: Qgis.SnappingType) -> QtGui.QIcon: ...
    @staticmethod
    def snappingTypeToIcon(type: Qgis.SnappingType) -> QtGui.QIcon: ...
    @staticmethod
    @deprecated("""""")
    def snappingTypeFlagToString(type: Qgis.SnappingType) -> str: ...
    @staticmethod
    def snappingTypeToString(type: Qgis.SnappingType) -> str: ...


class QgsSnappingUtils(QtCore.QObject):

    class IndexingStrategy(enum.IntEnum):
        IndexAlwaysFull = ... # type: QgsSnappingUtils.IndexingStrategy
        IndexNeverFull = ... # type: QgsSnappingUtils.IndexingStrategy
        IndexHybrid = ... # type: QgsSnappingUtils.IndexingStrategy
        IndexExtent = ... # type: QgsSnappingUtils.IndexingStrategy

    class LayerConfig(PyQt6.sip.wrapper):

        layer = ... # type: QgsVectorLayer
        tolerance = ... # type: float
        type = ... # type: QgsPointLocator.Type
        unit = ... # type: Qgis.MapToolUnit

        @typing.overload
        def __init__(self, l: QgsVectorLayer|None, t: QgsPointLocator.Type, tol: float, u: Qgis.MapToolUnit) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSnappingUtils.LayerConfig') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    def __init__(self, parent: QtCore.QObject|None = ..., enableSnappingForInvisibleFeature: bool = ...) -> None: ...

    def clearAllLocators(self) -> None: ...
    def prepareIndexProgress(self, index: int) -> None: ...
    def prepareIndexStarting(self, count: int) -> None: ...
    configChanged: typing.ClassVar[QtCore.pyqtSignal]
    def toggleEnabled(self) -> None: ...
    def setConfig(self, snappingConfig: QgsSnappingConfig) -> None: ...
    def getExtraSnapLayers(self) -> set[QgsVectorLayer]: ...
    def removeExtraSnapLayer(self, vl: QgsVectorLayer|None) -> None: ...
    def addExtraSnapLayer(self, vl: QgsVectorLayer|None) -> None: ...
    def setEnableSnappingForInvisibleFeature(self, enable: bool) -> None: ...
    def config(self) -> QgsSnappingConfig: ...
    def dump(self) -> str: ...
    def layers(self) -> list['QgsSnappingUtils.LayerConfig']: ...
    def indexingStrategy(self) -> 'QgsSnappingUtils.IndexingStrategy': ...
    def setIndexingStrategy(self, strategy: 'QgsSnappingUtils.IndexingStrategy') -> None: ...
    def currentLayer(self) -> QgsVectorLayer|None: ...
    def setCurrentLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def mapSettings(self) -> QgsMapSettings: ...
    def setMapSettings(self, settings: QgsMapSettings) -> None: ...
    def snapToCurrentLayer(self, point: QtCore.QPoint, type: QgsPointLocator.Type, filter: QgsPointLocator.MatchFilter|None = ...) -> QgsPointLocator.Match: ...
    @typing.overload
    def snapToMap(self, point: QtCore.QPoint, filter: QgsPointLocator.MatchFilter|None = ..., relaxed: bool = ...) -> QgsPointLocator.Match: ...
    @typing.overload
    def snapToMap(self, pointMap: QgsPointXY, filter: QgsPointLocator.MatchFilter|None = ..., relaxed: bool = ...) -> QgsPointLocator.Match: ...
    def locatorForLayer(self, vl: QgsVectorLayer|None) -> QgsPointLocator|None: ...


class QgsSpatialIndex(QgsFeatureSink):

    class Flag(enum.IntEnum):
        FlagStoreFeatureGeometries = ... # type: QgsSpatialIndex.Flag

    @typing.overload
    def __init__(self, flags: 'QgsSpatialIndex.Flag' = ...) -> None: ...
    @typing.overload
    def __init__(self, fi: QgsFeatureIterator, feedback: QgsFeedback|None = ..., flags: 'QgsSpatialIndex.Flag' = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QgsFeatureSource, feedback: QgsFeedback|None = ..., flags: 'QgsSpatialIndex.Flag' = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSpatialIndex') -> None: ...

    def refs(self) -> int: ...
    def geometry(self, id: int) -> 'QgsGeometry': ...
    @typing.overload
    def nearestNeighbor(self, point: QgsPointXY, neighbors: int = ..., maxDistance: float = ...) -> list[int]: ...
    @typing.overload
    def nearestNeighbor(self, geometry: 'QgsGeometry', neighbors: int = ..., maxDistance: float = ...) -> list[int]: ...
    def intersects(self, rectangle: 'QgsRectangle') -> list[int]: ...
    @typing.overload
    def deleteFeature(self, feature: QgsFeature) -> bool: ...
    @typing.overload
    def deleteFeature(self, id: int, bounds: 'QgsRectangle') -> bool: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    @typing.overload
    def addFeature(self, feature: QgsFeature, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    @typing.overload
    def addFeature(self, id: int, bounds: 'QgsRectangle') -> bool: ...
    @typing.overload
    @deprecated("""""")
    def insertFeature(self, feature: QgsFeature) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def insertFeature(self, id: int, bounds: 'QgsRectangle') -> bool: ...


class QgsSpatialIndexKDBush(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, fi: QgsFeatureIterator, feedback: QgsFeedback|None = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QgsFeatureSource, feedback: QgsFeedback|None = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSpatialIndexKDBush') -> None: ...

    def size(self) -> int: ...
    def within(self, point: QgsPointXY, radius: float) -> list['QgsSpatialIndexKDBushData']: ...
    def intersects(self, rectangle: 'QgsRectangle') -> list['QgsSpatialIndexKDBushData']: ...
    def finalize(self) -> None: ...
    def addFeature(self, id: int, point: QgsPointXY) -> bool: ...


class QgsSpatialIndexKDBushData(PyQt6.sip.wrapper):

    id = ... # type: int

    @typing.overload
    def __init__(self, id: int, x: float, y: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSpatialIndexKDBushData') -> None: ...

    def point(self) -> QgsPointXY: ...


class QgsSourceCache(QgsAbstractContentCacheBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    remoteSourceFetched: typing.ClassVar[QtCore.pyqtSignal]
    def localFilePath(self, path: str|None, blocking: bool = ...) -> str: ...


class QgsSqliteUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSqliteUtils') -> None: ...

    @staticmethod
    def systemTables() -> list[str]: ...
    @staticmethod
    def quotedValue(value: typing.Any) -> str: ...
    @staticmethod
    def quotedIdentifier(identifier: str|None) -> str: ...
    @staticmethod
    def quotedString(value: str|None) -> str: ...


class QgsSQLStatement(PyQt6.sip.wrapper):

    class NodeType(enum.IntEnum):
        ntUnaryOperator = ... # type: QgsSQLStatement.NodeType
        ntBinaryOperator = ... # type: QgsSQLStatement.NodeType
        ntInOperator = ... # type: QgsSQLStatement.NodeType
        ntBetweenOperator = ... # type: QgsSQLStatement.NodeType
        ntFunction = ... # type: QgsSQLStatement.NodeType
        ntLiteral = ... # type: QgsSQLStatement.NodeType
        ntColumnRef = ... # type: QgsSQLStatement.NodeType
        ntSelectedColumn = ... # type: QgsSQLStatement.NodeType
        ntSelect = ... # type: QgsSQLStatement.NodeType
        ntTableDef = ... # type: QgsSQLStatement.NodeType
        ntJoin = ... # type: QgsSQLStatement.NodeType
        ntColumnSorted = ... # type: QgsSQLStatement.NodeType
        ntCast = ... # type: QgsSQLStatement.NodeType

    class JoinType(enum.IntEnum):
        jtDefault = ... # type: QgsSQLStatement.JoinType
        jtLeft = ... # type: QgsSQLStatement.JoinType
        jtLeftOuter = ... # type: QgsSQLStatement.JoinType
        jtRight = ... # type: QgsSQLStatement.JoinType
        jtRightOuter = ... # type: QgsSQLStatement.JoinType
        jtCross = ... # type: QgsSQLStatement.JoinType
        jtInner = ... # type: QgsSQLStatement.JoinType
        jtFull = ... # type: QgsSQLStatement.JoinType

    class BinaryOperator(enum.IntEnum):
        boOr = ... # type: QgsSQLStatement.BinaryOperator
        boAnd = ... # type: QgsSQLStatement.BinaryOperator
        boEQ = ... # type: QgsSQLStatement.BinaryOperator
        boNE = ... # type: QgsSQLStatement.BinaryOperator
        boLE = ... # type: QgsSQLStatement.BinaryOperator
        boGE = ... # type: QgsSQLStatement.BinaryOperator
        boLT = ... # type: QgsSQLStatement.BinaryOperator
        boGT = ... # type: QgsSQLStatement.BinaryOperator
        boLike = ... # type: QgsSQLStatement.BinaryOperator
        boNotLike = ... # type: QgsSQLStatement.BinaryOperator
        boILike = ... # type: QgsSQLStatement.BinaryOperator
        boNotILike = ... # type: QgsSQLStatement.BinaryOperator
        boIs = ... # type: QgsSQLStatement.BinaryOperator
        boIsNot = ... # type: QgsSQLStatement.BinaryOperator
        boPlus = ... # type: QgsSQLStatement.BinaryOperator
        boMinus = ... # type: QgsSQLStatement.BinaryOperator
        boMul = ... # type: QgsSQLStatement.BinaryOperator
        boDiv = ... # type: QgsSQLStatement.BinaryOperator
        boIntDiv = ... # type: QgsSQLStatement.BinaryOperator
        boMod = ... # type: QgsSQLStatement.BinaryOperator
        boPow = ... # type: QgsSQLStatement.BinaryOperator
        boConcat = ... # type: QgsSQLStatement.BinaryOperator

    class UnaryOperator(enum.IntEnum):
        uoNot = ... # type: QgsSQLStatement.UnaryOperator
        uoMinus = ... # type: QgsSQLStatement.UnaryOperator

    class Node(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.Node') -> None: ...

        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...

    class NodeList(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.NodeList') -> None: ...

        def dump(self) -> str: ...
        def clone(self) -> 'QgsSQLStatement.NodeList|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def count(self) -> int: ...
        def list(self) -> list['QgsSQLStatement.Node']: ...
        def append(self, node: 'QgsSQLStatement.Node|None') -> None: ...

    class NodeUnaryOperator('QgsSQLStatement.Node'):

        def __init__(self, op: 'QgsSQLStatement.UnaryOperator', operand: 'QgsSQLStatement.Node|None') -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def operand(self) -> 'QgsSQLStatement.Node|None': ...
        def op(self) -> 'QgsSQLStatement.UnaryOperator': ...

    class NodeBinaryOperator('QgsSQLStatement.Node'):

        def __init__(self, op: 'QgsSQLStatement.BinaryOperator', opLeft: 'QgsSQLStatement.Node|None', opRight: 'QgsSQLStatement.Node|None') -> None: ...

        def leftAssociative(self) -> bool: ...
        def precedence(self) -> int: ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def opRight(self) -> 'QgsSQLStatement.Node|None': ...
        def opLeft(self) -> 'QgsSQLStatement.Node|None': ...
        def op(self) -> 'QgsSQLStatement.BinaryOperator': ...

    class NodeInOperator('QgsSQLStatement.Node'):

        def __init__(self, node: 'QgsSQLStatement.Node|None', list: 'QgsSQLStatement.NodeList|None', notin: bool = ...) -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def list(self) -> 'QgsSQLStatement.NodeList|None': ...
        def isNotIn(self) -> bool: ...
        def node(self) -> 'QgsSQLStatement.Node|None': ...

    class NodeBetweenOperator('QgsSQLStatement.Node'):

        def __init__(self, node: 'QgsSQLStatement.Node|None', minVal: 'QgsSQLStatement.Node|None', maxVal: 'QgsSQLStatement.Node|None', notBetween: bool = ...) -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def maxVal(self) -> 'QgsSQLStatement.Node|None': ...
        def minVal(self) -> 'QgsSQLStatement.Node|None': ...
        def isNotBetween(self) -> bool: ...
        def node(self) -> 'QgsSQLStatement.Node|None': ...

    class NodeFunction('QgsSQLStatement.Node'):

        def __init__(self, name: str|None, args: 'QgsSQLStatement.NodeList|None') -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def args(self) -> 'QgsSQLStatement.NodeList|None': ...
        def name(self) -> str: ...

    class NodeLiteral('QgsSQLStatement.Node'):

        @typing.overload
        def __init__(self, value: typing.Any) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.NodeLiteral') -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def value(self) -> typing.Any: ...

    class NodeColumnRef('QgsSQLStatement.Node'):

        @typing.overload
        def __init__(self, name: str|None, star: bool) -> None: ...
        @typing.overload
        def __init__(self, tableName: str|None, name: str|None, star: bool) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.NodeColumnRef') -> None: ...

        def cloneThis(self) -> 'QgsSQLStatement.NodeColumnRef|None': ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def distinct(self) -> bool: ...
        def star(self) -> bool: ...
        def name(self) -> str: ...
        def tableName(self) -> str: ...
        def setDistinct(self, distinct: bool = ...) -> None: ...

    class NodeSelectedColumn('QgsSQLStatement.Node'):

        def __init__(self, node: 'QgsSQLStatement.Node|None') -> None: ...

        def cloneThis(self) -> 'QgsSQLStatement.NodeSelectedColumn|None': ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def alias(self) -> str: ...
        def column(self) -> 'QgsSQLStatement.Node|None': ...
        def setAlias(self, alias: str|None) -> None: ...

    class NodeCast('QgsSQLStatement.Node'):

        def __init__(self, node: 'QgsSQLStatement.Node|None', type: str|None) -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def type(self) -> str: ...
        def node(self) -> 'QgsSQLStatement.Node|None': ...

    class NodeTableDef('QgsSQLStatement.Node'):

        @typing.overload
        def __init__(self, name: str|None) -> None: ...
        @typing.overload
        def __init__(self, name: str|None, alias: str|None) -> None: ...
        @typing.overload
        def __init__(self, schema: str|None, name: str|None, alias: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.NodeTableDef') -> None: ...

        def cloneThis(self) -> 'QgsSQLStatement.NodeTableDef|None': ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def alias(self) -> str: ...
        def schema(self) -> str: ...
        def name(self) -> str: ...

    class NodeJoin('QgsSQLStatement.Node'):

        @typing.overload
        def __init__(self, tabledef: 'QgsSQLStatement.NodeTableDef|None', onExpr: 'QgsSQLStatement.Node|None', type: 'QgsSQLStatement.JoinType') -> None: ...
        @typing.overload
        def __init__(self, tabledef: 'QgsSQLStatement.NodeTableDef|None', usingColumns: collections.abc.Iterable[str|None], type: 'QgsSQLStatement.JoinType') -> None: ...

        def cloneThis(self) -> 'QgsSQLStatement.NodeJoin|None': ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def type(self) -> 'QgsSQLStatement.JoinType': ...
        def usingColumns(self) -> list[str]: ...
        def onExpr(self) -> 'QgsSQLStatement.Node|None': ...
        def tableDef(self) -> 'QgsSQLStatement.NodeTableDef|None': ...

    class NodeColumnSorted('QgsSQLStatement.Node'):

        def __init__(self, column: 'QgsSQLStatement.NodeColumnRef|None', asc: bool) -> None: ...

        def cloneThis(self) -> 'QgsSQLStatement.NodeColumnSorted|None': ...
        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def ascending(self) -> bool: ...
        def column(self) -> 'QgsSQLStatement.NodeColumnRef|None': ...

    class NodeSelect('QgsSQLStatement.Node'):

        def __init__(self, tableList: collections.abc.Iterable['QgsSQLStatement.NodeTableDef'], columns: collections.abc.Iterable['QgsSQLStatement.NodeSelectedColumn'], distinct: bool) -> None: ...

        def clone(self) -> 'QgsSQLStatement.Node|None': ...
        def accept(self, v: 'QgsSQLStatement.Visitor') -> None: ...
        def dump(self) -> str: ...
        def nodeType(self) -> 'QgsSQLStatement.NodeType': ...
        def orderBy(self) -> list['QgsSQLStatement.NodeColumnSorted']: ...
        def where(self) -> 'QgsSQLStatement.Node|None': ...
        def joins(self) -> list['QgsSQLStatement.NodeJoin']: ...
        def distinct(self) -> bool: ...
        def columns(self) -> list['QgsSQLStatement.NodeSelectedColumn']: ...
        def tables(self) -> list['QgsSQLStatement.NodeTableDef']: ...
        def setOrderBy(self, orderBy: collections.abc.Iterable['QgsSQLStatement.NodeColumnSorted']) -> None: ...
        def setWhere(self, where: 'QgsSQLStatement.Node|None') -> None: ...
        def appendJoin(self, join: 'QgsSQLStatement.NodeJoin|None') -> None: ...
        def setJoins(self, joins: collections.abc.Iterable['QgsSQLStatement.NodeJoin']) -> None: ...

    class Visitor(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.Visitor') -> None: ...

        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeUnaryOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeBinaryOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeInOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeBetweenOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeFunction') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeLiteral') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeColumnRef') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeSelectedColumn') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeTableDef') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeSelect') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeJoin') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeColumnSorted') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeCast') -> None: ...

    class RecursiveVisitor('QgsSQLStatement.Visitor'):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSQLStatement.RecursiveVisitor') -> None: ...

        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeUnaryOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeBinaryOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeInOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeBetweenOperator') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeFunction') -> None: ...
        @typing.overload
        def visit(self, a0: 'QgsSQLStatement.NodeLiteral') -> None: ...
        @typing.overload
        def visit(self, a0: 'QgsSQLStatement.NodeColumnRef') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeSelectedColumn') -> None: ...
        @typing.overload
        def visit(self, a0: 'QgsSQLStatement.NodeTableDef') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeSelect') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeJoin') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeColumnSorted') -> None: ...
        @typing.overload
        def visit(self, n: 'QgsSQLStatement.NodeCast') -> None: ...

    @typing.overload
    def __init__(self, statement: str|None) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSQLStatement') -> None: ...
    @typing.overload
    def __init__(self, statement: str|None, allowFragments: bool) -> None: ...

    def acceptVisitor(self, v: 'QgsSQLStatement.Visitor') -> None: ...
    @staticmethod
    def quotedString(text: str|None) -> str: ...
    @staticmethod
    def stripMsQuotedIdentifier(text: str|None) -> str: ...
    @staticmethod
    def stripQuotedIdentifier(text: str|None) -> str: ...
    @staticmethod
    def quotedIdentifierIfNeeded(name: str|None) -> str: ...
    @staticmethod
    def quotedIdentifier(name: str|None) -> str: ...
    def dump(self) -> str: ...
    def statement(self) -> str: ...
    def rootNode(self) -> 'QgsSQLStatement.Node|None': ...
    def doBasicValidationChecks(self) -> typing.Tuple[bool, str]: ...
    def parserErrorString(self) -> str: ...
    def hasParserError(self) -> bool: ...


class QgsSQLStatementFragment(QgsSQLStatement):

    @typing.overload
    def __init__(self, fragment: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSQLStatementFragment') -> None: ...


class QgsStatisticalSummary(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, stats: Qgis.Statistic = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStatisticalSummary') -> None: ...

    @staticmethod
    def shortName(statistic: Qgis.Statistic) -> str: ...
    @staticmethod
    def displayName(statistic: Qgis.Statistic) -> str: ...
    def interQuartileRange(self) -> float: ...
    def thirdQuartile(self) -> float: ...
    def firstQuartile(self) -> float: ...
    def majority(self) -> float: ...
    def minority(self) -> float: ...
    def variety(self) -> int: ...
    def sampleStDev(self) -> float: ...
    def stDev(self) -> float: ...
    def last(self) -> float: ...
    def first(self) -> float: ...
    def range(self) -> float: ...
    def max(self) -> float: ...
    def min(self) -> float: ...
    def median(self) -> float: ...
    def mean(self) -> float: ...
    def sum(self) -> float: ...
    def countMissing(self) -> int: ...
    def count(self) -> int: ...
    def statistic(self, stat: Qgis.Statistic) -> float: ...
    def finalize(self) -> None: ...
    def addVariant(self, value: typing.Any) -> None: ...
    def addValue(self, value: float) -> None: ...
    def calculate(self, values: collections.abc.Iterable[float]) -> None: ...
    def reset(self) -> None: ...
    def setStatistics(self, stats: Qgis.Statistic) -> None: ...
    def statistics(self) -> Qgis.Statistic: ...


class QgsStoredExpression(PyQt6.sip.wrapper):

    class Category(enum.IntEnum):
        FilterExpression = ... # type: QgsStoredExpression.Category
        DefaultValueExpression = ... # type: QgsStoredExpression.Category
        All = ... # type: QgsStoredExpression.Category

    expression = ... # type: str|None
    id = ... # type: str|None
    name = ... # type: str|None
    tag = ... # type: 'QgsStoredExpression.Category'

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStoredExpression') -> None: ...


class QgsStoredExpressionManager(QtCore.QObject):

    def __init__(self) -> None: ...

    def readXml(self, layerNode: QtXml.QDomNode) -> bool: ...
    def writeXml(self, layerNode: QtXml.QDomNode) -> bool: ...
    def clearStoredExpressions(self) -> None: ...
    def findStoredExpressionByExpression(self, expression: str|None, tag: QgsStoredExpression.Category = ...) -> QgsStoredExpression: ...
    def storedExpression(self, id: str|None) -> QgsStoredExpression: ...
    def storedExpressions(self, tag: QgsStoredExpression.Category = ...) -> list[QgsStoredExpression]: ...
    def addStoredExpressions(self, storedExpressions: collections.abc.Iterable[QgsStoredExpression]) -> None: ...
    def updateStoredExpression(self, id: str|None, name: str|None, expression: str|None, tag: QgsStoredExpression.Category) -> None: ...
    def removeStoredExpression(self, id: str|None) -> None: ...
    def addStoredExpression(self, name: str|None, expression: str|None, tag: QgsStoredExpression.Category = ...) -> str: ...


class QgsStringStatisticalSummary(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, stats: Qgis.StringStatistic = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStringStatisticalSummary') -> None: ...

    @staticmethod
    def displayName(statistic: Qgis.StringStatistic) -> str: ...
    def majority(self) -> str: ...
    def minority(self) -> str: ...
    def meanLength(self) -> float: ...
    def maxLength(self) -> int: ...
    def minLength(self) -> int: ...
    def max(self) -> str: ...
    def min(self) -> str: ...
    def countMissing(self) -> int: ...
    def distinctValues(self) -> set[str]: ...
    def countDistinct(self) -> int: ...
    def count(self) -> int: ...
    def statistic(self, stat: Qgis.StringStatistic) -> typing.Any: ...
    def finalize(self) -> None: ...
    def addValue(self, value: typing.Any) -> None: ...
    def addString(self, string: str|None) -> None: ...
    def calculateFromVariants(self, values: collections.abc.Iterable[typing.Any]) -> None: ...
    def calculate(self, values: collections.abc.Iterable[str|None]) -> None: ...
    def reset(self) -> None: ...
    def setStatistics(self, stats: Qgis.StringStatistic) -> None: ...
    def statistics(self) -> Qgis.StringStatistic: ...


class QgsStringReplacement(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, match: str|None, replacement: str|None, caseSensitive: bool = ..., wholeWordOnly: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStringReplacement') -> None: ...

    def __ne__(self, other: object): ...
    @staticmethod
    def fromProperties(properties: dict[str|None, str|None]) -> 'QgsStringReplacement': ...
    def properties(self) -> dict[str, str]: ...
    def __eq__(self, other: object): ...
    def process(self, input: str|None) -> str: ...
    def wholeWordOnly(self) -> bool: ...
    def caseSensitive(self) -> bool: ...
    def replacement(self) -> str: ...
    def match(self) -> str: ...


class QgsStringReplacementCollection(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, replacements: collections.abc.Iterable[QgsStringReplacement] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStringReplacementCollection') -> None: ...

    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument) -> None: ...
    def process(self, input: str|None) -> str: ...
    def setReplacements(self, replacements: collections.abc.Iterable[QgsStringReplacement]) -> None: ...
    def replacements(self) -> list[QgsStringReplacement]: ...


class QgsStringUtils(PyQt6.sip.wrapper):

    UNACCENT_MAP = ... # type: dict[str|None, str|None]

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStringUtils') -> None: ...

    @staticmethod
    def unaccent(input: str|None) -> str: ...
    @staticmethod
    def createUnaccentMap() -> dict[str, str]: ...
    @staticmethod
    def containsByWord(candidate: str|None, words: str|None, sensitivity: QtCore.Qt.CaseSensitivity = ...) -> bool: ...
    @staticmethod
    def truncateMiddleOfString(string: str|None, maxLength: int) -> str: ...
    @staticmethod
    def qRegExpEscape(string: str|None) -> str: ...
    @staticmethod
    def htmlToMarkdown(html: str|None) -> str: ...
    @staticmethod
    def substituteVerticalCharacters(string: str|None) -> str: ...
    @staticmethod
    def wordWrap(string: str|None, length: int, useMaxLineLength: bool = ..., customDelimiter: str|None = ...) -> str: ...
    @staticmethod
    def isUrl(string: str|None) -> bool: ...
    @staticmethod
    def insertLinks(string: str|None) -> typing.Tuple[str, bool]: ...
    @staticmethod
    def fuzzyScore(candidate: str|None, search: str|None) -> float: ...
    @staticmethod
    def soundex(string: str|None) -> str: ...
    @staticmethod
    def hammingDistance(string1: str|None, string2: str|None, caseSensitive: bool = ...) -> int: ...
    @staticmethod
    def longestCommonSubstring(string1: str|None, string2: str|None, caseSensitive: bool = ...) -> str: ...
    @staticmethod
    def levenshteinDistance(string1: str|None, string2: str|None, caseSensitive: bool = ...) -> int: ...
    @staticmethod
    def ampersandEncode(string: str|None) -> str: ...
    @staticmethod
    def capitalize(string: str|None, capitalization: Qgis.Capitalization) -> str: ...


class QgsTableCell(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, content: typing.Any = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTableCell') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def setProperties(self, properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def properties(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def columnSpan(self) -> int: ...
    def rowSpan(self) -> int: ...
    def setSpan(self, rowSpan: int, columnSpan: int) -> None: ...
    def setVerticalAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def verticalAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setHorizontalAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def horizontalAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setNumericFormat(self, format: 'QgsNumericFormat|None') -> None: ...
    def numericFormat(self) -> 'QgsNumericFormat|None': ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def setForegroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def foregroundColor(self) -> QtGui.QColor: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def backgroundColor(self) -> QtGui.QColor: ...
    def setContent(self, content: typing.Any) -> None: ...
    def content(self) -> typing.Any: ...


class QgsTaskManager(QtCore.QObject):

    class TaskDefinition(PyQt6.sip.wrapper):

        dependentTasks = ... # type: collections.abc.Iterable[QgsTask]
        task = ... # type: QgsTask

        @typing.overload
        def __init__(self, task: QgsTask|None, dependentTasks: collections.abc.Iterable[QgsTask] = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsTaskManager.TaskDefinition') -> None: ...

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    taskTriggered: typing.ClassVar[QtCore.pyqtSignal]
    countActiveTasksChanged: typing.ClassVar[QtCore.pyqtSignal]
    allTasksFinished: typing.ClassVar[QtCore.pyqtSignal]
    taskAboutToBeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    taskAdded: typing.ClassVar[QtCore.pyqtSignal]
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    finalTaskProgressChanged: typing.ClassVar[QtCore.pyqtSignal]
    progressChanged: typing.ClassVar[QtCore.pyqtSignal]
    def triggerTask(self, task: QgsTask|None) -> None: ...
    def countActiveTasks(self, includeHidden: bool = ...) -> int: ...
    def activeTasks(self) -> list[QgsTask]: ...
    def tasksDependentOnLayer(self, layer: QgsMapLayer|None) -> list[QgsTask]: ...
    def dependentLayers(self, taskId: int) -> list[QgsMapLayer]: ...
    def dependenciesSatisfied(self, taskId: int) -> bool: ...
    def cancelAll(self) -> None: ...
    def taskId(self, task: QgsTask|None) -> int: ...
    def count(self) -> int: ...
    def tasks(self) -> list[QgsTask]: ...
    def task(self, id: int) -> QgsTask|None: ...
    @typing.overload
    def addTask(self, task: QgsTask|None, priority: int = ...) -> int: ...
    @typing.overload
    def addTask(self, task: 'QgsTaskManager.TaskDefinition', priority: int = ...) -> int: ...
    def threadPool(self) -> QtCore.QThreadPool|None: ...


class QgsTaskWithSerialSubTasks(QgsTask):

    def __init__(self, desc: str|None = ...) -> None: ...

    def run(self) -> bool: ...
    def cancel(self) -> None: ...
    def addSubTask(self, subTask: QgsTask|None) -> None: ...


class QgsTemporalController(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    updateTemporalRange: typing.ClassVar[QtCore.pyqtSignal]


class QgsTemporalNavigationObject(QgsTemporalController, QgsExpressionContextScopeGenerator):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def skipToEnd(self) -> None: ...
    def rewindToStart(self) -> None: ...
    def previous(self) -> None: ...
    def next(self) -> None: ...
    def playBackward(self) -> None: ...
    def playForward(self) -> None: ...
    def pause(self) -> None: ...
    def play(self) -> None: ...
    totalMovieFramesChanged: typing.ClassVar[QtCore.pyqtSignal]
    temporalFrameDurationChanged: typing.ClassVar[QtCore.pyqtSignal]
    temporalExtentsChanged: typing.ClassVar[QtCore.pyqtSignal]
    navigationModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    stateChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTotalMovieFrames(self, frames: int) -> None: ...
    def totalMovieFrames(self) -> int: ...
    def createExpressionContextScope(self) -> QgsExpressionContextScope|None: ...
    def findBestFrameNumberForFrameStart(self, frameStart: QtCore.QDateTime|datetime.datetime) -> int: ...
    def setLooping(self, loop: bool) -> None: ...
    def isLooping(self) -> bool: ...
    def totalFrameCount(self) -> int: ...
    def temporalRangeCumulative(self) -> bool: ...
    def setTemporalRangeCumulative(self, state: bool) -> None: ...
    def framesPerSecond(self) -> float: ...
    def setFramesPerSecond(self, rate: float) -> None: ...
    def dateTimeRangeForFrameNumber(self, frame: int) -> QgsDateTimeRange: ...
    def frameDuration(self) -> QgsInterval: ...
    def setFrameDuration(self, duration: QgsInterval) -> None: ...
    def currentFrameNumber(self) -> int: ...
    def setCurrentFrameNumber(self, frame: int) -> None: ...
    def availableTemporalRanges(self) -> list[QgsDateTimeRange]: ...
    def setAvailableTemporalRanges(self, ranges: collections.abc.Iterable[QgsDateTimeRange]) -> None: ...
    def temporalExtents(self) -> QgsDateTimeRange: ...
    def setTemporalExtents(self, extents: QgsDateTimeRange) -> None: ...
    def navigationMode(self) -> Qgis.TemporalNavigationMode: ...
    def setNavigationMode(self, mode: Qgis.TemporalNavigationMode) -> None: ...
    def animationState(self) -> Qgis.AnimationState: ...
    def setAnimationState(self, state: Qgis.AnimationState) -> None: ...


class QgsTemporalUtils(PyQt6.sip.wrapper):

    class AnimationExportSettings(PyQt6.sip.wrapper):

        animationRange = ... # type: QgsDateTimeRange
        availableTemporalRanges = ... # type: collections.abc.Iterable[QgsDateTimeRange]
        decorations = ... # type: collections.abc.Iterable[QgsMapDecoration]
        fileNameTemplate = ... # type: str|None
        frameDuration = ... # type: QgsInterval
        frameRate = ... # type: float
        outputDirectory = ... # type: str|None
        temporalRangeCumulative = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsTemporalUtils.AnimationExportSettings') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTemporalUtils') -> None: ...

    @staticmethod
    def calculateDateTimesFromISO8601(string: str|None, maxValues: int = ...) -> typing.Tuple[list[QtCore.QDateTime], bool, bool]: ...
    @staticmethod
    def calculateDateTimesUsingDuration(start: QtCore.QDateTime|datetime.datetime, end: QtCore.QDateTime|datetime.datetime, duration: str|None, maxValues: int = ...) -> typing.Tuple[list[QtCore.QDateTime], bool, bool]: ...
    @staticmethod
    def calculateFrameTime(start: QtCore.QDateTime|datetime.datetime, frame: int, interval: QgsInterval) -> QtCore.QDateTime: ...
    @staticmethod
    def exportAnimation(mapSettings: QgsMapSettings, settings: 'QgsTemporalUtils.AnimationExportSettings', feedback: QgsFeedback|None = ...) -> typing.Tuple[bool, str]: ...
    @staticmethod
    def usedTemporalRangesForProject(project: 'QgsProject|None') -> list[QgsDateTimeRange]: ...
    @staticmethod
    def calculateTemporalRangeForProject(project: 'QgsProject|None') -> QgsDateTimeRange: ...


class QgsTessellator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, originX: float, originY: float, addNormals: bool, invertNormals: bool = ..., addBackFaces: bool = ..., noZ: bool = ..., addTextureCoords: bool = ..., facade: int = ..., textureRotation: float = ...) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, bounds: 'QgsRectangle', addNormals: bool, invertNormals: bool = ..., addBackFaces: bool = ..., noZ: bool = ..., addTextureCoords: bool = ..., facade: int = ..., textureRotation: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTessellator') -> None: ...

    def uniqueVertexCount(self) -> int: ...
    def error(self) -> str: ...
    def zMaximum(self) -> float: ...
    def zMinimum(self) -> float: ...
    def indexStride(self) -> int: ...
    def stride(self) -> int: ...
    def dataVerticesCount(self) -> int: ...
    def vertexBuffer(self) -> QtCore.QByteArray: ...
    def indexBuffer(self) -> QtCore.QByteArray: ...
    @deprecated("""""")
    def data(self) -> list[float]: ...
    def addPolygon(self, polygon: 'QgsPolygon', extrusionHeight: float) -> None: ...
    def isOutputZUp(self) -> bool: ...
    def setOutputZUp(self, zUp: bool) -> None: ...
    def triangulationAlgorithm(self) -> Qgis.TriangulationAlgorithm: ...
    def setTriangulationAlgorithm(self, algorithm: Qgis.TriangulationAlgorithm) -> None: ...
    def hasInvertedNormals(self) -> bool: ...
    def setInvertNormals(self, invertNormals: bool) -> None: ...
    def hasBackFacesEnabled(self) -> bool: ...
    def setBackFacesEnabled(self, addBackFaces: bool) -> None: ...
    def hasNormals(self) -> bool: ...
    def setAddNormals(self, addNormals: bool) -> None: ...
    def hasTextureUVs(self) -> bool: ...
    def setAddTextureUVs(self, addTextureUVs: bool) -> None: ...
    def textureRotation(self) -> float: ...
    def setTextureRotation(self, rotation: float) -> None: ...
    def extrusionFaces(self) -> Qgis.ExtrusionFace: ...
    def setExtrusionFaces(self, faces: Qgis.ExtrusionFace) -> None: ...
    def isZValueIgnored(self) -> bool: ...
    def setInputZValueIgnored(self, ignore: bool) -> None: ...
    def setBounds(self, bounds: 'QgsRectangle') -> None: ...
    def origin(self) -> 'QgsVector3D': ...
    def setOrigin(self, origin: 'QgsVector3D') -> None: ...


class QgsTestUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTestUtils') -> None: ...

    @staticmethod
    def sanitizeFakeHttpEndpoint(urlString: str|None) -> str: ...
    @staticmethod
    def compareDomElements(element1: QtXml.QDomElement, element2: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def testProviderIteratorThreadSafety(provider: 'QgsVectorDataProvider|None', request: QgsFeatureRequest = ...) -> bool: ...


class QgsTileXYZ(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, tc: int = ..., tr: int = ..., tz: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTileXYZ') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def toString(self) -> str: ...
    def zoomLevel(self) -> int: ...
    def row(self) -> int: ...
    def column(self) -> int: ...


class QgsTileRange(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, c1: int = ..., c2: int = ..., r1: int = ..., r2: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTileRange') -> None: ...

    def count(self) -> int: ...
    def endRow(self) -> int: ...
    def startRow(self) -> int: ...
    def endColumn(self) -> int: ...
    def startColumn(self) -> int: ...
    def isValid(self) -> bool: ...


class QgsTileMatrix(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTileMatrix') -> None: ...

    def isRootTileMatrix(self) -> bool: ...
    def mapToTileCoordinates(self, mapPoint: QgsPointXY) -> QtCore.QPointF: ...
    def tileRangeFromExtent(self, mExtent: 'QgsRectangle') -> QgsTileRange: ...
    def tileCenter(self, id: QgsTileXYZ) -> QgsPointXY: ...
    def tileExtent(self, id: QgsTileXYZ) -> 'QgsRectangle': ...
    def setScale(self, scale: float) -> None: ...
    def scale(self) -> float: ...
    def extent(self) -> 'QgsRectangle': ...
    def matrixHeight(self) -> int: ...
    def matrixWidth(self) -> int: ...
    def setZoomLevel(self, level: int) -> None: ...
    def zoomLevel(self) -> int: ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def fromTileMatrix(zoomLevel: int, tileMatrix: 'QgsTileMatrix') -> 'QgsTileMatrix': ...
    @staticmethod
    def fromCustomDef(zoomLevel: int, crs: 'QgsCoordinateReferenceSystem', z0TopLeftPoint: QgsPointXY, z0Dimension: float, z0MatrixWidth: int = ..., z0MatrixHeight: int = ...) -> 'QgsTileMatrix': ...
    @staticmethod
    def fromWebMercator(zoomLevel: int) -> 'QgsTileMatrix': ...


class QgsTileMatrixSet(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTileMatrixSet') -> None: ...

    def tilesInRange(self, range: QgsTileRange, zoomLevel: int) -> list[QgsTileXYZ]: ...
    def setScaleToTileZoomMethod(self, method: Qgis.ScaleToTileZoomLevelMethod) -> None: ...
    def scaleToTileZoomMethod(self) -> Qgis.ScaleToTileZoomLevelMethod: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def calculateTileScaleForMap(self, actualMapScale: float, mapCrs: 'QgsCoordinateReferenceSystem', mapExtent: 'QgsRectangle', mapSize: QtCore.QSize, mapDpi: float) -> float: ...
    def scaleForRenderContext(self, context: QgsRenderContext) -> float: ...
    def scaleToZoomLevel(self, scale: float, clamp: bool = ...) -> int: ...
    def scaleToZoom(self, scale: float) -> float: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def tileAvailability(self, id: QgsTileXYZ) -> Qgis.TileAvailability: ...
    def dropMatricesOutsideZoomRange(self, minimumZoom: int, maximumZoom: int) -> None: ...
    def maximumZoom(self) -> int: ...
    def minimumZoom(self) -> int: ...
    def addMatrix(self, matrix: QgsTileMatrix) -> None: ...
    def setRootMatrix(self, matrix: QgsTileMatrix) -> None: ...
    def rootMatrix(self) -> QgsTileMatrix: ...
    def tileMatrix(self, zoom: int) -> QgsTileMatrix: ...
    def addGoogleCrs84QuadTiles(self, minimumZoom: int = ..., maximumZoom: int = ...) -> None: ...
    def isEmpty(self) -> bool: ...


class QgsTolerance(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTolerance') -> None: ...

    @staticmethod
    def toleranceInMapUnits(tolerance: float, layer: QgsMapLayer|None, mapSettings: QgsMapSettings, units: Qgis.MapToolUnit = ...) -> float: ...
    @staticmethod
    def toleranceInProjectUnits(tolerance: float, layer: QgsMapLayer|None, mapSettings: QgsMapSettings, units: Qgis.MapToolUnit) -> float: ...
    @staticmethod
    def defaultTolerance(layer: QgsMapLayer|None, mapSettings: QgsMapSettings) -> float: ...
    @typing.overload
    @staticmethod
    def vertexSearchRadius(mapSettings: QgsMapSettings) -> float: ...
    @typing.overload
    @staticmethod
    def vertexSearchRadius(layer: QgsMapLayer|None, mapSettings: QgsMapSettings) -> float: ...


class QgsTracer(QtCore.QObject):

    class PathError(enum.IntEnum):
        ErrNone = ... # type: QgsTracer.PathError
        ErrTooManyFeatures = ... # type: QgsTracer.PathError
        ErrPoint1 = ... # type: QgsTracer.PathError
        ErrPoint2 = ... # type: QgsTracer.PathError
        ErrNoPath = ... # type: QgsTracer.PathError

    def __init__(self) -> None: ...

    def invalidateGraph(self) -> None: ...
    def configure(self) -> None: ...
    def addPointsOnIntersectionsEnabled(self) -> bool: ...
    def setAddPointsOnIntersectionsEnabled(self, enable: bool) -> None: ...
    def isPointSnapped(self, pt: QgsPointXY) -> bool: ...
    def findShortestPath(self, p1: QgsPointXY, p2: QgsPointXY) -> typing.Tuple[list[QgsPointXY], 'QgsTracer.PathError|None']: ...
    def hasTopologyProblem(self) -> bool: ...
    def isInitialized(self) -> bool: ...
    def init(self) -> bool: ...
    def setMaxFeatureCount(self, count: int) -> None: ...
    def maxFeatureCount(self) -> int: ...
    def setOffsetParameters(self, quadSegments: int, joinStyle: int, miterLimit: float) -> None: ...
    def offsetParameters(self) -> typing.Tuple[int, int, float]: ...
    def setOffset(self, offset: float) -> None: ...
    def offset(self) -> float: ...
    def setExtent(self, extent: 'QgsRectangle') -> None: ...
    def extent(self) -> 'QgsRectangle': ...
    def setRenderContext(self, renderContext: QgsRenderContext|None) -> None: ...
    def setDestinationCrs(self, crs: 'QgsCoordinateReferenceSystem', context: 'QgsCoordinateTransformContext') -> None: ...
    def destinationCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setLayers(self, layers: collections.abc.Iterable[QgsVectorLayer]) -> None: ...
    def layers(self) -> list[QgsVectorLayer]: ...


class QgsVectorLayerTools(QtCore.QObject):

    def __init__(self) -> None: ...

    def project(self) -> 'QgsProject|None': ...
    def setProject(self, project: 'QgsProject|None') -> None: ...
    def setForceSuppressFormPopup(self, forceSuppressFormPopup: bool) -> None: ...
    def forceSuppressFormPopup(self) -> bool: ...
    def copyMoveFeatures(self, layer: QgsVectorLayer|None, request: QgsFeatureRequest, dx: float = ..., dy: float = ..., topologicalEditing: bool = ..., topologicalLayer: QgsVectorLayer|None = ..., childrenInfoMsg: str|None = ...) -> typing.Tuple[bool, QgsFeatureRequest, str]: ...
    def saveEdits(self, layer: QgsVectorLayer|None) -> bool: ...
    def stopEditing(self, layer: QgsVectorLayer|None, allowCancel: bool = ...) -> bool: ...
    def startEditing(self, layer: QgsVectorLayer|None) -> bool: ...
    def addFeatureV2(self, layer: QgsVectorLayer|None, defaultValues: dict[int, typing.Any] = ..., defaultGeometry: 'QgsGeometry' = ..., context: 'QgsVectorLayerToolsContext' = ...) -> typing.Tuple[bool, QgsFeature|None]: ...
    def addFeature(self, layer: QgsVectorLayer|None, defaultValues: dict[int, typing.Any] = ..., defaultGeometry: 'QgsGeometry' = ..., parentWidget: QtWidgets.QWidget|None = ..., showModal: bool = ..., hideParent: bool = ...) -> typing.Tuple[bool, QgsFeature|None]: ...


class QgsTrackedVectorLayerTools(QgsVectorLayerTools):

    def __init__(self) -> None: ...

    def rollback(self) -> None: ...
    def setVectorLayerTools(self, tools: QgsVectorLayerTools|None) -> None: ...
    def copyMoveFeatures(self, layer: QgsVectorLayer|None, request: QgsFeatureRequest, dx: float = ..., dy: float = ..., errorMsg: str|None = ..., topologicalEditing: bool = ..., topologicalLayer: QgsVectorLayer|None = ..., childrenInfoMsg: str|None = ...) -> bool: ...
    def saveEdits(self, layer: QgsVectorLayer|None) -> bool: ...
    def stopEditing(self, layer: QgsVectorLayer|None, allowCancel: bool) -> bool: ...
    def startEditing(self, layer: QgsVectorLayer|None) -> bool: ...
    def addFeatureV2(self, layer: QgsVectorLayer|None, defaultValues: dict[int, typing.Any], defaultGeometry: 'QgsGeometry', context: 'QgsVectorLayerToolsContext') -> typing.Tuple[bool, QgsFeature|None]: ...


class QgsTransaction(QtCore.QObject):

    def __init__(self) -> None: ...

    dirtied: typing.ClassVar[QtCore.pyqtSignal]
    afterRollbackToSavepoint: typing.ClassVar[QtCore.pyqtSignal]
    afterRollback: typing.ClassVar[QtCore.pyqtSignal]
    def lastSavePointIsDirty(self) -> bool: ...
    def savePoints(self) -> list[str]: ...
    def dirtyLastSavePoint(self) -> None: ...
    def rollbackToSavepoint(self, name: str|None) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def createSavepoint(self) -> typing.Tuple[str, str]: ...
    @typing.overload
    def createSavepoint(self, savePointId: str|None) -> typing.Tuple[str, str]: ...
    @staticmethod
    def supportsTransaction(layer: QgsVectorLayer|None) -> bool: ...
    def executeSql(self, sql: str|None, isDirty: bool = ..., name: str|None = ...) -> typing.Tuple[bool, str]: ...
    def rollback(self) -> typing.Tuple[bool, str]: ...
    def commit(self) -> typing.Tuple[bool, str]: ...
    def begin(self, statementTimeout: int = ...) -> typing.Tuple[bool, str]: ...
    def addLayer(self, layer: QgsVectorLayer|None, addLayersInEditMode: bool = ...) -> bool: ...
    def connectionString(self) -> str: ...
    @typing.overload
    @staticmethod
    def create(connString: str|None, providerKey: str|None) -> 'QgsTransaction|None': ...
    @typing.overload
    @staticmethod
    def create(layers: collections.abc.Iterable[QgsVectorLayer]) -> 'QgsTransaction|None': ...


class QgsTransactionGroup(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    commitError: typing.ClassVar[QtCore.pyqtSignal]
    def isEmpty(self) -> bool: ...
    def providerKey(self) -> str: ...
    def connString(self) -> str: ...
    def modified(self) -> bool: ...
    def layers(self) -> set[QgsVectorLayer]: ...
    def addLayer(self, layer: QgsVectorLayer|None) -> bool: ...


class QgsTranslationContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTranslationContext') -> None: ...

    def writeTsFile(self, locale: str|None) -> None: ...
    def registerTranslation(self, context: str|None, source: str|None) -> None: ...
    def setFileName(self, fileName: str|None) -> None: ...
    def fileName(self) -> str: ...
    def setProject(self, project: 'QgsProject|None') -> None: ...
    def project(self) -> 'QgsProject|None': ...


class QgsUnitTypes(PyQt6.sip.wrapper):

    class DistanceValue(PyQt6.sip.wrapper):

        unit = ... # type: Qgis.DistanceUnit
        value = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsUnitTypes.DistanceValue') -> None: ...

    class AreaValue(PyQt6.sip.wrapper):

        unit = ... # type: Qgis.AreaUnit
        value = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsUnitTypes.AreaValue') -> None: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsUnitTypes') -> None: ...

    @staticmethod
    def decodeLayoutUnit(string: str|None) -> typing.Tuple[Qgis.LayoutUnit, bool]: ...
    @staticmethod
    def decodeRenderUnit(string: str|None) -> typing.Tuple[Qgis.RenderUnit, bool]: ...
    @staticmethod
    def formatArea(area: float, decimals: int, unit: Qgis.AreaUnit, keepBaseUnit: bool = ...) -> str: ...
    @staticmethod
    def formatDistance(distance: float, decimals: int, unit: Qgis.DistanceUnit, keepBaseUnit: bool = ...) -> str: ...
    @staticmethod
    def scaledArea(area: float, unit: Qgis.AreaUnit, decimals: int, keepBaseUnit: bool = ...) -> 'QgsUnitTypes.AreaValue': ...
    @staticmethod
    def scaledDistance(distance: float, unit: Qgis.DistanceUnit, decimals: int, keepBaseUnit: bool = ...) -> 'QgsUnitTypes.DistanceValue': ...
    @staticmethod
    def formatAngle(angle: float, decimals: int, unit: Qgis.AngleUnit) -> str: ...
    @staticmethod
    def decodeAngleUnit(string: str|None) -> typing.Tuple[Qgis.AngleUnit, bool]: ...
    @staticmethod
    def volumeToDistanceUnit(volumeUnit: Qgis.VolumeUnit) -> Qgis.DistanceUnit: ...
    @staticmethod
    def distanceToVolumeUnit(distanceUnit: Qgis.DistanceUnit) -> Qgis.VolumeUnit: ...
    @staticmethod
    def stringToVolumeUnit(string: str|None) -> typing.Tuple[Qgis.VolumeUnit, bool]: ...
    @staticmethod
    def decodeVolumeUnit(string: str|None) -> typing.Tuple[Qgis.VolumeUnit, bool]: ...
    @staticmethod
    def stringToTemporalUnit(string: str|None) -> typing.Tuple[Qgis.TemporalUnit, bool]: ...
    @staticmethod
    def decodeTemporalUnit(string: str|None) -> typing.Tuple[Qgis.TemporalUnit, bool]: ...
    @staticmethod
    def areaToDistanceUnit(areaUnit: Qgis.AreaUnit) -> Qgis.DistanceUnit: ...
    @staticmethod
    def distanceToAreaUnit(distanceUnit: Qgis.DistanceUnit) -> Qgis.AreaUnit: ...
    @staticmethod
    def stringToAreaUnit(string: str|None) -> typing.Tuple[Qgis.AreaUnit, bool]: ...
    @staticmethod
    def decodeAreaUnit(string: str|None) -> typing.Tuple[Qgis.AreaUnit, bool]: ...
    @typing.overload
    @staticmethod
    def fromUnitToUnitFactor(fromUnit: Qgis.DistanceUnit, toUnit: Qgis.DistanceUnit) -> float: ...
    @typing.overload
    @staticmethod
    def fromUnitToUnitFactor(fromUnit: Qgis.AreaUnit, toUnit: Qgis.AreaUnit) -> float: ...
    @typing.overload
    @staticmethod
    def fromUnitToUnitFactor(fromUnit: Qgis.TemporalUnit, toUnit: Qgis.TemporalUnit) -> float: ...
    @typing.overload
    @staticmethod
    def fromUnitToUnitFactor(fromUnit: Qgis.VolumeUnit, toUnit: Qgis.VolumeUnit) -> float: ...
    @typing.overload
    @staticmethod
    def fromUnitToUnitFactor(fromUnit: Qgis.AngleUnit, toUnit: Qgis.AngleUnit) -> float: ...
    @staticmethod
    def stringToDistanceUnit(string: str|None) -> typing.Tuple[Qgis.DistanceUnit, bool]: ...
    @typing.overload
    @staticmethod
    def toAbbreviatedString(unit: Qgis.DistanceUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toAbbreviatedString(unit: Qgis.AreaUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toAbbreviatedString(unit: Qgis.TemporalUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toAbbreviatedString(unit: Qgis.VolumeUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toAbbreviatedString(unit: Qgis.RenderUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toAbbreviatedString(unit: Qgis.LayoutUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.DistanceUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.AreaUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.TemporalUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.VolumeUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.AngleUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.RenderUnit) -> str: ...
    @typing.overload
    @staticmethod
    def toString(unit: Qgis.LayoutUnit) -> str: ...
    @staticmethod
    def decodeDistanceUnit(string: str|None) -> typing.Tuple[Qgis.DistanceUnit, bool]: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.DistanceUnit) -> str: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.AreaUnit) -> str: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.TemporalUnit) -> str: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.VolumeUnit) -> str: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.AngleUnit) -> str: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.RenderUnit) -> str: ...
    @typing.overload
    @staticmethod
    def encodeUnit(unit: Qgis.LayoutUnit) -> str: ...
    @typing.overload
    @staticmethod
    def unitType(unit: Qgis.DistanceUnit) -> Qgis.DistanceUnitType: ...
    @typing.overload
    @staticmethod
    def unitType(unit: Qgis.AreaUnit) -> Qgis.DistanceUnitType: ...
    @typing.overload
    @staticmethod
    def unitType(unit: Qgis.VolumeUnit) -> Qgis.DistanceUnitType: ...
    @typing.overload
    @staticmethod
    def unitType(units: Qgis.LayoutUnit) -> Qgis.LayoutUnitType: ...
    @staticmethod
    def decodeUnitType(string: str|None) -> typing.Tuple[Qgis.UnitType, bool]: ...
    @staticmethod
    def encodeUnitType(type: Qgis.UnitType) -> str: ...


class QgsUnsetAttributeValue(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, defaultValueClause: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsUnsetAttributeValue') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def defaultValueClause(self) -> str: ...


class QgsUserProfile(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, folder: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsUserProfile') -> None: ...

    def icon(self) -> QtGui.QIcon: ...
    def setAlias(self, alias: str|None) -> QgsError: ...
    def alias(self) -> str: ...
    def initSettings(self) -> None: ...
    def name(self) -> str: ...
    def validate(self) -> QgsError: ...
    def folder(self) -> str: ...


class QgsUserProfileManager(QtCore.QObject):

    def __init__(self, rootLocation: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    profilesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def settings(self) -> QtCore.QSettings|None: ...
    def loadUserProfile(self, name: str|None) -> None: ...
    def setActiveUserProfile(self, profile: str|None) -> None: ...
    def userProfile(self) -> QgsUserProfile|None: ...
    def deleteProfile(self, name: str|None) -> QgsError: ...
    def createUserProfile(self, name: str|None) -> QgsError: ...
    def profileForName(self, name: str|None) -> QgsUserProfile|None: ...
    def setUserProfileSelectionPolicy(self, policy: Qgis.UserProfileSelectionPolicy) -> None: ...
    def userProfileSelectionPolicy(self) -> Qgis.UserProfileSelectionPolicy: ...
    def lastProfileName(self) -> str: ...
    def setDefaultFromActive(self) -> None: ...
    def setDefaultProfileName(self, name: str|None) -> None: ...
    def defaultProfileName(self) -> str: ...
    def profileExists(self, name: str|None) -> bool: ...
    def allProfiles(self) -> list[str]: ...
    def rootLocationIsSet(self) -> bool: ...
    def isNewProfileNotificationEnabled(self) -> bool: ...
    def setNewProfileNotificationEnabled(self, enabled: bool) -> None: ...
    def rootLocation(self) -> str: ...
    def setRootLocation(self, rootProfileLocation: str|None) -> None: ...
    def getProfile(self, defaultProfile: str|None = ..., createNew: bool = ..., initSettings: bool = ...) -> QgsUserProfile|None: ...
    @staticmethod
    def resolveProfilesFolder(basePath: str|None = ...) -> str: ...


class QgsVariantUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVariantUtils') -> None: ...

    @staticmethod
    def displayString(variant: typing.Any, precision: int = ...) -> str: ...
    @staticmethod
    def isNumericType(metaType: QtCore.QMetaType.Type) -> bool: ...
    @staticmethod
    def isNull(variant: typing.Any) -> bool: ...
    @typing.overload
    @staticmethod
    def typeToDisplayString(type: QtCore.QMetaType.Type, subType: QtCore.QMetaType.Type = ...) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def typeToDisplayString(type: typing.Any, subType: typing.Any = ...) -> str: ...


class QgsVector(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVector') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def toString(self, precision: int = ...) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def normalized(self) -> 'QgsVector': ...
    def rotateBy(self, rot: float) -> 'QgsVector': ...
    def crossProduct(self, v: 'QgsVector') -> float: ...
    @typing.overload
    def angle(self) -> float: ...
    @typing.overload
    def angle(self, v: 'QgsVector') -> float: ...
    def perpVector(self) -> 'QgsVector': ...
    def y(self) -> float: ...
    def x(self) -> float: ...
    def lengthSquared(self) -> float: ...
    def length(self) -> float: ...
    def __isub__(self, other: 'QgsVector') -> 'QgsVector': ...
    def __sub__(self, other: 'QgsVector') -> 'QgsVector': ...
    def __iadd__(self, other: 'QgsVector') -> 'QgsVector': ...
    def __add__(self, other: 'QgsVector') -> 'QgsVector': ...
    def __truediv__(self, scalar: float) -> 'QgsVector': ...
    @typing.overload
    def __mul__(self, scalar: float) -> 'QgsVector': ...
    @typing.overload
    def __mul__(self, v: 'QgsVector') -> float: ...
    def __neg__(self) -> 'QgsVector': ...


class QgsVector3D(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, z: float) -> None: ...
    @typing.overload
    def __init__(self, v: QtGui.QVector3D) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVector3D') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def toVector3D(self) -> QtGui.QVector3D: ...
    def toString(self, precision: int = ...) -> str: ...
    @staticmethod
    def perpendicularPoint(v1: 'QgsVector3D', v2: 'QgsVector3D', vp: 'QgsVector3D') -> 'QgsVector3D': ...
    def distance(self, other: 'QgsVector3D') -> float: ...
    def normalize(self) -> None: ...
    def lengthSquared(self) -> float: ...
    def length(self) -> float: ...
    @staticmethod
    def crossProduct(v1: 'QgsVector3D', v2: 'QgsVector3D') -> 'QgsVector3D': ...
    @staticmethod
    def dotProduct(v1: 'QgsVector3D', v2: 'QgsVector3D') -> float: ...
    def __truediv__(self, factor: float) -> 'QgsVector3D': ...
    def __mul__(self, factor: float) -> 'QgsVector3D': ...
    def __neg__(self) -> 'QgsVector3D': ...
    def __sub__(self, other: 'QgsVector3D') -> 'QgsVector3D': ...
    def __iadd__(self, other: 'QgsVector3D') -> 'QgsVector3D': ...
    def __add__(self, other: 'QgsVector3D') -> 'QgsVector3D': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def set(self, x: float, y: float, z: float) -> None: ...
    def setZ(self, z: float) -> None: ...
    def setY(self, y: float) -> None: ...
    def setX(self, x: float) -> None: ...
    def z(self) -> float: ...
    def y(self) -> float: ...
    def x(self) -> float: ...
    def isNull(self) -> bool: ...


class QgsVectorFileWriter(QgsFeatureSink):

    class ActionOnExistingFile(enum.IntEnum):
        CreateOrOverwriteFile = ... # type: QgsVectorFileWriter.ActionOnExistingFile
        CreateOrOverwriteLayer = ... # type: QgsVectorFileWriter.ActionOnExistingFile
        AppendToLayerNoNewFields = ... # type: QgsVectorFileWriter.ActionOnExistingFile
        AppendToLayerAddFields = ... # type: QgsVectorFileWriter.ActionOnExistingFile

    class EditionCapability(enum.IntEnum):
        CanAddNewLayer = ... # type: QgsVectorFileWriter.EditionCapability
        CanAppendToExistingLayer = ... # type: QgsVectorFileWriter.EditionCapability
        CanAddNewFieldsToExistingLayer = ... # type: QgsVectorFileWriter.EditionCapability
        CanDeleteLayer = ... # type: QgsVectorFileWriter.EditionCapability

    class VectorFormatOption(enum.IntEnum):
        SortRecommended = ... # type: QgsVectorFileWriter.VectorFormatOption
        SkipNonSpatialFormats = ... # type: QgsVectorFileWriter.VectorFormatOption
        SupportsMultipleLayers = ... # type: QgsVectorFileWriter.VectorFormatOption

    class FieldNameSource(enum.IntEnum):
        Original = ... # type: QgsVectorFileWriter.FieldNameSource
        PreferAlias = ... # type: QgsVectorFileWriter.FieldNameSource

    class WriterError(enum.IntEnum):
        NoError = ... # type: QgsVectorFileWriter.WriterError
        ErrDriverNotFound = ... # type: QgsVectorFileWriter.WriterError
        ErrCreateDataSource = ... # type: QgsVectorFileWriter.WriterError
        ErrCreateLayer = ... # type: QgsVectorFileWriter.WriterError
        ErrAttributeTypeUnsupported = ... # type: QgsVectorFileWriter.WriterError
        ErrAttributeCreationFailed = ... # type: QgsVectorFileWriter.WriterError
        ErrProjection = ... # type: QgsVectorFileWriter.WriterError
        ErrFeatureWriteFailed = ... # type: QgsVectorFileWriter.WriterError
        ErrInvalidLayer = ... # type: QgsVectorFileWriter.WriterError
        ErrSavingMetadata = ... # type: QgsVectorFileWriter.WriterError
        Canceled = ... # type: QgsVectorFileWriter.WriterError

    class OptionType(enum.IntEnum):
        Set = ... # type: QgsVectorFileWriter.OptionType
        String = ... # type: QgsVectorFileWriter.OptionType
        Int = ... # type: QgsVectorFileWriter.OptionType
        Hidden = ... # type: QgsVectorFileWriter.OptionType

    class Option(PyQt6.sip.wrapper):

        docString = ... # type: str|None
        type = ... # type: 'QgsVectorFileWriter.OptionType'

        @typing.overload
        def __init__(self, docString: str|None, type: 'QgsVectorFileWriter.OptionType') -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.Option') -> None: ...

    class SetOption('QgsVectorFileWriter.Option'):

        allowNone = ... # type: bool
        defaultValue = ... # type: str|None
        values = ... # type: collections.abc.Iterable[str|None]

        @typing.overload
        def __init__(self, docString: str|None, values: collections.abc.Iterable[str|None], defaultValue: str|None, allowNone: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.SetOption') -> None: ...

    class StringOption('QgsVectorFileWriter.Option'):

        defaultValue = ... # type: str|None

        @typing.overload
        def __init__(self, docString: str|None, defaultValue: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.StringOption') -> None: ...

    class IntOption('QgsVectorFileWriter.Option'):

        defaultValue = ... # type: int

        @typing.overload
        def __init__(self, docString: str|None, defaultValue: int) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.IntOption') -> None: ...

    class BoolOption('QgsVectorFileWriter.SetOption'):

        @typing.overload
        def __init__(self, docString: str|None, defaultValue: bool) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.BoolOption') -> None: ...

    class HiddenOption('QgsVectorFileWriter.Option'):

        mValue = ... # type: str|None

        @typing.overload
        def __init__(self, value: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.HiddenOption') -> None: ...

    class MetaData(PyQt6.sip.wrapper):

        compulsoryEncoding = ... # type: str|None
        driverOptions = ... # type: typing.Any
        ext = ... # type: str|None
        glob = ... # type: str|None
        layerOptions = ... # type: typing.Any
        longName = ... # type: str|None
        trLongName = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, longName: str|None, trLongName: str|None, glob: str|None, ext: str|None, driverOptions: typing.Any, layerOptions: typing.Any, compulsoryEncoding: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.MetaData') -> None: ...

    class FieldValueConverter(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.FieldValueConverter') -> None: ...

        def clone(self) -> 'QgsVectorFileWriter.FieldValueConverter|None': ...
        def convert(self, fieldIdxInLayer: int, value: typing.Any) -> typing.Any: ...
        def fieldDefinition(self, field: QgsField) -> QgsField: ...

    class SaveVectorOptions(PyQt6.sip.wrapper):

        actionOnExistingFile = ... # type: 'QgsVectorFileWriter.ActionOnExistingFile'
        attributes = ... # type: collections.abc.Iterable[int]
        attributesExportNames = ... # type: collections.abc.Iterable[str|None]
        ct = ... # type: 'QgsCoordinateTransform'
        datasourceOptions = ... # type: collections.abc.Iterable[str|None]
        driverName = ... # type: str|None
        feedback = ... # type: QgsFeedback
        fieldNameSource = ... # type: 'QgsVectorFileWriter.FieldNameSource'
        fieldValueConverter = ... # type: 'QgsVectorFileWriter.FieldValueConverter'
        fileEncoding = ... # type: str|None
        filterExtent = ... # type: 'QgsRectangle'
        forceMulti = ... # type: bool
        includeConstraints = ... # type: bool
        includeZ = ... # type: bool
        layerMetadata = ... # type: 'QgsLayerMetadata'
        layerName = ... # type: str|None
        layerOptions = ... # type: collections.abc.Iterable[str|None]
        onlySelectedFeatures = ... # type: bool
        overrideGeometryType = ... # type: Qgis.WkbType
        saveMetadata = ... # type: bool
        setFieldDomains = ... # type: bool
        skipAttributeCreation = ... # type: bool
        sourceDatabaseProviderConnection = ... # type: 'QgsAbstractDatabaseProviderConnection'
        symbologyExport = ... # type: Qgis.FeatureSymbologyExport
        symbologyScale = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.SaveVectorOptions') -> None: ...

    class FilterFormatDetails(PyQt6.sip.wrapper):

        driverName = ... # type: str|None
        filterString = ... # type: str|None
        globs = ... # type: collections.abc.Iterable[str|None]

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.FilterFormatDetails') -> None: ...

    class DriverDetails(PyQt6.sip.wrapper):

        driverName = ... # type: str|None
        longName = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorFileWriter.DriverDetails') -> None: ...

    @deprecated("""""")
    def __init__(self, vectorFileName: str|None, fileEncoding: str|None, fields: QgsFields, geometryType: Qgis.WkbType, srs: 'QgsCoordinateReferenceSystem' = ..., driverName: str|None = ..., datasourceOptions: collections.abc.Iterable[str|None] = ..., layerOptions: collections.abc.Iterable[str|None] = ..., newFilename: str|None = ..., symbologyExport: Qgis.FeatureSymbologyExport = ..., sinkFlags: QgsFeatureSink.SinkFlag = ...) -> None: ...

    @staticmethod
    def areThereNewFieldsToCreate(datasetName: str|None, layerName: str|None, layer: QgsVectorLayer|None, attributes: collections.abc.Iterable[int]) -> bool: ...
    @staticmethod
    def targetLayerExists(datasetName: str|None, layerName: str|None) -> bool: ...
    @staticmethod
    def editionCapabilities(datasetName: str|None) -> 'QgsVectorFileWriter.EditionCapability': ...
    @staticmethod
    def defaultLayerOptions(driverName: str|None) -> list[str]: ...
    @staticmethod
    def defaultDatasetOptions(driverName: str|None) -> list[str]: ...
    @staticmethod
    def driverMetadata(driverName: str|None, driverMetadata: 'QgsVectorFileWriter.MetaData') -> bool: ...
    def setSymbologyScale(self, scale: float) -> None: ...
    def symbologyScale(self) -> float: ...
    def setSymbologyExport(self, symExport: Qgis.FeatureSymbologyExport) -> None: ...
    def symbologyExport(self) -> Qgis.FeatureSymbologyExport: ...
    @staticmethod
    def deleteShapeFile(fileName: str|None) -> bool: ...
    def sourceFieldIndexToWriterFieldIndex(self) -> typing.Any: ...
    def addFeatureWithStyle(self, feature: QgsFeature, renderer: 'QgsFeatureRenderer|None', outputUnit: Qgis.DistanceUnit = ...) -> bool: ...
    def lastError(self) -> str: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def addFeature(self, feature: QgsFeature, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def capabilities(self) -> Qgis.VectorFileWriterCapability: ...
    def driverLongName(self) -> str: ...
    def driver(self) -> str: ...
    def errorMessage(self) -> str: ...
    def hasError(self) -> 'QgsVectorFileWriter.WriterError': ...
    @staticmethod
    def convertCodecNameForEncodingOption(codecName: str|None) -> str: ...
    @staticmethod
    def filterForDriver(driverName: str|None) -> str: ...
    @staticmethod
    def fileFilterString(options: 'QgsVectorFileWriter.VectorFormatOption' = ...) -> str: ...
    @staticmethod
    def driverForExtension(extension: str|None) -> str: ...
    @staticmethod
    def ogrDriverList(options: 'QgsVectorFileWriter.VectorFormatOption' = ...) -> list['QgsVectorFileWriter.DriverDetails']: ...
    @staticmethod
    def supportsFeatureStyles(driverName: str|None) -> bool: ...
    @staticmethod
    def supportedFormatExtensions(options: 'QgsVectorFileWriter.VectorFormatOption' = ...) -> list[str]: ...
    @staticmethod
    def supportedFiltersAndFormats(options: 'QgsVectorFileWriter.VectorFormatOption' = ...) -> list['QgsVectorFileWriter.FilterFormatDetails']: ...
    @staticmethod
    def writeAsVectorFormatV3(layer: QgsVectorLayer|None, fileName: str|None, transformContext: 'QgsCoordinateTransformContext', options: 'QgsVectorFileWriter.SaveVectorOptions') -> typing.Tuple['QgsVectorFileWriter.WriterError', str, str, str]: ...
    @staticmethod
    @deprecated("""""")
    def writeAsVectorFormatV2(layer: QgsVectorLayer|None, fileName: str|None, transformContext: 'QgsCoordinateTransformContext', options: 'QgsVectorFileWriter.SaveVectorOptions', newFilename: str|None = ..., newLayer: str|None = ...) -> typing.Tuple['QgsVectorFileWriter.WriterError', str]: ...
    @staticmethod
    def create(fileName: str|None, fields: QgsFields, geometryType: Qgis.WkbType, srs: 'QgsCoordinateReferenceSystem', transformContext: 'QgsCoordinateTransformContext', options: 'QgsVectorFileWriter.SaveVectorOptions', sinkFlags: QgsFeatureSink.SinkFlag = ..., newFilename: str|None = ..., newLayer: str|None = ...) -> 'QgsVectorFileWriter|None': ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def writeAsVectorFormat(layer: QgsVectorLayer|None, fileName: str|None, fileEncoding: str|None, destCRS: 'QgsCoordinateReferenceSystem' = ..., driverName: str|None = ..., onlySelected: bool = ..., datasourceOptions: collections.abc.Iterable[str|None] = ..., layerOptions: collections.abc.Iterable[str|None] = ..., skipAttributeCreation: bool = ..., newFilename: str|None = ..., symbologyExport: Qgis.FeatureSymbologyExport = ..., symbologyScale: float = ..., filterExtent: 'QgsRectangle|None' = ..., overrideGeometryType: Qgis.WkbType = ..., forceMulti: bool = ..., includeZ: bool = ..., attributes: collections.abc.Iterable[int] = ..., fieldValueConverter: 'QgsVectorFileWriter.FieldValueConverter|None' = ...) -> typing.Tuple['QgsVectorFileWriter.WriterError', str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def writeAsVectorFormat(layer: QgsVectorLayer|None, fileName: str|None, fileEncoding: str|None, ct: 'QgsCoordinateTransform', driverName: str|None = ..., onlySelected: bool = ..., datasourceOptions: collections.abc.Iterable[str|None] = ..., layerOptions: collections.abc.Iterable[str|None] = ..., skipAttributeCreation: bool = ..., newFilename: str|None = ..., symbologyExport: Qgis.FeatureSymbologyExport = ..., symbologyScale: float = ..., filterExtent: 'QgsRectangle|None' = ..., overrideGeometryType: Qgis.WkbType = ..., forceMulti: bool = ..., includeZ: bool = ..., attributes: collections.abc.Iterable[int] = ..., fieldValueConverter: 'QgsVectorFileWriter.FieldValueConverter|None' = ...) -> typing.Tuple['QgsVectorFileWriter.WriterError', str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def writeAsVectorFormat(layer: QgsVectorLayer|None, fileName: str|None, options: 'QgsVectorFileWriter.SaveVectorOptions', newFilename: str|None = ...) -> typing.Tuple['QgsVectorFileWriter.WriterError', str]: ...


class QgsVectorFileWriterTask(QgsTask):

    def __init__(self, layer: QgsVectorLayer|None, fileName: str|None, options: QgsVectorFileWriter.SaveVectorOptions, sinkFlags: QgsFeatureSink.SinkFlag = ...) -> None: ...

    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    writeComplete: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...


class QgsVectorSimplifyMethod(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorSimplifyMethod') -> None: ...

    def maximumScale(self) -> float: ...
    def setMaximumScale(self, maximumScale: float) -> None: ...
    def forceLocalOptimization(self) -> bool: ...
    def setForceLocalOptimization(self, localOptimization: bool) -> None: ...
    def threshold(self) -> float: ...
    def setThreshold(self, threshold: float) -> None: ...
    def tolerance(self) -> float: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def simplifyAlgorithm(self) -> Qgis.VectorSimplificationAlgorithm: ...
    def setSimplifyAlgorithm(self, simplifyAlgorithm: Qgis.VectorSimplificationAlgorithm) -> None: ...
    def simplifyHints(self) -> Qgis.VectorRenderingSimplificationFlag: ...
    def setSimplifyHints(self, simplifyHints: Qgis.VectorRenderingSimplificationFlag) -> None: ...


class QgsVirtualLayerDefinition(PyQt6.sip.wrapper):

    class SourceLayer(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, name: str|None, ref: str|None) -> None: ...
        @typing.overload
        def __init__(self, name: str|None, source: str|None, provider: str|None, encoding: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVirtualLayerDefinition.SourceLayer') -> None: ...

        def encoding(self) -> str: ...
        def source(self) -> str: ...
        def provider(self) -> str: ...
        def name(self) -> str: ...
        def reference(self) -> str: ...
        def isReferenced(self) -> bool: ...

    @typing.overload
    def __init__(self, filePath: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVirtualLayerDefinition') -> None: ...

    def setSubsetString(self, subsetString: str|None) -> None: ...
    def subsetString(self) -> str: ...
    def hasDefinedGeometry(self) -> bool: ...
    def hasReferencedLayers(self) -> bool: ...
    def hasSourceLayer(self, name: str|None) -> bool: ...
    def setFields(self, fields: QgsFields) -> None: ...
    def fields(self) -> QgsFields: ...
    def setGeometrySrid(self, srid: int) -> None: ...
    def geometrySrid(self) -> int: ...
    def setGeometryWkbType(self, t: Qgis.WkbType) -> None: ...
    def geometryWkbType(self) -> Qgis.WkbType: ...
    def setGeometryField(self, geometryField: str|None) -> None: ...
    def geometryField(self) -> str: ...
    def isLazy(self) -> bool: ...
    def setLazy(self, lazy: bool) -> None: ...
    def setUid(self, uid: str|None) -> None: ...
    def uid(self) -> str: ...
    def setFilePath(self, filePath: str|None) -> None: ...
    def filePath(self) -> str: ...
    def setQuery(self, query: str|None) -> None: ...
    def query(self) -> str: ...
    def sourceLayers(self) -> list['QgsVirtualLayerDefinition.SourceLayer']: ...
    @typing.overload
    def addSource(self, name: str|None, ref: str|None) -> None: ...
    @typing.overload
    def addSource(self, name: str|None, source: str|None, provider: str|None, encoding: str|None = ...) -> None: ...
    def toString(self) -> str: ...
    def toUrl(self) -> QtCore.QUrl: ...
    @staticmethod
    def fromUrl(url: QtCore.QUrl) -> 'QgsVirtualLayerDefinition': ...


class QgsVirtualLayerDefinitionUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVirtualLayerDefinitionUtils') -> None: ...

    @staticmethod
    def fromJoinedLayer(joinedLayer: QgsVectorLayer|None) -> QgsVirtualLayerDefinition: ...


class QgsVirtualLayerTask(QgsTask):

    def __init__(self, definition: QgsVirtualLayerDefinition) -> None: ...

    def setExceptionText(self, exceptionText: str|None) -> None: ...
    def exceptionText(self) -> str: ...
    def cancel(self) -> None: ...
    def run(self) -> bool: ...
    def definition(self) -> QgsVirtualLayerDefinition: ...
    def takeLayer(self) -> QgsVectorLayer|None: ...
    def layer(self) -> QgsVectorLayer|None: ...


class QgsWmsUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsWmsUtils') -> None: ...

    @staticmethod
    def wmsVersion(layer: 'QgsRasterLayer|None') -> str: ...
    @staticmethod
    def isWmsLayer(layer: QgsMapLayer|None) -> bool: ...


class QgsXmlUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsXmlUtils') -> None: ...

    @staticmethod
    def readVariant(element: QtXml.QDomElement) -> typing.Any: ...
    @staticmethod
    def writeVariant(value: typing.Any, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    @staticmethod
    def writeRectangle(rect: 'QgsRectangle', doc: QtXml.QDomDocument, elementName: str|None = ...) -> QtXml.QDomElement: ...
    @staticmethod
    def writeBox3D(box: 'QgsBox3D', doc: QtXml.QDomDocument, elementName: str|None = ...) -> QtXml.QDomElement: ...
    @staticmethod
    def writeMapUnits(units: Qgis.DistanceUnit, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    @staticmethod
    def readBox3D(element: QtXml.QDomElement) -> 'QgsBox3D': ...
    @staticmethod
    def readRectangle(element: QtXml.QDomElement) -> 'QgsRectangle': ...
    @staticmethod
    def readMapUnits(element: QtXml.QDomElement) -> Qgis.DistanceUnit: ...


class QgsZipUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsZipUtils') -> None: ...

    @staticmethod
    def extractFileFromZip(zipFilename: str|None, filenameInZip: str|None) -> typing.Tuple[bool, QtCore.QByteArray]: ...
    @staticmethod
    def files(zip: str|None) -> list[str]: ...
    @staticmethod
    def zip(zip: str|None, files: collections.abc.Iterable[str|None], overwrite: bool = ...) -> bool: ...
    @staticmethod
    def unzip(zip: str|None, dir: str|None, checkConsistency: bool = ...) -> typing.Tuple[bool, list[str]]: ...
    @staticmethod
    def isZipFile(filename: str|None) -> bool: ...


class Qgs3DRendererAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'Qgs3DRendererAbstractMetadata') -> None: ...

    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsAbstract3DRenderer|None': ...
    def type(self) -> str: ...


class Qgs3DRendererRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'Qgs3DRendererRegistry') -> None: ...

    def renderersList(self) -> list[str]: ...
    def rendererMetadata(self, type: str|None) -> Qgs3DRendererAbstractMetadata|None: ...
    def removeRenderer(self, type: str|None) -> None: ...
    def addRenderer(self, metadata: Qgs3DRendererAbstractMetadata|None) -> None: ...


class Qgs3DSymbolAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, visibleName: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'Qgs3DSymbolAbstractMetadata') -> None: ...

    def create(self) -> 'QgsAbstract3DSymbol|None': ...
    def visibleName(self) -> str: ...
    def type(self) -> str: ...


class Qgs3DSymbolRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def defaultSymbolForGeometryType(self, type: Qgis.GeometryType) -> 'QgsAbstract3DSymbol|None': ...
    def createSymbol(self, type: str|None) -> 'QgsAbstract3DSymbol|None': ...
    def addSymbolType(self, metadata: Qgs3DSymbolAbstractMetadata|None) -> bool: ...
    def symbolTypes(self) -> list[str]: ...
    def symbolMetadata(self, type: str|None) -> Qgs3DSymbolAbstractMetadata|None: ...


class QgsAbstract3DSymbol(PyQt6.sip.wrapper):

    class Property(enum.IntEnum):
        Height = ... # type: QgsAbstract3DSymbol.Property
        ExtrusionHeight = ... # type: QgsAbstract3DSymbol.Property

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstract3DSymbol') -> None: ...

    def copyBaseSettings(self, destination: 'QgsAbstract3DSymbol|None') -> None: ...
    def setDefaultPropertiesFromLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    def compatibleGeometryTypes(self) -> list[Qgis.GeometryType]: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def clone(self) -> 'QgsAbstract3DSymbol|None': ...
    def type(self) -> str: ...


class QgsAbstract3DRenderer(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def resolveReferences(self, project: 'QgsProject') -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def clone(self) -> 'QgsAbstract3DRenderer|None': ...
    def type(self) -> str: ...


class QgsAbstractPointCloud3DRenderer(QgsAbstract3DRenderer):

    def __init__(self) -> None: ...

    def convertFrom2DRenderer(self, renderer: 'QgsPointCloudRenderer|None') -> bool: ...


class QgsAction(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, type: Qgis.AttributeActionType, description: str|None, command: str|None, capture: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, type: Qgis.AttributeActionType, description: str|None, action: str|None, icon: str|None, capture: bool, shortTitle: str|None = ..., actionScopes: collections.abc.Iterable[str|None] = ..., notificationMessage: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, id: QtCore.QUuid, type: Qgis.AttributeActionType, description: str|None, action: str|None, icon: str|None, capture: bool, shortTitle: str|None = ..., actionScopes: collections.abc.Iterable[str|None] = ..., notificationMessage: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAction') -> None: ...

    def setCommand(self, newCommand: str|None) -> None: ...
    def html(self) -> str: ...
    def expressionContextScope(self) -> QgsExpressionContextScope: ...
    def setExpressionContextScope(self, scope: QgsExpressionContextScope) -> None: ...
    def writeXml(self, actionsNode: QtXml.QDomNode) -> None: ...
    def readXml(self, actionNode: QtXml.QDomNode, context: QgsReadWriteContext = ...) -> None: ...
    def setActionScopes(self, actionScopes: collections.abc.Iterable[str|None]) -> None: ...
    def actionScopes(self) -> set[str]: ...
    @typing.overload
    def run(self, layer: QgsVectorLayer|None, feature: QgsFeature, expressionContext: QgsExpressionContext) -> None: ...
    @typing.overload
    def run(self, expressionContext: QgsExpressionContext) -> None: ...
    def runable(self) -> bool: ...
    def setEnabledOnlyWhenEditable(self, enable: bool) -> None: ...
    def isEnabledOnlyWhenEditable(self) -> bool: ...
    def capture(self) -> bool: ...
    def type(self) -> Qgis.AttributeActionType: ...
    def notificationMessage(self) -> str: ...
    def command(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def iconPath(self) -> str: ...
    def isValid(self) -> bool: ...
    def id(self) -> QtCore.QUuid: ...
    def shortTitle(self) -> str: ...
    def name(self) -> str: ...


class QgsActionManager(QtCore.QObject):

    def __init__(self, layer: QgsVectorLayer|None) -> None: ...

    def defaultAction(self, actionScope: str|None) -> QgsAction: ...
    def setDefaultAction(self, actionScope: str|None, actionId: QtCore.QUuid) -> None: ...
    @typing.overload
    def action(self, id: QtCore.QUuid) -> QgsAction: ...
    @typing.overload
    def action(self, id: str|None) -> QgsAction: ...
    def readXml(self, layer_node: QtXml.QDomNode, context: QgsReadWriteContext = ...) -> bool: ...
    def writeXml(self, layer_node: QtXml.QDomNode) -> bool: ...
    def layer(self) -> QgsVectorLayer|None: ...
    def actions(self, actionScope: str|None = ...) -> list[QgsAction]: ...
    def clearActions(self) -> None: ...
    def doAction(self, actionId: QtCore.QUuid, feature: QgsFeature, context: QgsExpressionContext) -> None: ...
    def doActionFeature(self, actionId: QtCore.QUuid, feature: QgsFeature, defaultValueIndex: int = ..., scope: QgsExpressionContextScope = ...) -> None: ...
    def removeAction(self, actionId: QtCore.QUuid) -> None: ...
    @typing.overload
    def addAction(self, type: Qgis.AttributeActionType, name: str|None, command: str|None, capture: bool = ...) -> QtCore.QUuid: ...
    @typing.overload
    def addAction(self, type: Qgis.AttributeActionType, name: str|None, command: str|None, icon: str|None, capture: bool = ...) -> QtCore.QUuid: ...
    @typing.overload
    def addAction(self, action: QgsAction) -> None: ...


class QgsActionScope(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, id: str|None, title: str|None, description: str|None, expressionContextScope: QgsExpressionContextScope = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsActionScope') -> None: ...

    def __ne__(self, other: object): ...
    def __hash__(self) -> int: ...
    def isValid(self) -> bool: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def setId(self, id: str|None) -> None: ...
    def id(self) -> str: ...
    def setExpressionContextScope(self, expressionContextScope: QgsExpressionContextScope) -> None: ...
    def expressionContextScope(self) -> QgsExpressionContextScope: ...
    def __eq__(self, other: object): ...


class QgsActionScopeRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    actionScopesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def actionScope(self, id: str|None) -> QgsActionScope: ...
    def unregisterActionScope(self, actionScope: QgsActionScope) -> None: ...
    def registerActionScope(self, actionScope: QgsActionScope) -> None: ...
    def actionScopes(self) -> set[QgsActionScope]: ...


class QgsAnnotation(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def copyCommonProperties(self, target: 'QgsAnnotation|None') -> None: ...
    def _readXml(self, annotationElem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _writeXml(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def minimumFrameSize(self) -> QtCore.QSizeF: ...
    def renderAnnotation(self, context: QgsRenderContext, size: QtCore.QSizeF) -> None: ...
    mapLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    moved: typing.ClassVar[QtCore.pyqtSignal]
    appearanceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def setAssociatedFeature(self, feature: QgsFeature) -> None: ...
    def associatedFeature(self) -> QgsFeature: ...
    def setMapLayer(self, layer: QgsMapLayer|None) -> None: ...
    def mapLayer(self) -> QgsMapLayer|None: ...
    def markerSymbol(self) -> 'QgsMarkerSymbol|None': ...
    def setMarkerSymbol(self, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def readXml(self, itemElem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def render(self, context: QgsRenderContext) -> None: ...
    def fillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def contentsMargin(self) -> QgsMargins: ...
    def setContentsMargin(self, margins: QgsMargins) -> None: ...
    def frameSizeMm(self) -> QtCore.QSizeF: ...
    def setFrameSizeMm(self, size: QtCore.QSizeF) -> None: ...
    @deprecated("""""")
    def frameSize(self) -> QtCore.QSizeF: ...
    @deprecated("""""")
    def setFrameSize(self, size: QtCore.QSizeF) -> None: ...
    def frameOffsetFromReferencePointMm(self) -> QtCore.QPointF: ...
    def setFrameOffsetFromReferencePointMm(self, offset: QtCore.QPointF) -> None: ...
    @deprecated("""""")
    def frameOffsetFromReferencePoint(self) -> QtCore.QPointF: ...
    @deprecated("""""")
    def setFrameOffsetFromReferencePoint(self, offset: QtCore.QPointF) -> None: ...
    def setRelativePosition(self, position: QtCore.QPointF) -> None: ...
    def relativePosition(self) -> QtCore.QPointF: ...
    def setMapPositionCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def mapPositionCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setMapPosition(self, position: QgsPointXY) -> None: ...
    def mapPosition(self) -> QgsPointXY: ...
    def setHasFixedMapPosition(self, fixed: bool) -> None: ...
    def hasFixedMapPosition(self) -> bool: ...
    def setVisible(self, visible: bool) -> None: ...
    def isVisible(self) -> bool: ...
    def clone(self) -> 'QgsAnnotation|None': ...


class QgsAnnotationItem(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def renderCallout(self, context: QgsRenderContext, rect: QtCore.QRectF, angle: float, calloutContext: 'QgsCallout.QgsCalloutContext', feedback: QgsFeedback|None) -> None: ...
    def readCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeCommonProperties(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def copyCommonProperties(self, other: 'QgsAnnotationItem|None') -> None: ...
    def setOffsetFromCalloutUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetFromCalloutUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetFromCallout(self, offset: QtCore.QSizeF) -> None: ...
    def offsetFromCallout(self) -> QtCore.QSizeF: ...
    def setCalloutAnchor(self, anchor: 'QgsGeometry') -> None: ...
    def calloutAnchor(self) -> 'QgsGeometry': ...
    def setCallout(self, callout: 'QgsCallout|None') -> None: ...
    def callout(self) -> 'QgsCallout|None': ...
    def setSymbologyReferenceScale(self, scale: float) -> None: ...
    def symbologyReferenceScale(self) -> float: ...
    def setUseSymbologyReferenceScale(self, enabled: bool) -> None: ...
    def useSymbologyReferenceScale(self) -> bool: ...
    def nodesV2(self, context: 'QgsAnnotationItemEditContext') -> list['QgsAnnotationItemNode']: ...
    @deprecated("""""")
    def nodes(self) -> list['QgsAnnotationItemNode']: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def setZIndex(self, index: int) -> None: ...
    def zIndex(self) -> int: ...
    def transientEditResultsV2(self, operation: 'QgsAbstractAnnotationItemEditOperation|None', context: 'QgsAnnotationItemEditContext') -> 'QgsAnnotationItemEditOperationTransientResults|None': ...
    def transientEditResults(self, operation: 'QgsAbstractAnnotationItemEditOperation|None') -> 'QgsAnnotationItemEditOperationTransientResults|None': ...
    def applyEditV2(self, operation: 'QgsAbstractAnnotationItemEditOperation|None', context: 'QgsAnnotationItemEditContext') -> Qgis.AnnotationItemEditOperationResult: ...
    @deprecated("""""")
    def applyEdit(self, operation: 'QgsAbstractAnnotationItemEditOperation|None') -> Qgis.AnnotationItemEditOperationResult: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    @typing.overload
    def boundingBox(self) -> 'QgsRectangle': ...
    @typing.overload
    def boundingBox(self, context: QgsRenderContext) -> 'QgsRectangle': ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsAnnotationItem|None': ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...


class QgsAnnotationItemEditContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditContext') -> None: ...

    def setRenderContext(self, context: QgsRenderContext) -> None: ...
    def renderContext(self) -> QgsRenderContext: ...
    def setCurrentItemBounds(self, bounds: 'QgsRectangle') -> None: ...
    def currentItemBounds(self) -> 'QgsRectangle': ...


class QgsAbstractAnnotationItemEditOperation(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        MoveNode = ... # type: QgsAbstractAnnotationItemEditOperation.Type
        DeleteNode = ... # type: QgsAbstractAnnotationItemEditOperation.Type
        AddNode = ... # type: QgsAbstractAnnotationItemEditOperation.Type
        TranslateItem = ... # type: QgsAbstractAnnotationItemEditOperation.Type
        RotateItem = ... # type: QgsAbstractAnnotationItemEditOperation.Type

    @typing.overload
    def __init__(self, itemId: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractAnnotationItemEditOperation') -> None: ...

    def itemId(self) -> str: ...
    def type(self) -> 'QgsAbstractAnnotationItemEditOperation.Type': ...


class QgsAnnotationItemEditOperationMoveNode(QgsAbstractAnnotationItemEditOperation):

    @typing.overload
    def __init__(self, itemId: str|None, nodeId: 'QgsVertexId', before: 'QgsPoint', after: 'QgsPoint', translatePixelsX: float = ..., translatePixelsY: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditOperationMoveNode') -> None: ...

    def translationYPixels(self) -> float: ...
    def translationXPixels(self) -> float: ...
    def after(self) -> 'QgsPoint': ...
    def before(self) -> 'QgsPoint': ...
    def nodeId(self) -> 'QgsVertexId': ...
    def type(self) -> QgsAbstractAnnotationItemEditOperation.Type: ...


class QgsAnnotationItemEditOperationDeleteNode(QgsAbstractAnnotationItemEditOperation):

    @typing.overload
    def __init__(self, itemId: str|None, nodeId: 'QgsVertexId', before: 'QgsPoint') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditOperationDeleteNode') -> None: ...

    def before(self) -> 'QgsPoint': ...
    def nodeId(self) -> 'QgsVertexId': ...
    def type(self) -> QgsAbstractAnnotationItemEditOperation.Type: ...


class QgsAnnotationItemEditOperationAddNode(QgsAbstractAnnotationItemEditOperation):

    @typing.overload
    def __init__(self, itemId: str|None, point: 'QgsPoint') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditOperationAddNode') -> None: ...

    def point(self) -> 'QgsPoint': ...
    def type(self) -> QgsAbstractAnnotationItemEditOperation.Type: ...


class QgsAnnotationItemEditOperationTranslateItem(QgsAbstractAnnotationItemEditOperation):

    @typing.overload
    def __init__(self, itemId: str|None, translateX: float, translateY: float, translatePixelsX: float = ..., translatePixelsY: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditOperationTranslateItem') -> None: ...

    def translationYPixels(self) -> float: ...
    def translationXPixels(self) -> float: ...
    def translationY(self) -> float: ...
    def translationX(self) -> float: ...
    def nodeId(self) -> 'QgsVertexId': ...
    def type(self) -> QgsAbstractAnnotationItemEditOperation.Type: ...


class QgsAnnotationItemEditOperationRotateItem(QgsAbstractAnnotationItemEditOperation):

    @typing.overload
    def __init__(self, itemId: str|None, angle: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditOperationRotateItem') -> None: ...

    def angle(self) -> float: ...
    def type(self) -> QgsAbstractAnnotationItemEditOperation.Type: ...


class QgsAnnotationItemEditOperationTransientResults(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, representativeGeometry: 'QgsGeometry') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemEditOperationTransientResults') -> None: ...

    def representativeGeometry(self) -> 'QgsGeometry': ...


class QgsAnnotationItemNode(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, id: 'QgsVertexId', point: QgsPointXY, type: Qgis.AnnotationItemNodeType, cursor: QtCore.Qt.CursorShape = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemNode') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def setCursor(self, shape: QtCore.Qt.CursorShape) -> None: ...
    def cursor(self) -> QtCore.Qt.CursorShape: ...
    def setType(self, type: Qgis.AnnotationItemNodeType) -> None: ...
    def type(self) -> Qgis.AnnotationItemNodeType: ...
    def setPoint(self, point: QgsPointXY) -> None: ...
    def point(self) -> QgsPointXY: ...
    def id(self) -> 'QgsVertexId': ...
    def __repr__(self) -> typing.Any: ...


class QgsAnnotationItemAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, visibleName: str|None, visiblePluralName: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemAbstractMetadata') -> None: ...

    def createItem(self) -> QgsAnnotationItem|None: ...
    def visiblePluralName(self) -> str: ...
    def visibleName(self) -> str: ...
    def type(self) -> str: ...


class QgsAnnotationItemRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    typeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def itemTypes(self) -> dict[str, str]: ...
    def createItem(self, type: str|None) -> QgsAnnotationItem|None: ...
    def addItemType(self, metadata: QgsAnnotationItemAbstractMetadata|None) -> bool: ...
    def itemMetadata(self, type: str|None) -> QgsAnnotationItemAbstractMetadata|None: ...
    def populate(self) -> bool: ...


class QgsAnnotationLayer(QgsMapLayer):

    class LayerOptions(PyQt6.sip.wrapper):

        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAnnotationLayer.LayerOptions') -> None: ...

    def __init__(self, name: str|None, options: 'QgsAnnotationLayer.LayerOptions') -> None: ...

    def setLinkedVisibilityLayer(self, layer: QgsMapLayer|None) -> None: ...
    def linkedVisibilityLayer(self) -> QgsMapLayer|None: ...
    def setPaintEffect(self, effect: 'QgsPaintEffect|None') -> None: ...
    def paintEffect(self) -> 'QgsPaintEffect|None': ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def htmlMetadata(self) -> str: ...
    def dataProvider(self) -> 'QgsDataProvider|None': ...
    def supportsEditing(self) -> bool: ...
    def isEditable(self) -> bool: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory) -> bool: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, a3: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeXml(self, layer_node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def readXml(self, layerNode: QtXml.QDomNode, context: QgsReadWriteContext) -> bool: ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def extent(self) -> 'QgsRectangle': ...
    def createMapRenderer(self, rendererContext: QgsRenderContext) -> QgsMapLayerRenderer|None: ...
    def clone(self) -> 'QgsAnnotationLayer|None': ...
    def properties(self) -> Qgis.MapLayerProperty: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    @deprecated("""""")
    def applyEdit(self, operation: QgsAbstractAnnotationItemEditOperation|None) -> Qgis.AnnotationItemEditOperationResult: ...
    def itemsInBounds(self, bounds: 'QgsRectangle', context: QgsRenderContext, feedback: QgsFeedback|None = ...) -> list[str]: ...
    def item(self, id: str|None) -> QgsAnnotationItem|None: ...
    def items(self) -> typing.Any: ...
    def isEmpty(self) -> bool: ...
    def clear(self) -> None: ...
    def removeItem(self, id: str|None) -> bool: ...
    def replaceItem(self, id: str|None, item: QgsAnnotationItem|None) -> None: ...
    def addItem(self, item: QgsAnnotationItem|None) -> str: ...
    def reset(self) -> None: ...
    def __repr__(self) -> typing.Any: ...


class QgsAnnotationLineItem(QgsAnnotationItem):

    def __init__(self, curve: 'QgsCurve|None') -> None: ...

    def setSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def symbol(self) -> 'QgsLineSymbol|None': ...
    def setGeometry(self, geometry: 'QgsCurve|None') -> None: ...
    def geometry(self) -> 'QgsCurve|None': ...
    def clone(self) -> 'QgsAnnotationLineItem|None': ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    @staticmethod
    def create() -> 'QgsAnnotationLineItem|None': ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...
    def transientEditResultsV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> QgsAnnotationItemEditOperationTransientResults|None: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    def nodesV2(self, context: QgsAnnotationItemEditContext) -> list[QgsAnnotationItemNode]: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    def type(self) -> str: ...


class QgsAnnotationLineTextItem(QgsAnnotationItem):

    def __init__(self, text: str|None, curve: 'QgsCurve|None') -> None: ...

    def offsetFromLineMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetFromLineMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetFromLineUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetFromLineUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setOffsetFromLine(self, distance: float) -> None: ...
    def offsetFromLine(self) -> float: ...
    def setFormat(self, format: 'QgsTextFormat') -> None: ...
    def format(self) -> 'QgsTextFormat': ...
    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...
    def setGeometry(self, geometry: 'QgsCurve|None') -> None: ...
    def geometry(self) -> 'QgsCurve|None': ...
    def clone(self) -> 'QgsAnnotationLineTextItem|None': ...
    @typing.overload
    def boundingBox(self) -> 'QgsRectangle': ...
    @typing.overload
    def boundingBox(self, context: QgsRenderContext) -> 'QgsRectangle': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    @staticmethod
    def create() -> 'QgsAnnotationLineTextItem|None': ...
    def transientEditResultsV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> QgsAnnotationItemEditOperationTransientResults|None: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    def nodesV2(self, context: QgsAnnotationItemEditContext) -> list[QgsAnnotationItemNode]: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    def type(self) -> str: ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...


class QgsAnnotationMarkerItem(QgsAnnotationItem):

    def __init__(self, point: 'QgsPoint') -> None: ...

    def setSymbol(self, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def symbol(self) -> 'QgsMarkerSymbol|None': ...
    def setGeometry(self, geometry: 'QgsPoint') -> None: ...
    def geometry(self) -> QgsPointXY: ...
    @typing.overload
    def boundingBox(self) -> 'QgsRectangle': ...
    @typing.overload
    def boundingBox(self, context: QgsRenderContext) -> 'QgsRectangle': ...
    def clone(self) -> 'QgsAnnotationMarkerItem|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    @staticmethod
    def create() -> 'QgsAnnotationMarkerItem|None': ...
    def transientEditResultsV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> QgsAnnotationItemEditOperationTransientResults|None: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    def nodesV2(self, context: QgsAnnotationItemEditContext) -> list[QgsAnnotationItemNode]: ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    def type(self) -> str: ...


class QgsAnnotationManager(QtCore.QObject):

    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...

    annotationAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    annotationRemoved: typing.ClassVar[QtCore.pyqtSignal]
    annotationAdded: typing.ClassVar[QtCore.pyqtSignal]
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def cloneAnnotations(self) -> list[QgsAnnotation]: ...
    def annotations(self) -> list[QgsAnnotation]: ...
    def clear(self) -> None: ...
    def removeAnnotation(self, annotation: QgsAnnotation|None) -> bool: ...
    def addAnnotation(self, annotation: QgsAnnotation|None) -> bool: ...


class QgsAnnotationRectItem(QgsAnnotationItem):

    def __init__(self, bounds: 'QgsRectangle') -> None: ...

    def renderInBounds(self, context: QgsRenderContext, painterRect: QtCore.QRectF, feedback: QgsFeedback|None) -> None: ...
    def readCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeCommonProperties(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def copyCommonProperties(self, other: QgsAnnotationItem|None) -> None: ...
    def setFrameSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def frameSymbol(self) -> 'QgsFillSymbol|None': ...
    def setFrameEnabled(self, enabled: bool) -> None: ...
    def frameEnabled(self) -> bool: ...
    def setBackgroundSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def backgroundSymbol(self) -> 'QgsFillSymbol|None': ...
    def setBackgroundEnabled(self, enabled: bool) -> None: ...
    def backgroundEnabled(self) -> bool: ...
    def setFixedSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def fixedSizeUnit(self) -> Qgis.RenderUnit: ...
    def setFixedSize(self, size: QtCore.QSizeF) -> None: ...
    def fixedSize(self) -> QtCore.QSizeF: ...
    def setPlacementMode(self, mode: Qgis.AnnotationPlacementMode) -> None: ...
    def placementMode(self) -> Qgis.AnnotationPlacementMode: ...
    def setBounds(self, bounds: 'QgsRectangle') -> None: ...
    def bounds(self) -> 'QgsRectangle': ...
    @typing.overload
    def boundingBox(self) -> 'QgsRectangle': ...
    @typing.overload
    def boundingBox(self, context: QgsRenderContext) -> 'QgsRectangle': ...
    def transientEditResultsV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> QgsAnnotationItemEditOperationTransientResults|None: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    def nodesV2(self, context: QgsAnnotationItemEditContext) -> list[QgsAnnotationItemNode]: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...


class QgsAnnotationPictureItem(QgsAnnotationRectItem):

    def __init__(self, format: Qgis.PictureFormat, path: str|None, bounds: 'QgsRectangle') -> None: ...

    def renderInBounds(self, context: QgsRenderContext, painterBounds: QtCore.QRectF, feedback: QgsFeedback|None) -> None: ...
    def setLockAspectRatio(self, locked: bool) -> None: ...
    def lockAspectRatio(self) -> bool: ...
    def setPath(self, format: Qgis.PictureFormat, path: str|None) -> None: ...
    def format(self) -> Qgis.PictureFormat: ...
    def path(self) -> str: ...
    @staticmethod
    def create() -> 'QgsAnnotationPictureItem|None': ...
    def clone(self) -> 'QgsAnnotationPictureItem|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def type(self) -> str: ...


class QgsAnnotationPointTextItem(QgsAnnotationItem):

    def __init__(self, text: str|None, point: QgsPointXY) -> None: ...

    def setRotationMode(self, mode: Qgis.SymbolRotationMode) -> None: ...
    def rotationMode(self) -> Qgis.SymbolRotationMode: ...
    def setAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def alignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setAngle(self, angle: float) -> None: ...
    def angle(self) -> float: ...
    def setFormat(self, format: 'QgsTextFormat') -> None: ...
    def format(self) -> 'QgsTextFormat': ...
    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...
    def setPoint(self, point: QgsPointXY) -> None: ...
    def point(self) -> QgsPointXY: ...
    def transientEditResultsV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> QgsAnnotationItemEditOperationTransientResults|None: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    def nodesV2(self, context: QgsAnnotationItemEditContext) -> list[QgsAnnotationItemNode]: ...
    @typing.overload
    def boundingBox(self) -> 'QgsRectangle': ...
    @typing.overload
    def boundingBox(self, context: QgsRenderContext) -> 'QgsRectangle': ...
    def clone(self) -> 'QgsAnnotationPointTextItem|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    @staticmethod
    def create() -> 'QgsAnnotationPointTextItem|None': ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    def type(self) -> str: ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...


class QgsAnnotationPolygonItem(QgsAnnotationItem):

    def __init__(self, polygon: 'QgsCurvePolygon|None') -> None: ...

    def setSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def symbol(self) -> 'QgsFillSymbol|None': ...
    def setGeometry(self, geometry: 'QgsCurvePolygon|None') -> None: ...
    def geometry(self) -> 'QgsCurvePolygon|None': ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def clone(self) -> 'QgsAnnotationPolygonItem|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    @staticmethod
    def create() -> 'QgsAnnotationPolygonItem|None': ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...
    def transientEditResultsV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> QgsAnnotationItemEditOperationTransientResults|None: ...
    def applyEditV2(self, operation: QgsAbstractAnnotationItemEditOperation|None, context: QgsAnnotationItemEditContext) -> Qgis.AnnotationItemEditOperationResult: ...
    def nodesV2(self, context: QgsAnnotationItemEditContext) -> list[QgsAnnotationItemNode]: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def render(self, context: QgsRenderContext, feedback: QgsFeedback|None) -> None: ...
    def type(self) -> str: ...


class QgsAnnotationRectangleTextItem(QgsAnnotationRectItem):

    def __init__(self, text: str|None, bounds: 'QgsRectangle') -> None: ...

    def renderInBounds(self, context: QgsRenderContext, painterBounds: QtCore.QRectF, feedback: QgsFeedback|None) -> None: ...
    def marginsUnit(self) -> Qgis.RenderUnit: ...
    def setMarginsUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setMargins(self, margins: QgsMargins) -> None: ...
    def margins(self) -> QgsMargins: ...
    def setAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def alignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setFormat(self, format: 'QgsTextFormat') -> None: ...
    def format(self) -> 'QgsTextFormat': ...
    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...
    def clone(self) -> 'QgsAnnotationRectangleTextItem|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    @staticmethod
    def create() -> 'QgsAnnotationRectangleTextItem|None': ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def flags(self) -> Qgis.AnnotationItemFlag: ...
    def type(self) -> str: ...


class QgsHtmlAnnotation(QgsAnnotation):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def renderAnnotation(self, context: QgsRenderContext, size: QtCore.QSizeF) -> None: ...
    @staticmethod
    def create() -> 'QgsHtmlAnnotation|None': ...
    def setAssociatedFeature(self, feature: QgsFeature) -> None: ...
    def readXml(self, itemElem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def htmlSource(self) -> str: ...
    def setHtmlSource(self, htmlSource: str|None) -> None: ...
    def sourceFile(self) -> str: ...
    def setSourceFile(self, htmlFile: str|None) -> None: ...
    def minimumFrameSize(self) -> QtCore.QSizeF: ...
    def clone(self) -> 'QgsHtmlAnnotation|None': ...


class QgsRenderedAnnotationItemDetails(QgsRenderedItemDetails):

    @typing.overload
    def __init__(self, layerId: str|None, itemId: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRenderedAnnotationItemDetails') -> None: ...

    def itemId(self) -> str: ...
    def __repr__(self) -> typing.Any: ...


class QgsSvgAnnotation(QgsAnnotation):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def renderAnnotation(self, context: QgsRenderContext, size: QtCore.QSizeF) -> None: ...
    @staticmethod
    def create() -> 'QgsSvgAnnotation|None': ...
    def filePath(self) -> str: ...
    def setFilePath(self, file: str|None) -> None: ...
    def readXml(self, itemElem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def clone(self) -> 'QgsSvgAnnotation|None': ...


class QgsTextAnnotation(QgsAnnotation):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def renderAnnotation(self, context: QgsRenderContext, size: QtCore.QSizeF) -> None: ...
    @staticmethod
    def create() -> 'QgsTextAnnotation|None': ...
    def readXml(self, itemElem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def setDocument(self, doc: QtGui.QTextDocument|None) -> None: ...
    def document(self) -> QtGui.QTextDocument|None: ...
    def clone(self) -> 'QgsTextAnnotation|None': ...


class QgsAuthManager(QtCore.QObject):

    class MessageLevel(enum.IntEnum):
        INFO = ... # type: QgsAuthManager.MessageLevel
        WARNING = ... # type: QgsAuthManager.MessageLevel
        CRITICAL = ... # type: QgsAuthManager.MessageLevel

    AUTH_MAN_TAG = ... # type: str|None
    AUTH_PASSWORD_HELPER_DISPLAY_NAME = ... # type: str|None

    def __init__(self) -> None: ...

    def clearCachedConfig(self, authcfg: str|None) -> None: ...
    def clearAllCachedConfigs(self) -> None: ...
    authDatabaseChanged: typing.ClassVar[QtCore.pyqtSignal]
    authDatabaseEraseRequested: typing.ClassVar[QtCore.pyqtSignal]
    masterPasswordVerified: typing.ClassVar[QtCore.pyqtSignal]
    passwordHelperMessageLog: typing.ClassVar[QtCore.pyqtSignal]
    passwordHelperMessageOut: typing.ClassVar[QtCore.pyqtSignal]
    messageLog: typing.ClassVar[QtCore.pyqtSignal]
    messageOut: typing.ClassVar[QtCore.pyqtSignal]
    passwordHelperSuccess: typing.ClassVar[QtCore.pyqtSignal]
    passwordHelperFailure: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def passwordHelperDisplayName(titleCase: bool = ...) -> str: ...
    def passwordHelperSync(self) -> bool: ...
    def setPasswordHelperEnabled(self, enabled: bool) -> None: ...
    @staticmethod
    def passwordHelperEnabled() -> bool: ...
    def trustedCaCertsPemText(self) -> QtCore.QByteArray: ...
    def trustedCaCertsCache(self) -> list[QtNetwork.QSslCertificate]: ...
    def rebuildTrustedCaCertsCache(self) -> bool: ...
    def untrustedCaCerts(self, trustedCAs: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> list[QtNetwork.QSslCertificate]: ...
    def trustedCaCerts(self, includeinvalid: bool = ...) -> list[QtNetwork.QSslCertificate]: ...
    def rebuildCertTrustCache(self) -> bool: ...
    def certTrustCache(self) -> dict['QgsAuthCertUtils.CertTrustPolicy', list[str]]: ...
    def defaultCertTrustPolicy(self) -> 'QgsAuthCertUtils.CertTrustPolicy': ...
    def setDefaultCertTrustPolicy(self, policy: 'QgsAuthCertUtils.CertTrustPolicy') -> bool: ...
    def certificateTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> 'QgsAuthCertUtils.CertTrustPolicy': ...
    def removeCertTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def removeCertTrustPolicies(self, certs: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> bool: ...
    def certTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> 'QgsAuthCertUtils.CertTrustPolicy': ...
    def storeCertTrustPolicy(self, cert: QtNetwork.QSslCertificate, policy: 'QgsAuthCertUtils.CertTrustPolicy') -> bool: ...
    def rebuildCaCertsCache(self) -> bool: ...
    def mappedDatabaseCAs(self) -> dict[str, QtNetwork.QSslCertificate]: ...
    def databaseCAs(self) -> list[QtNetwork.QSslCertificate]: ...
    def extraFileCAs(self) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def systemRootCAs() -> list[QtNetwork.QSslCertificate]: ...
    def removeCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def existsCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def certAuthority(self, id: str|None) -> QtNetwork.QSslCertificate: ...
    def storeCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def storeCertAuthorities(self, certs: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> bool: ...
    def rebuildIgnoredSslErrorCache(self) -> bool: ...
    def updateIgnoredSslErrorsCache(self, shahostport: str|None, errors: collections.abc.Iterable[QtNetwork.QSslError]) -> bool: ...
    def updateIgnoredSslErrorsCacheFromConfig(self, config: 'QgsAuthConfigSslServer') -> bool: ...
    def dumpIgnoredSslErrorsCache_(self) -> None: ...
    def removeSslCertCustomConfig(self, id: str|None, hostport: str|None) -> bool: ...
    def existsSslCertCustomConfig(self, id: str|None, hostport: str|None) -> bool: ...
    def sslCertCustomConfigs(self) -> list['QgsAuthConfigSslServer']: ...
    def sslCertCustomConfigByHost(self, hostport: str|None) -> 'QgsAuthConfigSslServer': ...
    def sslCertCustomConfig(self, id: str|None, hostport: str|None) -> 'QgsAuthConfigSslServer': ...
    def storeSslCertCustomConfig(self, config: 'QgsAuthConfigSslServer') -> bool: ...
    def removeCertIdentity(self, id: str|None) -> bool: ...
    def existsCertIdentity(self, id: str|None) -> bool: ...
    def certIdentityIds(self) -> list[str]: ...
    def certIdentities(self) -> list[QtNetwork.QSslCertificate]: ...
    def certIdentityBundleToPem(self, id: str|None) -> list[str]: ...
    def certIdentity(self, id: str|None) -> QtNetwork.QSslCertificate: ...
    def storeCertIdentity(self, cert: QtNetwork.QSslCertificate, key: QtNetwork.QSslKey) -> bool: ...
    def initSslCaches(self) -> bool: ...
    def removeAuthSetting(self, key: str|None) -> bool: ...
    def existsAuthSetting(self, key: str|None) -> bool: ...
    def authSetting(self, key: str|None, defaultValue: typing.Any = ..., decrypt: bool = ...) -> typing.Any: ...
    def storeAuthSetting(self, key: str|None, value: typing.Any, encrypt: bool = ...) -> bool: ...
    def updateNetworkProxy(self, proxy: QtNetwork.QNetworkProxy, authcfg: str|None, dataprovider: str|None = ...) -> typing.Tuple[bool, QtNetwork.QNetworkProxy]: ...
    def updateDataSourceUriItems(self, connectionItems: collections.abc.Iterable[str|None], authcfg: str|None, dataprovider: str|None = ...) -> typing.Tuple[bool, list[str]]: ...
    def updateNetworkReply(self, reply: QtNetwork.QNetworkReply|None, authcfg: str|None, dataprovider: str|None = ...) -> bool: ...
    def updateNetworkRequest(self, request: QtNetwork.QNetworkRequest, authcfg: str|None, dataprovider: str|None = ...) -> typing.Tuple[bool, QtNetwork.QNetworkRequest]: ...
    def eraseAuthenticationDatabase(self, backup: bool, backuppath: str|None = ...) -> typing.Tuple[bool, str]: ...
    def backupAuthenticationDatabase(self, backuppath: str|None = ...) -> typing.Tuple[bool, str]: ...
    def removeAllAuthenticationConfigs(self) -> bool: ...
    def importAuthenticationConfigsFromXml(self, filename: str|None, password: str|None = ..., overwrite: bool = ...) -> bool: ...
    def exportAuthenticationConfigsToXml(self, filename: str|None, authcfgs: collections.abc.Iterable[str|None], password: str|None = ...) -> bool: ...
    def removeAuthenticationConfig(self, authcfg: str|None) -> bool: ...
    def loadAuthenticationConfig(self, authcfg: str|None, mconfig: 'QgsAuthMethodConfig', full: bool = ...) -> typing.Tuple[bool, 'QgsAuthMethodConfig']: ...
    def updateAuthenticationConfig(self, config: 'QgsAuthMethodConfig') -> bool: ...
    def storeAuthenticationConfig(self, mconfig: 'QgsAuthMethodConfig', overwrite: bool = ...) -> typing.Tuple[bool, 'QgsAuthMethodConfig']: ...
    def configIds(self) -> list[str]: ...
    def configIdRegex(self) -> str: ...
    @staticmethod
    def hasConfigId(txt: str|None) -> bool: ...
    def configIdUnique(self, id: str|None) -> bool: ...
    def uniqueConfigId(self) -> str: ...
    def supportedAuthMethodExpansions(self, authcfg: str|None) -> 'QgsAuthMethod.Expansion': ...
    def authMethodEditWidget(self, authMethodKey: str|None, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def authMethod(self, authMethodKey: str|None) -> 'QgsAuthMethod|None': ...
    def authMethodsKeys(self, dataprovider: str|None = ...) -> list[str]: ...
    def configAuthMethodKey(self, authcfg: str|None) -> str: ...
    def configAuthMethod(self, authcfg: str|None) -> 'QgsAuthMethod|None': ...
    def updateConfigAuthMethods(self) -> None: ...
    def availableAuthMethodConfigs(self, dataprovider: str|None = ...) -> dict[str, 'QgsAuthMethodConfig']: ...
    def registerCoreAuthMethods(self) -> bool: ...
    def authManTag(self) -> str: ...
    def setScheduledAuthDatabaseEraseRequestEmitted(self, emitted: bool) -> None: ...
    def resetMasterPassword(self, newpass: str|None, oldpass: str|None, keepbackup: bool, backuppath: str|None = ...) -> typing.Tuple[bool, str]: ...
    def masterPasswordSame(self, password: str|None) -> bool: ...
    def clearMasterPassword(self) -> None: ...
    def masterPasswordHashInDatabase(self) -> bool: ...
    def masterPasswordIsSet(self) -> bool: ...
    def verifyMasterPassword(self, compare: str|None = ...) -> bool: ...
    @typing.overload
    def setMasterPassword(self, verify: bool = ...) -> bool: ...
    @typing.overload
    def setMasterPassword(self, password: str|None, verify: bool = ...) -> bool: ...
    def authenticationDatabaseUriStripped(self) -> str: ...
    def authenticationDatabaseUri(self) -> str: ...
    @staticmethod
    def isFilesystemBasedDatabase(uri: str|None) -> bool: ...
    def authenticationDatabasePath(self) -> str: ...
    def disabledMessage(self) -> str: ...
    def isDisabled(self) -> bool: ...
    @deprecated("""""")
    def authDatabaseServersTable(self) -> str: ...
    def methodConfigTableName(self) -> str: ...
    @deprecated("""""")
    def authDatabaseConfigTable(self) -> str: ...
    @deprecated("""""")
    def authDatabaseConnection(self) -> QtSql.QSqlDatabase: ...
    def authConfigurationStorageRegistry(self) -> 'QgsAuthConfigurationStorageRegistry|None': ...
    def ensureInitialized(self) -> bool: ...
    def setup(self, pluginPath: str|None = ..., authDatabasePath: str|None = ...) -> None: ...
    @deprecated("""""")
    def init(self, pluginPath: str|None = ..., authDatabasePath: str|None = ...) -> bool: ...


class QgsBrowserModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        Path = ... # type: QgsBrowserModel.CustomRole
        Comment = ... # type: QgsBrowserModel.CustomRole
        Sort = ... # type: QgsBrowserModel.CustomRole
        ProviderKey = ... # type: QgsBrowserModel.CustomRole
        LayerMetadata = ... # type: QgsBrowserModel.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def removeRootItems(self) -> None: ...
    def addRootItems(self) -> None: ...
    def initialize(self) -> None: ...
    def hidePath(self, item: 'QgsDataItem|None') -> None: ...
    def updateProjectHome(self) -> None: ...
    def removeFavorite(self, index: QtCore.QModelIndex) -> None: ...
    def addFavoriteDirectory(self, directory: str|None, name: str|None = ...) -> None: ...
    def itemStateChanged(self, item: 'QgsDataItem|None', oldState: Qgis.BrowserItemState) -> None: ...
    def itemDataChanged(self, item: 'QgsDataItem|None') -> None: ...
    def endRemoveItems(self) -> None: ...
    def beginRemoveItems(self, parent: 'QgsDataItem|None', first: int, last: int) -> None: ...
    def endInsertItems(self) -> None: ...
    def beginInsertItems(self, parent: 'QgsDataItem|None', first: int, last: int) -> None: ...
    def refreshDrives(self) -> None: ...
    def reload(self) -> None: ...
    connectionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    stateChanged: typing.ClassVar[QtCore.pyqtSignal]
    def rootItems(self) -> list['QgsDataItem']: ...
    def driveItems(self) -> typing.Any: ...
    def initialized(self) -> bool: ...
    @deprecated("""""")
    def connectItem(self, item: 'QgsDataItem|None') -> None: ...
    def findUri(self, uri: str|None, index: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def findPath(self, path: str|None, matchFlag: QtCore.Qt.MatchFlag = ...) -> QtCore.QModelIndex: ...
    @typing.overload
    def refresh(self, path: str|None) -> None: ...
    @typing.overload
    def refresh(self, index: QtCore.QModelIndex = ...) -> None: ...
    def dataItem(self, idx: QtCore.QModelIndex) -> 'QgsDataItem|None': ...
    def findItem(self, item: 'QgsDataItem|None', parent: 'QgsDataItem|None' = ...) -> QtCore.QModelIndex: ...
    def fetchMore(self, parent: QtCore.QModelIndex) -> None: ...
    def canFetchMore(self, parent: QtCore.QModelIndex) -> bool: ...
    def hasChildren(self, parent: QtCore.QModelIndex = ...) -> bool: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def mimeTypes(self) -> list[str]: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsBrowserProxyModel(QtCore.QSortFilterProxyModel):

    class FilterSyntax(enum.IntEnum):
        Normal = ... # type: QgsBrowserProxyModel.FilterSyntax
        Wildcards = ... # type: QgsBrowserProxyModel.FilterSyntax
        RegularExpression = ... # type: QgsBrowserProxyModel.FilterSyntax

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def hasChildren(self, parent: QtCore.QModelIndex = ...) -> bool: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setShowLayers(self, showLayers: bool) -> None: ...
    def showLayers(self) -> bool: ...
    def setShownDataItemProviderKeyFilter(self, shownItemsFilter: collections.abc.Iterable[str|None]) -> None: ...
    def setHiddenDataItemProviderKeyFilter(self, hiddenItemsFilter: collections.abc.Iterable[str|None]) -> None: ...
    def setLayerType(self, type: Qgis.LayerType) -> None: ...
    def layerType(self) -> Qgis.LayerType: ...
    def setFilterByLayerType(self, enabled: bool) -> None: ...
    def filterByLayerType(self) -> bool: ...
    def caseSensitivity(self) -> QtCore.Qt.CaseSensitivity: ...
    def setFilterCaseSensitivity(self, sensitivity: QtCore.Qt.CaseSensitivity) -> None: ...
    def filterString(self) -> str: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def filterSyntax(self) -> 'QgsBrowserProxyModel.FilterSyntax': ...
    def setFilterSyntax(self, syntax: 'QgsBrowserProxyModel.FilterSyntax') -> None: ...
    def dataItem(self, index: QtCore.QModelIndex) -> 'QgsDataItem|None': ...
    def browserModel(self) -> QgsBrowserModel|None: ...
    def setBrowserModel(self, model: QgsBrowserModel|None) -> None: ...


class QgsDataItem(QtCore.QObject):

    def __init__(self, type: Qgis.BrowserItemType, parent: 'QgsDataItem|None', name: str|None, path: str|None, providerKey: str|None = ...) -> None: ...

    def updateIcon(self) -> None: ...
    connectionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    stateChanged: typing.ClassVar[QtCore.pyqtSignal]
    dataChanged: typing.ClassVar[QtCore.pyqtSignal]
    endRemoveItems: typing.ClassVar[QtCore.pyqtSignal]
    beginRemoveItems: typing.ClassVar[QtCore.pyqtSignal]
    endInsertItems: typing.ClassVar[QtCore.pyqtSignal]
    beginInsertItems: typing.ClassVar[QtCore.pyqtSignal]
    def childrenCreated(self) -> None: ...
    def refreshConnections(self, providerKey: str|None = ...) -> None: ...
    def depopulate(self) -> None: ...
    def deferredDelete(self) -> bool: ...
    @typing.overload
    def refresh(self, children: collections.abc.Iterable['QgsDataItem']) -> None: ...
    @typing.overload
    def refresh(self) -> None: ...
    @typing.overload
    def populate(self, children: collections.abc.Iterable['QgsDataItem']) -> None: ...
    @typing.overload
    def populate(self, foreground: bool = ...) -> None: ...
    def databaseConnection(self) -> 'QgsAbstractDatabaseProviderConnection|None': ...
    def moveToThread(self, targetThread: QtCore.QThread|None) -> None: ...
    @typing.overload
    @staticmethod
    def deleteLater(items: collections.abc.Iterable['QgsDataItem']) -> None: ...
    @typing.overload
    def deleteLater(self) -> None: ...
    def toolTip(self) -> str: ...
    def setToolTip(self, msg: str|None) -> None: ...
    def setIconName(self, iconName: str|None) -> None: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def setSortKey(self, key: typing.Any) -> None: ...
    def sortKey(self) -> typing.Any: ...
    @staticmethod
    def pathComponent(component: str|None) -> str: ...
    def setProviderKey(self, value: str|None) -> None: ...
    def providerKey(self) -> str: ...
    def setPath(self, path: str|None) -> None: ...
    def path(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def children(self) -> list['QgsDataItem']: ...
    def setParent(self, parent: 'QgsDataItem|None') -> None: ...
    def ancestorAtDepth(self, depth: int) -> 'QgsDataItem|None': ...
    def parent(self) -> 'QgsDataItem|None': ...
    def type(self) -> Qgis.BrowserItemType: ...
    @staticmethod
    def findItem(items: collections.abc.Iterable['QgsDataItem'], item: 'QgsDataItem|None') -> int: ...
    @deprecated("""""")
    def setCapabilities(self, capabilities: int) -> None: ...
    def setCapabilitiesV2(self, capabilities: Qgis.BrowserItemCapability) -> None: ...
    def capabilities2(self) -> Qgis.BrowserItemCapability: ...
    @deprecated("""""")
    def rename(self, name: str|None) -> bool: ...
    @deprecated("""""")
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> bool: ...
    def mimeUris(self) -> list[QgsMimeDataUtils.Uri]: ...
    @deprecated("""""")
    def mimeUri(self) -> QgsMimeDataUtils.Uri: ...
    def hasDragEnabled(self) -> bool: ...
    def handleDoubleClick(self) -> bool: ...
    @deprecated("""""")
    def handleDrop(self, a0: QtCore.QMimeData|None, a1: QtCore.Qt.DropAction) -> bool: ...
    @deprecated("""""")
    def acceptDrop(self) -> bool: ...
    def menus(self, parent: QtWidgets.QWidget|None) -> list[QtWidgets.QMenu]: ...
    def actions(self, parent: QtWidgets.QWidget|None) -> list[QtGui.QAction]: ...
    @deprecated("""""")
    def paramWidget(self) -> QtWidgets.QWidget|None: ...
    def equal(self, other: 'QgsDataItem|None') -> bool: ...
    def removeChildItem(self, child: 'QgsDataItem|None') -> 'QgsDataItem|None': ...
    def deleteChildItem(self, child: 'QgsDataItem|None') -> None: ...
    def addChildItem(self, child: 'QgsDataItem|None', refresh: bool = ...) -> None: ...
    def setState(self, state: Qgis.BrowserItemState) -> None: ...
    def state(self) -> Qgis.BrowserItemState: ...
    def creatorAncestorDepth(self) -> int: ...
    def createChildren(self) -> list['QgsDataItem']: ...
    def rowCount(self) -> int: ...
    def layerCollection(self) -> bool: ...
    def hasChildren(self) -> bool: ...
    def __repr__(self) -> typing.Any: ...


class QgsDataCollectionItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None = ..., providerKey: str|None = ...) -> None: ...

    @staticmethod
    def homeDirIcon(fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> QtGui.QIcon: ...
    @staticmethod
    def openDirIcon(fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> QtGui.QIcon: ...
    def databaseConnection(self) -> 'QgsAbstractDatabaseProviderConnection|None': ...
    @staticmethod
    def iconDataCollection() -> QtGui.QIcon: ...
    @staticmethod
    def iconDir(fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> QtGui.QIcon: ...
    def addChild(self, item: QgsDataItem|None) -> None: ...
    def __repr__(self) -> typing.Any: ...


class QgsConnectionsRootItem(QgsDataCollectionItem):

    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None = ..., providerKey: str|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...


class QgsDatabaseSchemaItem(QgsDataCollectionItem):

    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None = ..., providerKey: str|None = ...) -> None: ...

    def databaseConnection(self) -> 'QgsAbstractDatabaseProviderConnection|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsErrorItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, error: str|None, path: str|None) -> None: ...

    def __repr__(self) -> typing.Any: ...


class QgsDataItemProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataItemProvider') -> None: ...

    def handlesDirectoryPath(self, path: str|None) -> bool: ...
    def createDataItems(self, path: str|None, parentItem: QgsDataItem|None) -> list[QgsDataItem]: ...
    def createDataItem(self, path: str|None, parentItem: QgsDataItem|None) -> QgsDataItem|None: ...
    def capabilities(self) -> Qgis.DataItemProviderCapability: ...
    def dataProviderKey(self) -> str: ...
    def name(self) -> str: ...


class QgsDataItemProviderRegistry(QtCore.QObject):

    def __init__(self) -> None: ...

    providerWillBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    providerAdded: typing.ClassVar[QtCore.pyqtSignal]
    def dataProviderKey(self, dataItemProviderName: str|None) -> str: ...
    def removeProvider(self, provider: QgsDataItemProvider|None) -> None: ...
    def addProvider(self, provider: QgsDataItemProvider|None) -> None: ...
    def provider(self, providerName: str|None) -> QgsDataItemProvider|None: ...
    def providers(self) -> list[QgsDataItemProvider]: ...


class QgsDirectoryItem(QgsDataCollectionItem):

    @typing.overload
    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None) -> None: ...
    @typing.overload
    def __init__(self, parent: QgsDataItem|None, name: str|None, dirPath: str|None, path: str|None, providerKey: str|None = ...) -> None: ...

    def directoryChanged(self) -> None: ...
    def childrenCreated(self) -> None: ...
    def setMonitoring(self, monitoring: Qgis.BrowserDirectoryMonitoring) -> None: ...
    def monitoring(self) -> Qgis.BrowserDirectoryMonitoring: ...
    def isMonitored(self) -> bool: ...
    @staticmethod
    def pathShouldByMonitoredByDefault(path: str|None) -> bool: ...
    @staticmethod
    def monitoringForPath(path: str|None) -> Qgis.BrowserDirectoryMonitoring: ...
    @staticmethod
    def hiddenPath(path: str|None) -> bool: ...
    def mimeUris(self) -> list[QgsMimeDataUtils.Uri]: ...
    def hasDragEnabled(self) -> bool: ...
    @deprecated("""""")
    def paramWidget(self) -> QtWidgets.QWidget|None: ...
    @staticmethod
    def setCustomColor(directory: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setIconColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def iconColor(self) -> QtGui.QColor: ...
    def icon(self) -> QtGui.QIcon: ...
    def equal(self, other: QgsDataItem|None) -> bool: ...
    def dirPath(self) -> str: ...
    def createChildren(self) -> list[QgsDataItem]: ...
    def setState(self, state: Qgis.BrowserItemState) -> None: ...
    def __repr__(self) -> typing.Any: ...


class QgsDirectoryParamWidget(QtWidgets.QTreeWidget):

    def __init__(self, path: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showHideColumn(self) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...


class QgsFavoritesItem(QgsDataCollectionItem):

    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None = ...) -> None: ...

    def sortKey(self) -> typing.Any: ...
    @staticmethod
    def iconFavorites() -> QtGui.QIcon: ...
    def renameFavorite(self, path: str|None, name: str|None) -> None: ...
    def removeDirectory(self, item: QgsDirectoryItem|None) -> None: ...
    def addDirectory(self, directory: str|None, name: str|None = ...) -> None: ...
    def createChildren(self) -> list[QgsDataItem]: ...
    def __repr__(self) -> typing.Any: ...


class QgsFieldDomainsItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, path: str|None, connectionUri: str|None, providerKey: str|None) -> None: ...

    def connectionUri(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def createChildren(self) -> list[QgsDataItem]: ...
    def __repr__(self) -> typing.Any: ...


class QgsFieldDomainItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, domain: 'QgsFieldDomain|None') -> None: ...

    def connectionUri(self) -> str: ...
    def fieldDomain(self) -> 'QgsFieldDomain|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def __repr__(self) -> typing.Any: ...


class QgsFieldsItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, path: str|None, connectionUri: str|None, providerKey: str|None, schema: str|None, tableName: str|None) -> None: ...

    def canRenameFields(self) -> bool: ...
    def tableProperty(self) -> 'QgsAbstractDatabaseProviderConnection.TableProperty|None': ...
    def fields(self) -> QgsFields: ...
    def layer(self) -> QgsVectorLayer|None: ...
    def connectionUri(self) -> str: ...
    def tableName(self) -> str: ...
    def schema(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def createChildren(self) -> list[QgsDataItem]: ...
    def __repr__(self) -> typing.Any: ...


class QgsFieldItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, field: QgsField) -> None: ...

    def equal(self, other: QgsDataItem|None) -> bool: ...
    def field(self) -> QgsField: ...
    def icon(self) -> QtGui.QIcon: ...
    def __repr__(self) -> typing.Any: ...


class QgsLayerItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None, uri: str|None, layerType: Qgis.BrowserLayerType, providerKey: str|None) -> None: ...

    def setLayerMetadata(self, metadata: 'QgsLayerMetadata') -> None: ...
    def layerMetadata(self) -> 'QgsLayerMetadata': ...
    def databaseConnection(self) -> 'QgsAbstractDatabaseProviderConnection|None': ...
    def layerName(self) -> str: ...
    @staticmethod
    def iconPointCloud() -> QtGui.QIcon: ...
    @staticmethod
    def iconVectorTile() -> QtGui.QIcon: ...
    @staticmethod
    def iconMesh() -> QtGui.QIcon: ...
    @staticmethod
    def iconDefault() -> QtGui.QIcon: ...
    @staticmethod
    def iconRaster() -> QtGui.QIcon: ...
    @staticmethod
    def iconTable() -> QtGui.QIcon: ...
    @staticmethod
    def iconPolygon() -> QtGui.QIcon: ...
    @staticmethod
    def iconLine() -> QtGui.QIcon: ...
    @staticmethod
    def iconPoint() -> QtGui.QIcon: ...
    @staticmethod
    def iconForWkbType(type: Qgis.WkbType) -> QtGui.QIcon: ...
    @deprecated("""""")
    def deleteLayer(self) -> bool: ...
    @staticmethod
    def iconName(layerType: Qgis.BrowserLayerType) -> str: ...
    @staticmethod
    def layerTypeAsString(layerType: Qgis.BrowserLayerType) -> str: ...
    def comments(self) -> str: ...
    def supportedFormats(self) -> list[str]: ...
    def supportedCrs(self) -> list[str]: ...
    def uri(self) -> str: ...
    @staticmethod
    def typeFromMapLayer(layer: QgsMapLayer|None) -> Qgis.BrowserLayerType: ...
    def mapLayerType(self) -> Qgis.LayerType: ...
    def mimeUris(self) -> list[QgsMimeDataUtils.Uri]: ...
    def hasDragEnabled(self) -> bool: ...
    def equal(self, other: QgsDataItem|None) -> bool: ...
    def __repr__(self) -> typing.Any: ...


class QgsProjectItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None, providerKey: str|None = ...) -> None: ...

    def mimeUris(self) -> list[QgsMimeDataUtils.Uri]: ...
    def hasDragEnabled(self) -> bool: ...
    def __repr__(self) -> typing.Any: ...


class QgsRelationshipsItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, path: str|None, connectionUri: str|None, providerKey: str|None, schema: str|None = ..., tableName: str|None = ...) -> None: ...

    def tableName(self) -> str: ...
    def schema(self) -> str: ...
    def connectionUri(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def createChildren(self) -> list[QgsDataItem]: ...
    def __repr__(self) -> typing.Any: ...


class QgsRelationshipItem(QgsDataItem):

    def __init__(self, parent: QgsDataItem|None, relation: QgsWeakRelation) -> None: ...

    def relation(self) -> QgsWeakRelation: ...
    def icon(self) -> QtGui.QIcon: ...
    def __repr__(self) -> typing.Any: ...


class QgsZipItem(QgsDataCollectionItem):

    sProviderNames = ... # type: collections.abc.Iterable[str|None]

    @typing.overload
    def __init__(self, parent: QgsDataItem|None, name: str|None, path: str|None) -> None: ...
    @typing.overload
    def __init__(self, parent: QgsDataItem|None, name: str|None, filePath: str|None, path: str|None, providerKey: str|None = ...) -> None: ...

    @staticmethod
    def iconZip() -> QtGui.QIcon: ...
    @staticmethod
    def itemFromFilePath(parent: QgsDataItem|None, filePath: str|None, name: str|None, path: str|None) -> QgsDataItem|None: ...
    @staticmethod
    def itemFromPath(parent: QgsDataItem|None, path: str|None, name: str|None) -> QgsDataItem|None: ...
    @staticmethod
    @deprecated("""""")
    def vsiPrefix(uri: str|None) -> str: ...
    def mimeUris(self) -> list[QgsMimeDataUtils.Uri]: ...
    def hasDragEnabled(self) -> bool: ...
    def getZipFileList(self) -> list[str]: ...
    def createChildren(self) -> list[QgsDataItem]: ...
    def __repr__(self) -> typing.Any: ...


class QgsCallout(PyQt6.sip.wrapper):

    class LabelAnchorPoint(enum.IntEnum):
        LabelPointOnExterior = ... # type: QgsCallout.LabelAnchorPoint
        LabelCentroid = ... # type: QgsCallout.LabelAnchorPoint
        LabelTopLeft = ... # type: QgsCallout.LabelAnchorPoint
        LabelTopMiddle = ... # type: QgsCallout.LabelAnchorPoint
        LabelTopRight = ... # type: QgsCallout.LabelAnchorPoint
        LabelMiddleLeft = ... # type: QgsCallout.LabelAnchorPoint
        LabelMiddleRight = ... # type: QgsCallout.LabelAnchorPoint
        LabelBottomLeft = ... # type: QgsCallout.LabelAnchorPoint
        LabelBottomMiddle = ... # type: QgsCallout.LabelAnchorPoint
        LabelBottomRight = ... # type: QgsCallout.LabelAnchorPoint

    class AnchorPoint(enum.IntEnum):
        PoleOfInaccessibility = ... # type: QgsCallout.AnchorPoint
        PointOnExterior = ... # type: QgsCallout.AnchorPoint
        PointOnSurface = ... # type: QgsCallout.AnchorPoint
        Centroid = ... # type: QgsCallout.AnchorPoint

    class DrawOrder(enum.IntEnum):
        OrderBelowAllLabels = ... # type: QgsCallout.DrawOrder
        OrderBelowIndividualLabels = ... # type: QgsCallout.DrawOrder

    class Property(enum.IntEnum):
        MinimumCalloutLength = ... # type: QgsCallout.Property
        OffsetFromAnchor = ... # type: QgsCallout.Property
        OffsetFromLabel = ... # type: QgsCallout.Property
        DrawCalloutToAllParts = ... # type: QgsCallout.Property
        AnchorPointPosition = ... # type: QgsCallout.Property
        LabelAnchorPointPosition = ... # type: QgsCallout.Property
        OriginX = ... # type: QgsCallout.Property
        OriginY = ... # type: QgsCallout.Property
        DestinationX = ... # type: QgsCallout.Property
        DestinationY = ... # type: QgsCallout.Property
        Curvature = ... # type: QgsCallout.Property
        Orientation = ... # type: QgsCallout.Property
        Margins = ... # type: QgsCallout.Property
        WedgeWidth = ... # type: QgsCallout.Property
        CornerRadius = ... # type: QgsCallout.Property
        BlendMode = ... # type: QgsCallout.Property

    class QgsCalloutContext(PyQt6.sip.wrapper):

        allFeaturePartsLabeled = ... # type: bool
        originalFeatureCrs = ... # type: 'QgsCoordinateReferenceSystem'

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCallout.QgsCalloutContext') -> None: ...

        def positions(self) -> list['QgsCalloutPosition']: ...
        def addCalloutPosition(self, position: 'QgsCalloutPosition') -> None: ...
        def originalFeatureToMapTransform(self, renderContext: QgsRenderContext) -> 'QgsCoordinateTransform': ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCallout') -> None: ...

    def calloutLineToPart(self, labelGeometry: 'QgsGeometry', partGeometry: 'QgsAbstractGeometry|None', context: QgsRenderContext, calloutContext: 'QgsCallout.QgsCalloutContext') -> typing.Tuple['QgsGeometry', bool]: ...
    def calloutLabelPoint(self, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsCallout.LabelAnchorPoint', context: QgsRenderContext, calloutContext: 'QgsCallout.QgsCalloutContext') -> typing.Tuple['QgsGeometry', bool]: ...
    @deprecated("""""")
    def labelAnchorGeometry(self, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsCallout.LabelAnchorPoint') -> 'QgsGeometry': ...
    def draw(self, context: QgsRenderContext, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: 'QgsCallout.QgsCalloutContext') -> None: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    @staticmethod
    def decodeLabelAnchorPoint(name: str|None) -> typing.Tuple['QgsCallout.LabelAnchorPoint', bool]: ...
    @staticmethod
    def encodeLabelAnchorPoint(anchor: 'QgsCallout.LabelAnchorPoint') -> str: ...
    def setLabelAnchorPoint(self, anchor: 'QgsCallout.LabelAnchorPoint') -> None: ...
    def labelAnchorPoint(self) -> 'QgsCallout.LabelAnchorPoint': ...
    @staticmethod
    def decodeAnchorPoint(name: str|None) -> typing.Tuple['QgsCallout.AnchorPoint', bool]: ...
    @staticmethod
    def encodeAnchorPoint(anchor: 'QgsCallout.AnchorPoint') -> str: ...
    def setAnchorPoint(self, anchor: 'QgsCallout.AnchorPoint') -> None: ...
    def anchorPoint(self) -> 'QgsCallout.AnchorPoint': ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def render(self, context: QgsRenderContext, rect: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: 'QgsCallout.QgsCalloutContext') -> None: ...
    def drawOrder(self) -> 'QgsCallout.DrawOrder': ...
    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext) -> None: ...
    def containsAdvancedEffects(self) -> bool: ...
    def restoreProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def saveProperties(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def readProperties(self, props: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def properties(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsCallout|None': ...
    def type(self) -> str: ...


class QgsSimpleLineCallout(QgsCallout):

    def __init__(self) -> None: ...

    def createCalloutLine(self, start: 'QgsPoint', end: 'QgsPoint', context: QgsRenderContext, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: QgsCallout.QgsCalloutContext) -> 'QgsCurve|None': ...
    def draw(self, context: QgsRenderContext, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: QgsCallout.QgsCalloutContext) -> None: ...
    def setDrawCalloutToAllParts(self, drawToAllParts: bool) -> None: ...
    def drawCalloutToAllParts(self) -> bool: ...
    def offsetFromLabelMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetFromLabelMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetFromLabelUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetFromLabelUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setOffsetFromLabel(self, distance: float) -> None: ...
    def offsetFromLabel(self) -> float: ...
    def offsetFromAnchorMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetFromAnchorMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetFromAnchorUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetFromAnchorUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setOffsetFromAnchor(self, distance: float) -> None: ...
    def offsetFromAnchor(self) -> float: ...
    def minimumLengthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setMinimumLengthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def minimumLengthUnit(self) -> Qgis.RenderUnit: ...
    def setMinimumLengthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setMinimumLength(self, length: float) -> None: ...
    def minimumLength(self) -> float: ...
    def setLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def lineSymbol(self) -> 'QgsLineSymbol|None': ...
    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext) -> None: ...
    def readProperties(self, props: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def properties(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsSimpleLineCallout|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ..., context: QgsReadWriteContext = ...) -> QgsCallout|None: ...


class QgsManhattanLineCallout(QgsSimpleLineCallout):

    def __init__(self) -> None: ...

    def createCalloutLine(self, start: 'QgsPoint', end: 'QgsPoint', context: QgsRenderContext, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: QgsCallout.QgsCalloutContext) -> 'QgsCurve|None': ...
    def clone(self) -> 'QgsManhattanLineCallout|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ..., context: QgsReadWriteContext = ...) -> QgsCallout|None: ...


class QgsCurvedLineCallout(QgsSimpleLineCallout):

    class Orientation(enum.IntEnum):
        Automatic = ... # type: QgsCurvedLineCallout.Orientation
        Clockwise = ... # type: QgsCurvedLineCallout.Orientation
        CounterClockwise = ... # type: QgsCurvedLineCallout.Orientation

    def __init__(self) -> None: ...

    def createCalloutLine(self, start: 'QgsPoint', end: 'QgsPoint', context: QgsRenderContext, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: QgsCallout.QgsCalloutContext) -> 'QgsCurve|None': ...
    def setOrientation(self, orientation: 'QgsCurvedLineCallout.Orientation') -> None: ...
    def orientation(self) -> 'QgsCurvedLineCallout.Orientation': ...
    def setCurvature(self, curvature: float) -> None: ...
    def curvature(self) -> float: ...
    def properties(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsCurvedLineCallout|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ..., context: QgsReadWriteContext = ...) -> QgsCallout|None: ...


class QgsBalloonCallout(QgsCallout):

    def __init__(self) -> None: ...

    def draw(self, context: QgsRenderContext, bodyBoundingBox: QtCore.QRectF, angle: float, anchor: 'QgsGeometry', calloutContext: QgsCallout.QgsCalloutContext) -> None: ...
    def cornerRadiusMapUnitScale(self) -> QgsMapUnitScale: ...
    def setCornerRadiusMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def cornerRadiusUnit(self) -> Qgis.RenderUnit: ...
    def setCornerRadiusUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setCornerRadius(self, radius: float) -> None: ...
    def cornerRadius(self) -> float: ...
    def wedgeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setWedgeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def wedgeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setWedgeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setWedgeWidth(self, width: float) -> None: ...
    def wedgeWidth(self) -> float: ...
    def marginsUnit(self) -> Qgis.RenderUnit: ...
    def setMarginsUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setMargins(self, margins: QgsMargins) -> None: ...
    def margins(self) -> QgsMargins: ...
    def offsetFromAnchorMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetFromAnchorMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetFromAnchorUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetFromAnchorUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setOffsetFromAnchor(self, distance: float) -> None: ...
    def offsetFromAnchor(self) -> float: ...
    def setMarkerSymbol(self, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def markerSymbol(self) -> 'QgsMarkerSymbol|None': ...
    def setFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def fillSymbol(self) -> 'QgsFillSymbol|None': ...
    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext) -> None: ...
    def readProperties(self, props: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def properties(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsBalloonCallout|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ..., context: QgsReadWriteContext = ...) -> QgsCallout|None: ...


class QgsCalloutAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None, icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCalloutAbstractMetadata') -> None: ...

    def createCalloutWidget(self, a0: QgsMapLayer|None) -> QgsCalloutWidget|None: ...
    def createCallout(self, properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsCallout|None: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsCalloutMetadata(QgsCalloutAbstractMetadata):

    def __init__(self, a0: 'QgsCalloutMetadata') -> None: ...

    def createCalloutWidget(self, vl: QgsMapLayer|None) -> QgsCalloutWidget|None: ...
    def createCallout(self, properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsCallout|None: ...


class QgsCalloutRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def defaultCallout() -> QgsCallout|None: ...
    def calloutTypes(self) -> list[str]: ...
    @typing.overload
    def createCallout(self, type: str|None, properties: dict[str|None, typing.Any] = ..., context: QgsReadWriteContext = ...) -> QgsCallout|None: ...
    @typing.overload
    def createCallout(self, type: str|None, element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsCallout|None: ...
    def addCalloutType(self, metadata: QgsCalloutAbstractMetadata|None) -> bool: ...
    def calloutMetadata(self, type: str|None) -> QgsCalloutAbstractMetadata|None: ...


class QgsClassificationMethod(PyQt6.sip.wrapper):

    class ClassPosition(enum.IntEnum):
        LowerBound = ... # type: QgsClassificationMethod.ClassPosition
        Inner = ... # type: QgsClassificationMethod.ClassPosition
        UpperBound = ... # type: QgsClassificationMethod.ClassPosition

    class MethodProperty(enum.IntEnum):
        NoFlag = ... # type: QgsClassificationMethod.MethodProperty
        ValuesNotRequired = ... # type: QgsClassificationMethod.MethodProperty
        SymmetricModeAvailable = ... # type: QgsClassificationMethod.MethodProperty
        IgnoresClassCount = ... # type: QgsClassificationMethod.MethodProperty

    MAX_PRECISION = ... # type: int
    MIN_PRECISION = ... # type: int

    @typing.overload
    def __init__(self, properties: 'QgsClassificationMethod.MethodProperty' = ..., codeComplexity: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationMethod') -> None: ...

    def addParameter(self, definition: 'QgsProcessingParameterDefinition|None') -> None: ...
    def formatNumber(self, value: float) -> str: ...
    def copyBase(self, c: 'QgsClassificationMethod|None') -> None: ...
    def parameterValues(self) -> dict[str, typing.Any]: ...
    def setParameterValues(self, values: dict[str|None, typing.Any]) -> None: ...
    def parameterDefinitions(self) -> list['QgsProcessingParameterDefinition']: ...
    def parameterDefinition(self, parameterName: str|None) -> 'QgsProcessingParameterDefinition|None': ...
    @staticmethod
    def makeBreaksSymmetric(breaks: collections.abc.Iterable[float], symmetryPoint: float, astride: bool) -> list[float]: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsClassificationMethod'|None: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def classesV2(self, layer: QgsVectorLayer|None, expression: str|None, nclasses: int) -> typing.Tuple[list['QgsClassificationRange'], str]: ...
    @typing.overload
    @deprecated("""""")
    def classes(self, layer: QgsVectorLayer|None, expression: str|None, nclasses: int) -> list['QgsClassificationRange']: ...
    @typing.overload
    def classes(self, values: collections.abc.Iterable[float], nclasses: int) -> list['QgsClassificationRange']: ...
    @typing.overload
    def classes(self, minimum: float, maximum: float, nclasses: int) -> list['QgsClassificationRange']: ...
    @staticmethod
    def rangesToBreaks(classes: collections.abc.Iterable['QgsClassificationRange']) -> list[float]: ...
    def setLabelTrimTrailingZeroes(self, trimTrailingZeroes: bool) -> None: ...
    def labelTrimTrailingZeroes(self) -> bool: ...
    def setLabelPrecision(self, labelPrecision: int) -> None: ...
    def labelPrecision(self) -> int: ...
    def setLabelFormat(self, format: str|None) -> None: ...
    def labelFormat(self) -> str: ...
    def setSymmetricMode(self, enabled: bool, symmetryPoint: float = ..., symmetryAstride: bool = ...) -> None: ...
    def symmetryAstride(self) -> bool: ...
    def symmetryPoint(self) -> float: ...
    def symmetricModeEnabled(self) -> bool: ...
    def symmetricModeAvailable(self) -> bool: ...
    def codeComplexity(self) -> int: ...
    def valuesRequired(self) -> bool: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @typing.overload
    def labelForRange(self, lowerValue: float, upperValue: float, position: 'QgsClassificationMethod.ClassPosition' = ...) -> str: ...
    @typing.overload
    def labelForRange(self, range: 'QgsRendererRange', position: 'QgsClassificationMethod.ClassPosition' = ...) -> str: ...
    def flags(self) -> 'QgsClassificationMethod.MethodProperty': ...
    def icon(self) -> QtGui.QIcon: ...
    def id(self) -> str: ...
    def name(self) -> str: ...
    def clone(self) -> 'QgsClassificationMethod'|None: ...


class QgsClassificationCustom(QgsClassificationMethod):

    METHOD_ID = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationCustom') -> None: ...

    def valuesRequired(self) -> bool: ...
    def id(self) -> str: ...
    def name(self) -> str: ...
    def clone(self) -> QgsClassificationMethod|None: ...


class QgsClassificationEqualInterval(QgsClassificationMethod):

    METHOD_ID = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationEqualInterval') -> None: ...

    def valuesRequired(self) -> bool: ...
    def icon(self) -> QtGui.QIcon: ...
    def clone(self) -> QgsClassificationMethod|None: ...
    def id(self) -> str: ...
    def name(self) -> str: ...


class QgsClassificationFixedInterval(QgsClassificationMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationFixedInterval') -> None: ...

    def valuesRequired(self) -> bool: ...
    def icon(self) -> QtGui.QIcon: ...
    def id(self) -> str: ...
    def name(self) -> str: ...
    def clone(self) -> QgsClassificationMethod|None: ...


class QgsClassificationJenks(QgsClassificationMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationJenks') -> None: ...

    def icon(self) -> QtGui.QIcon: ...
    def clone(self) -> QgsClassificationMethod|None: ...
    def id(self) -> str: ...
    def name(self) -> str: ...


class QgsClassificationLogarithmic(QgsClassificationMethod):

    class NegativeValueHandling(enum.IntEnum):
        NoHandling = ... # type: QgsClassificationLogarithmic.NegativeValueHandling
        Discard = ... # type: QgsClassificationLogarithmic.NegativeValueHandling
        PrependBreak = ... # type: QgsClassificationLogarithmic.NegativeValueHandling

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationLogarithmic') -> None: ...

    def valuesRequired(self) -> bool: ...
    def labelForRange(self, lowerValue: float, upperValue: float, position: QgsClassificationMethod.ClassPosition) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def id(self) -> str: ...
    def name(self) -> str: ...
    def clone(self) -> QgsClassificationMethod|None: ...


class QgsClassificationRange(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, label: str|None, lowerBound: float, upperBound: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationRange') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def label(self) -> str: ...
    def upperBound(self) -> float: ...
    def lowerBound(self) -> float: ...


class QgsClassificationMethodRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationMethodRegistry') -> None: ...

    def icon(self, id: str|None) -> QtGui.QIcon: ...
    def methodNames(self) -> dict[str, str]: ...
    def method(self, id: str|None) -> QgsClassificationMethod|None: ...
    def addMethod(self, method: QgsClassificationMethod|None) -> bool: ...


class QgsClassificationPrettyBreaks(QgsClassificationMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationPrettyBreaks') -> None: ...

    def valuesRequired(self) -> bool: ...
    def icon(self) -> QtGui.QIcon: ...
    def clone(self) -> QgsClassificationMethod|None: ...
    def id(self) -> str: ...
    def name(self) -> str: ...


class QgsClassificationQuantile(QgsClassificationMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationQuantile') -> None: ...

    def icon(self) -> QtGui.QIcon: ...
    def clone(self) -> QgsClassificationMethod|None: ...
    def id(self) -> str: ...
    def name(self) -> str: ...


class QgsClassificationStandardDeviation(QgsClassificationMethod):

    METHOD_ID = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClassificationStandardDeviation') -> None: ...

    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def labelForRange(self, lowerValue: float, upperValue: float, position: QgsClassificationMethod.ClassPosition) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def clone(self) -> QgsClassificationMethod|None: ...
    def id(self) -> str: ...
    def name(self) -> str: ...


class QgsDiagram(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsDiagram') -> None: ...

    def sizeForValue(self, value: float, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def scaledFont(self, s: QgsDiagramSettings, c: QgsRenderContext) -> QtGui.QFont: ...
    @typing.overload
    def sizePainterUnits(self, size: QtCore.QSizeF, s: QgsDiagramSettings, c: QgsRenderContext) -> QtCore.QSizeF: ...
    @typing.overload
    def sizePainterUnits(self, l: float, s: QgsDiagramSettings, c: QgsRenderContext) -> float: ...
    def setPenWidth(self, pen: QtGui.QPen|QtGui.QColor|QtCore.Qt.GlobalColor|int, s: QgsDiagramSettings, c: QgsRenderContext) -> None: ...
    def legendSize(self, value: float, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> float: ...
    @typing.overload
    def diagramSize(self, attributes: typing.Any, c: QgsRenderContext, s: QgsDiagramSettings) -> QtCore.QSizeF: ...
    @typing.overload
    def diagramSize(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def diagramName(self) -> str: ...
    def renderDiagram(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, position: QtCore.QPointF) -> None: ...
    def getExpression(self, expression: str|None, context: QgsExpressionContext) -> 'QgsExpression|None': ...
    def clearCache(self) -> None: ...
    def clone(self) -> 'QgsDiagram|None': ...


class QgsHistogramDiagram(QgsDiagram):

    def __init__(self) -> None: ...

    def diagramName(self) -> str: ...
    def legendSize(self, value: float, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> float: ...
    @typing.overload
    def diagramSize(self, attributes: typing.Any, c: QgsRenderContext, s: QgsDiagramSettings) -> QtCore.QSizeF: ...
    @typing.overload
    def diagramSize(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def renderDiagram(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, position: QtCore.QPointF) -> None: ...
    def clone(self) -> 'QgsHistogramDiagram|None': ...


class QgsPieDiagram(QgsDiagram):

    def __init__(self) -> None: ...

    def diagramName(self) -> str: ...
    def legendSize(self, value: float, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> float: ...
    @typing.overload
    def diagramSize(self, attributes: typing.Any, c: QgsRenderContext, s: QgsDiagramSettings) -> QtCore.QSizeF: ...
    @typing.overload
    def diagramSize(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def renderDiagram(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, position: QtCore.QPointF) -> None: ...
    def clone(self) -> 'QgsPieDiagram|None': ...


class QgsStackedBarDiagram(QgsDiagram):

    def __init__(self) -> None: ...

    def diagramName(self) -> str: ...
    def legendSize(self, value: float, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> float: ...
    @typing.overload
    def diagramSize(self, attributes: typing.Any, c: QgsRenderContext, s: QgsDiagramSettings) -> QtCore.QSizeF: ...
    @typing.overload
    def diagramSize(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def renderDiagram(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, position: QtCore.QPointF) -> None: ...
    def clone(self) -> 'QgsStackedBarDiagram|None': ...


class QgsStackedDiagram(QgsDiagram):

    def __init__(self) -> None: ...

    def diagramName(self) -> str: ...
    def legendSize(self, value: float, s: QgsDiagramSettings, is_: QgsDiagramInterpolationSettings) -> float: ...
    @typing.overload
    def diagramSize(self, attributes: typing.Any, c: QgsRenderContext, s: QgsDiagramSettings) -> QtCore.QSizeF: ...
    @typing.overload
    def diagramSize(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, is_: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def renderDiagram(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, position: QtCore.QPointF) -> None: ...
    def subDiagramPosition(self, newPos: QtCore.QPointF, c: QgsRenderContext, s: QgsDiagramSettings, subSettings: QgsDiagramSettings) -> None: ...
    def clone(self) -> 'QgsStackedDiagram|None': ...


class QgsTextDiagram(QgsDiagram):

    class Orientation(enum.IntEnum):
        Horizontal = ... # type: QgsTextDiagram.Orientation
        Vertical = ... # type: QgsTextDiagram.Orientation

    class Shape(enum.IntEnum):
        Circle = ... # type: QgsTextDiagram.Shape
        Rectangle = ... # type: QgsTextDiagram.Shape
        Triangle = ... # type: QgsTextDiagram.Shape

    def __init__(self) -> None: ...

    def diagramName(self) -> str: ...
    def legendSize(self, value: float, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> float: ...
    @typing.overload
    def diagramSize(self, attributes: typing.Any, c: QgsRenderContext, s: QgsDiagramSettings) -> QtCore.QSizeF: ...
    @typing.overload
    def diagramSize(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, interpolationSettings: QgsDiagramInterpolationSettings) -> QtCore.QSizeF: ...
    def renderDiagram(self, feature: QgsFeature, c: QgsRenderContext, s: QgsDiagramSettings, position: QtCore.QPointF) -> None: ...
    def clone(self) -> 'QgsTextDiagram|None': ...


class QgsDxfExport(PyQt6.sip.wrapper):

    class DxfPolylineFlag(enum.IntEnum):
        Closed = ... # type: QgsDxfExport.DxfPolylineFlag
        Curve = ... # type: QgsDxfExport.DxfPolylineFlag
        Spline = ... # type: QgsDxfExport.DxfPolylineFlag
        Is3DPolyline = ... # type: QgsDxfExport.DxfPolylineFlag
        Is3DPolygonMesh = ... # type: QgsDxfExport.DxfPolylineFlag
        PolygonMesh = ... # type: QgsDxfExport.DxfPolylineFlag
        PolyfaceMesh = ... # type: QgsDxfExport.DxfPolylineFlag
        ContinuousPattern = ... # type: QgsDxfExport.DxfPolylineFlag

    class HAlign(enum.IntEnum):
        HLeft = ... # type: QgsDxfExport.HAlign
        HCenter = ... # type: QgsDxfExport.HAlign
        HRight = ... # type: QgsDxfExport.HAlign
        HAligned = ... # type: QgsDxfExport.HAlign
        HMiddle = ... # type: QgsDxfExport.HAlign
        HFit = ... # type: QgsDxfExport.HAlign
        Undefined = ... # type: QgsDxfExport.HAlign

    class VAlign(enum.IntEnum):
        VBaseLine = ... # type: QgsDxfExport.VAlign
        VBottom = ... # type: QgsDxfExport.VAlign
        VMiddle = ... # type: QgsDxfExport.VAlign
        VTop = ... # type: QgsDxfExport.VAlign
        Undefined = ... # type: QgsDxfExport.VAlign

    class ExportResult(enum.Enum):
        Success = ... # type: QgsDxfExport.ExportResult
        InvalidDeviceError = ... # type: QgsDxfExport.ExportResult
        DeviceNotWritableError = ... # type: QgsDxfExport.ExportResult
        EmptyExtentError = ... # type: QgsDxfExport.ExportResult

    class Flag(enum.IntEnum):
        FlagNoMText = ... # type: QgsDxfExport.Flag
        FlagOnlySelectedFeatures = ... # type: QgsDxfExport.Flag
        FlagHairlineWidthExport = ... # type: QgsDxfExport.Flag

    class DxfLayer(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, vl: QgsVectorLayer|None, layerOutputAttributeIndex: int = ..., buildDDBlocks: bool = ..., ddBlocksMaxNumberOfClasses: int = ..., overriddenName: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDxfExport.DxfLayer') -> None: ...

        def overriddenName(self) -> str: ...
        def dataDefinedBlocksMaximumNumberOfClasses(self) -> int: ...
        def buildDataDefinedBlocks(self) -> bool: ...
        def splitLayerAttribute(self) -> str: ...
        def layerOutputAttributeIndex(self) -> int: ...
        def layer(self) -> QgsVectorLayer|None: ...

    def __init__(self) -> None: ...

    def registerDxfLayer(self, layerId: str|None, fid: int, layer: str|None) -> None: ...
    @staticmethod
    def encodings() -> list[str]: ...
    @staticmethod
    def dxfEncoding(name: str|None) -> str: ...
    @staticmethod
    def dxfLayerName(name: str|None) -> str: ...
    def clipValueToMapUnitScale(self, scale: QgsMapUnitScale, pixelToMMFactor: float) -> float: ...
    @staticmethod
    def mapUnitScaleFactor(scale: float, symbolUnits: Qgis.RenderUnit, mapUnits: Qgis.DistanceUnit, mapUnitsPerPixel: float = ...) -> float: ...
    def writeMText(self, layer: str|None, text: str|None, pt: 'QgsPoint', width: float, angle: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def writeTextV2(self, layer: str|None, text: str|None, pt: 'QgsPoint', size: float, angle: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, hali: 'QgsDxfExport.HAlign' = ..., vali: 'QgsDxfExport.VAlign' = ...) -> None: ...
    def writeCircleV2(self, layer: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, pt: 'QgsPoint', radius: float, lineStyleName: str|None, width: float) -> None: ...
    def writeFillCircleV2(self, layer: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, pt: 'QgsPoint', radius: float) -> None: ...
    def writePointV2(self, layer: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, pt: 'QgsPoint') -> None: ...
    def writeLine(self, pt1: 'QgsPoint', pt2: 'QgsPoint', layer: str|None, lineStyleName: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, width: float = ...) -> None: ...
    def writeHandle(self, code: int = ..., handle: int = ...) -> int: ...
    def writeString(self, s: str|None) -> None: ...
    def writeDouble(self, d: float) -> None: ...
    def writeInt(self, i: int) -> None: ...
    def writeGroupCode(self, code: int) -> None: ...
    def writeGroupPointV2(self, code: int, p: 'QgsPoint') -> None: ...
    @typing.overload
    def writeGroup(self, code: int, s: str|None) -> None: ...
    @typing.overload
    def writeGroup(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, exactMatch: int = ..., rgbCode: int = ..., transparencyCode: int = ...) -> None: ...
    def writeGroupDouble(self, code: int, d: float) -> None: ...
    def writeGroupLong(self, code: int, i: int) -> None: ...
    def writeGroupInt(self, code: int, i: int) -> None: ...
    @typing.overload
    def layerName(self, id: str|None, f: QgsFeature) -> str: ...
    @typing.overload
    def layerName(self, vl: QgsVectorLayer|None) -> str: ...
    @staticmethod
    def closestColorMatch(color: int) -> int: ...
    def force2d(self) -> bool: ...
    def setForce2d(self, force2d: bool) -> None: ...
    def layerTitleAsName(self) -> bool: ...
    def setLayerTitleAsName(self, layerTitleAsName: bool) -> None: ...
    def extent(self) -> 'QgsRectangle': ...
    def setExtent(self, r: 'QgsRectangle') -> None: ...
    def symbologyExport(self) -> Qgis.FeatureSymbologyExport: ...
    def setSymbologyExport(self, e: Qgis.FeatureSymbologyExport) -> None: ...
    def destinationCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setDestinationCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def mapUnits(self) -> Qgis.DistanceUnit: ...
    def symbologyScale(self) -> float: ...
    def setSymbologyScale(self, scale: float) -> None: ...
    def feedbackMessage(self) -> str: ...
    def writeToFile(self, d: QtCore.QIODevice|None, codec: str|None) -> 'QgsDxfExport.ExportResult': ...
    def addLayers(self, layers: collections.abc.Iterable['QgsDxfExport.DxfLayer']) -> None: ...
    def flags(self) -> 'QgsDxfExport.Flag': ...
    def setFlags(self, flags: 'QgsDxfExport.Flag') -> None: ...
    def setMapSettings(self, settings: QgsMapSettings) -> None: ...


class QgsEditFormConfig(PyQt6.sip.wrapper):

    class DataDefinedProperty(enum.IntEnum):
        NoProperty = ... # type: QgsEditFormConfig.DataDefinedProperty
        AllProperties = ... # type: QgsEditFormConfig.DataDefinedProperty
        Alias = ... # type: QgsEditFormConfig.DataDefinedProperty
        Editable = ... # type: QgsEditFormConfig.DataDefinedProperty

    class GroupData(PyQt6.sip.wrapper):

        mFields = ... # type: collections.abc.Iterable[str|None]
        mName = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str|None, fields: collections.abc.Iterable[str|None]) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsEditFormConfig.GroupData') -> None: ...

    class TabData(PyQt6.sip.wrapper):

        mFields = ... # type: collections.abc.Iterable[str|None]
        mGroups = ... # type: collections.abc.Iterable['QgsEditFormConfig.GroupData']
        mName = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, name: str|None, fields: collections.abc.Iterable[str|None], groups: collections.abc.Iterable['QgsEditFormConfig.GroupData']) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsEditFormConfig.TabData') -> None: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, o: 'QgsEditFormConfig') -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

    def __ne__(self, other: object): ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    def dataDefinedFieldProperties(self, fieldName: str|None) -> QgsPropertyCollection: ...
    def setDataDefinedFieldProperties(self, fieldName: str|None, properties: QgsPropertyCollection) -> None: ...
    @deprecated("""""")
    def attributeEditorElementFromDomElement(self, elem: QtXml.QDomElement, parent: 'QgsAttributeEditorElement|None', layerId: str|None = ..., context: QgsReadWriteContext = ...) -> 'QgsAttributeEditorElement|None': ...
    def writeXml(self, node: QtXml.QDomNode, context: QgsReadWriteContext) -> None: ...
    def readXml(self, node: QtXml.QDomNode, context: QgsReadWriteContext) -> None: ...
    def setSuppress(self, s: Qgis.AttributeFormSuppression) -> None: ...
    def suppress(self) -> Qgis.AttributeFormSuppression: ...
    def setInitCodeSource(self, initCodeSource: Qgis.AttributeFormPythonInitCodeSource) -> None: ...
    def initCodeSource(self) -> Qgis.AttributeFormPythonInitCodeSource: ...
    def setInitFilePath(self, filePath: str|None) -> None: ...
    def initFilePath(self) -> str: ...
    def setInitCode(self, code: str|None) -> None: ...
    def initCode(self) -> str: ...
    def setInitFunction(self, function: str|None) -> None: ...
    def initFunction(self) -> str: ...
    def setReuseLastValuePolicy(self, index: int, policy: Qgis.AttributeFormReuseLastValuePolicy) -> None: ...
    def reuseLastValuePolicy(self, index: int) -> Qgis.AttributeFormReuseLastValuePolicy: ...
    def setReuseLastValue(self, index: int, reuse: bool) -> None: ...
    def reuseLastValue(self, index: int) -> bool: ...
    def setLabelOnTop(self, idx: int, onTop: bool) -> None: ...
    def labelOnTop(self, idx: int) -> bool: ...
    def setReadOnly(self, idx: int, readOnly: bool = ...) -> None: ...
    def readOnly(self, idx: int) -> bool: ...
    def removeWidgetConfig(self, widgetName: str|None) -> bool: ...
    def widgetConfig(self, widgetName: str|None) -> dict[str, typing.Any]: ...
    def setWidgetConfig(self, widgetName: str|None, config: dict[str|None, typing.Any]) -> bool: ...
    def setUiForm(self, ui: str|None) -> None: ...
    def uiForm(self) -> str: ...
    def setLayout(self, editorLayout: Qgis.AttributeFormLayout) -> None: ...
    def layout(self) -> Qgis.AttributeFormLayout: ...
    def invisibleRootContainer(self) -> 'QgsAttributeEditorContainer|None': ...
    def clearTabs(self) -> None: ...
    def tabs(self) -> list['QgsAttributeEditorElement']: ...
    def addTab(self, data: 'QgsAttributeEditorElement|None') -> None: ...
    def __eq__(self, other: object): ...


class QgsAttributeEditorElement(PyQt6.sip.wrapper):

    class LabelStyle(PyQt6.sip.wrapper):

        color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
        font = ... # type: QtGui.QFont
        overrideColor = ... # type: bool
        overrideFont = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAttributeEditorElement.LabelStyle') -> None: ...

    @typing.overload
    def __init__(self, type: Qgis.AttributeEditorType, name: str|None, parent: 'QgsAttributeEditorElement|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorElement') -> None: ...

    def setLabelStyle(self, labelStyle: 'QgsAttributeEditorElement.LabelStyle') -> None: ...
    def labelStyle(self) -> 'QgsAttributeEditorElement.LabelStyle': ...
    def setVerticalStretch(self, stretch: int) -> None: ...
    def verticalStretch(self) -> int: ...
    def setHorizontalStretch(self, stretch: int) -> None: ...
    def horizontalStretch(self) -> int: ...
    def setShowLabel(self, showLabel: bool) -> None: ...
    def showLabel(self) -> bool: ...
    def clone(self, parent: 'QgsAttributeEditorElement|None') -> 'QgsAttributeEditorElement|None': ...
    def toDomElement(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def parent(self) -> 'QgsAttributeEditorElement|None': ...
    def type(self) -> Qgis.AttributeEditorType: ...
    def name(self) -> str: ...
    @staticmethod
    def create(element: QtXml.QDomElement, layerId: str|None, fields: QgsFields, context: QgsReadWriteContext, parent: 'QgsAttributeEditorElement|None' = ...) -> 'QgsAttributeEditorElement|None': ...


class QgsAttributeEditorAction(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, action: QgsAction, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, uuid: QtCore.QUuid, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorAction') -> None: ...

    def setAction(self, newAction: QgsAction) -> None: ...
    def action(self, layer: QgsVectorLayer|None) -> QgsAction: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...


class QgsAttributeEditorContainer(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, name: str|None, parent: QgsAttributeEditorElement|None, backgroundColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorContainer') -> None: ...

    def setBackgroundColor(self, backgroundColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def backgroundColor(self) -> QtGui.QColor: ...
    def setVisibilityExpression(self, visibilityExpression: QgsOptionalExpression) -> None: ...
    def visibilityExpression(self) -> QgsOptionalExpression: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...
    def setColumnCount(self, columnCount: int) -> None: ...
    def columnCount(self) -> int: ...
    def setName(self, name: str|None) -> None: ...
    def clear(self) -> None: ...
    def findElements(self, type: Qgis.AttributeEditorType) -> list[QgsAttributeEditorElement]: ...
    def children(self) -> list[QgsAttributeEditorElement]: ...
    def setCollapsed(self, collapsed: bool) -> None: ...
    def collapsed(self) -> bool: ...
    @deprecated("""""")
    def isGroupBox(self) -> bool: ...
    @deprecated("""""")
    def setIsGroupBox(self, isGroupBox: bool) -> None: ...
    def type(self) -> Qgis.AttributeEditorContainerType: ...
    def setType(self, type: Qgis.AttributeEditorContainerType) -> None: ...
    def addChildElement(self, element: QgsAttributeEditorElement|None) -> None: ...


class QgsAttributeEditorField(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, name: str|None, idx: int, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorField') -> None: ...

    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...
    def idx(self) -> int: ...


class QgsAttributeEditorRelation(QgsAttributeEditorElement):

    class Button(enum.IntEnum):
        Link = ... # type: QgsAttributeEditorRelation.Button
        Unlink = ... # type: QgsAttributeEditorRelation.Button
        SaveChildEdits = ... # type: QgsAttributeEditorRelation.Button
        AddChildFeature = ... # type: QgsAttributeEditorRelation.Button
        DuplicateChildFeature = ... # type: QgsAttributeEditorRelation.Button
        DeleteChildFeature = ... # type: QgsAttributeEditorRelation.Button
        ZoomToChildFeature = ... # type: QgsAttributeEditorRelation.Button
        AllButtons = ... # type: QgsAttributeEditorRelation.Button

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, name: str|None, relationId: str|None, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, relation: QgsRelation, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, relationId: str|None, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, relation: QgsRelation, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorRelation') -> None: ...

    def setRelationEditorConfiguration(self, config: dict[str|None, typing.Any]) -> None: ...
    def relationEditorConfiguration(self) -> dict[str, typing.Any]: ...
    def setRelationWidgetTypeId(self, relationWidgetTypeId: str|None) -> None: ...
    def relationWidgetTypeId(self) -> str: ...
    def setLabel(self, label: str|None = ...) -> None: ...
    def label(self) -> str: ...
    def setNmRelationId(self, nmRelationId: typing.Any = ...) -> None: ...
    def nmRelationId(self) -> typing.Any: ...
    def setForceSuppressFormPopup(self, forceSuppressFormPopup: bool) -> None: ...
    def forceSuppressFormPopup(self) -> bool: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...
    def init(self, relManager: QgsRelationManager|None) -> bool: ...
    def relation(self) -> QgsRelation: ...


class QgsAttributeEditorHtmlElement(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, name: str|None, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorHtmlElement') -> None: ...

    def setHtmlCode(self, htmlCode: str|None) -> None: ...
    def htmlCode(self) -> str: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...


class QgsAttributeEditorTextElement(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, name: str|None, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorTextElement') -> None: ...

    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...


class QgsAttributeEditorQmlElement(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, name: str|None, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorQmlElement') -> None: ...

    def setQmlCode(self, qmlCode: str|None) -> None: ...
    def qmlCode(self) -> str: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...


class QgsAttributeEditorSpacerElement(QgsAttributeEditorElement):

    @typing.overload
    def __init__(self, name: str|None, parent: QgsAttributeEditorElement|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorSpacerElement') -> None: ...

    def setDrawLine(self, drawLine: bool) -> None: ...
    def drawLine(self) -> bool: ...
    def clone(self, parent: QgsAttributeEditorElement|None) -> QgsAttributeEditorElement|None: ...


class QgsProfileRenderContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, context: QgsRenderContext) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfileRenderContext') -> None: ...

    def setElevationRange(self, range: QgsDoubleRange) -> None: ...
    def elevationRange(self) -> QgsDoubleRange: ...
    def setDistanceRange(self, range: QgsDoubleRange) -> None: ...
    def distanceRange(self) -> QgsDoubleRange: ...
    def setWorldTransform(self, transform: QtGui.QTransform) -> None: ...
    def worldTransform(self) -> QtGui.QTransform: ...
    def renderContext(self) -> QgsRenderContext: ...


class QgsProfileIdentifyContext(PyQt6.sip.wrapper):

    displayRatioElevationVsDistance = ... # type: float
    maximumPointDistanceDelta = ... # type: float
    maximumPointElevationDelta = ... # type: float
    maximumSurfaceDistanceDelta = ... # type: float
    maximumSurfaceElevationDelta = ... # type: float
    project = ... # type: 'QgsProject'

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfileIdentifyContext') -> None: ...


class QgsProfileIdentifyResults(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, layer: QgsMapLayer|None = ..., results: collections.abc.Iterable[dict[str, typing.Any]] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfileIdentifyResults') -> None: ...

    def results(self) -> collections.abc.Iterable[dict[str, typing.Any]]: ...
    def layer(self) -> QgsMapLayer|None: ...


class QgsAbstractProfileResults(PyQt6.sip.wrapper):

    class Feature(PyQt6.sip.wrapper):

        attributes = ... # type: dict[str|None, typing.Any]
        geometry = ... # type: 'QgsGeometry'
        layerIdentifier = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractProfileResults.Feature') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractProfileResults') -> None: ...

    def copyPropertiesFromGenerator(self, generator: 'QgsAbstractProfileGenerator|None') -> None: ...
    @typing.overload
    def identify(self, point: 'QgsProfilePoint', context: QgsProfileIdentifyContext) -> list[QgsProfileIdentifyResults]: ...
    @typing.overload
    def identify(self, distanceRange: QgsDoubleRange, elevationRange: QgsDoubleRange, context: QgsProfileIdentifyContext) -> list[QgsProfileIdentifyResults]: ...
    def snapPoint(self, point: 'QgsProfilePoint', context: 'QgsProfileSnapContext') -> 'QgsProfileSnapResult': ...
    def zRange(self) -> QgsDoubleRange: ...
    def renderResults(self, context: QgsProfileRenderContext) -> None: ...
    def asFeatures(self, type: Qgis.ProfileExportType, feedback: QgsFeedback|None = ...) -> list['QgsAbstractProfileResults.Feature']: ...
    def asGeometries(self) -> list['QgsGeometry']: ...
    def sampledPoints(self) -> list['QgsPoint']: ...
    def distanceToHeightMap(self) -> typing.Any: ...
    def type(self) -> str: ...


class QgsProfileGenerationContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfileGenerationContext') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def convertDistanceToPixels(self, size: float, unit: Qgis.RenderUnit) -> float: ...
    def dpi(self) -> float: ...
    def setDpi(self, dpi: float) -> None: ...
    def setElevationRange(self, range: QgsDoubleRange) -> None: ...
    def elevationRange(self) -> QgsDoubleRange: ...
    def setDistanceRange(self, range: QgsDoubleRange) -> None: ...
    def distanceRange(self) -> QgsDoubleRange: ...
    def setMapUnitsPerDistancePixel(self, units: float) -> None: ...
    def mapUnitsPerDistancePixel(self) -> float: ...
    def setMaximumErrorMapUnits(self, error: float) -> None: ...
    def maximumErrorMapUnits(self) -> float: ...


class QgsAbstractProfileGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractProfileGenerator') -> None: ...

    def type(self) -> str: ...
    def takeResults(self) -> QgsAbstractProfileResults|None: ...
    def feedback(self) -> QgsFeedback|None: ...
    def generateProfile(self, context: QgsProfileGenerationContext = ...) -> bool: ...
    def flags(self) -> Qgis.ProfileGeneratorFlag: ...
    def sourceId(self) -> str: ...


class QgsElevationProfile(QtCore.QObject):

    def __init__(self, project: 'QgsProject|None') -> None: ...

    useProjectLayerTreeChanged: typing.ClassVar[QtCore.pyqtSignal]
    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setUseProjectLayerTree(self, useProjectTree: bool) -> None: ...
    def setDistanceUnit(self, unit: Qgis.DistanceUnit) -> None: ...
    def setLockAxisScales(self, lock: bool) -> None: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def setName(self, name: str|None) -> None: ...
    def setSubsectionsSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def subsectionsSymbol(self) -> 'QgsLineSymbol|None': ...
    def distanceUnit(self) -> Qgis.DistanceUnit: ...
    def lockAxisScales(self) -> bool: ...
    def tolerance(self) -> float: ...
    def profileCurve(self) -> 'QgsCurve|None': ...
    def setProfileCurve(self, curve: 'QgsCurve|None') -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def useProjectLayerTree(self) -> bool: ...
    def layerTree(self) -> 'QgsLayerTree|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def name(self) -> str: ...


class QgsProjectStoredObjectManagerBase(QtCore.QObject):

    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...

    def markProjectDirty(self) -> None: ...
    objectAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    objectRemoved: typing.ClassVar[QtCore.pyqtSignal]
    objectAdded: typing.ClassVar[QtCore.pyqtSignal]
    objectAboutToBeAdded: typing.ClassVar[QtCore.pyqtSignal]


class QgsElevationProfileManager(QgsProjectStoredObjectManagerBase):

    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...

    def setupObjectConnections(self, profile: QgsElevationProfile|None) -> None: ...
    profileRenamed: typing.ClassVar[QtCore.pyqtSignal]
    profileAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    profileRemoved: typing.ClassVar[QtCore.pyqtSignal]
    profileAdded: typing.ClassVar[QtCore.pyqtSignal]
    profileAboutToBeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def generateUniqueTitle(self) -> str: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def profileByName(self, name: str|None) -> QgsElevationProfile|None: ...
    def profiles(self) -> list[QgsElevationProfile]: ...
    def clear(self) -> None: ...
    def removeProfile(self, profile: QgsElevationProfile|None) -> bool: ...
    def addProfile(self, profile: QgsElevationProfile|None) -> bool: ...


class QgsProjectStoredObjectManagerModelBase(QtCore.QAbstractListModel):

    class CustomRole(enum.IntEnum):
        Object = ... # type: QgsProjectStoredObjectManagerModelBase.CustomRole
        IsEmptyObject = ... # type: QgsProjectStoredObjectManagerModelBase.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...


class QgsElevationProfileManagerModel(QgsProjectStoredObjectManagerModelBase):

    class CustomRole(enum.IntEnum):
        ElevationProfile = ... # type: QgsElevationProfileManagerModel.CustomRole

    def __init__(self, manager: QgsElevationProfileManager|None, parent: QtCore.QObject|None = ...) -> None: ...

    def indexFromProfile(self, profile: QgsElevationProfile|None) -> QtCore.QModelIndex: ...
    def profileFromIndex(self, index: QtCore.QModelIndex) -> QgsElevationProfile|None: ...


class QgsProjectStoredObjectManagerProxyModelBase(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def filterAcceptsRowInternal(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def filterString(self) -> str: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...


class QgsElevationProfileManagerProxyModel(QgsProjectStoredObjectManagerProxyModelBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...


class QgsProfileExporter(PyQt6.sip.wrapper):

    def __init__(self, sources: collections.abc.Iterable[QgsAbstractProfileSource], request: 'QgsProfileRequest', type: Qgis.ProfileExportType) -> None: ...

    def toLayers(self) -> list[QgsVectorLayer]: ...
    def run(self, feedback: QgsFeedback|None = ...) -> None: ...


class QgsProfileExporterTask(QgsTask):

    class ExportResult(enum.Enum):
        Success = ... # type: QgsProfileExporterTask.ExportResult
        Empty = ... # type: QgsProfileExporterTask.ExportResult
        DeviceError = ... # type: QgsProfileExporterTask.ExportResult
        DxfExportFailed = ... # type: QgsProfileExporterTask.ExportResult
        LayerExportFailed = ... # type: QgsProfileExporterTask.ExportResult
        Canceled = ... # type: QgsProfileExporterTask.ExportResult

    def __init__(self, sources: collections.abc.Iterable[QgsAbstractProfileSource], request: 'QgsProfileRequest', type: Qgis.ProfileExportType, destination: str|None, transformContext: 'QgsCoordinateTransformContext') -> None: ...

    def error(self) -> str: ...
    def createdFiles(self) -> list[str]: ...
    def result(self) -> 'QgsProfileExporterTask.ExportResult': ...
    def takeLayers(self) -> list[QgsVectorLayer]: ...
    def cancel(self) -> None: ...
    def run(self) -> bool: ...


class QgsProfilePoint(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, distance: float, elevation: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfilePoint') -> None: ...

    def __getitem__(self, a0: int) -> typing.Any: ...
    def __len__(self) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def isEmpty(self) -> bool: ...
    def elevation(self) -> float: ...
    def distance(self) -> float: ...
    def setElevation(self, elevation: float) -> None: ...
    def setDistance(self, distance: float) -> None: ...


class QgsProfilePlotRenderer(QtCore.QObject):

    def __init__(self, sources: collections.abc.Iterable[QgsAbstractProfileSource], request: 'QgsProfileRequest') -> None: ...

    generationFinished: typing.ClassVar[QtCore.pyqtSignal]
    def asFeatures(self, type: Qgis.ProfileExportType, feedback: QgsFeedback|None = ...) -> list[QgsAbstractProfileResults.Feature]: ...
    @typing.overload
    def identify(self, point: QgsProfilePoint, context: QgsProfileIdentifyContext) -> list[QgsProfileIdentifyResults]: ...
    @typing.overload
    def identify(self, distanceRange: QgsDoubleRange, elevationRange: QgsDoubleRange, context: QgsProfileIdentifyContext) -> list[QgsProfileIdentifyResults]: ...
    def snapPoint(self, point: QgsProfilePoint, context: 'QgsProfileSnapContext') -> 'QgsProfileSnapResult': ...
    def renderSubsectionsIndicator(self, context: QgsRenderContext, plotArea: QtCore.QRectF, distanceMin: float, distanceMax: float, zMin: float, zMax: float) -> None: ...
    def setSubsectionsSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def subsectionsSymbol(self) -> 'QgsLineSymbol|None': ...
    @staticmethod
    def defaultSubSectionsSymbol() -> 'QgsLineSymbol'|None: ...
    def render(self, context: QgsRenderContext, width: float, height: float, distanceMin: float, distanceMax: float, zMin: float, zMax: float, sourceId: str|None = ...) -> None: ...
    def renderToImage(self, width: int, height: int, distanceMin: float, distanceMax: float, zMin: float, zMax: float, sourceId: str|None = ..., devicePixelRatio: float = ...) -> QtGui.QImage: ...
    def zRange(self) -> QgsDoubleRange: ...
    def regenerateInvalidatedResults(self) -> None: ...
    def invalidateResults(self, source: QgsAbstractProfileSource|None) -> bool: ...
    def replaceSource(self, source: QgsAbstractProfileSource|None) -> None: ...
    def invalidateAllRefinableSources(self) -> None: ...
    def setContext(self, context: QgsProfileGenerationContext) -> None: ...
    def isActive(self) -> bool: ...
    def waitForFinished(self) -> None: ...
    def cancelGenerationWithoutBlocking(self) -> None: ...
    def cancelGeneration(self) -> None: ...
    def generateSynchronously(self) -> None: ...
    def startGeneration(self) -> None: ...
    def sourceIds(self) -> list[str]: ...


class QgsProfileRequest(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, curve: 'QgsCurve|None') -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsProfileRequest') -> None: ...

    def setExpressionContext(self, context: QgsExpressionContext) -> 'QgsProfileRequest': ...
    def expressionContext(self) -> QgsExpressionContext: ...
    def stepDistance(self) -> float: ...
    def setStepDistance(self, distance: float) -> 'QgsProfileRequest': ...
    def terrainProvider(self) -> 'QgsAbstractTerrainProvider|None': ...
    def setTerrainProvider(self, provider: 'QgsAbstractTerrainProvider|None') -> 'QgsProfileRequest': ...
    def tolerance(self) -> float: ...
    def setTolerance(self, tolerance: float) -> 'QgsProfileRequest': ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> 'QgsProfileRequest': ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> 'QgsProfileRequest': ...
    def profileCurve(self) -> 'QgsCurve|None': ...
    def setProfileCurve(self, curve: 'QgsCurve|None') -> 'QgsProfileRequest': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsProfileSnapContext(PyQt6.sip.wrapper):

    displayRatioElevationVsDistance = ... # type: float
    maximumPointDistanceDelta = ... # type: float
    maximumPointElevationDelta = ... # type: float
    maximumSurfaceDistanceDelta = ... # type: float
    maximumSurfaceElevationDelta = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfileSnapContext') -> None: ...


class QgsProfileSnapResult(PyQt6.sip.wrapper):

    snappedPoint = ... # type: QgsProfilePoint

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProfileSnapResult') -> None: ...

    def isValid(self) -> bool: ...


class QgsProfileSourceRegistry(QtCore.QObject):

    def __init__(self) -> None: ...

    profileSourceUnregistered: typing.ClassVar[QtCore.pyqtSignal]
    profileSourceRegistered: typing.ClassVar[QtCore.pyqtSignal]
    def findSourceById(self, sourceId: str|None) -> QgsAbstractProfileSource|None: ...
    @typing.overload
    @deprecated("""""")
    def unregisterProfileSource(self, source: QgsAbstractProfileSource|None) -> bool: ...
    @typing.overload
    def unregisterProfileSource(self, sourceId: str|None) -> bool: ...
    def registerProfileSource(self, source: QgsAbstractProfileSource|None) -> bool: ...
    def profileSources(self) -> list[QgsAbstractProfileSource]: ...


class QgsAbstractTerrainProvider(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def readCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def setOffset(self, offset: float) -> None: ...
    def offset(self) -> float: ...
    def setScale(self, scale: float) -> None: ...
    def scale(self) -> float: ...
    def heightAt(self, x: float, y: float) -> float: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def prepare(self) -> None: ...
    def clone(self) -> 'QgsAbstractTerrainProvider|None': ...
    def type(self) -> str: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def equals(self, other: 'QgsAbstractTerrainProvider|None') -> bool: ...


class QgsFlatTerrainProvider(QgsAbstractTerrainProvider):

    def __init__(self) -> None: ...

    def equals(self, other: QgsAbstractTerrainProvider|None) -> bool: ...
    def prepare(self) -> None: ...
    def clone(self) -> 'QgsFlatTerrainProvider|None': ...
    def heightAt(self, x: float, y: float) -> float: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def type(self) -> str: ...


class QgsRasterDemTerrainProvider(QgsAbstractTerrainProvider):

    def __init__(self) -> None: ...

    def layer(self) -> 'QgsRasterLayer|None': ...
    def setLayer(self, layer: 'QgsRasterLayer|None') -> None: ...
    def prepare(self) -> None: ...
    def equals(self, other: QgsAbstractTerrainProvider|None) -> bool: ...
    def clone(self) -> 'QgsRasterDemTerrainProvider|None': ...
    def heightAt(self, x: float, y: float) -> float: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def type(self) -> str: ...


class QgsMeshTerrainProvider(QgsAbstractTerrainProvider):

    def __init__(self) -> None: ...

    def layer(self) -> 'QgsMeshLayer|None': ...
    def setLayer(self, layer: 'QgsMeshLayer|None') -> None: ...
    def prepare(self) -> None: ...
    def equals(self, other: QgsAbstractTerrainProvider|None) -> bool: ...
    def clone(self) -> 'QgsMeshTerrainProvider|None': ...
    def heightAt(self, x: float, y: float) -> float: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def type(self) -> str: ...


class QgsExternalStorage(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExternalStorage') -> None: ...

    def doFetch(self, url: str|None, authCfg: str|None = ...) -> 'QgsExternalStorageFetchedContent|None': ...
    def doStore(self, filePath: str|None, url: str|None, authCfg: str|None = ...) -> 'QgsExternalStorageStoredContent|None': ...
    def fetch(self, url: str|None, authCfg: str|None = ..., fetchingMode: Qgis.ActionStart = ...) -> 'QgsExternalStorageFetchedContent|None': ...
    def store(self, filePath: str|None, url: str|None, authCfg: str|None = ..., storingMode: Qgis.ActionStart = ...) -> 'QgsExternalStorageStoredContent|None': ...
    def displayName(self) -> str: ...
    def type(self) -> str: ...


class QgsExternalStorageContent(QtCore.QObject):

    def __init__(self) -> None: ...

    def setStatus(self, status: Qgis.ContentStatus) -> None: ...
    def reportError(self, errorMsg: str|None) -> None: ...
    canceled: typing.ClassVar[QtCore.pyqtSignal]
    progressChanged: typing.ClassVar[QtCore.pyqtSignal]
    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    def errorString(self) -> str: ...
    def status(self) -> Qgis.ContentStatus: ...


class QgsExternalStorageFetchedContent(QgsExternalStorageContent):

    def __init__(self) -> None: ...

    fetched: typing.ClassVar[QtCore.pyqtSignal]
    def fetch(self) -> None: ...
    def filePath(self) -> str: ...


class QgsExternalStorageStoredContent(QgsExternalStorageContent):

    def __init__(self) -> None: ...

    stored: typing.ClassVar[QtCore.pyqtSignal]
    def store(self) -> None: ...
    def url(self) -> str: ...


class QgsExternalStorageRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExternalStorageRegistry') -> None: ...

    def unregisterExternalStorage(self, storage: QgsExternalStorage|None) -> None: ...
    def registerExternalStorage(self, storage: QgsExternalStorage|None) -> None: ...
    def externalStorages(self) -> list[QgsExternalStorage]: ...
    def externalStorageFromType(self, type: str|None) -> QgsExternalStorage|None: ...


class QgsPaintEffect(PyQt6.sip.wrapper):

    class DrawMode(enum.IntEnum):
        Modifier = ... # type: QgsPaintEffect.DrawMode
        Render = ... # type: QgsPaintEffect.DrawMode
        ModifyAndRender = ... # type: QgsPaintEffect.DrawMode

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsPaintEffect') -> None: ...

    @deprecated("""""")
    def fixQPictureDpi(self, painter: QtGui.QPainter|None) -> None: ...
    def boundingRect(self, rect: QtCore.QRectF, context: QgsRenderContext) -> QtCore.QRectF: ...
    def imageOffset(self, context: QgsRenderContext) -> QtCore.QPointF: ...
    def sourceAsImage(self, context: QgsRenderContext) -> QtGui.QImage: ...
    def source(self) -> QtGui.QPicture: ...
    def drawSource(self, painter: QtGui.QPainter) -> None: ...
    def draw(self, context: QgsRenderContext) -> None: ...
    def setDrawMode(self, drawMode: 'QgsPaintEffect.DrawMode') -> None: ...
    def drawMode(self) -> 'QgsPaintEffect.DrawMode': ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def end(self, context: QgsRenderContext) -> None: ...
    def begin(self, context: QgsRenderContext) -> None: ...
    def render(self, picture: QtGui.QPicture, context: QgsRenderContext) -> None: ...
    def saveProperties(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement) -> bool: ...
    @typing.overload
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def readProperties(self, element: QtXml.QDomElement) -> bool: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...
    def clone(self) -> 'QgsPaintEffect|None': ...
    def type(self) -> str: ...


class QgsBlurEffect(QgsPaintEffect):

    class BlurMethod(enum.IntEnum):
        StackBlur = ... # type: QgsBlurEffect.BlurMethod
        GaussianBlur = ... # type: QgsBlurEffect.BlurMethod

    def __init__(self) -> None: ...

    def boundingRect(self, rect: QtCore.QRectF, context: QgsRenderContext) -> QtCore.QRectF: ...
    def draw(self, context: QgsRenderContext) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def blurMethod(self) -> 'QgsBlurEffect.BlurMethod': ...
    def setBlurMethod(self, method: 'QgsBlurEffect.BlurMethod') -> None: ...
    def blurMapUnitScale(self) -> QgsMapUnitScale: ...
    def setBlurMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def blurUnit(self) -> Qgis.RenderUnit: ...
    def setBlurUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def blurLevel(self) -> float: ...
    def setBlurLevel(self, level: float) -> None: ...
    def clone(self) -> 'QgsBlurEffect|None': ...
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def type(self) -> str: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsColorEffect(QgsPaintEffect):

    def __init__(self) -> None: ...

    def draw(self, context: QgsRenderContext) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def colorizeStrength(self) -> int: ...
    def setColorizeStrength(self, colorizeStrength: int) -> None: ...
    def colorizeColor(self) -> QtGui.QColor: ...
    def setColorizeColor(self, colorizeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def colorizeOn(self) -> bool: ...
    def setColorizeOn(self, colorizeOn: bool) -> None: ...
    def grayscaleMode(self) -> 'QgsImageOperation.GrayscaleMode': ...
    def setGrayscaleMode(self, grayscaleMode: 'QgsImageOperation.GrayscaleMode') -> None: ...
    def saturation(self) -> float: ...
    def setSaturation(self, saturation: float) -> None: ...
    def contrast(self) -> int: ...
    def setContrast(self, contrast: int) -> None: ...
    def brightness(self) -> int: ...
    def setBrightness(self, brightness: int) -> None: ...
    def clone(self) -> 'QgsColorEffect|None': ...
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def type(self) -> str: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsEffectStack(QgsPaintEffect):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsEffectStack') -> None: ...
    @typing.overload
    def __init__(self, effect: QgsPaintEffect) -> None: ...

    def draw(self, context: QgsRenderContext) -> None: ...
    def effect(self, index: int) -> QgsPaintEffect|None: ...
    def count(self) -> int: ...
    def effectList(self) -> list[QgsPaintEffect]: ...
    def takeEffect(self, index: int) -> QgsPaintEffect|None: ...
    def changeEffect(self, index: int, effect: QgsPaintEffect|None) -> bool: ...
    def insertEffect(self, index: int, effect: QgsPaintEffect|None) -> bool: ...
    def appendEffect(self, effect: QgsPaintEffect|None) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    @typing.overload
    def readProperties(self, element: QtXml.QDomElement) -> bool: ...
    @typing.overload
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def saveProperties(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement) -> bool: ...
    def clone(self) -> 'QgsEffectStack|None': ...
    def type(self) -> str: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsGlowEffect(QgsPaintEffect):

    class GlowColorType(enum.IntEnum):
        SingleColor = ... # type: QgsGlowEffect.GlowColorType
        ColorRamp = ... # type: QgsGlowEffect.GlowColorType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsGlowEffect') -> None: ...

    def shadeExterior(self) -> bool: ...
    def draw(self, context: QgsRenderContext) -> None: ...
    def boundingRect(self, rect: QtCore.QRectF, context: QgsRenderContext) -> QtCore.QRectF: ...
    def colorType(self) -> 'QgsGlowEffect.GlowColorType': ...
    def setColorType(self, colorType: 'QgsGlowEffect.GlowColorType') -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def ramp(self) -> QgsColorRamp|None: ...
    def setRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def blurMapUnitScale(self) -> QgsMapUnitScale: ...
    def setBlurMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def blurUnit(self) -> Qgis.RenderUnit: ...
    def setBlurUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def blurLevel(self) -> float: ...
    def setBlurLevel(self, level: float) -> None: ...
    def spreadMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSpreadMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def spreadUnit(self) -> Qgis.RenderUnit: ...
    def setSpreadUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def spread(self) -> float: ...
    def setSpread(self, spread: float) -> None: ...
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...


class QgsOuterGlowEffect(QgsGlowEffect):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOuterGlowEffect') -> None: ...

    def shadeExterior(self) -> bool: ...
    def clone(self) -> 'QgsOuterGlowEffect|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsInnerGlowEffect(QgsGlowEffect):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsInnerGlowEffect') -> None: ...

    def shadeExterior(self) -> bool: ...
    def clone(self) -> 'QgsInnerGlowEffect|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsImageOperation(PyQt6.sip.wrapper):

    class FlipType(enum.IntEnum):
        FlipHorizontal = ... # type: QgsImageOperation.FlipType
        FlipVertical = ... # type: QgsImageOperation.FlipType

    class GrayscaleMode(enum.IntEnum):
        GrayscaleLightness = ... # type: QgsImageOperation.GrayscaleMode
        GrayscaleLuminosity = ... # type: QgsImageOperation.GrayscaleMode
        GrayscaleAverage = ... # type: QgsImageOperation.GrayscaleMode
        GrayscaleOff = ... # type: QgsImageOperation.GrayscaleMode

    class DistanceTransformProperties(PyQt6.sip.wrapper):

        ramp = ... # type: QgsColorRamp
        shadeExterior = ... # type: bool
        spread = ... # type: float
        useMaxDistance = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsImageOperation.DistanceTransformProperties') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsImageOperation') -> None: ...

    @staticmethod
    def cropTransparent(image: QtGui.QImage, minSize: QtCore.QSize = ..., center: bool = ...) -> QtGui.QImage: ...
    @staticmethod
    def nonTransparentImageRect(image: QtGui.QImage, minSize: QtCore.QSize = ..., center: bool = ...) -> QtCore.QRect: ...
    @staticmethod
    def flipImage(image: QtGui.QImage, type: 'QgsImageOperation.FlipType') -> None: ...
    @staticmethod
    def gaussianBlur(image: QtGui.QImage, radius: int, feedback: QgsFeedback|None = ...) -> QtGui.QImage|None: ...
    @staticmethod
    def stackBlur(image: QtGui.QImage, radius: int, alphaOnly: bool = ..., feedback: QgsFeedback|None = ...) -> None: ...
    @staticmethod
    def distanceTransform(image: QtGui.QImage, properties: 'QgsImageOperation.DistanceTransformProperties', feedback: QgsFeedback|None = ...) -> None: ...
    @staticmethod
    def overlayColor(image: QtGui.QImage, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @staticmethod
    def multiplyOpacity(image: QtGui.QImage, factor: float, feedback: QgsFeedback|None = ...) -> None: ...
    @staticmethod
    def adjustHueSaturation(image: QtGui.QImage, saturation: float, colorizeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., colorizeStrength: float = ..., feedback: QgsFeedback|None = ...) -> None: ...
    @staticmethod
    def adjustBrightnessContrast(image: QtGui.QImage, brightness: int, contrast: float, feedback: QgsFeedback|None = ...) -> None: ...
    @staticmethod
    def convertToGrayscale(image: QtGui.QImage, mode: 'QgsImageOperation.GrayscaleMode' = ..., feedback: QgsFeedback|None = ...) -> None: ...


class QgsDrawSourceEffect(QgsPaintEffect):

    def __init__(self) -> None: ...

    def draw(self, context: QgsRenderContext) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsDrawSourceEffect|None': ...
    def type(self) -> str: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsEffectPainter(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, renderContext: QgsRenderContext) -> None: ...
    @typing.overload
    def __init__(self, renderContext: QgsRenderContext, effect: QgsPaintEffect|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEffectPainter') -> None: ...

    def setEffect(self, effect: QgsPaintEffect|None) -> None: ...


class QgsPaintEffectAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPaintEffectAbstractMetadata') -> None: ...

    def createWidget(self) -> QgsPaintEffectWidget|None: ...
    def createPaintEffect(self, map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsPaintEffectRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def isDefaultStack(effect: QgsPaintEffect|None) -> bool: ...
    @staticmethod
    def defaultStack() -> QgsPaintEffect|None: ...
    def effects(self) -> list[str]: ...
    @typing.overload
    def createEffect(self, name: str|None, properties: dict[str|None, typing.Any] = ...) -> QgsPaintEffect|None: ...
    @typing.overload
    def createEffect(self, element: QtXml.QDomElement) -> QgsPaintEffect|None: ...
    def addEffectType(self, metadata: QgsPaintEffectAbstractMetadata|None) -> bool: ...
    def effectMetadata(self, name: str|None) -> QgsPaintEffectAbstractMetadata|None: ...


class QgsShadowEffect(QgsPaintEffect):

    def __init__(self) -> None: ...

    def exteriorShadow(self) -> bool: ...
    def draw(self, context: QgsRenderContext) -> None: ...
    def boundingRect(self, rect: QtCore.QRectF, context: QgsRenderContext) -> QtCore.QRectF: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetDistance(self) -> float: ...
    def setOffsetDistance(self, distance: float) -> None: ...
    def offsetAngle(self) -> int: ...
    def setOffsetAngle(self, angle: int) -> None: ...
    def blurMapUnitScale(self) -> QgsMapUnitScale: ...
    def setBlurMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def blurUnit(self) -> Qgis.RenderUnit: ...
    def setBlurUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def blurLevel(self) -> float: ...
    def setBlurLevel(self, level: float) -> None: ...
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def flags(self) -> Qgis.PaintEffectFlag: ...


class QgsDropShadowEffect(QgsShadowEffect):

    def __init__(self) -> None: ...

    def exteriorShadow(self) -> bool: ...
    def clone(self) -> 'QgsDropShadowEffect|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsInnerShadowEffect(QgsShadowEffect):

    def __init__(self) -> None: ...

    def exteriorShadow(self) -> bool: ...
    def clone(self) -> 'QgsInnerShadowEffect|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsTransformEffect(QgsPaintEffect):

    def __init__(self) -> None: ...

    def boundingRect(self, rect: QtCore.QRectF, context: QgsRenderContext) -> QtCore.QRectF: ...
    def draw(self, context: QgsRenderContext) -> None: ...
    def reflectY(self) -> bool: ...
    def setReflectY(self, reflectY: bool) -> None: ...
    def reflectX(self) -> bool: ...
    def setReflectX(self, reflectX: bool) -> None: ...
    def shearY(self) -> float: ...
    def setShearY(self, shearY: float) -> None: ...
    def shearX(self) -> float: ...
    def setShearX(self, shearX: float) -> None: ...
    def rotation(self) -> float: ...
    def setRotation(self, rotation: float) -> None: ...
    def scaleY(self) -> float: ...
    def setScaleY(self, scaleY: float) -> None: ...
    def scaleX(self) -> float: ...
    def setScaleX(self, scaleX: float) -> None: ...
    def translateMapUnitScale(self) -> QgsMapUnitScale: ...
    def setTranslateMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def translateUnit(self) -> Qgis.RenderUnit: ...
    def setTranslateUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def translateY(self) -> float: ...
    def setTranslateY(self, translateY: float) -> None: ...
    def translateX(self) -> float: ...
    def setTranslateX(self, translateX: float) -> None: ...
    def clone(self) -> 'QgsTransformEffect|None': ...
    def readProperties(self, props: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def type(self) -> str: ...
    @staticmethod
    def create(map: dict[str|None, typing.Any]) -> QgsPaintEffect|None: ...


class QgsExpression(PyQt6.sip.wrapper):

    class SpatialOperator(enum.IntEnum):
        soBbox = ... # type: QgsExpression.SpatialOperator
        soIntersects = ... # type: QgsExpression.SpatialOperator
        soContains = ... # type: QgsExpression.SpatialOperator
        soCrosses = ... # type: QgsExpression.SpatialOperator
        soEquals = ... # type: QgsExpression.SpatialOperator
        soDisjoint = ... # type: QgsExpression.SpatialOperator
        soOverlaps = ... # type: QgsExpression.SpatialOperator
        soTouches = ... # type: QgsExpression.SpatialOperator
        soWithin = ... # type: QgsExpression.SpatialOperator

    class ParserError(PyQt6.sip.wrapper):

        class ParserErrorType(enum.IntEnum):
            Unknown = ... # type: QgsExpression.ParserError.ParserErrorType
            FunctionUnknown = ... # type: QgsExpression.ParserError.ParserErrorType
            FunctionWrongArgs = ... # type: QgsExpression.ParserError.ParserErrorType
            FunctionInvalidParams = ... # type: QgsExpression.ParserError.ParserErrorType
            FunctionNamedArgsError = ... # type: QgsExpression.ParserError.ParserErrorType

        errorMsg = ... # type: str|None
        errorType = ... # type: 'QgsExpression.ParserError.ParserErrorType'
        firstColumn = ... # type: int
        firstLine = ... # type: int
        lastColumn = ... # type: int
        lastLine = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpression.ParserError') -> None: ...

    @typing.overload
    def __init__(self, expr: str|None) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsExpression') -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

    def __ne__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def attemptReduceToInClause(expressions: collections.abc.Iterable[str|None]) -> typing.Tuple[bool, str]: ...
    @staticmethod
    def isFieldEqualityExpression(expression: str|None) -> typing.Tuple[bool, str, typing.Any]: ...
    @typing.overload
    @staticmethod
    def createFieldEqualityExpression(fieldName: str|None, value: typing.Any, fieldType: QtCore.QMetaType.Type = ...) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def createFieldEqualityExpression(fieldName: str|None, value: typing.Any, fieldType: typing.Any) -> str: ...
    @staticmethod
    def formatPreviewString(value: typing.Any, htmlOutput: bool = ..., maximumPreviewLength: int = ...) -> str: ...
    @staticmethod
    def group(group: str|None) -> str: ...
    @staticmethod
    def formatVariableHelp(description: str|None, showValue: bool = ..., value: typing.Any = ...) -> str: ...
    @staticmethod
    def variableHelpText(variableName: str|None) -> str: ...
    @staticmethod
    def addVariableHelpText(name: str|None, description: str|None) -> bool: ...
    @staticmethod
    def tags(name: str|None) -> list[str]: ...
    @staticmethod
    def helpText(name: str|None) -> str: ...
    @typing.overload
    @staticmethod
    def quotedValue(value: typing.Any) -> str: ...
    @typing.overload
    @staticmethod
    def quotedValue(value: typing.Any, type: QtCore.QMetaType.Type) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def quotedValue(value: typing.Any, type: typing.Any) -> str: ...
    @staticmethod
    def quotedString(text: str|None) -> str: ...
    @staticmethod
    def quotedColumnRef(name: str|None) -> str: ...
    @staticmethod
    def functionCount() -> int: ...
    @staticmethod
    def functionIndex(name: str|None) -> int: ...
    @staticmethod
    def isFunctionName(name: str|None) -> bool: ...
    @staticmethod
    def cleanRegisteredFunctions() -> None: ...
    @staticmethod
    def unregisterFunction(name: str|None) -> bool: ...
    @staticmethod
    def registerFunction(function: QgsExpressionFunction|None, transferOwnership: bool = ...) -> bool: ...
    @staticmethod
    def BuiltinFunctions() -> list[str]: ...
    @staticmethod
    def Functions() -> list[QgsExpressionFunction]: ...
    @staticmethod
    def evaluateToDouble(text: str|None, fallbackValue: float) -> float: ...
    @staticmethod
    def replaceExpressionText(action: str|None, context: QgsExpressionContext|None, distanceArea: QgsDistanceArea|None = ...) -> str: ...
    def setAreaUnits(self, unit: Qgis.AreaUnit) -> None: ...
    def areaUnits(self) -> Qgis.AreaUnit: ...
    def setDistanceUnits(self, unit: Qgis.DistanceUnit) -> None: ...
    def distanceUnits(self) -> Qgis.DistanceUnit: ...
    def setGeomCalculator(self, calc: QgsDistanceArea|None) -> None: ...
    def geomCalculator(self) -> QgsDistanceArea|None: ...
    def dump(self) -> str: ...
    def expression(self) -> str: ...
    def setExpression(self, expression: str|None) -> None: ...
    @staticmethod
    def checkExpression(text: str|None, context: QgsExpressionContext|None) -> typing.Tuple[bool, str]: ...
    @staticmethod
    def quoteFieldExpression(expression: str|None, layer: QgsVectorLayer|None) -> str: ...
    @staticmethod
    def expressionToLayerFieldIndex(expression: str|None, layer: QgsVectorLayer|None) -> int: ...
    def isField(self) -> bool: ...
    def setEvalErrorString(self, str: str|None) -> None: ...
    def evalErrorString(self) -> str: ...
    def hasEvalError(self) -> bool: ...
    @typing.overload
    def evaluate(self) -> typing.Any: ...
    @typing.overload
    def evaluate(self, context: QgsExpressionContext|None) -> typing.Any: ...
    def needsGeometry(self) -> bool: ...
    def referencedAttributeIndexes(self, fields: QgsFields) -> typing.Any: ...
    def referencedFunctions(self) -> set[str]: ...
    @typing.overload
    def referencedVariables(self) -> set[str]: ...
    @typing.overload
    @staticmethod
    def referencedVariables(text: str|None) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def prepare(self, context: QgsExpressionContext|None) -> bool: ...
    def rootNode(self) -> 'QgsExpressionNode|None': ...
    def parserErrors(self) -> list['QgsExpression.ParserError']: ...
    def parserErrorString(self) -> str: ...
    def hasParserError(self) -> bool: ...
    def isValid(self) -> bool: ...
    def __eq__(self, other: object): ...


class QgsExpressionContextUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionContextUtils') -> None: ...

    @staticmethod
    def meshExpressionScope(elementType: 'QgsMesh.ElementType') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def registerContextFunctions() -> None: ...
    @staticmethod
    def notificationScope(message: str|None = ...) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def processingModelAlgorithmScope(model: 'QgsProcessingModelAlgorithm|None', parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def processingAlgorithmScope(algorithm: 'QgsProcessingAlgorithm|None', parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def createFeatureBasedContext(feature: QgsFeature, fields: QgsFields) -> QgsExpressionContext: ...
    @staticmethod
    def setLayoutMultiFrameVariables(frame: 'QgsLayoutMultiFrame|None', variables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def setLayoutMultiFrameVariable(frame: 'QgsLayoutMultiFrame|None', name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def multiFrameScope(frame: 'QgsLayoutMultiFrame|None') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def setLayoutItemVariables(item: 'QgsLayoutItem|None', variables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def setLayoutItemVariable(item: 'QgsLayoutItem|None', name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def layoutItemScope(item: 'QgsLayoutItem|None') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def atlasScope(atlas: 'QgsLayoutAtlas|None') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def setLayoutVariables(layout: 'QgsLayout|None', variables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def setLayoutVariable(layout: 'QgsLayout|None', name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def layoutScope(layout: 'QgsLayout|None') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def updateSymbolScope(symbol: 'QgsSymbol|None', symbolScope: QgsExpressionContextScope|None = ...) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def mapLayerPositionScope(position: QgsPointXY) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def mapToolCaptureScope(matches: collections.abc.Iterable[QgsPointLocator.Match]) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def mapSettingsScope(mapSettings: QgsMapSettings) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def setLayerVariables(layer: QgsMapLayer|None, variables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def setLayerVariable(layer: QgsMapLayer|None, name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def globalProjectLayerScopes(layer: QgsMapLayer|None) -> list[QgsExpressionContextScope]: ...
    @staticmethod
    def layerScope(layer: QgsMapLayer|None) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def removeProjectVariable(project: 'QgsProject|None', name: str|None) -> None: ...
    @staticmethod
    def setProjectVariables(project: 'QgsProject|None', variables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def setProjectVariable(project: 'QgsProject|None', name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def projectScope(project: 'QgsProject|None') -> QgsExpressionContextScope|None: ...
    @staticmethod
    def removeGlobalVariable(name: str|None) -> None: ...
    @staticmethod
    def setGlobalVariables(variables: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def setGlobalVariable(name: str|None, value: typing.Any) -> None: ...
    @staticmethod
    def parentFormScope(formFeature: QgsFeature = ..., formMode: str|None = ...) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def formScope(formFeature: QgsFeature = ..., formMode: str|None = ...) -> QgsExpressionContextScope|None: ...
    @staticmethod
    def globalScope() -> QgsExpressionContextScope|None: ...


class QgsExpressionNode(PyQt6.sip.wrapper):

    class NodeType(enum.IntEnum):
        ntUnaryOperator = ... # type: QgsExpressionNode.NodeType
        ntBinaryOperator = ... # type: QgsExpressionNode.NodeType
        ntInOperator = ... # type: QgsExpressionNode.NodeType
        ntFunction = ... # type: QgsExpressionNode.NodeType
        ntLiteral = ... # type: QgsExpressionNode.NodeType
        ntColumnRef = ... # type: QgsExpressionNode.NodeType
        ntCondition = ... # type: QgsExpressionNode.NodeType
        ntIndexOperator = ... # type: QgsExpressionNode.NodeType
        ntBetweenOperator = ... # type: QgsExpressionNode.NodeType

    class NamedNode(PyQt6.sip.wrapper):

        name = ... # type: str|None
        node = ... # type: 'QgsExpressionNode'

        @typing.overload
        def __init__(self, name: str|None, node: 'QgsExpressionNode|None') -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpressionNode.NamedNode') -> None: ...

    class NodeList(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpressionNode.NodeList') -> None: ...

        def dump(self) -> str: ...
        def clone(self) -> 'QgsExpressionNode.NodeList|None': ...
        def names(self) -> list[str]: ...
        def at(self, i: int) -> 'QgsExpressionNode|None': ...
        def list(self) -> list['QgsExpressionNode']: ...
        def hasNamedNodes(self) -> bool: ...
        def reserve(self, size: int) -> None: ...
        def count(self) -> int: ...
        @typing.overload
        def append(self, node: 'QgsExpressionNode|None') -> None: ...
        @typing.overload
        def append(self, node: 'QgsExpressionNode.NamedNode|None') -> None: ...

    parserFirstColumn = ... # type: int
    parserFirstLine = ... # type: int
    parserLastColumn = ... # type: int
    parserLastLine = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsExpressionNode') -> None: ...

    def effectiveNode(self) -> 'QgsExpressionNode|None': ...
    def cachedStaticValue(self) -> typing.Any: ...
    def hasCachedStaticValue(self) -> bool: ...
    def prepare(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def clone(self) -> 'QgsExpressionNode|None': ...
    def eval(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def dump(self) -> str: ...
    def nodeType(self) -> 'QgsExpressionNode.NodeType': ...


class QgsExpressionNodeUnaryOperator(QgsExpressionNode):

    class UnaryOperator(enum.IntEnum):
        uoNot = ... # type: QgsExpressionNodeUnaryOperator.UnaryOperator
        uoMinus = ... # type: QgsExpressionNodeUnaryOperator.UnaryOperator

    def __init__(self, op: 'QgsExpressionNodeUnaryOperator.UnaryOperator', operand: QgsExpressionNode|None) -> None: ...

    def text(self) -> str: ...
    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def operand(self) -> QgsExpressionNode|None: ...
    def op(self) -> 'QgsExpressionNodeUnaryOperator.UnaryOperator': ...
    def __repr__(self) -> typing.Any: ...


class QgsExpressionNodeBinaryOperator(QgsExpressionNode):

    class BinaryOperator(enum.IntEnum):
        boOr = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boAnd = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boEQ = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boNE = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boLE = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boGE = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boLT = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boGT = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boRegexp = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boLike = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boNotLike = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boILike = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boNotILike = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boIs = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boIsNot = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boPlus = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boMinus = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boMul = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boDiv = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boIntDiv = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boMod = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boPow = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator
        boConcat = ... # type: QgsExpressionNodeBinaryOperator.BinaryOperator

    def __init__(self, op: 'QgsExpressionNodeBinaryOperator.BinaryOperator', opLeft: QgsExpressionNode|None, opRight: QgsExpressionNode|None) -> None: ...

    def text(self) -> str: ...
    def leftAssociative(self) -> bool: ...
    def precedence(self) -> int: ...
    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def opRight(self) -> QgsExpressionNode|None: ...
    def opLeft(self) -> QgsExpressionNode|None: ...
    def op(self) -> 'QgsExpressionNodeBinaryOperator.BinaryOperator': ...
    def __repr__(self) -> typing.Any: ...


class QgsExpressionNodeIndexOperator(QgsExpressionNode):

    def __init__(self, container: QgsExpressionNode|None, index: QgsExpressionNode|None) -> None: ...

    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def index(self) -> QgsExpressionNode|None: ...
    def container(self) -> QgsExpressionNode|None: ...


class QgsExpressionNodeBetweenOperator(QgsExpressionNode):

    def __init__(self, node: QgsExpressionNode|None, nodeLowerBound: QgsExpressionNode|None, nodeHigherBound: QgsExpressionNode|None, negate: bool = ...) -> None: ...

    def negate(self) -> bool: ...
    def higherBound(self) -> QgsExpressionNode|None: ...
    def lowerBound(self) -> QgsExpressionNode|None: ...
    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def node(self) -> QgsExpressionNode|None: ...


class QgsExpressionNodeInOperator(QgsExpressionNode):

    def __init__(self, node: QgsExpressionNode|None, list: QgsExpressionNode.NodeList|None, notin: bool = ...) -> None: ...

    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def list(self) -> QgsExpressionNode.NodeList|None: ...
    def isNotIn(self) -> bool: ...
    def node(self) -> QgsExpressionNode|None: ...


class QgsExpressionNodeFunction(QgsExpressionNode):

    def __init__(self, fnIndex: int, args: QgsExpressionNode.NodeList|None) -> None: ...

    @staticmethod
    def validateParams(fnIndex: int, args: QgsExpressionNode.NodeList|None, error: str|None) -> bool: ...
    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def args(self) -> QgsExpressionNode.NodeList|None: ...
    def fnIndex(self) -> int: ...
    def __repr__(self) -> typing.Any: ...


class QgsExpressionNodeLiteral(QgsExpressionNode):

    @typing.overload
    def __init__(self, value: typing.Any) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionNodeLiteral') -> None: ...

    def valueAsString(self) -> str: ...
    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def value(self) -> typing.Any: ...
    def __repr__(self) -> typing.Any: ...


class QgsExpressionNodeColumnRef(QgsExpressionNode):

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionNodeColumnRef') -> None: ...

    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def dump(self) -> str: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...
    def name(self) -> str: ...
    def __repr__(self) -> typing.Any: ...


class QgsExpressionNodeCondition(QgsExpressionNode):

    class WhenThen(PyQt6.sip.wrapper):

        def __init__(self, whenExp: QgsExpressionNode|None, thenExp: QgsExpressionNode|None) -> None: ...

        def thenExp(self) -> QgsExpressionNode|None: ...
        def whenExp(self) -> QgsExpressionNode|None: ...
        def clone(self) -> 'QgsExpressionNodeCondition.WhenThen|None': ...

    def __init__(self, conditions: collections.abc.Iterable['QgsExpressionNodeCondition.WhenThen'], elseExp: QgsExpressionNode|None = ...) -> None: ...

    def isStatic(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def clone(self) -> QgsExpressionNode|None: ...
    def needsGeometry(self) -> bool: ...
    def referencedFunctions(self) -> set[str]: ...
    def referencedVariables(self) -> set[str]: ...
    def referencedColumns(self) -> set[str]: ...
    def elseExp(self) -> QgsExpressionNode|None: ...
    def conditions(self) -> list['QgsExpressionNodeCondition.WhenThen']: ...
    def dump(self) -> str: ...
    def prepareNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> bool: ...
    def evalNode(self, parent: QgsExpression|None, context: QgsExpressionContext|None) -> typing.Any: ...
    def nodeType(self) -> QgsExpressionNode.NodeType: ...


class QgsCheckBoxFieldFormatter(QgsFieldFormatter):

    class TextDisplayMethod(enum.IntEnum):
        ShowTrueFalse = ... # type: QgsCheckBoxFieldFormatter.TextDisplayMethod
        ShowStoredValues = ... # type: QgsCheckBoxFieldFormatter.TextDisplayMethod

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCheckBoxFieldFormatter') -> None: ...

    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsDateTimeFieldFormatter(QgsFieldFormatter):

    DATETIME_DISPLAY_FORMAT = ... # type: str|None
    DATETIME_FORMAT = ... # type: str|None
    DATE_DISPLAY_FORMAT = ... # type: str|None
    DATE_FORMAT = ... # type: str|None
    DISPLAY_FOR_ISO_FORMAT = ... # type: str|None
    QT_ISO_FORMAT = ... # type: str|None
    TIME_FORMAT = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDateTimeFieldFormatter') -> None: ...

    @typing.overload
    @staticmethod
    def defaultDisplayFormat(type: QtCore.QMetaType.Type) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def defaultDisplayFormat(type: typing.Any) -> str: ...
    @typing.overload
    @staticmethod
    def defaultFormat(type: QtCore.QMetaType.Type) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def defaultFormat(type: typing.Any) -> str: ...
    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsFallbackFieldFormatter(QgsFieldFormatter):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFallbackFieldFormatter') -> None: ...

    def id(self) -> str: ...


class QgsKeyValueFieldFormatter(QgsFieldFormatter):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsKeyValueFieldFormatter') -> None: ...

    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsListFieldFormatter(QgsFieldFormatter):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsListFieldFormatter') -> None: ...

    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsRangeFieldFormatter(QgsFieldFormatter):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRangeFieldFormatter') -> None: ...

    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsRelationReferenceFieldFormatter(QgsFieldFormatter):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRelationReferenceFieldFormatter') -> None: ...

    def availableValues(self, config: dict[str|None, typing.Any], countLimit: int, context: QgsFieldFormatterContext) -> list[typing.Any]: ...
    def createCache(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any]) -> typing.Any: ...
    def sortValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> typing.Any: ...
    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsValueMapFieldFormatter(QgsFieldFormatter):

    NULL_VALUE = ... # type: str|None

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsValueMapFieldFormatter') -> None: ...

    def availableValues(self, config: dict[str|None, typing.Any], countLimit: int, context: QgsFieldFormatterContext) -> list[typing.Any]: ...
    def sortValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> typing.Any: ...
    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsValueRelationFieldFormatter(QgsFieldFormatter):

    class ValueRelationItem(PyQt6.sip.wrapper):

        description = ... # type: str|None
        group = ... # type: typing.Any
        key = ... # type: typing.Any
        value = ... # type: str|None

        @typing.overload
        def __init__(self, key: typing.Any, value: str|None, description: str|None = ..., group: typing.Any = ...) -> None: ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsValueRelationFieldFormatter.ValueRelationItem') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsValueRelationFieldFormatter') -> None: ...

    def availableValues(self, config: dict[str|None, typing.Any], countLimit: int, context: QgsFieldFormatterContext) -> list[typing.Any]: ...
    @staticmethod
    def resolveLayer(config: dict[str|None, typing.Any], project: 'QgsProject|None') -> QgsVectorLayer|None: ...
    @staticmethod
    def expressionIsUsable(expression: str|None, feature: QgsFeature, parentFeature: QgsFeature = ...) -> bool: ...
    @staticmethod
    def expressionParentFormVariables(expression: str|None) -> set[str]: ...
    @staticmethod
    def expressionParentFormAttributes(expression: str|None) -> set[str]: ...
    @staticmethod
    def expressionRequiresParentFormScope(expression: str|None) -> bool: ...
    @staticmethod
    def expressionFormVariables(expression: str|None) -> set[str]: ...
    @staticmethod
    def expressionFormAttributes(expression: str|None) -> set[str]: ...
    @staticmethod
    def expressionRequiresFormScope(expression: str|None) -> bool: ...
    @staticmethod
    def valueToStringList(value: typing.Any) -> list[str]: ...
    @typing.overload
    def createCache(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any]) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def createCache(config: dict[str|None, typing.Any], formFeature: QgsFeature = ..., parentFormFeature: QgsFeature = ...) -> list['QgsValueRelationFieldFormatter.ValueRelationItem']: ...
    def sortValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> typing.Any: ...
    def representValue(self, layer: QgsVectorLayer|None, fieldIndex: int, config: dict[str|None, typing.Any], cache: typing.Any, value: typing.Any) -> str: ...
    def id(self) -> str: ...


class QgsLocatorFilter(QtCore.QObject):

    class Flag(enum.IntEnum):
        FlagFast = ... # type: QgsLocatorFilter.Flag

    class Priority(enum.IntEnum):
        Highest = ... # type: QgsLocatorFilter.Priority
        High = ... # type: QgsLocatorFilter.Priority
        Medium = ... # type: QgsLocatorFilter.Priority
        Low = ... # type: QgsLocatorFilter.Priority
        Lowest = ... # type: QgsLocatorFilter.Priority

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    resultFetched: typing.ClassVar[QtCore.pyqtSignal]
    finished: typing.ClassVar[QtCore.pyqtSignal]
    def setFetchResultsDelay(self, delay: int) -> None: ...
    def fetchResultsDelay(self) -> int: ...
    def logMessage(self, message: str|None, level: Qgis.MessageLevel = ...) -> None: ...
    def openConfigWidget(self, parent: QtWidgets.QWidget|None = ...) -> None: ...
    def hasConfigWidget(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    @staticmethod
    def fuzzyScore(candidate: str|None, search: str|None) -> float: ...
    @staticmethod
    def stringMatches(candidate: str|None, search: str|None) -> bool: ...
    def activePrefix(self) -> str: ...
    def setUseWithoutPrefix(self, useWithoutPrefix: bool) -> None: ...
    def useWithoutPrefix(self) -> bool: ...
    def clearPreviousResults(self) -> None: ...
    def triggerResultFromAction(self, result: 'QgsLocatorResult', actionId: int) -> None: ...
    def resultDeselected(self, result: 'QgsLocatorResult') -> None: ...
    def resultSelected(self, result: 'QgsLocatorResult') -> None: ...
    def triggerResult(self, result: 'QgsLocatorResult') -> None: ...
    def fetchResults(self, string: str|None, context: 'QgsLocatorContext', feedback: QgsFeedback|None) -> None: ...
    def prepare(self, string: str|None, context: 'QgsLocatorContext') -> list[str]: ...
    def prefix(self) -> str: ...
    def priority(self) -> 'QgsLocatorFilter.Priority': ...
    def flags(self) -> 'QgsLocatorFilter.Flag': ...
    def description(self) -> str: ...
    def displayName(self) -> str: ...
    def name(self) -> str: ...
    def clone(self) -> 'QgsLocatorFilter|None': ...


class QgsAbstractGeocoderLocatorFilter(QgsLocatorFilter):

    def __init__(self, name: str|None, displayName: str|None, prefix: str|None, geocoder: 'QgsGeocoderInterface|None', boundingBox: 'QgsRectangle' = ...) -> None: ...

    def geocoderResultToLocatorResult(self, result: 'QgsGeocoderResult') -> 'QgsLocatorResult': ...
    def locatorResultToGeocoderResult(self, result: 'QgsLocatorResult') -> 'QgsGeocoderResult': ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def geocoder(self) -> 'QgsGeocoderInterface|None': ...
    def triggerResult(self, result: 'QgsLocatorResult') -> None: ...
    def fetchResults(self, string: str|None, context: 'QgsLocatorContext', feedback: QgsFeedback|None) -> None: ...
    def prefix(self) -> str: ...
    def displayName(self) -> str: ...
    def name(self) -> str: ...


class QgsGeocoderInterface(PyQt6.sip.wrapper):

    class Flag(enum.Enum):
        GeocodesStrings = ... # type: QgsGeocoderInterface.Flag
        GeocodesFeatures = ... # type: QgsGeocoderInterface.Flag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeocoderInterface') -> None: ...

    def geocodeString(self, string: str|None, context: 'QgsGeocoderContext', feedback: QgsFeedback|None = ...) -> list['QgsGeocoderResult']: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def appendedFields(self) -> QgsFields: ...
    def geocodeFeature(self, feature: QgsFeature, context: 'QgsGeocoderContext', feedback: QgsFeedback|None = ...) -> list['QgsGeocoderResult']: ...
    def flags(self) -> 'QgsGeocoderInterface.Flag': ...


class QgsGeocoderContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeocoderContext') -> None: ...

    def setAreaOfInterestCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def areaOfInterestCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setAreaOfInterest(self, area: 'QgsGeometry') -> None: ...
    def areaOfInterest(self) -> 'QgsGeometry': ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...


class QgsGeocoderResult(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, identifier: str|None, geometry: 'QgsGeometry', crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeocoderResult') -> None: ...

    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setGroup(self, group: str|None) -> None: ...
    def group(self) -> str: ...
    def setAdditionalAttributes(self, attributes: dict[str|None, typing.Any]) -> None: ...
    def additionalAttributes(self) -> dict[str, typing.Any]: ...
    def setViewport(self, viewport: 'QgsRectangle') -> None: ...
    def viewport(self) -> 'QgsRectangle': ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setGeometry(self, geometry: 'QgsGeometry') -> None: ...
    def geometry(self) -> 'QgsGeometry': ...
    def identifier(self) -> str: ...
    def error(self) -> str: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def errorResult(errorMessage: str|None) -> 'QgsGeocoderResult': ...


class QgsNominatimGeocoder(QgsGeocoderInterface):

    @typing.overload
    def __init__(self, countryCodes: str|None = ..., endpoint: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNominatimGeocoder') -> None: ...

    def setCountryCodes(self, countryCodes: str|None) -> None: ...
    def countryCodes(self) -> str: ...
    def setRequestsPerSecond(self, number: float) -> None: ...
    def requestsPerSecond(self) -> float: ...
    def setEndpoint(self, endpoint: str|None) -> None: ...
    def endpoint(self) -> str: ...
    def jsonToResult(self, json: dict[str|None, typing.Any]) -> QgsGeocoderResult: ...
    def requestUrl(self, address: str|None, bounds: 'QgsRectangle' = ...) -> QtCore.QUrl: ...
    def geocodeString(self, string: str|None, context: QgsGeocoderContext, feedback: QgsFeedback|None = ...) -> list[QgsGeocoderResult]: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def appendedFields(self) -> QgsFields: ...
    def flags(self) -> QgsGeocoderInterface.Flag: ...


class QgsGoogleMapsGeocoder(QgsGeocoderInterface):

    @typing.overload
    def __init__(self, apiKey: str|None, regionBias: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGoogleMapsGeocoder') -> None: ...

    def setRegion(self, region: str|None) -> None: ...
    def region(self) -> str: ...
    def setApiKey(self, key: str|None) -> None: ...
    def apiKey(self) -> str: ...
    def setEndpoint(self, endpoint: str|None) -> None: ...
    def jsonToResult(self, json: dict[str|None, typing.Any]) -> QgsGeocoderResult: ...
    def requestUrl(self, address: str|None, bounds: 'QgsRectangle' = ...) -> QtCore.QUrl: ...
    def geocodeString(self, string: str|None, context: QgsGeocoderContext, feedback: QgsFeedback|None = ...) -> list[QgsGeocoderResult]: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def appendedFields(self) -> QgsFields: ...
    def flags(self) -> QgsGeocoderInterface.Flag: ...


class QgsAbstractGeometry(PyQt6.sip.wrapper):

    class WkbFlag(enum.IntEnum):
        FlagExportTrianglesAsPolygons = ... # type: QgsAbstractGeometry.WkbFlag
        FlagExportNanAsDoubleMin = ... # type: QgsAbstractGeometry.WkbFlag

    class AxisOrder(enum.IntEnum):
        XY = ... # type: QgsAbstractGeometry.AxisOrder
        YX = ... # type: QgsAbstractGeometry.AxisOrder

    class SegmentationToleranceType(enum.IntEnum):
        MaximumAngle = ... # type: QgsAbstractGeometry.SegmentationToleranceType
        MaximumDifference = ... # type: QgsAbstractGeometry.SegmentationToleranceType

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, geom: 'QgsAbstractGeometry') -> None: ...

    def clearCache(self) -> None: ...
    def calculateBoundingBox3D(self) -> 'QgsBox3D': ...
    def calculateBoundingBox(self) -> 'QgsRectangle': ...
    def setZMTypeFromSubGeometry(self, subggeom: 'QgsAbstractGeometry|None', baseGeomType: Qgis.WkbType) -> None: ...
    def childPoint(self, index: int) -> 'QgsPoint': ...
    def childGeometry(self, index: int) -> 'QgsAbstractGeometry|None': ...
    def childCount(self) -> int: ...
    def hasChildGeometries(self) -> bool: ...
    def compareToSameClass(self, other: 'QgsAbstractGeometry|None') -> int: ...
    def sortIndex(self) -> int: ...
    def createEmptyWithSameType(self) -> 'QgsAbstractGeometry|None': ...
    def vertices(self) -> 'QgsVertexIterator': ...
    def parts(self) -> 'QgsGeometryPartIterator': ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def simplifiedTypeRef(self) -> 'QgsAbstractGeometry|None': ...
    def convertTo(self, type: Qgis.WkbType) -> bool: ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def partCount(self) -> int: ...
    def ringCount(self, part: int = ...) -> int: ...
    def vertexCount(self, part: int = ..., ring: int = ...) -> int: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsAbstractGeometry|None': ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsAbstractGeometry|None': ...
    def toCurveType(self) -> 'QgsAbstractGeometry|None': ...
    def segmentize(self, tolerance: float = ..., toleranceType: 'QgsAbstractGeometry.SegmentationToleranceType' = ...) -> 'QgsAbstractGeometry|None': ...
    @typing.overload
    def boundingBoxIntersects(self, rectangle: 'QgsRectangle') -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, box3d: 'QgsBox3D') -> bool: ...
    def hasCurvedSegments(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def centroid(self) -> 'QgsPoint': ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def area3D(self) -> float: ...
    def area(self) -> float: ...
    def perimeter(self) -> float: ...
    def length(self) -> float: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def vertexAt(self, id: 'QgsVertexId') -> 'QgsPoint': ...
    def nCoordinates(self) -> int: ...
    def coordinateSequence(self) -> typing.Any: ...
    def adjacentVertices(self, vertex: 'QgsVertexId') -> typing.Tuple['QgsVertexId', 'QgsVertexId']: ...
    def nextVertex(self, id: 'QgsVertexId') -> typing.Tuple[bool, 'QgsPoint']: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def asQPainterPath(self) -> QtGui.QPainterPath: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: 'QgsAbstractGeometryTransformer|None', feedback: QgsFeedback|None = ...) -> bool: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asJson(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: 'QgsAbstractGeometry.AxisOrder' = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: 'QgsAbstractGeometry.AxisOrder' = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: 'QgsAbstractGeometry.WkbFlag' = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: 'QgsAbstractGeometry.WkbFlag' = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def normalize(self) -> None: ...
    def boundary(self) -> 'QgsAbstractGeometry|None': ...
    def isMeasure(self) -> bool: ...
    def is3D(self) -> bool: ...
    def wktTypeStr(self) -> str: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def geometryType(self) -> str: ...
    def dimension(self) -> int: ...
    def boundingBox3D(self) -> 'QgsBox3D': ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def clear(self) -> None: ...
    def compareTo(self, other: 'QgsAbstractGeometry|None') -> int: ...
    def clone(self) -> 'QgsAbstractGeometry|None': ...
    def fuzzyDistanceEqual(self, other: 'QgsAbstractGeometry', epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: 'QgsAbstractGeometry', epsilon: float = ...) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsVertexIterator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, geometry: QgsAbstractGeometry|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVertexIterator') -> None: ...

    def __next__(self) -> 'QgsPoint': ...
    def __iter__(self) -> 'QgsVertexIterator|None': ...
    def next(self) -> 'QgsPoint': ...
    def hasNext(self) -> bool: ...


class QgsGeometryPartIterator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, geometry: QgsAbstractGeometry|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometryPartIterator') -> None: ...

    def __next__(self) -> QgsAbstractGeometry: ...
    def __iter__(self) -> 'QgsGeometryPartIterator|None': ...
    def next(self) -> QgsAbstractGeometry|None: ...
    def hasNext(self) -> bool: ...


class QgsGeometryConstPartIterator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, geometry: QgsAbstractGeometry|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometryConstPartIterator') -> None: ...

    def __next__(self) -> QgsAbstractGeometry: ...
    def __iter__(self) -> 'QgsGeometryConstPartIterator|None': ...
    def next(self) -> QgsAbstractGeometry|None: ...
    def hasNext(self) -> bool: ...


class QgsBox3D(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, x: 'QgsPoint'|QgsVector3D|'QgsRectangle'|float|None = ..., y: typing.Optional['QgsPoint', QgsVector3D, float] = ..., z: bool|float|None = ..., x2: bool|float|None = ..., y2: float|None = ..., z2: float|None = ..., n: bool|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBox3D') -> None: ...

    def __ne__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def __iadd__(self, v: QgsVector3D) -> 'QgsBox3D': ...
    def __isub__(self, v: QgsVector3D) -> 'QgsBox3D': ...
    def __add__(self, v: QgsVector3D) -> 'QgsBox3D': ...
    def __sub__(self, v: QgsVector3D) -> 'QgsBox3D': ...
    def corners(self) -> list[QgsVector3D]: ...
    def toString(self, precision: int = ...) -> str: ...
    def isEmpty(self) -> bool: ...
    def isNull(self) -> bool: ...
    def grow(self, delta: float) -> None: ...
    @typing.overload
    def scale(self, scaleFactor: float, center: 'QgsPoint' = ...) -> None: ...
    @typing.overload
    def scale(self, scaleFactor: float, centerX: float, centerY: float, centerZ: float) -> None: ...
    def __eq__(self, other: object): ...
    @typing.overload
    @deprecated("""""")
    def distanceTo(self, point: QtGui.QVector3D) -> float: ...
    @typing.overload
    def distanceTo(self, point: QgsVector3D) -> float: ...
    def toRectangle(self) -> 'QgsRectangle': ...
    @typing.overload
    def combineWith(self, box: 'QgsBox3D') -> None: ...
    @typing.overload
    def combineWith(self, x: float, y: float, z: float) -> None: ...
    @typing.overload
    def contains(self, other: 'QgsBox3D') -> bool: ...
    @typing.overload
    def contains(self, point: 'QgsPoint') -> bool: ...
    @typing.overload
    def contains(self, x: float, y: float, z: float) -> bool: ...
    def intersects(self, other: 'QgsBox3D') -> bool: ...
    def is3D(self) -> bool: ...
    def is2d(self) -> bool: ...
    def intersect(self, other: 'QgsBox3D') -> 'QgsBox3D': ...
    def volume(self) -> float: ...
    def area(self) -> float: ...
    def center(self) -> QgsVector3D: ...
    def depth(self) -> float: ...
    def height(self) -> float: ...
    def width(self) -> float: ...
    def normalize(self) -> None: ...
    def setNull(self) -> None: ...
    def zMaximum(self) -> float: ...
    def zMinimum(self) -> float: ...
    def setZMaximum(self, z: float) -> None: ...
    def setZMinimum(self, z: float) -> None: ...
    def yMaximum(self) -> float: ...
    def yMinimum(self) -> float: ...
    def setYMaximum(self, y: float) -> None: ...
    def setYMinimum(self, y: float) -> None: ...
    def xMaximum(self) -> float: ...
    def xMinimum(self) -> float: ...
    def setXMaximum(self, x: float) -> None: ...
    def setXMinimum(self, x: float) -> None: ...
    def set(self, xMin: float, yMin: float, zMin: float, xMax: float, yMax: float, zMax: float, normalize: bool = ...) -> None: ...


class QgsEllipse(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, center: 'QgsPoint', semiMajorAxis: float, semiMinorAxis: float, azimuth: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEllipse') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def toString(self, pointPrecision: int = ..., axisPrecision: int = ..., azimuthPrecision: int = ...) -> str: ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def orientedBoundingBox(self) -> 'QgsPolygon|None': ...
    def toLineString(self, segments: int = ...) -> 'QgsLineString|None': ...
    def toPolygon(self, segments: int = ...) -> 'QgsPolygon|None': ...
    def points(self, segments: int = ...) -> list['QgsPoint']: ...
    def quadrant(self) -> list['QgsPoint']: ...
    def perimeter(self) -> float: ...
    def area(self) -> float: ...
    def eccentricity(self) -> float: ...
    def foci(self) -> list['QgsPoint']: ...
    def focusDistance(self) -> float: ...
    def setAzimuth(self, azimuth: float) -> None: ...
    def setSemiMinorAxis(self, semiMinorAxis: float) -> None: ...
    def setSemiMajorAxis(self, semiMajorAxis: float) -> None: ...
    def setCenter(self, center: 'QgsPoint') -> None: ...
    def azimuth(self) -> float: ...
    def semiMinorAxis(self) -> float: ...
    def semiMajorAxis(self) -> float: ...
    def center(self) -> 'QgsPoint': ...
    def isEmpty(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def fromCenter2Points(ptc: 'QgsPoint', pt1: 'QgsPoint', pt2: 'QgsPoint') -> 'QgsEllipse': ...
    @staticmethod
    def fromCenterPoint(ptc: 'QgsPoint', pt1: 'QgsPoint') -> 'QgsEllipse': ...
    @staticmethod
    def fromExtent(pt1: 'QgsPoint', pt2: 'QgsPoint') -> 'QgsEllipse': ...
    @staticmethod
    def fromFoci(pt1: 'QgsPoint', pt2: 'QgsPoint', pt3: 'QgsPoint') -> 'QgsEllipse': ...


class QgsCircle(QgsEllipse):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, center: 'QgsPoint', radius: float, azimuth: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCircle') -> None: ...

    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def calculateSegments(radius: float, parameter: float, minSegments: int, method: Qgis.SegmentCalculationMethod) -> int: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def toString(self, pointPrecision: int = ..., radiusPrecision: int = ..., azimuthPrecision: int = ...) -> str: ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def contains(self, point: 'QgsPoint', epsilon: float = ...) -> bool: ...
    def toCircularString(self, oriented: bool = ...) -> 'QgsCircularString'|None: ...
    def northQuadrant(self) -> list['QgsPoint']: ...
    def setRadius(self, radius: float) -> None: ...
    def radius(self) -> float: ...
    def setSemiMinorAxis(self, semiMinorAxis: float) -> None: ...
    def setSemiMajorAxis(self, semiMajorAxis: float) -> None: ...
    def perimeter(self) -> float: ...
    def area(self) -> float: ...
    def innerTangents(self, other: 'QgsCircle') -> typing.Tuple[int, QgsPointXY, QgsPointXY, QgsPointXY, QgsPointXY]: ...
    def outerTangents(self, other: 'QgsCircle') -> typing.Tuple[int, QgsPointXY, QgsPointXY, QgsPointXY, QgsPointXY]: ...
    def tangentToPoint(self, p: QgsPointXY) -> typing.Tuple[bool, QgsPointXY, QgsPointXY]: ...
    def intersections(self, other: 'QgsCircle', useZ: bool = ...) -> typing.Tuple[int, 'QgsPoint', 'QgsPoint']: ...
    @staticmethod
    def minimalCircleFrom3Points(pt1: 'QgsPoint', pt2: 'QgsPoint', pt3: 'QgsPoint', epsilon: float = ...) -> 'QgsCircle': ...
    @staticmethod
    def fromExtent(pt1: 'QgsPoint', pt2: 'QgsPoint') -> 'QgsCircle': ...
    @staticmethod
    def from3TangentsMulti(pt1_tg1: 'QgsPoint', pt2_tg1: 'QgsPoint', pt1_tg2: 'QgsPoint', pt2_tg2: 'QgsPoint', pt1_tg3: 'QgsPoint', pt2_tg3: 'QgsPoint', epsilon: float = ..., pos: 'QgsPoint' = ...) -> list['QgsCircle']: ...
    @staticmethod
    def from3Tangents(pt1_tg1: 'QgsPoint', pt2_tg1: 'QgsPoint', pt1_tg2: 'QgsPoint', pt2_tg2: 'QgsPoint', pt1_tg3: 'QgsPoint', pt2_tg3: 'QgsPoint', epsilon: float = ..., pos: 'QgsPoint' = ...) -> 'QgsCircle': ...
    @staticmethod
    def fromCenterPoint(center: 'QgsPoint', pt1: 'QgsPoint') -> 'QgsCircle': ...
    @staticmethod
    def fromCenterDiameter(center: 'QgsPoint', diameter: float, azimuth: float = ...) -> 'QgsCircle': ...
    @staticmethod
    def from3Points(pt1: 'QgsPoint', pt2: 'QgsPoint', pt3: 'QgsPoint', epsilon: float = ...) -> 'QgsCircle': ...
    @staticmethod
    def from2Points(pt1: 'QgsPoint', pt2: 'QgsPoint') -> 'QgsCircle': ...


class QgsCurve(QgsAbstractGeometry):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCurve') -> None: ...

    def childPoint(self, index: int) -> 'QgsPoint': ...
    def childCount(self) -> int: ...
    def clearCache(self) -> None: ...
    def distanceBetweenVertices(self, fromVertex: 'QgsVertexId', toVertex: 'QgsVertexId') -> float: ...
    def scroll(self, firstVertexIndex: int) -> None: ...
    def orientation(self) -> Qgis.AngularDirection: ...
    def sinuosity(self) -> float: ...
    def straightDistance2d(self) -> float: ...
    def curveSubstring(self, startDistance: float, endDistance: float) -> 'QgsCurve|None': ...
    def interpolatePoint(self, distance: float) -> 'QgsPoint|None': ...
    def asQPolygonF(self) -> QtGui.QPolygonF: ...
    def mAt(self, index: int) -> float: ...
    def zAt(self, index: int) -> float: ...
    def yAt(self, index: int) -> float: ...
    def xAt(self, index: int) -> float: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def boundingBox3D(self) -> QgsBox3D: ...
    def normalize(self) -> None: ...
    def toCurveType(self) -> 'QgsCurve|None': ...
    def vertexAt(self, id: 'QgsVertexId') -> 'QgsPoint': ...
    def partCount(self) -> int: ...
    def ringCount(self, part: int = ...) -> int: ...
    def vertexCount(self, part: int = ..., ring: int = ...) -> int: ...
    def segmentize(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> 'QgsCurve|None': ...
    def asKml(self, precision: int = ...) -> str: ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def reversed(self) -> 'QgsCurve|None': ...
    def indexOf(self, point: 'QgsPoint') -> int: ...
    def pointAt(self, node: int) -> typing.Tuple[bool, 'QgsPoint', Qgis.VertexType]: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def adjacentVertices(self, vertex: 'QgsVertexId') -> typing.Tuple['QgsVertexId', 'QgsVertexId']: ...
    def nextVertex(self, id: 'QgsVertexId') -> typing.Tuple[bool, 'QgsPoint']: ...
    def coordinateSequence(self) -> typing.Any: ...
    def sumUpArea3D(self) -> float: ...
    def sumUpArea(self) -> float: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def numPoints(self) -> int: ...
    def points(self) -> list['QgsPoint']: ...
    def drawAsPolygon(self, p: QtGui.QPainter) -> None: ...
    def asQPainterPath(self) -> QtGui.QPainterPath: ...
    def addToPainterPath(self, path: QtGui.QPainterPath) -> None: ...
    def curveToLine(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> 'QgsLineString|None': ...
    def isRing(self) -> bool: ...
    def isClosed2D(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def endPoint(self) -> 'QgsPoint': ...
    def startPoint(self) -> 'QgsPoint': ...
    def clone(self) -> 'QgsCurve|None': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def equals(self, other: 'QgsCurve') -> bool: ...


class QgsCircularString(QgsCurve):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p1: 'QgsPoint', p2: 'QgsPoint', p3: 'QgsPoint') -> None: ...
    @typing.overload
    def __init__(self, x: collections.abc.Iterable[float], y: collections.abc.Iterable[float], z: collections.abc.Iterable[float] = ..., m: collections.abc.Iterable[float] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCircularString') -> None: ...

    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsCircularString|None': ...
    def scroll(self, firstVertexIndex: int) -> None: ...
    def mAt(self, index: int) -> float: ...
    def zAt(self, index: int) -> float: ...
    def yAt(self, index: int) -> float: ...
    def xAt(self, index: int) -> float: ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def curveSubstring(self, startDistance: float, endDistance: float) -> 'QgsCircularString|None': ...
    def interpolatePoint(self, distance: float) -> 'QgsPoint|None': ...
    def reversed(self) -> 'QgsCircularString|None': ...
    def distanceBetweenVertices(self, fromVertex: 'QgsVertexId', toVertex: 'QgsVertexId') -> float: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def hasCurvedSegments(self) -> bool: ...
    def sumUpArea3D(self) -> float: ...
    def sumUpArea(self) -> float: ...
    def pointAt(self, node: int, point: 'QgsPoint') -> typing.Tuple[bool, Qgis.VertexType]: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def drawAsPolygon(self, p: QtGui.QPainter) -> None: ...
    def addToPainterPath(self, path: QtGui.QPainterPath) -> None: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: 'QgsAbstractGeometryTransformer|None', feedback: QgsFeedback|None = ...) -> bool: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> QgsAbstractGeometry|None: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsCircularString|None': ...
    def curveToLine(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> 'QgsLineString|None': ...
    def endPoint(self) -> 'QgsPoint': ...
    def startPoint(self) -> 'QgsPoint': ...
    def length(self) -> float: ...
    def append(self, string: 'QgsCircularString|None') -> None: ...
    def setPoints(self, points: collections.abc.Iterable['QgsPoint']) -> None: ...
    def points(self) -> list['QgsPoint']: ...
    def pointN(self, i: int) -> 'QgsPoint': ...
    def indexOf(self, point: 'QgsPoint') -> int: ...
    def numPoints(self) -> int: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def isEmpty(self) -> bool: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsCircularString|None': ...
    def dimension(self) -> int: ...
    def geometryType(self) -> str: ...
    def equals(self, other: QgsCurve) -> bool: ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    @staticmethod
    def fromTwoPointsAndCenter(p1: 'QgsPoint', p2: 'QgsPoint', center: 'QgsPoint', useShortestArc: bool = ...) -> 'QgsCircularString': ...


class QgsCompoundCurve(QgsCurve):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, curve: 'QgsCompoundCurve') -> None: ...

    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsCompoundCurve|None': ...
    def scroll(self, firstVertexIndex: int) -> None: ...
    def mAt(self, index: int) -> float: ...
    def zAt(self, index: int) -> float: ...
    def yAt(self, index: int) -> float: ...
    def xAt(self, index: int) -> float: ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def curveSubstring(self, startDistance: float, endDistance: float) -> 'QgsCompoundCurve|None': ...
    def interpolatePoint(self, distance: float) -> 'QgsPoint|None': ...
    def reversed(self) -> 'QgsCompoundCurve|None': ...
    def distanceBetweenVertices(self, fromVertex: 'QgsVertexId', toVertex: 'QgsVertexId') -> float: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def hasCurvedSegments(self) -> bool: ...
    def close(self) -> None: ...
    def sumUpArea3D(self) -> float: ...
    def sumUpArea(self) -> float: ...
    def pointAt(self, node: int, point: 'QgsPoint') -> typing.Tuple[bool, Qgis.VertexType]: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def drawAsPolygon(self, p: QtGui.QPainter) -> None: ...
    def addToPainterPath(self, path: QtGui.QPainterPath) -> None: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: 'QgsAbstractGeometryTransformer|None', feedback: QgsFeedback|None = ...) -> bool: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def toggleCircularAtVertex(self, position: 'QgsVertexId') -> bool: ...
    def condenseCurves(self) -> None: ...
    def addVertex(self, pt: 'QgsPoint') -> None: ...
    def removeCurve(self, i: int) -> None: ...
    def addCurve(self, c: QgsCurve|None, extendPrevious: bool = ...) -> None: ...
    def curveAt(self, i: int) -> QgsCurve|None: ...
    def nCurves(self) -> int: ...
    def simplifiedTypeRef(self) -> QgsAbstractGeometry|None: ...
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> QgsAbstractGeometry|None: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsCompoundCurve|None': ...
    def curveToLine(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> 'QgsLineString|None': ...
    def indexOf(self, point: 'QgsPoint') -> int: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def isEmpty(self) -> bool: ...
    def numPoints(self) -> int: ...
    def points(self) -> list['QgsPoint']: ...
    def endPoint(self) -> 'QgsPoint': ...
    def startPoint(self) -> 'QgsPoint': ...
    def length(self) -> float: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsCompoundCurve|None': ...
    def dimension(self) -> int: ...
    def geometryType(self) -> str: ...
    def equals(self, other: QgsCurve) -> bool: ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...


class QgsSurface(QgsAbstractGeometry):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSurface') -> None: ...

    def clearCache(self) -> None: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def boundingBox3D(self) -> QgsBox3D: ...


class QgsCurvePolygon(QgsSurface):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p: 'QgsCurvePolygon') -> None: ...

    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def childGeometry(self, index: int) -> QgsAbstractGeometry|None: ...
    def childCount(self) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsCurvePolygon|None': ...
    def toCurveType(self) -> 'QgsCurvePolygon|None': ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexAt(self, id: 'QgsVertexId') -> 'QgsPoint': ...
    def partCount(self) -> int: ...
    def ringCount(self, part: int = ...) -> int: ...
    def vertexCount(self, part: int = ..., ring: int = ...) -> int: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def segmentize(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> QgsAbstractGeometry|None: ...
    def hasCurvedSegments(self) -> bool: ...
    def adjacentVertices(self, vertex: 'QgsVertexId') -> typing.Tuple['QgsVertexId', 'QgsVertexId']: ...
    def nextVertex(self, id: 'QgsVertexId') -> typing.Tuple[bool, 'QgsPoint']: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def isEmpty(self) -> bool: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def nCoordinates(self) -> int: ...
    def coordinateSequence(self) -> typing.Any: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: 'QgsAbstractGeometryTransformer|None', feedback: QgsFeedback|None = ...) -> bool: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def asQPainterPath(self) -> QtGui.QPainterPath: ...
    def forceCounterClockwise(self) -> None: ...
    def forceClockwise(self) -> None: ...
    def forceRHR(self) -> None: ...
    def removeInvalidRings(self) -> None: ...
    def removeInteriorRings(self, minimumAllowedArea: float = ...) -> None: ...
    def removeInteriorRing(self, i: int) -> bool: ...
    def addInteriorRing(self, ring: QgsCurve|None) -> None: ...
    def setInteriorRings(self, rings: collections.abc.Iterable[QgsCurve]) -> None: ...
    def setExteriorRing(self, ring: QgsCurve|None) -> None: ...
    def toPolygon(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> 'QgsPolygon|None': ...
    def interiorRing(self, i: int) -> QgsCurve: ...
    def exteriorRing(self) -> QgsCurve|None: ...
    def numInteriorRings(self) -> int: ...
    def roundness(self) -> float: ...
    @typing.overload
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, box: 'QgsRectangle') -> bool: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsCurvePolygon|None': ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsCurvePolygon|None': ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def perimeter(self) -> float: ...
    def area3D(self) -> float: ...
    def area(self) -> float: ...
    def surfaceToPolygon(self) -> 'QgsPolygon|None': ...
    def normalize(self) -> None: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsCurvePolygon|None': ...
    def dimension(self) -> int: ...
    def geometryType(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...


class QgsGeometryParameters(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometryParameters') -> None: ...

    def setGridSize(self, size: float) -> None: ...
    def gridSize(self) -> float: ...


class QgsGeometry(PyQt6.sip.wrapper):

    class Error(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, m: str|None) -> None: ...
        @typing.overload
        def __init__(self, m: str|None, p: QgsPointXY) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsGeometry.Error') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def __repr__(self) -> typing.Any: ...
        def hasWhere(self) -> bool: ...
        def where(self) -> QgsPointXY: ...
        def what(self) -> str: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometry') -> None: ...
    @typing.overload
    def __init__(self, geom: QgsAbstractGeometry|None) -> None: ...

    @typing.overload
    def chamfer(self, vertexIndex: int, distance1: float, distance2: float = ...) -> 'QgsGeometry': ...
    @typing.overload
    @staticmethod
    def chamfer(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', distance1: float, distance2: float = ...) -> 'QgsGeometry': ...
    @typing.overload
    def fillet(self, vertexIndex: int, radius: float, segments: int = ...) -> 'QgsGeometry': ...
    @typing.overload
    @staticmethod
    def fillet(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', radius: float, segments: int = ...) -> 'QgsGeometry': ...
    @typing.overload
    @staticmethod
    def convertPointList(input: collections.abc.Iterable[QgsPointXY], output: collections.abc.Iterable['QgsPoint']) -> None: ...
    @typing.overload
    @staticmethod
    def convertPointList(input: collections.abc.Iterable['QgsPoint'], output: collections.abc.Iterable[QgsPointXY]) -> None: ...
    @staticmethod
    def createGeometryEngine(geometry: QgsAbstractGeometry|None, precision: float = ..., flags: Qgis.GeosCreationFlag = ...) -> 'QgsGeometryEngine|None': ...
    def smooth(self, iterations: int = ..., offset: float = ..., minimumDistance: float = ..., maxAngle: float = ...) -> 'QgsGeometry': ...
    @staticmethod
    def compare(obj1: typing.Any, obj2: typing.Any, epsilon: float = ...) -> bool: ...
    @staticmethod
    @deprecated("""""")
    def createPolygonFromQPolygonF(polygon: QtGui.QPolygonF) -> typing.Any: ...
    @staticmethod
    @deprecated("""""")
    def createPolylineFromQPolygonF(polygon: QtGui.QPolygonF) -> list[QgsPointXY]: ...
    @staticmethod
    def fromQPolygonF(polygon: QtGui.QPolygonF) -> 'QgsGeometry': ...
    @staticmethod
    def fromQPointF(point: QtCore.QPointF) -> 'QgsGeometry': ...
    def lastError(self) -> str: ...
    def vertexNrFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def vertexIdFromVertexNr(self, number: int) -> typing.Tuple[bool, 'QgsVertexId']: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def mapToPixel(self, mtp: QgsMapToPixel) -> None: ...
    def requiresConversionToStraightSegments(self) -> bool: ...
    def convertToStraightSegment(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> None: ...
    @staticmethod
    def polygonize(geometries: collections.abc.Iterable['QgsGeometry']) -> 'QgsGeometry': ...
    @staticmethod
    def unaryUnion(geometries: collections.abc.Iterable['QgsGeometry'], parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def normalize(self) -> None: ...
    def validateGeometry(self, method: Qgis.GeometryValidationEngine = ..., flags: Qgis.GeometryValidityFlag = ...) -> list['QgsGeometry.Error']: ...
    def forcePolygonCounterClockwise(self) -> 'QgsGeometry': ...
    def forcePolygonClockwise(self) -> 'QgsGeometry': ...
    def forceRHR(self) -> 'QgsGeometry': ...
    def isPolygonClockwise(self) -> bool: ...
    def isPolygonCounterClockwise(self) -> bool: ...
    def polygonOrientation(self) -> Qgis.AngularDirection: ...
    def makeValid(self, method: Qgis.MakeValidMethod = ..., keepCollapsed: bool = ...) -> 'QgsGeometry': ...
    def avoidIntersectionsV2(self, avoidIntersectionsLayers: collections.abc.Iterable[QgsVectorLayer]) -> Qgis.GeometryOperationResult: ...
    @deprecated("""""")
    def avoidIntersections(self, avoidIntersectionsLayers: collections.abc.Iterable[QgsVectorLayer]) -> int: ...
    def convertGeometryCollectionToSubclass(self, geomType: Qgis.GeometryType) -> bool: ...
    def convertToSingleType(self) -> bool: ...
    def convertToCurvedMultiType(self) -> bool: ...
    def convertToMultiType(self) -> bool: ...
    def deletePart(self, partNum: int) -> bool: ...
    def deleteRing(self, ringNum: int, partNum: int = ...) -> bool: ...
    def asQPolygonF(self) -> QtGui.QPolygonF: ...
    def asQPointF(self) -> QtCore.QPointF: ...
    def asGeometryCollection(self) -> list['QgsGeometry']: ...
    def asMultiPolygon(self) -> QgsMultiPolygonXY: ...
    def asMultiPolyline(self) -> QgsMultiPolylineXY: ...
    def asMultiPoint(self) -> QgsMultiPointXY: ...
    def asPolygon(self) -> QgsPolygonXY: ...
    def asPolyline(self) -> QgsPolylineXY: ...
    def asPoint(self) -> QgsPointXY: ...
    def convertToType(self, destType: Qgis.GeometryType, destMultipart: bool = ...) -> 'QgsGeometry': ...
    def coerceToType(self, type: Qgis.WkbType, defaultZ: float = ..., defaultM: float = ..., avoidDuplicates: bool = ...) -> list['QgsGeometry']: ...
    def asJson(self, precision: int = ...) -> str: ...
    def __repr__(self) -> typing.Any: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def randomPointsInPolygon(self, count: int, seed: int = ...) -> QgsPolylineXY: ...
    def extrude(self, x: float, y: float) -> 'QgsGeometry': ...
    def symDifference(self, geometry: 'QgsGeometry', parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def difference(self, geometry: 'QgsGeometry', parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def mergeLines(self, parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def combine(self, geometry: 'QgsGeometry', parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def clipped(self, rectangle: 'QgsRectangle') -> 'QgsGeometry': ...
    def intersection(self, geometry: 'QgsGeometry', parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def interpolateAngle(self, distance: float) -> float: ...
    def lineLocatePoint(self, point: 'QgsGeometry') -> float: ...
    def interpolate(self, distance: float) -> 'QgsGeometry': ...
    def subdivide(self, maxNodes: int = ..., parameters: QgsGeometryParameters = ...) -> 'QgsGeometry': ...
    def sharedPaths(self, other: 'QgsGeometry') -> 'QgsGeometry': ...
    def node(self) -> 'QgsGeometry': ...
    def unionCoverage(self) -> 'QgsGeometry': ...
    def simplifyCoverageVW(self, tolerance: float, preserveBoundary: bool) -> 'QgsGeometry': ...
    def validateCoverage(self, gapWidth: float) -> typing.Tuple[Qgis.CoverageValidityResult, 'QgsGeometry|None']: ...
    def constrainedDelaunayTriangulation(self) -> 'QgsGeometry': ...
    def delaunayTriangulation(self, tolerance: float = ..., edgesOnly: bool = ...) -> 'QgsGeometry': ...
    def voronoiDiagram(self, extent: 'QgsGeometry' = ..., tolerance: float = ..., edgesOnly: bool = ...) -> 'QgsGeometry': ...
    def concaveHull(self, targetPercent: float, allowHoles: bool = ...) -> 'QgsGeometry': ...
    def convexHull(self) -> 'QgsGeometry': ...
    def minimumClearanceLine(self) -> 'QgsGeometry': ...
    def minimumClearance(self) -> float: ...
    def minimumWidth(self) -> 'QgsGeometry': ...
    def largestEmptyCircle(self, tolerance: float, boundary: 'QgsGeometry' = ...) -> 'QgsGeometry': ...
    def poleOfInaccessibility(self, precision: float) -> typing.Tuple['QgsGeometry', float]: ...
    def pointOnSurface(self) -> 'QgsGeometry': ...
    def centroid(self) -> 'QgsGeometry': ...
    def convertToCurves(self, distanceTolerance: float = ..., angleTolerance: float = ...) -> 'QgsGeometry': ...
    def densifyByDistance(self, distance: float) -> 'QgsGeometry': ...
    def densifyByCount(self, extraNodesPerSegment: int) -> 'QgsGeometry': ...
    def simplify(self, tolerance: float) -> 'QgsGeometry': ...
    def extendLine(self, startDistance: float, endDistance: float) -> 'QgsGeometry': ...
    def variableWidthBufferByM(self, segments: int) -> 'QgsGeometry': ...
    def taperedBuffer(self, startWidth: float, endWidth: float, segments: int) -> 'QgsGeometry': ...
    def singleSidedBuffer(self, distance: float, segments: int, side: Qgis.BufferSide, joinStyle: Qgis.JoinStyle = ..., miterLimit: float = ...) -> 'QgsGeometry': ...
    def offsetCurve(self, distance: float, segments: int, joinStyle: Qgis.JoinStyle, miterLimit: float) -> 'QgsGeometry': ...
    @typing.overload
    def buffer(self, distance: float, segments: int) -> 'QgsGeometry': ...
    @typing.overload
    def buffer(self, distance: float, segments: int, endCapStyle: Qgis.EndCapStyle, joinStyle: Qgis.JoinStyle, miterLimit: float) -> 'QgsGeometry': ...
    def crosses(self, geometry: 'QgsGeometry') -> bool: ...
    def within(self, geometry: 'QgsGeometry') -> bool: ...
    def overlaps(self, geometry: 'QgsGeometry') -> bool: ...
    def touches(self, geometry: 'QgsGeometry') -> bool: ...
    def disjoint(self, geometry: 'QgsGeometry') -> bool: ...
    @typing.overload
    def contains(self, p: QgsPointXY|None) -> bool: ...
    @typing.overload
    def contains(self, x: float, y: float) -> bool: ...
    @typing.overload
    def contains(self, geometry: 'QgsGeometry') -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, rectangle: 'QgsRectangle') -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, geometry: 'QgsGeometry') -> bool: ...
    @typing.overload
    def intersects(self, rectangle: 'QgsRectangle') -> bool: ...
    @typing.overload
    def intersects(self, geometry: 'QgsGeometry') -> bool: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ...) -> 'QgsGeometry': ...
    def applyDashPattern(self, pattern: collections.abc.Iterable[float], startRule: Qgis.DashPatternLineEndingRule = ..., endRule: Qgis.DashPatternLineEndingRule = ..., adjustment: Qgis.DashPatternSizeAdjustment = ..., patternOffset: float = ...) -> 'QgsGeometry': ...
    def roundWavesRandomized(self, minimumWavelength: float, maximumWavelength: float, minimumAmplitude: float, maximumAmplitude: float, seed: int = ...) -> 'QgsGeometry': ...
    def roundWaves(self, wavelength: float, amplitude: float, strictWavelength: bool = ...) -> 'QgsGeometry': ...
    def squareWavesRandomized(self, minimumWavelength: float, maximumWavelength: float, minimumAmplitude: float, maximumAmplitude: float, seed: int = ...) -> 'QgsGeometry': ...
    def squareWaves(self, wavelength: float, amplitude: float, strictWavelength: bool = ...) -> 'QgsGeometry': ...
    def triangularWavesRandomized(self, minimumWavelength: float, maximumWavelength: float, minimumAmplitude: float, maximumAmplitude: float, seed: int = ...) -> 'QgsGeometry': ...
    def triangularWaves(self, wavelength: float, amplitude: float, strictWavelength: bool = ...) -> 'QgsGeometry': ...
    def orthogonalize(self, tolerance: float = ..., maxIterations: int = ..., angleThreshold: float = ...) -> 'QgsGeometry': ...
    def minimalEnclosingCircle(self, segments: int = ...) -> typing.Tuple['QgsGeometry', QgsPointXY, float]: ...
    def orientedMinimumBoundingBox(self) -> typing.Tuple['QgsGeometry', float, float, float, float]: ...
    def boundingBox3D(self) -> QgsBox3D: ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def makeDifference(self, other: 'QgsGeometry') -> 'QgsGeometry': ...
    def reshapeGeometry(self, reshapeLineString: 'QgsLineString') -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitGeometry(self, splitLine: list['QgsPoint'|QgsPointXY], topological: bool, splitFeature: bool = ...) -> tuple[Qgis.GeometryOperationResult, list['QgsPoint']|list[QgsPointXY], list['QgsPoint']|list[QgsPointXY]]: ...
    @typing.overload
    def splitGeometry(self, curve: QgsCurve|None, preserveCircular: bool, topological: bool, splitFeature: bool = ...) -> typing.Tuple[Qgis.GeometryOperationResult, list['QgsGeometry'], list['QgsPoint']]: ...
    def rotate(self, rotation: float, center: QgsPointXY) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', direction: Qgis.TransformDirection = ..., transformZ: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> Qgis.GeometryOperationResult: ...
    def translate(self, dx: float, dy: float, dz: float = ..., dm: float = ...) -> Qgis.GeometryOperationResult: ...
    def removeInteriorRings(self, minimumAllowedArea: float = ...) -> 'QgsGeometry': ...
    def addPartGeometry(self, newPart: 'QgsGeometry') -> Qgis.GeometryOperationResult: ...
    def addPartV2(self, part: QgsAbstractGeometry|None, wkbType: Qgis.WkbType = ...) -> Qgis.GeometryOperationResult: ...
    @deprecated("""""")
    def addPart(self, part: QgsAbstractGeometry|None, geomType: Qgis.GeometryType = ...) -> Qgis.GeometryOperationResult: ...
    def addPointsV2(self, points: collections.abc.Iterable['QgsPoint'], wkbType: Qgis.WkbType = ...) -> Qgis.GeometryOperationResult: ...
    @deprecated("""""")
    def addPoints(self, points: collections.abc.Iterable['QgsPoint'], geomType: Qgis.GeometryType = ...) -> Qgis.GeometryOperationResult: ...
    def addPointsXYV2(self, points: collections.abc.Iterable[QgsPointXY], wkbType: Qgis.WkbType = ...) -> Qgis.GeometryOperationResult: ...
    @deprecated("""""")
    def addPointsXY(self, points: collections.abc.Iterable[QgsPointXY], geomType: Qgis.GeometryType = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def addRing(self, ring: collections.abc.Iterable[QgsPointXY]) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def addRing(self, ring: QgsCurve|None) -> Qgis.GeometryOperationResult: ...
    def closestSegmentWithContext(self, point: QgsPointXY, epsilon: float = ...) -> typing.Tuple[float, QgsPointXY, int, int]: ...
    def closestVertexWithContext(self, point: QgsPointXY) -> typing.Tuple[float, int]: ...
    def shortestLine(self, other: 'QgsGeometry') -> 'QgsGeometry': ...
    def nearestPoint(self, other: 'QgsGeometry') -> 'QgsGeometry': ...
    def sqrDistToVertexAt(self, point: QgsPointXY, atVertex: int) -> float: ...
    def vertexAt(self, atVertex: int) -> 'QgsPoint': ...
    def toggleCircularAtVertex(self, atVertex: int) -> bool: ...
    def deleteVertex(self, atVertex: int) -> bool: ...
    @typing.overload
    def moveVertex(self, x: float, y: float, atVertex: int) -> bool: ...
    @typing.overload
    def moveVertex(self, p: 'QgsPoint', atVertex: int) -> bool: ...
    def addTopologicalPoint(self, point: 'QgsPoint', snappingTolerance: float = ..., segmentSearchEpsilon: float = ...) -> bool: ...
    @typing.overload
    def insertVertex(self, x: float, y: float, beforeVertex: int) -> bool: ...
    @typing.overload
    def insertVertex(self, point: 'QgsPoint', beforeVertex: int) -> bool: ...
    def adjacentVertices(self, atVertex: int) -> typing.Tuple[int, int]: ...
    def angleAtVertex(self, vertex: int) -> float: ...
    def distanceToVertex(self, vertex: int) -> float: ...
    def closestVertex(self, point: QgsPointXY) -> typing.Tuple[QgsPointXY, int, int, int, float]: ...
    def frechetDistanceDensify(self, geom: 'QgsGeometry', densifyFraction: float) -> float: ...
    def frechetDistance(self, geom: 'QgsGeometry') -> float: ...
    def hausdorffDistanceDensify(self, geom: 'QgsGeometry', densifyFraction: float) -> float: ...
    def hausdorffDistance(self, geom: 'QgsGeometry') -> float: ...
    def constParts(self) -> QgsGeometryConstPartIterator: ...
    def parts(self) -> QgsGeometryPartIterator: ...
    def vertices(self) -> QgsVertexIterator: ...
    def distance(self, geom: 'QgsGeometry') -> float: ...
    def length(self) -> float: ...
    def area3D(self) -> float: ...
    def area(self) -> float: ...
    def isAxisParallelRectangle(self, maximumDeviation: float, simpleRectanglesOnly: bool = ...) -> bool: ...
    def isSimple(self) -> bool: ...
    def isGeosValid(self, flags: Qgis.GeometryValidityFlag = ...) -> bool: ...
    def isGeosEqual(self, a0: 'QgsGeometry') -> bool: ...
    def equals(self, geometry: 'QgsGeometry') -> bool: ...
    def isMultipart(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def type(self) -> Qgis.GeometryType: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def fromWkb(self, wkb: QtCore.QByteArray|bytes|bytearray|memoryview) -> None: ...
    @staticmethod
    def createWedgeBufferFromAngles(center: 'QgsPoint', startAngle: float, endAngle: float, outerRadius: float, innerRadius: float = ...) -> 'QgsGeometry': ...
    @staticmethod
    def createWedgeBuffer(center: 'QgsPoint', azimuth: float, angularWidth: float, outerRadius: float, innerRadius: float = ...) -> 'QgsGeometry': ...
    @staticmethod
    def collectTinPatches(geometries: collections.abc.Iterable['QgsGeometry']) -> 'QgsGeometry': ...
    @staticmethod
    def collectGeometry(geometries: collections.abc.Iterable['QgsGeometry']) -> 'QgsGeometry': ...
    @staticmethod
    def fromBox3D(box: QgsBox3D) -> 'QgsGeometry': ...
    @staticmethod
    def fromRect(rect: 'QgsRectangle') -> 'QgsGeometry': ...
    @staticmethod
    def fromMultiPolygonXY(multipoly: typing.Any) -> 'QgsGeometry': ...
    @staticmethod
    def fromPolygonXY(polygon: typing.Any) -> 'QgsGeometry': ...
    @staticmethod
    def fromMultiPolylineXY(multiline: typing.Any) -> 'QgsGeometry': ...
    @staticmethod
    def fromPolyline(polyline: collections.abc.Iterable['QgsPoint']) -> 'QgsGeometry': ...
    @staticmethod
    def fromPolylineXY(polyline: collections.abc.Iterable[QgsPointXY]) -> 'QgsGeometry': ...
    @staticmethod
    def fromMultiPointXY(multipoint: collections.abc.Iterable[QgsPointXY]) -> 'QgsGeometry': ...
    @staticmethod
    def fromPoint(point: 'QgsPoint') -> 'QgsGeometry': ...
    @staticmethod
    def fromPointXY(point: QgsPointXY) -> 'QgsGeometry': ...
    @staticmethod
    def fromWkt(wkt: str|None) -> 'QgsGeometry': ...
    def isNull(self) -> bool: ...
    @deprecated("""""")
    def set(self, geometry: QgsAbstractGeometry|None) -> None: ...
    def get(self) -> QgsAbstractGeometry|None: ...
    def constGet(self) -> QgsAbstractGeometry|None: ...


class QgsGeometryCollection(QgsAbstractGeometry):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, c: 'QgsGeometryCollection') -> None: ...

    def clearCache(self) -> None: ...
    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    def wktOmitChildType(self) -> bool: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def childGeometry(self, index: int) -> QgsAbstractGeometry|None: ...
    def childCount(self) -> int: ...
    def createEmptyWithSameType(self) -> 'QgsGeometryCollection|None': ...
    def extractPartsByType(self, type: Qgis.WkbType, useFlatType: bool = ...) -> 'QgsGeometryCollection|None': ...
    def __iter__(self) -> QgsGeometryPartIterator: ...
    def __delitem__(self, index: int) -> None: ...
    def __getitem__(self, index: int) -> QgsAbstractGeometry: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsGeometryCollection|None': ...
    def simplifiedTypeRef(self) -> QgsAbstractGeometry|None: ...
    def toCurveType(self) -> 'QgsGeometryCollection|None': ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def vertexAt(self, id: 'QgsVertexId') -> 'QgsPoint': ...
    def partCount(self) -> int: ...
    def ringCount(self, part: int = ...) -> int: ...
    def vertexCount(self, part: int = ..., ring: int = ...) -> int: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def segmentize(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> QgsAbstractGeometry|None: ...
    def hasCurvedSegments(self) -> bool: ...
    def perimeter(self) -> float: ...
    def area3D(self) -> float: ...
    def area(self) -> float: ...
    def length(self) -> float: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def nextVertex(self, id: 'QgsVertexId') -> typing.Tuple[bool, 'QgsPoint']: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def nCoordinates(self) -> int: ...
    def coordinateSequence(self) -> typing.Any: ...
    def boundingBox3D(self) -> QgsBox3D: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def asQPainterPath(self) -> QtGui.QPainterPath: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: 'QgsAbstractGeometryTransformer|None', feedback: QgsFeedback|None = ...) -> bool: ...
    def normalize(self) -> None: ...
    def takeGeometries(self) -> list[QgsAbstractGeometry]: ...
    def removeGeometry(self, nr: int) -> bool: ...
    def insertGeometry(self, g: QgsAbstractGeometry|None, index: int) -> bool: ...
    def addGeometries(self, geometries: collections.abc.Iterable[QgsAbstractGeometry]) -> bool: ...
    def addGeometry(self, g: QgsAbstractGeometry|None) -> bool: ...
    def reserve(self, size: int) -> None: ...
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def adjacentVertices(self, vertex: 'QgsVertexId') -> typing.Tuple['QgsVertexId', 'QgsVertexId']: ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsGeometryCollection|None': ...
    def clear(self) -> None: ...
    def geometryType(self) -> str: ...
    def dimension(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def geometryN(self, n: int) -> QgsAbstractGeometry: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def numGeometries(self) -> int: ...
    def clone(self) -> 'QgsGeometryCollection|None': ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsGeometryEngine(PyQt6.sip.wrapper):

    class EngineOperationResult(enum.IntEnum):
        Success = ... # type: QgsGeometryEngine.EngineOperationResult
        NothingHappened = ... # type: QgsGeometryEngine.EngineOperationResult
        MethodNotImplemented = ... # type: QgsGeometryEngine.EngineOperationResult
        EngineError = ... # type: QgsGeometryEngine.EngineOperationResult
        NodedGeometryError = ... # type: QgsGeometryEngine.EngineOperationResult
        InvalidBaseGeometry = ... # type: QgsGeometryEngine.EngineOperationResult
        InvalidInput = ... # type: QgsGeometryEngine.EngineOperationResult
        SplitCannotSplitPoint = ... # type: QgsGeometryEngine.EngineOperationResult

    @typing.overload
    def __init__(self, geometry: QgsAbstractGeometry|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometryEngine') -> None: ...

    def logError(self, engineName: str|None, message: str|None) -> None: ...
    def setLogErrors(self, enabled: bool) -> None: ...
    def offsetCurve(self, distance: float, segments: int, joinStyle: Qgis.JoinStyle, miterLimit: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def splitGeometry(self, splitLine: 'QgsLineString', topological: bool, topologyTestPoints: collections.abc.Iterable['QgsPoint'], errorMsg: str|None = ..., skipIntersectionCheck: bool = ...) -> typing.Tuple['QgsGeometryEngine.EngineOperationResult', list[QgsGeometry]]: ...
    def isSimple(self, errorMsg: str|None = ...) -> bool: ...
    def isEmpty(self, errorMsg: str|None) -> bool: ...
    def isEqual(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def isValid(self, errorMsg: str|None = ..., allowSelfTouchingHoles: bool = ..., errorLoc: QgsGeometry|None = ...) -> bool: ...
    def length(self, errorMsg: str|None = ...) -> float: ...
    def area(self, errorMsg: str|None = ...) -> float: ...
    def relatePattern(self, geom: QgsAbstractGeometry|None, pattern: str|None, errorMsg: str|None = ...) -> bool: ...
    def relate(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> str: ...
    def disjoint(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def contains(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def overlaps(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def within(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def crosses(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def touches(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def intersects(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def distanceWithin(self, geom: QgsAbstractGeometry|None, maxdistance: float, errorMsg: str|None = ...) -> bool: ...
    def distance(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> float: ...
    def convexHull(self, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def pointOnSurface(self, errorMsg: str|None = ...) -> 'QgsPoint|None': ...
    def centroid(self, errorMsg: str|None = ...) -> 'QgsPoint|None': ...
    def envelope(self, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def interpolate(self, distance: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def simplify(self, tolerance: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def buffer(self, distance: float, segments: int, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def buffer(self, distance: float, segments: int, endCapStyle: Qgis.EndCapStyle, joinStyle: Qgis.JoinStyle, miterLimit: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def symDifference(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def combine(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def combine(self, geomList: collections.abc.Iterable[QgsAbstractGeometry], errorMsg: str|None, parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def combine(self, geometries: collections.abc.Iterable[QgsGeometry], errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    def difference(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    def intersection(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    def prepareGeometry(self) -> None: ...
    def geometryChanged(self) -> None: ...


class QgsAbstractGeometryTransformer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractGeometryTransformer') -> None: ...

    def transformPoint(self, x: float, y: float, z: float, m: float) -> typing.Tuple[bool, float, float, float, float]: ...


class QgsGeometryUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometryUtils') -> None: ...

    @staticmethod
    def interpolateZ(a: 'QgsPoint', b: 'QgsPoint', c: 'QgsPoint', x: float, y: float) -> float: ...
    @staticmethod
    def checkWeaklyFor3DPlane(geom: QgsAbstractGeometry|None, epsilon: float = ...) -> typing.Tuple[bool, 'QgsPoint', 'QgsPoint', 'QgsPoint']: ...
    @staticmethod
    def filletVertex(curve: QgsCurve|None, vertexIndex: int, radius: float, segments: int) -> QgsAbstractGeometry|None: ...
    @staticmethod
    def chamferVertex(curve: QgsCurve|None, vertexIndex: int, distance1: float, distance2: float) -> QgsAbstractGeometry|None: ...
    @staticmethod
    def maxFilletRadius(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', epsilon: float = ...) -> float: ...
    @staticmethod
    def createFilletGeometry(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', radius: float, segments: int) -> QgsAbstractGeometry|None: ...
    @staticmethod
    def createChamferGeometry(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', distance1: float, distance2: float) -> 'QgsLineString'|None: ...
    @staticmethod
    def createFillet(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', radius: float, epsilon: float = ...) -> typing.Tuple[bool, 'QgsPoint', 'QgsPoint', 'QgsPoint']: ...
    @staticmethod
    def createChamfer(segment1Start: 'QgsPoint', segment1End: 'QgsPoint', segment2Start: 'QgsPoint', segment2End: 'QgsPoint', distance1: float, distance2: float, epsilon: float = ...) -> typing.Tuple[bool, 'QgsPoint', 'QgsPoint']: ...
    @staticmethod
    def interpolatePointOnSegment(x: float, y: float, segmentStart: 'QgsPoint', segmentEnd: 'QgsPoint') -> 'QgsPoint': ...
    @staticmethod
    def createPointWithMatchingDimensions(x: float, y: float, reference: 'QgsPoint') -> 'QgsPoint': ...
    @staticmethod
    def segmentIntersection(p1: 'QgsPoint', p2: 'QgsPoint', q1: 'QgsPoint', q2: 'QgsPoint', tolerance: float = ..., acceptImproperIntersection: bool = ...) -> typing.Tuple[bool, 'QgsPoint', bool]: ...
    @staticmethod
    def intersectionPointOfLinesByBearing(pt1: 'QgsPoint', bearing1: float, pt2: 'QgsPoint', bearing2: float) -> typing.Tuple[bool, 'QgsPoint']: ...
    @staticmethod
    def lineIntersection(p1: 'QgsPoint', v1: QgsVector, p2: 'QgsPoint', v2: QgsVector) -> typing.Tuple[bool, 'QgsPoint']: ...
    @staticmethod
    def circleCenterRadius(pt1: 'QgsPoint', pt2: 'QgsPoint', pt3: 'QgsPoint') -> typing.Tuple[float, float, float]: ...
    @staticmethod
    def bisector(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float) -> typing.Tuple[bool, float, float]: ...
    @staticmethod
    def angleBisector(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float, dX: float, dY: float) -> typing.Tuple[bool, float, float, float]: ...
    @typing.overload
    @staticmethod
    def pointsAreCollinear(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float, epsilon: float) -> bool: ...
    @typing.overload
    @staticmethod
    def pointsAreCollinear(pt1: 'QgsPoint', pt2: 'QgsPoint', pt3: 'QgsPoint', epsilon: float) -> bool: ...
    @staticmethod
    def weightedPointInTriangle(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float, weightB: float, weightC: float) -> typing.Tuple[float, float]: ...
    @staticmethod
    def pointFractionAlongLine(x1: float, y1: float, x2: float, y2: float, px: float, py: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def triangleArea(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float) -> float: ...
    @staticmethod
    def linesIntersection3D(La1: QgsVector3D, La2: QgsVector3D, Lb1: QgsVector3D, Lb2: QgsVector3D) -> typing.Tuple[bool, QgsVector3D]: ...
    @staticmethod
    def skewLinesProjection(P1: QgsVector3D, P12: QgsVector3D, P2: QgsVector3D, P22: QgsVector3D, epsilon: float = ...) -> typing.Tuple[bool, QgsVector3D]: ...
    @staticmethod
    @deprecated("""""")
    def skewLinesDistance(P1: QgsVector3D, P12: QgsVector3D, P2: QgsVector3D, P22: QgsVector3D) -> float: ...
    @staticmethod
    def perpendicularCenterSegment(centerPointX: float, centerPointY: float, segmentPoint1x: float, segmentPoint1y: float, segmentPoint2x: float, segmentPoint2y: float, segmentLength: float = ...) -> typing.Tuple[float, float, float, float]: ...
    @staticmethod
    def closestSideOfRectangle(right: float, bottom: float, left: float, top: float, x: float, y: float) -> int: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def averageAngle(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def averageAngle(a1: float, a2: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def linePerpendicularAngle(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def angleBetweenThreePoints(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def lineAngle(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def normalizedAngle(angle: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def interpolateArcValue(angle: float, a1: float, a2: float, a3: float, zm1: float, zm2: float, zm3: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def sweepAngle(centerX: float, centerY: float, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def circleLength(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @staticmethod
    @deprecated("""""")
    def angleOnCircle(angle: float, angle1: float, angle2: float, angle3: float) -> bool: ...
    @staticmethod
    @deprecated("""""")
    def circleAngleBetween(angle: float, angle1: float, angle2: float, clockwise: bool) -> bool: ...
    @staticmethod
    @deprecated("""""")
    def circleClockwise(angle1: float, angle2: float, angle3: float) -> bool: ...
    @staticmethod
    @deprecated("""""")
    def ccwAngle(dy: float, dx: float) -> float: ...
    @staticmethod
    def perpendicularOffsetPointAlongSegment(x1: float, y1: float, x2: float, y2: float, proportion: float, offset: float) -> typing.Tuple[float, float]: ...
    @staticmethod
    @deprecated("""""")
    def sqrDistToLine(ptX: float, ptY: float, x1: float, y1: float, x2: float, y2: float, epsilon: float) -> typing.Tuple[float, float, float]: ...
    @staticmethod
    def distance3D(pt1: 'QgsPoint', pt2: 'QgsPoint') -> float: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def distance2D(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @typing.overload
    @staticmethod
    def distance2D(pt1: 'QgsPoint', pt2: 'QgsPoint') -> float: ...
    @staticmethod
    def sqrDistance3D(pt1: 'QgsPoint', pt2: 'QgsPoint') -> float: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def sqrDistance2D(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @typing.overload
    @staticmethod
    def sqrDistance2D(pt1: 'QgsPoint', pt2: 'QgsPoint') -> float: ...
    @typing.overload
    @staticmethod
    def transferFirstZOrMValueToPoint(points: collections.abc.Iterable['QgsPoint'], point: 'QgsPoint') -> bool: ...
    @typing.overload
    @staticmethod
    def transferFirstZOrMValueToPoint(geom: QgsGeometry, point: 'QgsPoint') -> bool: ...
    @staticmethod
    def transferFirstMValueToPoint(points: collections.abc.Iterable['QgsPoint'], point: 'QgsPoint') -> bool: ...
    @staticmethod
    def transferFirstZValueToPoint(points: collections.abc.Iterable['QgsPoint'], point: 'QgsPoint') -> bool: ...
    @staticmethod
    @deprecated("""""")
    def setZValueFromPoints(points: collections.abc.Iterable['QgsPoint'], point: 'QgsPoint') -> bool: ...
    @staticmethod
    def perpendicularSegment(p: 'QgsPoint', s1: 'QgsPoint', s2: 'QgsPoint') -> 'QgsLineString': ...
    @staticmethod
    def coefficients(pt1: 'QgsPoint', pt2: 'QgsPoint') -> typing.Tuple[float, float, float]: ...
    @staticmethod
    def gradient(pt1: 'QgsPoint', pt2: 'QgsPoint') -> float: ...
    @staticmethod
    def interpolatePointOnLineByValue(x1: float, y1: float, v1: float, x2: float, y2: float, v2: float, value: float) -> QgsPointXY: ...
    @typing.overload
    @staticmethod
    def interpolatePointOnLine(x1: float, y1: float, x2: float, y2: float, fraction: float) -> QgsPointXY: ...
    @typing.overload
    @staticmethod
    def interpolatePointOnLine(p1: 'QgsPoint', p2: 'QgsPoint', fraction: float) -> 'QgsPoint': ...
    @staticmethod
    def midpoint(pt1: 'QgsPoint', pt2: 'QgsPoint') -> 'QgsPoint': ...
    @staticmethod
    def segmentSide(pt1: 'QgsPoint', pt3: 'QgsPoint', pt2: 'QgsPoint') -> int: ...
    @staticmethod
    def pointContinuesArc(a1: 'QgsPoint', a2: 'QgsPoint', a3: 'QgsPoint', b: 'QgsPoint', distanceTolerance: float, pointSpacingAngleTolerance: float) -> bool: ...
    @staticmethod
    def segmentizeArc(p1: 'QgsPoint', p2: 'QgsPoint', p3: 'QgsPoint', tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ..., hasZ: bool = ..., hasM: bool = ...) -> list['QgsPoint']: ...
    @staticmethod
    def circleTangentDirection(tangentPoint: 'QgsPoint', cp1: 'QgsPoint', cp2: 'QgsPoint', cp3: 'QgsPoint') -> float: ...
    @staticmethod
    def segmentMidPointFromCenter(p1: 'QgsPoint', p2: 'QgsPoint', center: 'QgsPoint', useShortestArc: bool = ...) -> 'QgsPoint': ...
    @staticmethod
    def segmentMidPoint(p1: 'QgsPoint', p2: 'QgsPoint', radius: float, mousePos: 'QgsPoint') -> typing.Tuple[bool, 'QgsPoint']: ...
    @staticmethod
    def interpolatePointOnCubicBezier(p0: 'QgsPoint', p1: 'QgsPoint', p2: 'QgsPoint', p3: 'QgsPoint', t: float) -> 'QgsPoint': ...
    @staticmethod
    def interpolatePointOnArc(pt1: 'QgsPoint', pt2: 'QgsPoint', pt3: 'QgsPoint', distance: float) -> 'QgsPoint': ...
    @staticmethod
    def pointOnLineWithDistance(startPoint: 'QgsPoint', directionPoint: 'QgsPoint', distance: float) -> 'QgsPoint': ...
    @typing.overload
    @staticmethod
    def leftOfLine(point: 'QgsPoint', p1: 'QgsPoint', p2: 'QgsPoint') -> int: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def leftOfLine(x: float, y: float, x1: float, y1: float, x2: float, y2: float) -> int: ...
    @staticmethod
    def projectPointOnSegment(p: 'QgsPoint', s1: 'QgsPoint', s2: 'QgsPoint') -> 'QgsPoint': ...
    @staticmethod
    def circleCircleInnerTangents(center1: QgsPointXY, radius1: float, center2: QgsPointXY, radius2: float) -> typing.Tuple[int, QgsPointXY, QgsPointXY, QgsPointXY, QgsPointXY]: ...
    @staticmethod
    def circleCircleOuterTangents(center1: QgsPointXY, radius1: float, center2: QgsPointXY, radius2: float) -> typing.Tuple[int, QgsPointXY, QgsPointXY, QgsPointXY, QgsPointXY]: ...
    @staticmethod
    def tangentPointAndCircle(center: QgsPointXY, radius: float, p: QgsPointXY) -> typing.Tuple[bool, QgsPointXY, QgsPointXY]: ...
    @staticmethod
    def circleCircleIntersections(center1: QgsPointXY, radius1: float, center2: QgsPointXY, radius2: float) -> typing.Tuple[int, QgsPointXY, QgsPointXY]: ...
    @staticmethod
    def lineCircleIntersection(center: QgsPointXY, radius: float, linePoint1: QgsPointXY, linePoint2: QgsPointXY, intersection: QgsPointXY) -> typing.Tuple[bool, QgsPointXY]: ...
    @staticmethod
    def distToInfiniteLine(point: 'QgsPoint', linePoint1: 'QgsPoint', linePoint2: 'QgsPoint', epsilon: float = ...) -> float: ...
    @staticmethod
    def verticesAtDistance(geometry: QgsAbstractGeometry, distance: float) -> typing.Tuple[bool, 'QgsVertexId', 'QgsVertexId']: ...
    @staticmethod
    def distanceToVertex(geom: QgsAbstractGeometry, id: 'QgsVertexId') -> float: ...
    @staticmethod
    def closestPoint(geometry: QgsAbstractGeometry, point: 'QgsPoint') -> 'QgsPoint': ...
    @staticmethod
    def closestVertex(geom: QgsAbstractGeometry, pt: 'QgsPoint') -> typing.Tuple['QgsPoint', 'QgsVertexId']: ...
    @staticmethod
    def extractLineStrings(geom: QgsAbstractGeometry|None) -> list['QgsLineString']: ...


class QgsGeometryUtilsBase(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeometryUtilsBase') -> None: ...

    @staticmethod
    def azimuth(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @staticmethod
    def project(aX: float, aY: float, aZ: float, distance: float, azimuth: float, inclination: float) -> typing.Tuple[float, float, float]: ...
    @staticmethod
    def segmentIntersection(p1x: float, p1y: float, p2x: float, p2y: float, q1x: float, q1y: float, q2x: float, q2y: float, tolerance: float = ..., acceptImproperIntersection: bool = ...) -> typing.Tuple[bool, float, float, bool]: ...
    @staticmethod
    def intersectionPointOfLinesByBearing(x1: float, y1: float, bearing1: float, x2: float, y2: float, bearing2: float) -> typing.Tuple[bool, float, float]: ...
    @staticmethod
    def lineIntersection(p1x: float, p1y: float, v1: QgsVector, p2x: float, p2y: float, v2: QgsVector) -> typing.Tuple[bool, float, float]: ...
    @staticmethod
    def bisector(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float) -> typing.Tuple[bool, float, float]: ...
    @staticmethod
    def angleBisector(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float, dX: float, dY: float) -> typing.Tuple[bool, float, float, float]: ...
    @staticmethod
    def points3DAreCollinear(x1: float, y1: float, z1: float, x2: float, y2: float, z2: float, x3: float, y3: float, z3: float, epsilon: float) -> bool: ...
    @staticmethod
    def pointsAreCollinear(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float, epsilon: float) -> bool: ...
    @staticmethod
    def weightedPointInTriangle(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float, weightB: float, weightC: float) -> typing.Tuple[float, float]: ...
    @staticmethod
    def pointFractionAlongLine(x1: float, y1: float, x2: float, y2: float, px: float, py: float) -> float: ...
    @staticmethod
    def triangleArea(aX: float, aY: float, bX: float, bY: float, cX: float, cY: float) -> float: ...
    @staticmethod
    def linesIntersection3D(La1: QgsVector3D, La2: QgsVector3D, Lb1: QgsVector3D, Lb2: QgsVector3D) -> typing.Tuple[bool, QgsVector3D]: ...
    @staticmethod
    def skewLinesProjection(P1: QgsVector3D, P12: QgsVector3D, P2: QgsVector3D, P22: QgsVector3D, epsilon: float = ...) -> typing.Tuple[bool, QgsVector3D]: ...
    @staticmethod
    def skewLinesDistance(P1: QgsVector3D, P12: QgsVector3D, P2: QgsVector3D, P22: QgsVector3D) -> float: ...
    @staticmethod
    def perpendicularCenterSegment(centerPointX: float, centerPointY: float, segmentPoint1x: float, segmentPoint1y: float, segmentPoint2x: float, segmentPoint2y: float, segmentLength: float = ...) -> typing.Tuple[float, float, float, float]: ...
    @staticmethod
    def closestSideOfRectangle(right: float, bottom: float, left: float, top: float, x: float, y: float) -> int: ...
    @typing.overload
    @staticmethod
    def averageAngle(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @typing.overload
    @staticmethod
    def averageAngle(a1: float, a2: float) -> float: ...
    @staticmethod
    def linePerpendicularAngle(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @staticmethod
    def angleBetweenThreePoints(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @staticmethod
    def lineAngle(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @staticmethod
    def normalizedAngle(angle: float) -> float: ...
    @staticmethod
    def interpolateArcValue(angle: float, a1: float, a2: float, a3: float, zm1: float, zm2: float, zm3: float) -> float: ...
    @staticmethod
    def sweepAngle(centerX: float, centerY: float, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @staticmethod
    def calculateArcLength(centerX: float, centerY: float, radius: float, x1: float, y1: float, x2: float, y2: float, x3: float, y3: float, fromVertex: int, toVertex: int) -> float: ...
    @staticmethod
    def circleLength(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> float: ...
    @staticmethod
    def angleOnCircle(angle: float, angle1: float, angle2: float, angle3: float) -> bool: ...
    @staticmethod
    def circleAngleBetween(angle: float, angle1: float, angle2: float, clockwise: bool) -> bool: ...
    @staticmethod
    def circleClockwise(angle1: float, angle2: float, angle3: float) -> bool: ...
    @staticmethod
    def circleCenterRadius(x1: float, y1: float, x2: float, y2: float, x3: float, y3: float) -> typing.Tuple[float, float, float]: ...
    @staticmethod
    def ccwAngle(dy: float, dx: float) -> float: ...
    @staticmethod
    def perpendicularOffsetPointAlongSegment(x1: float, y1: float, x2: float, y2: float, proportion: float, offset: float) -> typing.Tuple[float, float]: ...
    @staticmethod
    def leftOfLine(x: float, y: float, x1: float, y1: float, x2: float, y2: float) -> int: ...
    @staticmethod
    def sqrDistToLine(ptX: float, ptY: float, x1: float, y1: float, x2: float, y2: float, epsilon: float) -> typing.Tuple[float, float, float]: ...
    @typing.overload
    @staticmethod
    def distance2D(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @typing.overload
    @staticmethod
    def distance2D(point1: QtCore.QPointF, point2: QtCore.QPointF) -> float: ...
    @typing.overload
    @staticmethod
    def sqrDistance2D(x1: float, y1: float, x2: float, y2: float) -> float: ...
    @typing.overload
    @staticmethod
    def sqrDistance2D(point1: QtCore.QPointF, point2: QtCore.QPointF) -> float: ...
    @staticmethod
    def distance3D(x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> float: ...
    @staticmethod
    def sqrDistance3D(x1: float, y1: float, z1: float, x2: float, y2: float, z2: float) -> float: ...


class QgsGeos(QgsGeometryEngine):

    def __init__(self, geometry: QgsAbstractGeometry|None, precision: float = ..., flags: Qgis.GeosCreationFlag = ...) -> None: ...

    def unionCoverage(self) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def simplifyCoverageVW(self, tolerance: float, preserveBoundary: bool) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def concaveHull(self, targetPercent: float, allowHoles: bool = ...) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def constrainedDelaunayTriangulation(self) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def delaunayTriangulation(self, tolerance: float = ..., edgesOnly: bool = ...) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def voronoiDiagram(self, extent: QgsAbstractGeometry|None = ..., tolerance: float = ..., edgesOnly: bool = ...) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    @typing.overload
    def lineLocatePoint(self, point: 'QgsPoint') -> typing.Tuple[float, str]: ...
    @typing.overload
    def lineLocatePoint(self, x: float, y: float) -> typing.Tuple[float, str]: ...
    @typing.overload
    def shortestLine(self, other: QgsGeometry) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    @typing.overload
    def shortestLine(self, other: QgsAbstractGeometry|None) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def closestPoint(self, other: QgsGeometry) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def mergeLines(self, parameters: QgsGeometryParameters = ...) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def sharedPaths(self, other: QgsAbstractGeometry|None) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def node(self) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def minimumClearanceLine(self) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def minimumClearance(self) -> typing.Tuple[float, str]: ...
    def minimumWidth(self) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def largestEmptyCircle(self, tolerance: float, boundary: QgsAbstractGeometry|None = ...) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def maximumInscribedCircle(self, tolerance: float) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def singleSidedBuffer(self, distance: float, segments: int, side: Qgis.BufferSide, joinStyle: Qgis.JoinStyle, miterLimit: float) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def offsetCurve(self, distance: float, segments: int, joinStyle: Qgis.JoinStyle, miterLimit: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def splitGeometry(self, splitLine: 'QgsLineString', newGeometries: collections.abc.Iterable[QgsGeometry], topological: bool, topologyTestPoints: collections.abc.Iterable['QgsPoint'], errorMsg: str|None = ..., skipIntersectionCheck: bool = ...) -> QgsGeometryEngine.EngineOperationResult: ...
    def isSimple(self, errorMsg: str|None = ...) -> bool: ...
    def isEmpty(self, errorMsg: str|None = ...) -> bool: ...
    def isEqual(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def isValid(self, errorMsg: str|None = ..., allowSelfTouchingHoles: bool = ..., errorLoc: QgsGeometry|None = ...) -> bool: ...
    def length(self, errorMsg: str|None = ...) -> float: ...
    def area(self, errorMsg: str|None = ...) -> float: ...
    def relatePattern(self, geom: QgsAbstractGeometry|None, pattern: str|None, errorMsg: str|None = ...) -> bool: ...
    def relate(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> str: ...
    def disjoint(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def overlaps(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def within(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def crosses(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def touches(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def intersects(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def frechetDistanceDensify(self, geometry: QgsAbstractGeometry|None, densifyFraction: float) -> typing.Tuple[float, str]: ...
    def frechetDistance(self, geometry: QgsAbstractGeometry|None) -> typing.Tuple[float, str]: ...
    def hausdorffDistanceDensify(self, geometry: QgsAbstractGeometry|None, densifyFraction: float) -> typing.Tuple[float, str]: ...
    def hausdorffDistance(self, geometry: QgsAbstractGeometry|None) -> typing.Tuple[float, str]: ...
    @typing.overload
    def contains(self, x: float, y: float) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def contains(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> bool: ...
    def distanceWithin(self, geom: QgsAbstractGeometry|None, maxdistance: float, errorMsg: str|None = ...) -> bool: ...
    @typing.overload
    def distance(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ...) -> float: ...
    @typing.overload
    def distance(self, x: float, y: float) -> typing.Tuple[float, str]: ...
    def convexHull(self, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def pointOnSurface(self, errorMsg: str|None = ...) -> 'QgsPoint|None': ...
    def centroid(self, errorMsg: str|None = ...) -> 'QgsPoint|None': ...
    def envelope(self, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def interpolate(self, distance: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def simplify(self, tolerance: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def buffer(self, distance: float, segments: int, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def buffer(self, distance: float, segments: int, endCapStyle: Qgis.EndCapStyle, joinStyle: Qgis.JoinStyle, miterLimit: float, errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...
    def symDifference(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def combine(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def combine(self, geomList: collections.abc.Iterable[QgsAbstractGeometry], errorMsg: str|None, parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def combine(self, a0: collections.abc.Iterable[QgsGeometry], errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    def subdivide(self, maxNodes: int, parameters: QgsGeometryParameters = ...) -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def clip(self, rectangle: 'QgsRectangle') -> typing.Tuple[QgsAbstractGeometry|None, str]: ...
    def difference(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    def intersection(self, geom: QgsAbstractGeometry|None, errorMsg: str|None = ..., parameters: QgsGeometryParameters = ...) -> QgsAbstractGeometry|None: ...
    def prepareGeometry(self) -> None: ...
    def geometryChanged(self) -> None: ...
    def makeValid(self, method: Qgis.MakeValidMethod = ..., keepCollapsed: bool = ..., errorMsg: str|None = ...) -> QgsAbstractGeometry|None: ...


class QgsLineSegment2D(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, start: QgsPointXY, end: QgsPointXY) -> None: ...
    @typing.overload
    def __init__(self, x1: float, y1: float, x2: float, y2: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLineSegment2D') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def reverse(self) -> None: ...
    def pointLeftOfLine(self, point: QgsPointXY) -> int: ...
    def setEnd(self, end: QgsPointXY) -> None: ...
    def setStart(self, start: QgsPointXY) -> None: ...
    def setEndY(self, y: float) -> None: ...
    def setEndX(self, x: float) -> None: ...
    def setStartY(self, y: float) -> None: ...
    def setStartX(self, x: float) -> None: ...
    def end(self) -> QgsPointXY: ...
    def start(self) -> QgsPointXY: ...
    def endY(self) -> float: ...
    def endX(self) -> float: ...
    def startY(self) -> float: ...
    def startX(self) -> float: ...
    def lengthSquared(self) -> float: ...
    def length(self) -> float: ...


class QgsLineString(QgsCurve):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, points: collections.abc.Sequence['QgsPoint'|QgsPointXY|collections.abc.Sequence[float]]) -> None: ...
    @typing.overload
    def __init__(self, segment: QgsLineSegment2D) -> None: ...
    @typing.overload
    def __init__(self, x: collections.abc.Iterable[float], y: collections.abc.Iterable[float], z: collections.abc.Iterable[float] = ..., m: collections.abc.Iterable[float] = ..., is25DType: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, p1: 'QgsPoint', p2: 'QgsPoint') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLineString') -> None: ...

    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def lineLocatePointByM(self, m: float, use3DDistance: bool = ...) -> typing.Tuple[bool, float, float, float, float]: ...
    def interpolateM(self, use3DDistance: bool = ...) -> 'QgsLineString'|None: ...
    def measuredLine(self, start: float, end: float) -> 'QgsLineString'|None: ...
    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    @deprecated("""""")
    def calculateBoundingBox3d(self) -> QgsBox3D: ...
    def __delitem__(self, index: int) -> None: ...
    def __setitem__(self, index: int, point: 'QgsPoint') -> None: ...
    def __getitem__(self, index: int) -> 'QgsPoint': ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsLineString|None': ...
    def scroll(self, firstVertexIndex: int) -> None: ...
    def convertTo(self, type: Qgis.WkbType) -> bool: ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def distanceBetweenVertices(self, fromVertex: 'QgsVertexId', toVertex: 'QgsVertexId') -> float: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def sumUpArea3D(self) -> float: ...
    def sumUpArea(self) -> float: ...
    def centroid(self) -> 'QgsPoint': ...
    def pointAt(self, node: int, point: 'QgsPoint') -> typing.Tuple[bool, Qgis.VertexType]: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def curveSubstring(self, startDistance: float, endDistance: float) -> 'QgsLineString|None': ...
    def interpolatePoint(self, distance: float) -> 'QgsPoint|None': ...
    def reversed(self) -> 'QgsLineString|None': ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def drawAsPolygon(self, p: QtGui.QPainter) -> None: ...
    def addToPainterPath(self, path: QtGui.QPainterPath) -> None: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: QgsAbstractGeometryTransformer|None, feedback: QgsFeedback|None = ...) -> bool: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def points(self) -> list['QgsPoint']: ...
    def nCoordinates(self) -> int: ...
    def numPoints(self) -> int: ...
    def curveToLine(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> 'QgsLineString|None': ...
    def endPoint(self) -> 'QgsPoint': ...
    def startPoint(self) -> 'QgsPoint': ...
    def length3D(self) -> float: ...
    def splitToDisjointXYParts(self) -> list['QgsLineString']: ...
    def length(self) -> float: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsLineString|None': ...
    def asQPolygonF(self) -> QtGui.QPolygonF: ...
    def collectDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> list['QgsVertexId']: ...
    @typing.overload
    def boundingBoxIntersects(self, rectangle: 'QgsRectangle') -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    def isClosed2D(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsLineString|None': ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def indexOf(self, point: 'QgsPoint') -> int: ...
    def isEmpty(self) -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsLineString|None': ...
    def dimension(self) -> int: ...
    def geometryType(self) -> str: ...
    def extend(self, startDistance: float, endDistance: float) -> None: ...
    def toCurveType(self) -> QgsCompoundCurve|None: ...
    def close(self) -> None: ...
    def addVertex(self, pt: 'QgsPoint') -> None: ...
    def append(self, line: 'QgsLineString|None') -> None: ...
    def setPoints(self, points: collections.abc.Iterable['QgsPoint']) -> None: ...
    def setMAt(self, index: int, m: float) -> None: ...
    def setZAt(self, index: int, z: float) -> None: ...
    def setYAt(self, index: int, y: float) -> None: ...
    def setXAt(self, index: int, x: float) -> None: ...
    def mAt(self, index: int) -> float: ...
    def zAt(self, index: int) -> float: ...
    def yAt(self, index: int) -> float: ...
    def xAt(self, index: int) -> float: ...
    def pointN(self, i: int) -> 'QgsPoint': ...
    def equals(self, other: QgsCurve) -> bool: ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    @staticmethod
    def fromQPolygonF(polygon: QtGui.QPolygonF) -> 'QgsLineString'|None: ...
    @staticmethod
    def fromBezierCurve(start: 'QgsPoint', controlPoint1: 'QgsPoint', controlPoint2: 'QgsPoint', end: 'QgsPoint', segments: int = ...) -> 'QgsLineString'|None: ...


class QgsMultiCurve(QgsGeometryCollection):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMultiCurve') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsMultiCurve|None': ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def reversed(self) -> 'QgsMultiCurve|None': ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsMultiCurve|None': ...
    def insertGeometry(self, g: QgsAbstractGeometry|None, index: int) -> bool: ...
    def addGeometries(self, geometries: collections.abc.Iterable[QgsAbstractGeometry]) -> bool: ...
    def addGeometry(self, g: QgsAbstractGeometry|None) -> bool: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def toCurveType(self) -> 'QgsMultiCurve|None': ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsMultiCurve|None': ...
    def geometryType(self) -> str: ...
    def curveN(self, index: int) -> QgsCurve: ...


class QgsMultiLineString(QgsMultiCurve):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, linestrings: collections.abc.Iterable[QgsLineString]) -> None: ...
    @typing.overload
    def __init__(self, linestrings: collections.abc.Iterable[QgsLineString]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMultiLineString') -> None: ...

    def wktOmitChildType(self) -> bool: ...
    def measuredLine(self, start: float, end: float) -> 'QgsMultiLineString|None': ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsMultiLineString|None': ...
    def toCurveType(self) -> QgsMultiCurve|None: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsMultiLineString|None': ...
    def insertGeometry(self, g: QgsAbstractGeometry|None, index: int) -> bool: ...
    def addGeometries(self, geometries: collections.abc.Iterable[QgsAbstractGeometry]) -> bool: ...
    def addGeometry(self, g: QgsAbstractGeometry|None) -> bool: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsMultiLineString|None': ...
    def geometryType(self) -> str: ...
    def lineStringN(self, index: int) -> QgsLineString: ...


class QgsMultiPoint(QgsGeometryCollection):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, points: collections.abc.Sequence['QgsPoint'|QgsPointXY|collections.abc.Sequence[float]]) -> None: ...
    @typing.overload
    def __init__(self, x: collections.abc.Iterable[float], y: collections.abc.Iterable[float], z: collections.abc.Iterable[float] = ..., m: collections.abc.Iterable[float] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMultiPoint') -> None: ...

    def wktOmitChildType(self) -> bool: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsMultiPoint|None': ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsMultiPoint|None': ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def insertGeometry(self, g: QgsAbstractGeometry|None, index: int) -> bool: ...
    def addGeometries(self, geometries: collections.abc.Iterable[QgsAbstractGeometry]) -> bool: ...
    def addGeometry(self, g: QgsAbstractGeometry|None) -> bool: ...
    def nCoordinates(self) -> int: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def clear(self) -> None: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def toCurveType(self) -> 'QgsMultiPoint|None': ...
    def clone(self) -> 'QgsMultiPoint|None': ...
    def geometryType(self) -> str: ...
    def pointN(self, index: int) -> 'QgsPoint': ...


class QgsMultiSurface(QgsGeometryCollection):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMultiSurface') -> None: ...

    def createEmptyWithSameType(self) -> 'QgsMultiSurface|None': ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsMultiSurface|None': ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def insertGeometry(self, g: QgsAbstractGeometry|None, index: int) -> bool: ...
    def addGeometries(self, geometries: collections.abc.Iterable[QgsAbstractGeometry]) -> bool: ...
    def addGeometry(self, g: QgsAbstractGeometry|None) -> bool: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def toCurveType(self) -> 'QgsMultiSurface|None': ...
    def clone(self) -> 'QgsMultiSurface|None': ...
    def clear(self) -> None: ...
    def geometryType(self) -> str: ...
    def surfaceN(self, index: int) -> QgsSurface: ...


class QgsMultiPolygon(QgsMultiSurface):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, polygons: collections.abc.Iterable['QgsPolygon']) -> None: ...
    @typing.overload
    def __init__(self, polygons: collections.abc.Iterable['QgsPolygon']) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMultiPolygon') -> None: ...

    def wktOmitChildType(self) -> bool: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsMultiPolygon|None': ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def toCurveType(self) -> QgsMultiSurface|None: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsMultiPolygon|None': ...
    def insertGeometry(self, g: QgsAbstractGeometry|None, index: int) -> bool: ...
    def addGeometries(self, geometries: collections.abc.Iterable[QgsAbstractGeometry]) -> bool: ...
    def addGeometry(self, g: QgsAbstractGeometry|None) -> bool: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def clone(self) -> 'QgsMultiPolygon|None': ...
    def clear(self) -> None: ...
    def geometryType(self) -> str: ...
    def polygonN(self, index: int) -> 'QgsPolygon': ...


class QgsNurbsCurve(QgsCurve):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, controlPoints: collections.abc.Iterable['QgsPoint'], degree: int, knots: collections.abc.Iterable[float], weights: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNurbsCurve') -> None: ...

    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def clearCache(self) -> None: ...
    def isAnchorVertex(self, localIndex: int) -> bool: ...
    @staticmethod
    def generateKnotsForBezierConversion(nAnchors: int, degree: int = ...) -> list[float]: ...
    @staticmethod
    def generateUniformKnots(numControlPoints: int, degree: int) -> list[float]: ...
    def setWeight(self, index: int, weight: float) -> None: ...
    def weight(self, index: int) -> float: ...
    def setWeights(self, weights: collections.abc.Iterable[float]) -> None: ...
    def weights(self) -> list[float]: ...
    def setKnots(self, knots: collections.abc.Iterable[float]) -> None: ...
    def knots(self) -> list[float]: ...
    def setControlPoints(self, points: collections.abc.Iterable['QgsPoint']) -> None: ...
    def controlPoints(self) -> list['QgsPoint']: ...
    def setDegree(self, degree: int) -> None: ...
    def degree(self) -> int: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def vertexCount(self, part: int = ..., ring: int = ...) -> int: ...
    def vertexAt(self, id: 'QgsVertexId') -> 'QgsPoint': ...
    def toCurveType(self) -> QgsCurve|None: ...
    def partCount(self) -> int: ...
    def hasCurvedSegments(self) -> bool: ...
    def geometryType(self) -> str: ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def centroid(self) -> 'QgsPoint': ...
    @typing.overload
    def boundingBoxIntersects(self, rectangle: 'QgsRectangle') -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    def clear(self) -> None: ...
    def isEmpty(self) -> bool: ...
    def dimension(self) -> int: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def boundingBox3D(self) -> QgsBox3D: ...
    def boundingBox(self) -> 'QgsRectangle': ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def createEmptyWithSameType(self) -> QgsAbstractGeometry|None: ...
    @typing.overload
    def transform(self, transformer: QgsAbstractGeometryTransformer|None, feedback: QgsFeedback|None = ...) -> bool: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    def swapXy(self) -> None: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> QgsAbstractGeometry|None: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> QgsAbstractGeometry|None: ...
    def distanceBetweenVertices(self, fromVertex: 'QgsVertexId', toVertex: 'QgsVertexId') -> float: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def length(self) -> float: ...
    def curveSubstring(self, startDistance: float, endDistance: float) -> QgsCurve|None: ...
    def addToPainterPath(self, path: QtGui.QPainterPath) -> None: ...
    def asQPolygonF(self) -> QtGui.QPolygonF: ...
    def mAt(self, index: int) -> float: ...
    def zAt(self, index: int) -> float: ...
    def yAt(self, index: int) -> float: ...
    def xAt(self, index: int) -> float: ...
    def sumUpArea3D(self) -> float: ...
    def sumUpArea(self) -> float: ...
    def startPoint(self) -> 'QgsPoint': ...
    def scroll(self, firstVertexIndex: int) -> None: ...
    def reversed(self) -> QgsCurve|None: ...
    def points(self) -> list['QgsPoint']: ...
    def pointAt(self, node: int) -> typing.Tuple[bool, 'QgsPoint', Qgis.VertexType]: ...
    def numPoints(self) -> int: ...
    def interpolatePoint(self, distance: float) -> 'QgsPoint|None': ...
    def indexOf(self, point: 'QgsPoint') -> int: ...
    def equals(self, other: QgsCurve) -> bool: ...
    def endPoint(self) -> 'QgsPoint': ...
    def drawAsPolygon(self, p: QtGui.QPainter) -> None: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def curveToLine(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> QgsLineString|None: ...
    def isClosed2D(self) -> bool: ...
    def isClosed(self) -> bool: ...
    def isPolyBezier(self) -> bool: ...
    def isRational(self) -> bool: ...
    def isBSpline(self) -> bool: ...
    def isBezier(self) -> bool: ...
    def evaluate(self, t: float) -> 'QgsPoint': ...
    def clone(self) -> 'QgsNurbsCurve|None': ...


class QgsNurbsUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNurbsUtils') -> None: ...

    @staticmethod
    def findNurbsCurveForVertex(geom: QgsAbstractGeometry|None, vid: 'QgsVertexId') -> typing.Tuple[QgsNurbsCurve|None, int]: ...
    @staticmethod
    def extractNurbsCurve(geom: QgsAbstractGeometry|None) -> QgsNurbsCurve|None: ...
    @staticmethod
    def containsNurbsCurve(geom: QgsAbstractGeometry|None) -> bool: ...


class QgsOrientedBox3D(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, center: collections.abc.Iterable[float], halfAxes: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def __init__(self, center: QgsVector3D, halfAxes: collections.abc.Iterable[QgsVector3D]) -> None: ...
    @typing.overload
    def __init__(self, center: QgsVector3D, halfSizes: QgsVector3D, quaternion: QtGui.QQuaternion) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOrientedBox3D') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def intersects(self, other: 'QgsOrientedBox3D') -> bool: ...
    def transformed(self, transform: QgsMatrix4x4) -> 'QgsOrientedBox3D': ...
    def reprojectedExtent(self, ct: 'QgsCoordinateTransform') -> QgsBox3D: ...
    def longestSide(self) -> float: ...
    def size(self) -> QgsVector3D: ...
    def corners(self) -> list[QgsVector3D]: ...
    def extent(self) -> QgsBox3D: ...
    def halfAxes(self) -> list[float]: ...
    def center(self) -> QgsVector3D: ...
    def centerZ(self) -> float: ...
    def centerY(self) -> float: ...
    def centerX(self) -> float: ...
    def isNull(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def fromBox3D(box: QgsBox3D) -> 'QgsOrientedBox3D': ...


class QgsPoint(QgsAbstractGeometry):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, x: 'QgsPoint'|QtCore.QPointF|float|None = ..., y: float|None = ..., z: float|None = ..., m: float|None = ..., wkbType: int|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPoint') -> None: ...

    def childPoint(self, index: int) -> 'QgsPoint': ...
    def childCount(self) -> int: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsPoint|None': ...
    def convertTo(self, type: Qgis.WkbType) -> bool: ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, rectangle: 'QgsRectangle') -> bool: ...
    @typing.overload
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def toCurveType(self) -> 'QgsPoint|None': ...
    def vertexAt(self, a0: 'QgsVertexId') -> 'QgsPoint': ...
    def partCount(self) -> int: ...
    def ringCount(self, a0: int = ...) -> int: ...
    def vertexCount(self, a0: int = ..., a1: int = ...) -> int: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def adjacentVertices(self, vertex: 'QgsVertexId') -> typing.Tuple['QgsVertexId', 'QgsVertexId']: ...
    def nextVertex(self, id: 'QgsVertexId') -> typing.Tuple[bool, 'QgsPoint']: ...
    def closestSegment(self, pt: 'QgsPoint', epsilon: float = ...) -> typing.Tuple[float, 'QgsPoint', 'QgsVertexId', int]: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: 'QgsPoint') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: 'QgsPoint') -> bool: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def nCoordinates(self) -> int: ...
    def coordinateSequence(self) -> typing.Any: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: QgsAbstractGeometryTransformer|None, feedback: QgsFeedback|None = ...) -> bool: ...
    def asQPainterPath(self) -> QtGui.QPainterPath: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, a0: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsPoint|None': ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsPoint|None': ...
    def clone(self) -> 'QgsPoint|None': ...
    def dimension(self) -> int: ...
    def geometryType(self) -> str: ...
    def boundingBox3D(self) -> QgsBox3D: ...
    def isEmpty(self) -> bool: ...
    def normalize(self) -> None: ...
    def __add__(self, v: QgsVector) -> 'QgsPoint': ...
    def __isub__(self, v: QgsVector) -> 'QgsPoint': ...
    def __iadd__(self, v: QgsVector) -> 'QgsPoint': ...
    @typing.overload
    def __sub__(self, p: 'QgsPoint') -> QgsVector: ...
    @typing.overload
    def __sub__(self, v: QgsVector) -> 'QgsPoint': ...
    def project(self, distance: float, azimuth: float, inclination: float = ...) -> 'QgsPoint': ...
    def inclination(self, other: 'QgsPoint') -> float: ...
    def azimuth(self, other: 'QgsPoint') -> float: ...
    @typing.overload
    def distanceSquared3D(self, x: float, y: float, z: float) -> float: ...
    @typing.overload
    def distanceSquared3D(self, other: 'QgsPoint') -> float: ...
    @typing.overload
    def distance3D(self, x: float, y: float, z: float) -> float: ...
    @typing.overload
    def distance3D(self, other: 'QgsPoint') -> float: ...
    @typing.overload
    def distanceSquared(self, x: float, y: float) -> float: ...
    @typing.overload
    def distanceSquared(self, other: 'QgsPoint') -> float: ...
    @typing.overload
    def distance(self, x: float, y: float) -> float: ...
    @typing.overload
    def distance(self, other: 'QgsPoint') -> float: ...
    def toQgsVector3D(self) -> QgsVector3D: ...
    def toVector4D(self) -> QtGui.QVector4D: ...
    def toVector3D(self) -> QtGui.QVector3D: ...
    def toQPointF(self) -> QtCore.QPointF: ...
    def setM(self, m: float) -> None: ...
    def setZ(self, z: float) -> None: ...
    def setY(self, y: float) -> None: ...
    def setX(self, x: float) -> None: ...
    def m(self) -> float: ...
    def z(self) -> float: ...
    def y(self) -> float: ...
    def x(self) -> float: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...


class QgsPolygon(QgsCurvePolygon):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, exterior: QgsLineString|None, rings: collections.abc.Iterable[QgsLineString] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPolygon') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsPolygon|None': ...
    def pointDistanceToBoundary(self, x: float, y: float) -> float: ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def setExteriorRing(self, ring: QgsCurve|None) -> None: ...
    def addInteriorRing(self, ring: QgsCurve|None) -> None: ...
    def toCurveType(self) -> QgsCurvePolygon|None: ...
    def surfaceToPolygon(self) -> 'QgsPolygon|None': ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsPolygon|None': ...
    def geometryType(self) -> str: ...


class QgsPolyhedralSurface(QgsSurface):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p: 'QgsPolyhedralSurface') -> None: ...
    @typing.overload
    def __init__(self, multiPolygon: QgsMultiPolygon|None) -> None: ...

    def calculateBoundingBox3D(self) -> QgsBox3D: ...
    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def childGeometry(self, index: int) -> QgsAbstractGeometry|None: ...
    def childCount(self) -> int: ...
    def __getitem__(self, index: int) -> QgsPolygon: ...
    def __len__(self) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsPolyhedralSurface|None': ...
    def toMultiPolygon(self) -> QgsMultiPolygon|None: ...
    def toCurveType(self) -> QgsMultiSurface|None: ...
    def swapXy(self) -> None: ...
    def dropMValue(self) -> bool: ...
    def dropZValue(self) -> bool: ...
    def addMValue(self, mValue: float = ...) -> bool: ...
    def addZValue(self, zValue: float = ...) -> bool: ...
    def segmentLength(self, startVertex: 'QgsVertexId') -> float: ...
    def vertexAt(self, id: 'QgsVertexId') -> QgsPoint: ...
    def partCount(self) -> int: ...
    def ringCount(self, part: int = ...) -> int: ...
    def vertexCount(self, part: int = ..., ring: int = ...) -> int: ...
    def vertexAngle(self, vertex: 'QgsVertexId') -> float: ...
    def segmentize(self, tolerance: float = ..., toleranceType: QgsAbstractGeometry.SegmentationToleranceType = ...) -> QgsAbstractGeometry|None: ...
    def hasCurvedSegments(self) -> bool: ...
    def adjacentVertices(self, vertex: 'QgsVertexId') -> typing.Tuple['QgsVertexId', 'QgsVertexId']: ...
    def nextVertex(self, id: 'QgsVertexId') -> typing.Tuple[bool, QgsPoint]: ...
    def closestSegment(self, pt: QgsPoint, epsilon: float = ...) -> typing.Tuple[float, QgsPoint, 'QgsVertexId', int]: ...
    def isEmpty(self) -> bool: ...
    def vertexNumberFromVertexId(self, id: 'QgsVertexId') -> int: ...
    def nCoordinates(self) -> int: ...
    def coordinateSequence(self) -> typing.Any: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def moveVertex(self, position: 'QgsVertexId', newPos: QgsPoint) -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: QgsPoint) -> bool: ...
    @typing.overload
    def transform(self, ct: 'QgsCoordinateTransform', d: Qgis.TransformDirection = ..., transformZ: bool = ...) -> None: ...
    @typing.overload
    def transform(self, t: QtGui.QTransform, zTranslate: float = ..., zScale: float = ..., mTranslate: float = ..., mScale: float = ...) -> None: ...
    @typing.overload
    def transform(self, transformer: QgsAbstractGeometryTransformer|None, feedback: QgsFeedback|None = ...) -> bool: ...
    def draw(self, p: QtGui.QPainter) -> None: ...
    def asQPainterPath(self) -> QtGui.QPainterPath: ...
    def removePatch(self, ringIndex: int) -> bool: ...
    def addPatch(self, patch: QgsPolygon|None) -> None: ...
    def setPatches(self, patches: collections.abc.Iterable[QgsPolygon]) -> None: ...
    def patchN(self, i: int) -> QgsPolygon: ...
    def numPatches(self) -> int: ...
    def boundingBoxIntersects(self, box3d: QgsBox3D) -> bool: ...
    def removeDuplicateNodes(self, epsilon: float = ..., useZValues: bool = ...) -> bool: ...
    def simplifyByDistance(self, tolerance: float) -> 'QgsPolyhedralSurface|None': ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsPolyhedralSurface|None': ...
    def boundary(self) -> QgsAbstractGeometry|None: ...
    def perimeter(self) -> float: ...
    def area3D(self) -> float: ...
    def area(self) -> float: ...
    def normalize(self) -> None: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asWkt(self, precision: int = ...) -> str: ...
    def asWkb(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> QtCore.QByteArray: ...
    def wkbSize(self, flags: QgsAbstractGeometry.WkbFlag = ...) -> int: ...
    def isValid(self, flags: Qgis.GeometryValidityFlag = ...) -> typing.Tuple[bool, str]: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsPolyhedralSurface|None': ...
    def dimension(self) -> int: ...
    def geometryType(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...


class QgsQuadrilateral(PyQt6.sip.wrapper):

    class Point(enum.IntEnum):
        Point1 = ... # type: QgsQuadrilateral.Point
        Point2 = ... # type: QgsQuadrilateral.Point
        Point3 = ... # type: QgsQuadrilateral.Point
        Point4 = ... # type: QgsQuadrilateral.Point

    class ConstructionOption(enum.IntEnum):
        Distance = ... # type: QgsQuadrilateral.ConstructionOption
        Projected = ... # type: QgsQuadrilateral.ConstructionOption

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p1: QgsPoint, p2: QgsPoint, p3: QgsPoint, p4: QgsPoint) -> None: ...
    @typing.overload
    def __init__(self, p1: QgsPointXY, p2: QgsPointXY, p3: QgsPointXY, p4: QgsPointXY) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsQuadrilateral') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def perimeter(self) -> float: ...
    def area(self) -> float: ...
    def toString(self, pointPrecision: int = ...) -> str: ...
    def toLineString(self, force2D: bool = ...) -> QgsLineString|None: ...
    def toPolygon(self, force2D: bool = ...) -> QgsPolygon|None: ...
    def points(self) -> list[QgsPoint]: ...
    def setPoints(self, p1: QgsPoint, p2: QgsPoint, p3: QgsPoint, p4: QgsPoint) -> bool: ...
    def setPoint(self, newPoint: QgsPoint, index: 'QgsQuadrilateral.Point') -> bool: ...
    def isValid(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def equals(self, other: 'QgsQuadrilateral', epsilon: float = ...) -> bool: ...
    @staticmethod
    def fromRectangle(rectangle: 'QgsRectangle') -> 'QgsQuadrilateral': ...
    @staticmethod
    def rectangleFromCenterPoint(center: QgsPoint, point: QgsPoint) -> 'QgsQuadrilateral': ...
    @staticmethod
    def squareFromDiagonal(p1: QgsPoint, p2: QgsPoint) -> 'QgsQuadrilateral': ...
    @staticmethod
    def rectangleFromExtent(p1: QgsPoint, p2: QgsPoint) -> 'QgsQuadrilateral': ...
    @staticmethod
    def rectangleFrom3Points(p1: QgsPoint, p2: QgsPoint, p3: QgsPoint, mode: 'QgsQuadrilateral.ConstructionOption') -> 'QgsQuadrilateral': ...


class QgsRectangle(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, xMin: float, yMin: float = ..., xMax: float = ..., yMax: float = ..., normalize: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, p1: QgsPointXY, p2: QgsPointXY, normalize: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, qRectF: QtCore.QRectF) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsRectangle') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def snappedToGrid(self, spacing: float) -> 'QgsRectangle': ...
    def toBox3d(self, zMin: float, zMax: float) -> QgsBox3D: ...
    def invert(self) -> None: ...
    def isFinite(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def asPolygon(self) -> str: ...
    def toString(self, precision: int = ...) -> str: ...
    def toRectF(self) -> QtCore.QRectF: ...
    def asWktPolygon(self) -> str: ...
    def asWktCoordinates(self) -> str: ...
    def isMaximal(self) -> bool: ...
    def isValid(self) -> bool: ...
    def isNull(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def __iadd__(self, v: QgsVector) -> 'QgsRectangle': ...
    def __isub__(self, v: QgsVector) -> 'QgsRectangle': ...
    def __add__(self, v: QgsVector) -> 'QgsRectangle': ...
    def __sub__(self, v: QgsVector) -> 'QgsRectangle': ...
    def distance(self, point: QgsPointXY) -> float: ...
    @typing.overload
    def combineExtentWith(self, rect: 'QgsRectangle') -> None: ...
    @typing.overload
    def combineExtentWith(self, x: float, y: float) -> None: ...
    @typing.overload
    def combineExtentWith(self, point: QgsPointXY) -> None: ...
    @typing.overload
    def contains(self, rect: 'QgsRectangle') -> bool: ...
    @typing.overload
    def contains(self, p: QgsPointXY) -> bool: ...
    @typing.overload
    def contains(self, x: float, y: float) -> bool: ...
    def intersects(self, rect: 'QgsRectangle') -> bool: ...
    def intersect(self, rect: 'QgsRectangle') -> 'QgsRectangle': ...
    def buffered(self, width: float) -> 'QgsRectangle': ...
    def include(self, p: QgsPointXY) -> None: ...
    def grow(self, delta: float) -> None: ...
    def scaled(self, scaleFactor: float, center: QgsPointXY|None = ...) -> 'QgsRectangle': ...
    @typing.overload
    def scale(self, scaleFactor: float, c: QgsPointXY|None = ...) -> None: ...
    @typing.overload
    def scale(self, scaleFactor: float, centerX: float, centerY: float) -> None: ...
    def center(self) -> QgsPointXY: ...
    def perimeter(self) -> float: ...
    def area(self) -> float: ...
    def height(self) -> float: ...
    def width(self) -> float: ...
    def normalize(self) -> None: ...
    def yMinimum(self) -> float: ...
    def yMaximum(self) -> float: ...
    def xMinimum(self) -> float: ...
    def xMaximum(self) -> float: ...
    @deprecated("""""")
    def setMinimal(self) -> None: ...
    def setNull(self) -> None: ...
    def setYMaximum(self, y: float) -> None: ...
    def setYMinimum(self, y: float) -> None: ...
    def setXMaximum(self, x: float) -> None: ...
    def setXMinimum(self, x: float) -> None: ...
    @typing.overload
    def set(self, p1: QgsPointXY, p2: QgsPointXY, normalize: bool = ...) -> None: ...
    @typing.overload
    def set(self, xMin: float, yMin: float, xMax: float, yMax: float, normalize: bool = ...) -> None: ...
    @staticmethod
    def fromCenterAndSize(center: QgsPointXY, width: float, height: float) -> 'QgsRectangle': ...
    @staticmethod
    def fromWkt(wkt: str|None) -> 'QgsRectangle': ...


class QgsReferencedGeometryBase(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, crs: 'QgsCoordinateReferenceSystem' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReferencedGeometryBase') -> None: ...

    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...


class QgsReferencedRectangle(QgsRectangle, QgsReferencedGeometryBase):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, rectangle: QgsRectangle, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReferencedRectangle') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsReferencedPointXY(QgsPointXY, QgsReferencedGeometryBase):

    @typing.overload
    def __init__(self, point: QgsPointXY, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReferencedPointXY') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsReferencedGeometry(QgsGeometry, QgsReferencedGeometryBase):

    @typing.overload
    def __init__(self, geometry: QgsGeometry, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReferencedGeometry') -> None: ...

    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def fromReferencedRect(rectangle: QgsReferencedRectangle) -> 'QgsReferencedGeometry': ...
    @staticmethod
    def fromReferencedPointXY(point: QgsReferencedPointXY) -> 'QgsReferencedGeometry': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsRegularPolygon(PyQt6.sip.wrapper):

    class ConstructionOption(enum.IntEnum):
        InscribedCircle = ... # type: QgsRegularPolygon.ConstructionOption
        CircumscribedCircle = ... # type: QgsRegularPolygon.ConstructionOption

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, center: QgsPoint, radius: float, azimuth: float, numberSides: int, circle: 'QgsRegularPolygon.ConstructionOption') -> None: ...
    @typing.overload
    def __init__(self, center: QgsPoint, pt1: QgsPoint, numberSides: int, circle: 'QgsRegularPolygon.ConstructionOption') -> None: ...
    @typing.overload
    def __init__(self, pt1: QgsPoint, pt2: QgsPoint, numberSides: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRegularPolygon') -> None: ...

    def length(self) -> float: ...
    def perimeter(self) -> float: ...
    def area(self) -> float: ...
    def centralAngle(self) -> float: ...
    def interiorAngle(self) -> float: ...
    def toString(self, pointPrecision: int = ..., radiusPrecision: int = ..., anglePrecision: int = ...) -> str: ...
    def circumscribedCircle(self) -> QgsCircle: ...
    def inscribedCircle(self) -> QgsCircle: ...
    def triangulate(self) -> list['QgsTriangle']: ...
    def toTriangle(self) -> 'QgsTriangle': ...
    def toLineString(self) -> QgsLineString|None: ...
    def toPolygon(self) -> QgsPolygon|None: ...
    def points(self) -> list[QgsPoint]: ...
    def setNumberSides(self, numberSides: int) -> None: ...
    def setFirstVertex(self, firstVertex: QgsPoint) -> None: ...
    def setRadius(self, radius: float) -> None: ...
    def setCenter(self, center: QgsPoint) -> None: ...
    def numberSides(self) -> int: ...
    def apothem(self) -> float: ...
    def firstVertex(self) -> QgsPoint: ...
    def radius(self) -> float: ...
    def center(self) -> QgsPoint: ...
    def isEmpty(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsSphere(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, x: float, y: float, z: float, radius: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSphere') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def boundingBox(self) -> QgsBox3D: ...
    def toCircle(self) -> QgsCircle: ...
    def surfaceArea(self) -> float: ...
    def volume(self) -> float: ...
    def diameter(self) -> float: ...
    def setRadius(self, radius: float) -> None: ...
    def radius(self) -> float: ...
    @typing.overload
    def setCenter(self, center: QgsPoint) -> None: ...
    @typing.overload
    def setCenter(self, x: float, y: float, z: float) -> None: ...
    def centerZ(self) -> float: ...
    def centerY(self) -> float: ...
    def centerX(self) -> float: ...
    def centerVector(self) -> QgsVector3D: ...
    def center(self) -> QgsPoint: ...
    def isEmpty(self) -> bool: ...
    def isNull(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsTriangle(QgsPolygon):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p1: QgsPoint, p2: QgsPoint, p3: QgsPoint) -> None: ...
    @typing.overload
    def __init__(self, p1: QgsPointXY, p2: QgsPointXY, p3: QgsPointXY) -> None: ...
    @typing.overload
    def __init__(self, p1: QtCore.QPointF, p2: QtCore.QPointF, p3: QtCore.QPointF) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTriangle') -> None: ...

    def createEmptyWithSameType(self) -> 'QgsTriangle|None': ...
    def inscribedCircle(self) -> QgsCircle: ...
    def inscribedRadius(self) -> float: ...
    def inscribedCenter(self) -> QgsPoint: ...
    def circumscribedCircle(self) -> QgsCircle: ...
    def circumscribedRadius(self) -> float: ...
    def circumscribedCenter(self) -> QgsPoint: ...
    def orthocenter(self, lengthTolerance: float = ...) -> QgsPoint: ...
    def medial(self) -> 'QgsTriangle': ...
    def bisectors(self, lengthTolerance: float = ...) -> list[QgsLineString]: ...
    def medians(self) -> list[QgsLineString]: ...
    def altitudes(self) -> list[QgsLineString]: ...
    def isScalene(self, lengthTolerance: float = ...) -> bool: ...
    def isRight(self, angleTolerance: float = ...) -> bool: ...
    def isEquilateral(self, lengthTolerance: float = ...) -> bool: ...
    def isIsocele(self, lengthTolerance: float = ...) -> bool: ...
    def isDegenerate(self) -> bool: ...
    def angles(self) -> list[float]: ...
    def lengths(self) -> list[float]: ...
    @typing.overload
    def vertexAt(self, id: 'QgsVertexId') -> QgsPoint: ...
    @typing.overload
    def vertexAt(self, atVertex: int) -> QgsPoint: ...
    def boundary(self) -> QgsCurve|None: ...
    def setExteriorRing(self, ring: QgsCurve|None) -> None: ...
    def moveVertex(self, vId: 'QgsVertexId', newPos: QgsPoint) -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: QgsPoint) -> bool: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def addInteriorRing(self, ring: QgsCurve|None) -> None: ...
    def toCurveType(self) -> QgsCurvePolygon|None: ...
    def surfaceToPolygon(self) -> QgsPolygon|None: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkbPtr: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsTriangle|None': ...
    def geometryType(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsTriangulatedSurface(QgsPolyhedralSurface):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, p: 'QgsTriangulatedSurface') -> None: ...

    def compareToSameClass(self, other: QgsAbstractGeometry|None) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def createEmptyWithSameType(self) -> 'QgsTriangulatedSurface|None': ...
    def triangleN(self, index: int) -> QgsPolygon: ...
    def addTriangle(self, triangle: QgsTriangle|None) -> None: ...
    def addPatch(self, patch: QgsPolygon|None) -> None: ...
    def setTriangles(self, triangles: collections.abc.Iterable[QgsTriangle]) -> None: ...
    def deleteVertex(self, position: 'QgsVertexId') -> bool: ...
    def insertVertex(self, position: 'QgsVertexId', vertex: QgsPoint) -> bool: ...
    def snappedToGrid(self, hSpacing: float, vSpacing: float, dSpacing: float = ..., mSpacing: float = ..., removeRedundantPoints: bool = ...) -> 'QgsTriangulatedSurface|None': ...
    def normalize(self) -> None: ...
    def asKml(self, precision: int = ...) -> str: ...
    def asGml3(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def asGml2(self, doc: QtXml.QDomDocument, precision: int = ..., ns: str|None = ..., axisOrder: QgsAbstractGeometry.AxisOrder = ...) -> QtXml.QDomElement: ...
    def fromWkt(self, wkt: str|None) -> bool: ...
    def fromWkb(self, wkb: 'QgsConstWkbPtr') -> bool: ...
    def clear(self) -> None: ...
    def clone(self) -> 'QgsTriangulatedSurface|None': ...
    def geometryType(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def fuzzyDistanceEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...
    def fuzzyEqual(self, other: QgsAbstractGeometry, epsilon: float = ...) -> bool: ...


class QgsVertexId(PyQt6.sip.wrapper):

    part = ... # type: int
    ring = ... # type: int
    type = ... # type: Qgis.VertexType
    vertex = ... # type: int

    @typing.overload
    def __init__(self, _part: int = ..., _ring: int = ..., _vertex: int = ..., _type: Qgis.VertexType = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVertexId') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def vertexEqual(self, o: 'QgsVertexId') -> bool: ...
    def ringEqual(self, o: 'QgsVertexId') -> bool: ...
    def partEqual(self, o: 'QgsVertexId') -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @typing.overload
    def isValid(self) -> bool: ...
    @typing.overload
    def isValid(self, geom: QgsAbstractGeometry|None) -> bool: ...


class QgsWkbPtr(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, p: PyQt6.sip.array[bytes]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsWkbPtr') -> None: ...


class QgsConstWkbPtr(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, p: PyQt6.sip.array[bytes]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsConstWkbPtr') -> None: ...


class QgsWkbTypes(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsWkbTypes') -> None: ...

    @staticmethod
    def to25D(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def dropM(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def dropZ(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def addM(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def addZ(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def hasM(type: Qgis.WkbType) -> bool: ...
    @staticmethod
    def hasZ(type: Qgis.WkbType) -> bool: ...
    @staticmethod
    def geometryDisplayString(type: Qgis.GeometryType) -> str: ...
    @staticmethod
    def translatedDisplayString(type: Qgis.WkbType) -> str: ...
    @staticmethod
    def displayString(type: Qgis.WkbType) -> str: ...
    @staticmethod
    def geometryType(type: Qgis.WkbType) -> Qgis.GeometryType: ...
    @staticmethod
    def coordDimensions(type: Qgis.WkbType) -> int: ...
    @staticmethod
    def wkbDimensions(type: Qgis.WkbType) -> int: ...
    @staticmethod
    def isNurbsType(type: Qgis.WkbType) -> bool: ...
    @staticmethod
    def isCurvedType(type: Qgis.WkbType) -> bool: ...
    @staticmethod
    def isMultiType(type: Qgis.WkbType) -> bool: ...
    @staticmethod
    def isSingleType(type: Qgis.WkbType) -> bool: ...
    @staticmethod
    def parseType(wktStr: str|None) -> Qgis.WkbType: ...
    @staticmethod
    def zmType(type: Qgis.WkbType, hasZ: bool, hasM: bool) -> Qgis.WkbType: ...
    @staticmethod
    def flatType(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def linearType(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def curveType(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def promoteNonPointTypesToMulti(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def multiType(type: Qgis.WkbType) -> Qgis.WkbType: ...
    @staticmethod
    def singleType(type: Qgis.WkbType) -> Qgis.WkbType: ...


class QgsRay3D(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, origin: QtGui.QVector3D, direction: QtGui.QVector3D) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRay3D') -> None: ...

    def point(self, distance: float) -> QtGui.QVector3D: ...
    def angleToPoint(self, point: QtGui.QVector3D) -> float: ...
    def isInFront(self, point: QtGui.QVector3D) -> bool: ...
    def projectedDistance(self, point: QtGui.QVector3D) -> float: ...
    def projectedPoint(self, point: QtGui.QVector3D) -> QtGui.QVector3D: ...
    def setDirection(self, direction: QtGui.QVector3D) -> None: ...
    def setOrigin(self, origin: QtGui.QVector3D) -> None: ...
    def directionInversed(self) -> QtGui.QVector3D: ...
    def direction(self) -> QtGui.QVector3D: ...
    def origin(self) -> QtGui.QVector3D: ...


class QgsAbstractBabelFormat(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractBabelFormat') -> None: ...

    @staticmethod
    def featureTypeToArgument(type: Qgis.GpsFeatureType) -> str: ...
    def exportCommand(self, babel: str|None, featureType: Qgis.GpsFeatureType, input: str|None, output: str|None, flags: Qgis.BabelCommandFlag = ...) -> list[str]: ...
    def importCommand(self, babel: str|None, featureType: Qgis.GpsFeatureType, input: str|None, output: str|None, flags: Qgis.BabelCommandFlag = ...) -> list[str]: ...
    def capabilities(self) -> Qgis.BabelFormatCapability: ...
    def name(self) -> str: ...


class QgsBabelSimpleImportFormat(QgsAbstractBabelFormat):

    @typing.overload
    def __init__(self, format: str|None, description: str|None, capabilities: Qgis.BabelFormatCapability, extensions: collections.abc.Iterable[str|None] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBabelSimpleImportFormat') -> None: ...

    def importCommand(self, babel: str|None, featureType: Qgis.GpsFeatureType, input: str|None, output: str|None, flags: Qgis.BabelCommandFlag = ...) -> list[str]: ...
    def extensions(self) -> list[str]: ...
    def description(self) -> str: ...


class QgsBabelFormatRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def reloadFromSettings(self) -> None: ...
    def devices(self) -> typing.Any: ...
    def deviceFormat(self, name: str|None) -> 'QgsBabelGpsDeviceFormat|None': ...
    def deviceNames(self) -> list[str]: ...
    def importFileFilter(self) -> str: ...
    def importFormatByDescription(self, description: str|None) -> QgsBabelSimpleImportFormat|None: ...
    def importFormat(self, name: str|None) -> QgsBabelSimpleImportFormat|None: ...
    def importFormatNames(self) -> list[str]: ...


class QgsBabelGpsDeviceFormat(QgsAbstractBabelFormat):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, waypointDownloadCommand: str|None, waypointUploadCommand: str|None, routeDownloadCommand: str|None, routeUploadCommand: str|None, trackDownloadCommand: str|None, trackUploadCommand: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBabelGpsDeviceFormat') -> None: ...

    def exportCommand(self, babel: str|None, type: Qgis.GpsFeatureType, in_: str|None, out: str|None, flags: Qgis.BabelCommandFlag = ...) -> list[str]: ...
    def importCommand(self, babel: str|None, type: Qgis.GpsFeatureType, in_: str|None, out: str|None, flags: Qgis.BabelCommandFlag = ...) -> list[str]: ...


class QgsNmeaConnection(QgsGpsConnection):

    def __init__(self, device: QtCore.QIODevice|None) -> None: ...

    def processHchdgSentence(self, data: str, len: int) -> None: ...
    def processHdtSentence(self, data: str, len: int) -> None: ...
    def processGstSentence(self, data: str, len: int) -> None: ...
    def processGsaSentence(self, data: str, len: int) -> None: ...
    def processVtgSentence(self, data: str, len: int) -> None: ...
    def processGsvSentence(self, data: str, len: int) -> None: ...
    def processRmcSentence(self, data: str, len: int) -> None: ...
    def processGgaSentence(self, data: str, len: int) -> None: ...
    def processStringBuffer(self) -> None: ...
    def parseData(self) -> None: ...


class QgsGpsdConnection(QgsNmeaConnection):

    def __init__(self, host: str|None, port: int, device: str|None) -> None: ...


class QgsGpsDetector(QtCore.QObject):

    def __init__(self, portName: str|None = ..., useUnsafeSignals: bool = ...) -> None: ...

    detectionFailed: typing.ClassVar[QtCore.pyqtSignal]
    connectionDetected: typing.ClassVar[QtCore.pyqtSignal]
    def connDestroyed(self, a0: QtCore.QObject|None) -> None: ...
    detected: typing.ClassVar[QtCore.pyqtSignal]
    def advance(self) -> None: ...
    @staticmethod
    def availablePorts() -> list[tuple[str, str]]: ...
    def takeConnection(self) -> QgsGpsConnection|None: ...


class QgsGpsInformation(PyQt6.sip.wrapper):

    direction = ... # type: float
    elevation = ... # type: float
    elevation_diff = ... # type: float
    fixMode = ... # type: str
    fixType = ... # type: int
    hacc = ... # type: float
    hdop = ... # type: float
    hvacc = ... # type: float
    latitude = ... # type: float
    longitude = ... # type: float
    pdop = ... # type: float
    quality = ... # type: int
    qualityIndicator = ... # type: Qgis.GpsQualityIndicator
    satInfoComplete = ... # type: bool
    satPrn = ... # type: collections.abc.Iterable[int]
    satellitesInView = ... # type: collections.abc.Iterable['QgsSatelliteInfo']
    satellitesUsed = ... # type: int
    speed = ... # type: float
    status = ... # type: str
    utcDateTime = ... # type: QtCore.QDateTime|datetime.datetime
    utcTime = ... # type: QtCore.QTime|datetime.time
    vacc = ... # type: float
    vdop = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGpsInformation') -> None: ...

    def componentValue(self, component: Qgis.GpsInformationComponent) -> typing.Any: ...
    def qualityDescription(self) -> str: ...
    @deprecated("""""")
    def fixStatus(self) -> Qgis.GpsFixStatus: ...
    def isValid(self) -> bool: ...
    def setNavigationStatus(self, status: Qgis.GpsNavigationStatus) -> None: ...
    def navigationStatus(self) -> Qgis.GpsNavigationStatus: ...
    def bestFixStatus(self) -> typing.Tuple[Qgis.GpsFixStatus, Qgis.GnssConstellation]: ...
    def constellationFixStatus(self) -> dict[Qgis.GnssConstellation, Qgis.GpsFixStatus]: ...


class QgsGpsLogger(QtCore.QObject):

    def __init__(self, connection: QgsGpsConnection|None, parent: QtCore.QObject|None = ...) -> None: ...

    def addTrackVertex(self) -> None: ...
    distanceAreaChanged: typing.ClassVar[QtCore.pyqtSignal]
    stateChanged: typing.ClassVar[QtCore.pyqtSignal]
    trackVertexAdded: typing.ClassVar[QtCore.pyqtSignal]
    trackReset: typing.ClassVar[QtCore.pyqtSignal]
    trackIsEmptyChanged: typing.ClassVar[QtCore.pyqtSignal]
    def componentValue(self, component: Qgis.GpsInformationComponent) -> typing.Any: ...
    def trackDistanceFromStart(self) -> float: ...
    def totalTrackLength(self) -> float: ...
    def updateGpsSettings(self) -> None: ...
    def setAutomaticallyAddTrackVertices(self, enabled: bool) -> None: ...
    def automaticallyAddTrackVertices(self) -> bool: ...
    def resetTrack(self) -> None: ...
    def lastMValue(self) -> float: ...
    def lastElevation(self) -> float: ...
    def trackStartTime(self) -> QtCore.QDateTime: ...
    def lastTimestamp(self) -> QtCore.QDateTime: ...
    def lastPosition(self) -> QgsPointXY: ...
    def currentGeometry(self, type: Qgis.WkbType) -> typing.Tuple[QgsGeometry, str]: ...
    def currentTrack(self) -> list[QgsPoint]: ...
    def distanceArea(self) -> QgsDistanceArea: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def setEllipsoid(self, ellipsoid: str|None) -> None: ...
    def setConnection(self, connection: QgsGpsConnection|None) -> None: ...
    def connection(self) -> QgsGpsConnection|None: ...


class QgsGpsConnectionRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def connectionList(self) -> list[QgsGpsConnection]: ...
    def unregisterConnection(self, c: QgsGpsConnection|None) -> None: ...
    def registerConnection(self, c: QgsGpsConnection|None) -> None: ...


class QgsSatelliteInfo(PyQt6.sip.wrapper):

    azimuth = ... # type: float
    elevation = ... # type: float
    id = ... # type: int
    inUse = ... # type: bool
    satType = ... # type: str
    signal = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSatelliteInfo') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def constellation(self) -> Qgis.GnssConstellation: ...


class QgsVectorLayerGpsLogger(QgsGpsLogger):

    def __init__(self, connection: QgsGpsConnection|None, parent: QtCore.QObject|None = ...) -> None: ...

    def endCurrentTrack(self) -> None: ...
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def destinationField(self, component: Qgis.GpsInformationComponent) -> str: ...
    def setDestinationField(self, component: Qgis.GpsInformationComponent, field: str|None) -> None: ...
    def tracksLayer(self) -> QgsVectorLayer|None: ...
    def pointsLayer(self) -> QgsVectorLayer|None: ...
    def setTracksLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setPointsLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setWriteToEditBuffer(self, buffer: bool) -> None: ...
    def writeToEditBuffer(self) -> bool: ...


class QgsCalloutPosition(PyQt6.sip.wrapper):

    featureId = ... # type: int
    layerID = ... # type: str|None
    providerID = ... # type: str|None

    @typing.overload
    def __init__(self, id: int, layer: str|None, providerId: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCalloutPosition') -> None: ...

    def setDestinationIsPinned(self, pinned: bool) -> None: ...
    def destinationIsPinned(self) -> bool: ...
    def setOriginIsPinned(self, pinned: bool) -> None: ...
    def originIsPinned(self) -> bool: ...
    def setDestination(self, destination: QtCore.QPointF) -> None: ...
    def destination(self) -> QtCore.QPointF: ...
    def setOrigin(self, origin: QtCore.QPointF) -> None: ...
    def origin(self) -> QtCore.QPointF: ...


class QgsLabeling(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabeling') -> None: ...


class QgsLabelCandidate(PyQt6.sip.wrapper):

    cost = ... # type: float
    rect = ... # type: QtCore.QRectF

    @typing.overload
    def __init__(self, r: QtCore.QRectF, c: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelCandidate') -> None: ...


class QgsLabelingEngineSettings(PyQt6.sip.wrapper):

    class Search(enum.IntEnum):
        Chain = ... # type: QgsLabelingEngineSettings.Search
        Popmusic_Tabu = ... # type: QgsLabelingEngineSettings.Search
        Popmusic_Chain = ... # type: QgsLabelingEngineSettings.Search
        Popmusic_Tabu_Chain = ... # type: QgsLabelingEngineSettings.Search
        Falp = ... # type: QgsLabelingEngineSettings.Search

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsLabelingEngineSettings') -> None: ...

    def setRules(self, rules: collections.abc.Iterable['QgsAbstractLabelingEngineRule']) -> None: ...
    def addRule(self, rule: 'QgsAbstractLabelingEngineRule|None') -> None: ...
    def rules(self) -> list['QgsAbstractLabelingEngineRule']: ...
    def setPlacementVersion(self, version: Qgis.LabelPlacementEngineVersion) -> None: ...
    def placementVersion(self) -> Qgis.LabelPlacementEngineVersion: ...
    def setUnplacedLabelColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def unplacedLabelColor(self) -> QtGui.QColor: ...
    def setDefaultTextRenderFormat(self, format: Qgis.TextRenderFormat) -> None: ...
    def defaultTextRenderFormat(self) -> Qgis.TextRenderFormat: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeSettingsToProject(self, project: 'QgsProject|None') -> None: ...
    def readSettingsFromProject(self, project: 'QgsProject|None') -> None: ...
    @deprecated("""""")
    def searchMethod(self) -> 'QgsLabelingEngineSettings.Search': ...
    @deprecated("""""")
    def setSearchMethod(self, s: 'QgsLabelingEngineSettings.Search') -> None: ...
    @deprecated("""""")
    def setNumCandidatePositions(self, candPoint: int, candLine: int, candPolygon: int) -> None: ...
    @deprecated("""""")
    def numCandidatePositions(self) -> typing.Tuple[int, int, int]: ...
    def setMaximumPolygonCandidatesPerCmSquared(self, candidates: float) -> None: ...
    def maximumPolygonCandidatesPerCmSquared(self) -> float: ...
    def setMaximumLineCandidatesPerCm(self, candidates: float) -> None: ...
    def maximumLineCandidatesPerCm(self) -> float: ...
    def setFlag(self, f: Qgis.LabelingFlag, enabled: bool = ...) -> None: ...
    def testFlag(self, f: Qgis.LabelingFlag) -> bool: ...
    def flags(self) -> Qgis.LabelingFlag: ...
    def setFlags(self, flags: Qgis.LabelingFlag) -> None: ...
    def clear(self) -> None: ...


class QgsLabelingResults(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def setMapSettings(self, settings: QgsMapSettings) -> None: ...
    def calloutsWithinRectangle(self, rectangle: QgsRectangle) -> list[QgsCalloutPosition]: ...
    def groupedLabelPositions(self, groupId: int) -> list['QgsLabelPosition']: ...
    def labelsWithinRect(self, r: QgsRectangle) -> list['QgsLabelPosition']: ...
    def labelsAtPosition(self, p: QgsPointXY) -> list['QgsLabelPosition']: ...
    def allLabels(self) -> list['QgsLabelPosition']: ...


class QgsLabelLineSettings(PyQt6.sip.wrapper):

    class AnchorTextPoint(enum.IntEnum):
        StartOfText = ... # type: QgsLabelLineSettings.AnchorTextPoint
        CenterOfText = ... # type: QgsLabelLineSettings.AnchorTextPoint
        EndOfText = ... # type: QgsLabelLineSettings.AnchorTextPoint
        FollowPlacement = ... # type: QgsLabelLineSettings.AnchorTextPoint

    class AnchorClipping(enum.IntEnum):
        UseVisiblePartsOfLine = ... # type: QgsLabelLineSettings.AnchorClipping
        UseEntireLine = ... # type: QgsLabelLineSettings.AnchorClipping

    class AnchorType(enum.IntEnum):
        HintOnly = ... # type: QgsLabelLineSettings.AnchorType
        Strict = ... # type: QgsLabelLineSettings.AnchorType

    class DirectionSymbolPlacement(enum.IntEnum):
        SymbolLeftRight = ... # type: QgsLabelLineSettings.DirectionSymbolPlacement
        SymbolAbove = ... # type: QgsLabelLineSettings.DirectionSymbolPlacement
        SymbolBelow = ... # type: QgsLabelLineSettings.DirectionSymbolPlacement

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelLineSettings') -> None: ...

    def setCurvedLabelMode(self, mode: Qgis.CurvedLabelMode) -> None: ...
    def curvedLabelMode(self) -> Qgis.CurvedLabelMode: ...
    def setAnchorTextPoint(self, point: 'QgsLabelLineSettings.AnchorTextPoint') -> None: ...
    def anchorTextPoint(self) -> 'QgsLabelLineSettings.AnchorTextPoint': ...
    def setAnchorClipping(self, clipping: 'QgsLabelLineSettings.AnchorClipping') -> None: ...
    def anchorClipping(self) -> 'QgsLabelLineSettings.AnchorClipping': ...
    def setAnchorType(self, type: 'QgsLabelLineSettings.AnchorType') -> None: ...
    def anchorType(self) -> 'QgsLabelLineSettings.AnchorType': ...
    def setLineAnchorPercent(self, percent: float) -> None: ...
    def lineAnchorPercent(self) -> float: ...
    def setOverrunDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def overrunDistanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOverrunDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def overrunDistanceUnit(self) -> Qgis.RenderUnit: ...
    def setOverrunDistance(self, distance: float) -> None: ...
    def overrunDistance(self) -> float: ...
    def setDirectionSymbolPlacement(self, placement: 'QgsLabelLineSettings.DirectionSymbolPlacement') -> None: ...
    def directionSymbolPlacement(self) -> 'QgsLabelLineSettings.DirectionSymbolPlacement': ...
    def setReverseDirectionSymbol(self, reversed: bool) -> None: ...
    def reverseDirectionSymbol(self) -> bool: ...
    def setRightDirectionSymbol(self, symbol: str|None) -> None: ...
    def rightDirectionSymbol(self) -> str: ...
    def setLeftDirectionSymbol(self, symbol: str|None) -> None: ...
    def leftDirectionSymbol(self) -> str: ...
    def setAddDirectionSymbol(self, enabled: bool) -> None: ...
    def addDirectionSymbol(self) -> bool: ...
    def updateDataDefinedProperties(self, properties: QgsPropertyCollection, context: QgsExpressionContext) -> None: ...
    def setMergeLines(self, merge: bool) -> None: ...
    def mergeLines(self) -> bool: ...
    def setPlacementFlags(self, flags: Qgis.LabelLinePlacementFlag) -> None: ...
    def placementFlags(self) -> Qgis.LabelLinePlacementFlag: ...


class QgsLabelObstacleSettings(PyQt6.sip.wrapper):

    class ObstacleType(enum.IntEnum):
        PolygonInterior = ... # type: QgsLabelObstacleSettings.ObstacleType
        PolygonBoundary = ... # type: QgsLabelObstacleSettings.ObstacleType
        PolygonWhole = ... # type: QgsLabelObstacleSettings.ObstacleType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelObstacleSettings') -> None: ...

    def updateDataDefinedProperties(self, properties: QgsPropertyCollection, context: QgsExpressionContext) -> None: ...
    def obstacleGeometry(self) -> QgsGeometry: ...
    def setObstacleGeometry(self, obstacleGeom: QgsGeometry) -> None: ...
    def setType(self, type: 'QgsLabelObstacleSettings.ObstacleType') -> None: ...
    def type(self) -> 'QgsLabelObstacleSettings.ObstacleType': ...
    def setFactor(self, factor: float) -> None: ...
    def factor(self) -> float: ...
    def setIsObstacle(self, isObstacle: bool) -> None: ...
    def isObstacle(self) -> bool: ...


class QgsLabelPlacementSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelPlacementSettings') -> None: ...

    def updateDataDefinedProperties(self, properties: QgsPropertyCollection, context: QgsExpressionContext) -> None: ...
    def setWhitespaceCollisionHandling(self, handling: Qgis.LabelWhitespaceCollisionHandling) -> None: ...
    def whitespaceCollisionHandling(self) -> Qgis.LabelWhitespaceCollisionHandling: ...
    def setMultiPartBehavior(self, behavior: Qgis.MultiPartLabelingBehavior) -> None: ...
    def multiPartBehavior(self) -> Qgis.MultiPartLabelingBehavior: ...
    def setPrioritization(self, prioritization: Qgis.LabelPrioritization) -> None: ...
    def prioritization(self) -> Qgis.LabelPrioritization: ...
    def setAllowDegradedPlacement(self, allow: bool) -> None: ...
    def allowDegradedPlacement(self) -> bool: ...
    def setOverlapHandling(self, handling: Qgis.LabelOverlapHandling) -> None: ...
    def overlapHandling(self) -> Qgis.LabelOverlapHandling: ...


class QgsLabelPointSettings(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelPointSettings') -> None: ...

    def setMaximumDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def maximumDistanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setMaximumDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def maximumDistanceUnit(self) -> Qgis.RenderUnit: ...
    def setMaximumDistance(self, distance: float) -> None: ...
    def maximumDistance(self) -> float: ...
    def setPredefinedPositionOrder(self, order: collections.abc.Iterable[Qgis.LabelPredefinedPointPosition]) -> None: ...
    def predefinedPositionOrder(self) -> list[Qgis.LabelPredefinedPointPosition]: ...
    def setQuadrant(self, quadrant: Qgis.LabelQuadrantPosition) -> None: ...
    def quadrant(self) -> Qgis.LabelQuadrantPosition: ...
    def updateDataDefinedProperties(self, properties: QgsPropertyCollection, context: QgsExpressionContext) -> None: ...


class QgsLabelPosition(PyQt6.sip.wrapper):

    cornerPoints = ... # type: collections.abc.Iterable[QgsPointXY]
    featureId = ... # type: int
    groupedLabelId = ... # type: int
    height = ... # type: float
    isDiagram = ... # type: bool
    isPinned = ... # type: bool
    isUnplaced = ... # type: bool
    labelFont = ... # type: QtGui.QFont
    labelGeometry = ... # type: QgsGeometry
    labelRect = ... # type: QgsRectangle
    labelText = ... # type: str|None
    layerID = ... # type: str|None
    providerID = ... # type: str|None
    rotation = ... # type: float
    upsideDown = ... # type: bool
    width = ... # type: float

    @typing.overload
    def __init__(self, id: int, r: float, corners: collections.abc.Iterable[QgsPointXY], rect: QgsRectangle, w: float, h: float, layer: str|None, labeltext: str|None, labelfont: QtGui.QFont, upside_down: bool, diagram: bool = ..., pinned: bool = ..., providerId: str|None = ..., labelGeometry: QgsGeometry = ..., isUnplaced: bool = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelPosition') -> None: ...

    def __repr__(self) -> typing.Any: ...


class QgsLabelSearchTree(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def setMapSettings(self, settings: QgsMapSettings) -> None: ...
    def calloutsInRectangle(self, rectangle: QgsRectangle) -> list[QgsCalloutPosition]: ...
    def allLabels(self) -> list[QgsLabelPosition]: ...
    @deprecated("""""")
    def clear(self) -> None: ...


class QgsLabelThinningSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLabelThinningSettings') -> None: ...

    def updateDataDefinedProperties(self, properties: QgsPropertyCollection, context: QgsExpressionContext) -> None: ...
    def setAllowDuplicateRemoval(self, allow: bool) -> None: ...
    def allowDuplicateRemoval(self) -> bool: ...
    def minimumDistanceToDuplicateMapUnitScale(self) -> QgsMapUnitScale: ...
    def setMinimumDistanceToDuplicateMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def minimumDistanceToDuplicateUnit(self) -> Qgis.RenderUnit: ...
    def setMinimumDistanceToDuplicateUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setMinimumDistanceToDuplicate(self, distance: float) -> None: ...
    def minimumDistanceToDuplicate(self) -> float: ...
    def labelMarginDistanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setLabelMarginDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def labelMarginDistanceUnit(self) -> Qgis.RenderUnit: ...
    def setLabelMarginDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setLabelMarginDistance(self, distance: float) -> None: ...
    def labelMarginDistance(self) -> float: ...
    def setMinimumFeatureSize(self, size: float) -> None: ...
    def minimumFeatureSize(self) -> float: ...
    def setMaximumNumberLabels(self, number: int) -> None: ...
    def maximumNumberLabels(self) -> int: ...
    def setLimitNumberLabelsEnabled(self, enabled: bool) -> None: ...
    def limitNumberOfLabelsEnabled(self) -> bool: ...


class QgsPalLayerSettings(PyQt6.sip.wrapper):

    class Property(enum.IntEnum):
        Size = ... # type: QgsPalLayerSettings.Property
        Bold = ... # type: QgsPalLayerSettings.Property
        Italic = ... # type: QgsPalLayerSettings.Property
        Underline = ... # type: QgsPalLayerSettings.Property
        Color = ... # type: QgsPalLayerSettings.Property
        Strikeout = ... # type: QgsPalLayerSettings.Property
        Family = ... # type: QgsPalLayerSettings.Property
        FontStyle = ... # type: QgsPalLayerSettings.Property
        FontSizeUnit = ... # type: QgsPalLayerSettings.Property
        FontTransp = ... # type: QgsPalLayerSettings.Property
        FontOpacity = ... # type: QgsPalLayerSettings.Property
        FontCase = ... # type: QgsPalLayerSettings.Property
        FontLetterSpacing = ... # type: QgsPalLayerSettings.Property
        FontWordSpacing = ... # type: QgsPalLayerSettings.Property
        FontBlendMode = ... # type: QgsPalLayerSettings.Property
        FontStretchFactor = ... # type: QgsPalLayerSettings.Property
        MultiLineWrapChar = ... # type: QgsPalLayerSettings.Property
        AutoWrapLength = ... # type: QgsPalLayerSettings.Property
        MultiLineHeight = ... # type: QgsPalLayerSettings.Property
        MultiLineAlignment = ... # type: QgsPalLayerSettings.Property
        TextOrientation = ... # type: QgsPalLayerSettings.Property
        TabStopDistance = ... # type: QgsPalLayerSettings.Property
        DirSymbDraw = ... # type: QgsPalLayerSettings.Property
        DirSymbLeft = ... # type: QgsPalLayerSettings.Property
        DirSymbRight = ... # type: QgsPalLayerSettings.Property
        DirSymbPlacement = ... # type: QgsPalLayerSettings.Property
        DirSymbReverse = ... # type: QgsPalLayerSettings.Property
        NumFormat = ... # type: QgsPalLayerSettings.Property
        NumDecimals = ... # type: QgsPalLayerSettings.Property
        NumPlusSign = ... # type: QgsPalLayerSettings.Property
        BufferDraw = ... # type: QgsPalLayerSettings.Property
        BufferSize = ... # type: QgsPalLayerSettings.Property
        BufferUnit = ... # type: QgsPalLayerSettings.Property
        BufferColor = ... # type: QgsPalLayerSettings.Property
        BufferTransp = ... # type: QgsPalLayerSettings.Property
        BufferOpacity = ... # type: QgsPalLayerSettings.Property
        BufferJoinStyle = ... # type: QgsPalLayerSettings.Property
        BufferBlendMode = ... # type: QgsPalLayerSettings.Property
        MaskEnabled = ... # type: QgsPalLayerSettings.Property
        MaskBufferSize = ... # type: QgsPalLayerSettings.Property
        MaskBufferUnit = ... # type: QgsPalLayerSettings.Property
        MaskOpacity = ... # type: QgsPalLayerSettings.Property
        MaskJoinStyle = ... # type: QgsPalLayerSettings.Property
        ShapeDraw = ... # type: QgsPalLayerSettings.Property
        ShapeKind = ... # type: QgsPalLayerSettings.Property
        ShapeSVGFile = ... # type: QgsPalLayerSettings.Property
        ShapeSizeType = ... # type: QgsPalLayerSettings.Property
        ShapeSizeX = ... # type: QgsPalLayerSettings.Property
        ShapeSizeY = ... # type: QgsPalLayerSettings.Property
        ShapeSizeUnits = ... # type: QgsPalLayerSettings.Property
        ShapeRotationType = ... # type: QgsPalLayerSettings.Property
        ShapeRotation = ... # type: QgsPalLayerSettings.Property
        ShapeOffset = ... # type: QgsPalLayerSettings.Property
        ShapeOffsetUnits = ... # type: QgsPalLayerSettings.Property
        ShapeRadii = ... # type: QgsPalLayerSettings.Property
        ShapeRadiiUnits = ... # type: QgsPalLayerSettings.Property
        ShapeTransparency = ... # type: QgsPalLayerSettings.Property
        ShapeOpacity = ... # type: QgsPalLayerSettings.Property
        ShapeBlendMode = ... # type: QgsPalLayerSettings.Property
        ShapeFillColor = ... # type: QgsPalLayerSettings.Property
        ShapeStrokeColor = ... # type: QgsPalLayerSettings.Property
        ShapeStrokeWidth = ... # type: QgsPalLayerSettings.Property
        ShapeStrokeWidthUnits = ... # type: QgsPalLayerSettings.Property
        ShapeJoinStyle = ... # type: QgsPalLayerSettings.Property
        ShadowDraw = ... # type: QgsPalLayerSettings.Property
        ShadowUnder = ... # type: QgsPalLayerSettings.Property
        ShadowOffsetAngle = ... # type: QgsPalLayerSettings.Property
        ShadowOffsetDist = ... # type: QgsPalLayerSettings.Property
        ShadowOffsetUnits = ... # type: QgsPalLayerSettings.Property
        ShadowRadius = ... # type: QgsPalLayerSettings.Property
        ShadowRadiusUnits = ... # type: QgsPalLayerSettings.Property
        ShadowTransparency = ... # type: QgsPalLayerSettings.Property
        ShadowOpacity = ... # type: QgsPalLayerSettings.Property
        ShadowScale = ... # type: QgsPalLayerSettings.Property
        ShadowColor = ... # type: QgsPalLayerSettings.Property
        ShadowBlendMode = ... # type: QgsPalLayerSettings.Property
        CentroidWhole = ... # type: QgsPalLayerSettings.Property
        OffsetQuad = ... # type: QgsPalLayerSettings.Property
        OffsetXY = ... # type: QgsPalLayerSettings.Property
        OffsetUnits = ... # type: QgsPalLayerSettings.Property
        LabelDistance = ... # type: QgsPalLayerSettings.Property
        MaximumDistance = ... # type: QgsPalLayerSettings.Property
        DistanceUnits = ... # type: QgsPalLayerSettings.Property
        OffsetRotation = ... # type: QgsPalLayerSettings.Property
        CurvedCharAngleInOut = ... # type: QgsPalLayerSettings.Property
        PositionX = ... # type: QgsPalLayerSettings.Property
        PositionY = ... # type: QgsPalLayerSettings.Property
        PositionPoint = ... # type: QgsPalLayerSettings.Property
        Hali = ... # type: QgsPalLayerSettings.Property
        Vali = ... # type: QgsPalLayerSettings.Property
        Rotation = ... # type: QgsPalLayerSettings.Property
        LabelRotation = ... # type: QgsPalLayerSettings.Property
        RepeatDistance = ... # type: QgsPalLayerSettings.Property
        RepeatDistanceUnit = ... # type: QgsPalLayerSettings.Property
        Priority = ... # type: QgsPalLayerSettings.Property
        PredefinedPositionOrder = ... # type: QgsPalLayerSettings.Property
        LinePlacementOptions = ... # type: QgsPalLayerSettings.Property
        OverrunDistance = ... # type: QgsPalLayerSettings.Property
        LabelAllParts = ... # type: QgsPalLayerSettings.Property
        PolygonLabelOutside = ... # type: QgsPalLayerSettings.Property
        LineAnchorPercent = ... # type: QgsPalLayerSettings.Property
        LineAnchorClipping = ... # type: QgsPalLayerSettings.Property
        LineAnchorType = ... # type: QgsPalLayerSettings.Property
        LineAnchorTextPoint = ... # type: QgsPalLayerSettings.Property
        CurvedLabelMode = ... # type: QgsPalLayerSettings.Property
        ScaleVisibility = ... # type: QgsPalLayerSettings.Property
        MinScale = ... # type: QgsPalLayerSettings.Property
        MinimumScale = ... # type: QgsPalLayerSettings.Property
        MaxScale = ... # type: QgsPalLayerSettings.Property
        MaximumScale = ... # type: QgsPalLayerSettings.Property
        FontLimitPixel = ... # type: QgsPalLayerSettings.Property
        FontMinPixel = ... # type: QgsPalLayerSettings.Property
        FontMaxPixel = ... # type: QgsPalLayerSettings.Property
        IsObstacle = ... # type: QgsPalLayerSettings.Property
        ObstacleFactor = ... # type: QgsPalLayerSettings.Property
        ZIndex = ... # type: QgsPalLayerSettings.Property
        CalloutDraw = ... # type: QgsPalLayerSettings.Property
        AllowDegradedPlacement = ... # type: QgsPalLayerSettings.Property
        OverlapHandling = ... # type: QgsPalLayerSettings.Property
        WhitespaceCollisionHandling = ... # type: QgsPalLayerSettings.Property
        LabelMarginDistance = ... # type: QgsPalLayerSettings.Property
        RemoveDuplicateLabels = ... # type: QgsPalLayerSettings.Property
        RemoveDuplicateLabelDistance = ... # type: QgsPalLayerSettings.Property
        Show = ... # type: QgsPalLayerSettings.Property
        AlwaysShow = ... # type: QgsPalLayerSettings.Property

    angleOffset = ... # type: float
    autoWrapLength = ... # type: int
    centroidInside = ... # type: bool
    centroidWhole = ... # type: bool
    ct = ... # type: 'QgsCoordinateTransform'
    decimals = ... # type: int
    dist = ... # type: float
    distMapUnitScale = ... # type: QgsMapUnitScale
    distUnits = ... # type: Qgis.RenderUnit
    drawLabels = ... # type: bool
    extentGeom = ... # type: QgsGeometry
    fieldIndex = ... # type: int
    fieldName = ... # type: str|None
    fitInPolygonOnly = ... # type: bool
    fontLimitPixelSize = ... # type: bool
    fontMaxPixelSize = ... # type: int
    fontMinPixelSize = ... # type: int
    formatNumbers = ... # type: bool
    geometryGenerator = ... # type: str|None
    geometryGeneratorEnabled = ... # type: bool
    geometryGeneratorType = ... # type: Qgis.GeometryType
    isExpression = ... # type: bool
    labelOffsetMapUnitScale = ... # type: QgsMapUnitScale
    layerType = ... # type: Qgis.GeometryType
    mCurFeat = ... # type: QgsFeature
    mCurFields = ... # type: QgsFields
    mFeatsRegPal = ... # type: int
    mFeatsSendingToPal = ... # type: int
    mFeaturesToLabel = ... # type: int
    maxCurvedCharAngleIn = ... # type: float
    maxCurvedCharAngleOut = ... # type: float
    maximumScale = ... # type: float
    minimumScale = ... # type: float
    multilineAlign = ... # type: Qgis.LabelMultiLineAlignment
    offsetType = ... # type: Qgis.LabelOffsetType
    offsetUnits = ... # type: Qgis.RenderUnit
    placement = ... # type: Qgis.LabelPlacement
    plusSign = ... # type: bool
    preserveRotation = ... # type: bool
    previewBkgrdColor = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    priority = ... # type: int
    ptOne = ... # type: QgsPointXY
    ptZero = ... # type: QgsPointXY
    repeatDistance = ... # type: float
    repeatDistanceMapUnitScale = ... # type: QgsMapUnitScale
    repeatDistanceUnit = ... # type: Qgis.RenderUnit
    scaleVisibility = ... # type: bool
    substitutions = ... # type: QgsStringReplacementCollection
    upsidedownLabels = ... # type: Qgis.UpsideDownLabelHandling
    useMaxLineLengthForAutoWrap = ... # type: bool
    useSubstitutions = ... # type: bool
    wrapChar = ... # type: str|None
    xOffset = ... # type: float
    xform = ... # type: QgsMapToPixel
    yOffset = ... # type: float
    zIndex = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, s: 'QgsPalLayerSettings') -> None: ...

    @staticmethod
    def fromMimeData(data: QtCore.QMimeData|None) -> typing.Tuple['QgsPalLayerSettings', bool]: ...
    def toMimeData(self) -> QtCore.QMimeData|None: ...
    def setUnplacedVisibility(self, visibility: Qgis.UnplacedLabelVisibility) -> None: ...
    def unplacedVisibility(self) -> Qgis.UnplacedLabelVisibility: ...
    @staticmethod
    def labelSettingsPreviewPixmap(settings: 'QgsPalLayerSettings', size: QtCore.QSize, previewText: str|None = ..., padding: int = ..., screen: QgsScreenProperties = ...) -> QtGui.QPixmap: ...
    def setPlacementSettings(self, settings: QgsLabelPlacementSettings) -> None: ...
    def placementSettings(self) -> QgsLabelPlacementSettings: ...
    def setThinningSettings(self, settings: QgsLabelThinningSettings) -> None: ...
    def thinningSettings(self) -> QgsLabelThinningSettings: ...
    def setObstacleSettings(self, settings: QgsLabelObstacleSettings) -> None: ...
    def obstacleSettings(self) -> QgsLabelObstacleSettings: ...
    def setPointSettings(self, settings: QgsLabelPointSettings) -> None: ...
    def pointSettings(self) -> QgsLabelPointSettings: ...
    def setLineSettings(self, settings: QgsLabelLineSettings) -> None: ...
    def lineSettings(self) -> QgsLabelLineSettings: ...
    def setCallout(self, callout: QgsCallout|None) -> None: ...
    def callout(self) -> QgsCallout|None: ...
    def setFormat(self, format: 'QgsTextFormat') -> None: ...
    def format(self) -> 'QgsTextFormat': ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def registerFeature(self, f: QgsFeature, context: QgsRenderContext) -> None: ...
    @deprecated("""""")
    def calculateLabelSize(self, fm: QtGui.QFontMetricsF|None, text: str|None, f: QgsFeature|None = ..., context: QgsRenderContext|None = ...) -> typing.Tuple[float, float, float, float]: ...
    def legendString(self) -> str: ...
    def setLegendString(self, legendString: str|None) -> None: ...
    def setRotationUnit(self, angleUnit: Qgis.AngleUnit) -> None: ...
    def rotationUnit(self) -> Qgis.AngleUnit: ...
    def setPolygonPlacementFlags(self, flags: Qgis.LabelPolygonPlacementFlag) -> None: ...
    def polygonPlacementFlags(self) -> Qgis.LabelPolygonPlacementFlag: ...
    def getLabelExpression(self) -> QgsExpression|None: ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    def containsAdvancedEffects(self) -> bool: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext) -> None: ...
    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def prepare(self, context: QgsRenderContext, attributeNames: collections.abc.Iterable[str|None], fields: QgsFields, mapSettings: QgsMapSettings, crs: 'QgsCoordinateReferenceSystem') -> typing.Tuple[bool, set[str]]: ...


class QgsPalLabeling(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPalLabeling') -> None: ...

    @staticmethod
    def splitToGraphemes(text: str|None) -> list[str]: ...
    @staticmethod
    def splitToLines(text: str|None, wrapCharacter: str|None, autoWrapLength: int = ..., useMaxLineLengthWhenAutoWrapping: bool = ...) -> list[str]: ...
    @staticmethod
    def geometryRequiresPreparation(geometry: QgsGeometry, context: QgsRenderContext, ct: 'QgsCoordinateTransform', clipGeometry: QgsGeometry = ..., mergeLines: bool = ...) -> bool: ...
    @staticmethod
    def prepareGeometry(geometry: QgsGeometry, context: QgsRenderContext, ct: 'QgsCoordinateTransform', clipGeometry: QgsGeometry = ..., mergeLines: bool = ...) -> QgsGeometry: ...
    @staticmethod
    def staticWillUseLayer(layer: QgsMapLayer|None) -> bool: ...


class QgsAbstractVectorLayerLabeling(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @typing.overload
    @deprecated("""""")
    def writeTextSymbolizer(self, parent: QtXml.QDomNode, settings: QgsPalLayerSettings, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeTextSymbolizer(self, parent: QtXml.QDomNode, settings: QgsPalLayerSettings, context: QgsSldExportContext) -> bool: ...
    @staticmethod
    def defaultSettingsForLayer(layer: QgsVectorLayer|None) -> QgsPalLayerSettings: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, parent: QtXml.QDomNode, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, parent: QtXml.QDomNode, context: QgsSldExportContext) -> bool: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsAbstractVectorLayerLabeling|None': ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def setSettings(self, settings: QgsPalLayerSettings|None, providerId: str|None = ...) -> None: ...
    def settings(self, providerId: str|None = ...) -> QgsPalLayerSettings: ...
    def subProviders(self) -> list[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> 'QgsAbstractVectorLayerLabeling|None': ...
    def type(self) -> str: ...


class QgsRuleBasedLabeling(QgsAbstractVectorLayerLabeling):

    class Rule(PyQt6.sip.wrapper):

        class RegisterResult(enum.IntEnum):
            Filtered = ... # type: QgsRuleBasedLabeling.Rule.RegisterResult
            Inactive = ... # type: QgsRuleBasedLabeling.Rule.RegisterResult
            Registered = ... # type: QgsRuleBasedLabeling.Rule.RegisterResult

        def __init__(self, settings: QgsPalLayerSettings|None, maximumScale: float = ..., minimumScale: float = ..., filterExp: str|None = ..., description: str|None = ..., elseRule: bool = ...) -> None: ...

        def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
        def hasNonDefaultCompositionMode(self) -> bool: ...
        def requiresAdvancedEffects(self) -> bool: ...
        def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
        @staticmethod
        def create(ruleElem: QtXml.QDomElement, context: QgsReadWriteContext, reuseId: bool = ...) -> 'QgsRuleBasedLabeling.Rule|None': ...
        def clone(self, resetRuleKey: bool = ...) -> 'QgsRuleBasedLabeling.Rule|None': ...
        def findRuleByKey(self, key: str|None) -> 'QgsRuleBasedLabeling.Rule|None': ...
        def removeChildAt(self, i: int) -> None: ...
        def insertChild(self, i: int, rule: 'QgsRuleBasedLabeling.Rule|None') -> None: ...
        def appendChild(self, rule: 'QgsRuleBasedLabeling.Rule|None') -> None: ...
        def parent(self) -> 'QgsRuleBasedLabeling.Rule|None': ...
        def descendants(self) -> list['QgsRuleBasedLabeling.Rule']: ...
        def children(self) -> list['QgsRuleBasedLabeling.Rule']: ...
        def setRuleKey(self, key: str|None) -> None: ...
        def setIsElse(self, iselse: bool) -> None: ...
        def setActive(self, state: bool) -> None: ...
        def setDescription(self, description: str|None) -> None: ...
        def setFilterExpression(self, filterExp: str|None) -> None: ...
        def setMaximumScale(self, scale: float) -> None: ...
        def setMinimumScale(self, scale: float) -> None: ...
        def setSettings(self, settings: QgsPalLayerSettings|None) -> None: ...
        def ruleKey(self) -> str: ...
        def isElse(self) -> bool: ...
        def active(self) -> bool: ...
        def description(self) -> str: ...
        def filterExpression(self) -> str: ...
        def minimumScale(self) -> float: ...
        def maximumScale(self) -> float: ...
        def dependsOnScale(self) -> bool: ...
        def settings(self) -> QgsPalLayerSettings|None: ...

    def __init__(self, root: 'QgsRuleBasedLabeling.Rule|None') -> None: ...

    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, parent: QtXml.QDomNode, properties: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, parent: QtXml.QDomNode, context: QgsSldExportContext) -> bool: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def setSettings(self, settings: QgsPalLayerSettings|None, providerId: str|None = ...) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def settings(self, providerId: str|None = ...) -> QgsPalLayerSettings: ...
    def subProviders(self) -> list[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> 'QgsRuleBasedLabeling|None': ...
    def type(self) -> str: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsRuleBasedLabeling|None': ...
    def rootRule(self) -> 'QgsRuleBasedLabeling.Rule|None': ...


class QgsVectorLayerSimpleLabeling(QgsAbstractVectorLayerLabeling):

    def __init__(self, settings: QgsPalLayerSettings) -> None: ...

    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsVectorLayerSimpleLabeling|None': ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, parent: QtXml.QDomNode, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, parent: QtXml.QDomNode, context: QgsSldExportContext) -> bool: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def setSettings(self, settings: QgsPalLayerSettings|None, providerId: str|None = ...) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def settings(self, providerId: str|None = ...) -> QgsPalLayerSettings: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> QgsAbstractVectorLayerLabeling|None: ...
    def type(self) -> str: ...


class QgsLabelingEngineContext(PyQt6.sip.wrapper):

    def __init__(self, renderContext: QgsRenderContext) -> None: ...

    def setMapBoundaryGeometry(self, geometry: QgsGeometry) -> None: ...
    def mapBoundaryGeometry(self) -> QgsGeometry: ...
    def setExtent(self, extent: QgsRectangle) -> None: ...
    def extent(self) -> QgsRectangle: ...
    def renderContext(self) -> QgsRenderContext: ...


class QgsAbstractLabelingEngineRule(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractLabelingEngineRule') -> None: ...

    def copyCommonProperties(self, other: 'QgsAbstractLabelingEngineRule|None') -> None: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def prepare(self, context: QgsRenderContext) -> bool: ...
    def setActive(self, active: bool) -> None: ...
    def active(self) -> bool: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def description(self) -> str: ...
    def isAvailable(self) -> bool: ...
    def displayType(self) -> str: ...
    def id(self) -> str: ...
    def clone(self) -> 'QgsAbstractLabelingEngineRule|None': ...


class QgsAbstractLabelingEngineRuleDistanceFromFeature(QgsAbstractLabelingEngineRule):

    def __init__(self) -> None: ...

    def copyCommonProperties(self, other: QgsAbstractLabelingEngineRule|None) -> None: ...
    def setCost(self, cost: float) -> None: ...
    def cost(self) -> float: ...
    def setDistanceUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def distanceUnit(self) -> Qgis.RenderUnit: ...
    def setDistance(self, distance: float) -> None: ...
    def distance(self) -> float: ...
    def setTargetLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def targetLayer(self) -> QgsVectorLayer|None: ...
    def setLabeledLayer(self, layer: QgsMapLayer|None) -> None: ...
    def labeledLayer(self) -> QgsMapLayer|None: ...
    def isAvailable(self) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def prepare(self, context: QgsRenderContext) -> bool: ...


class QgsLabelingEngineRuleMinimumDistanceLabelToFeature(QgsAbstractLabelingEngineRuleDistanceFromFeature):

    def __init__(self) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def description(self) -> str: ...
    def displayType(self) -> str: ...
    def id(self) -> str: ...
    def clone(self) -> 'QgsLabelingEngineRuleMinimumDistanceLabelToFeature|None': ...


class QgsLabelingEngineRuleMaximumDistanceLabelToFeature(QgsAbstractLabelingEngineRuleDistanceFromFeature):

    def __init__(self) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def description(self) -> str: ...
    def displayType(self) -> str: ...
    def id(self) -> str: ...
    def clone(self) -> 'QgsLabelingEngineRuleMaximumDistanceLabelToFeature|None': ...


class QgsLabelingEngineRuleMinimumDistanceLabelToLabel(QgsAbstractLabelingEngineRule):

    def __init__(self) -> None: ...

    def setDistanceUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def distanceUnit(self) -> Qgis.RenderUnit: ...
    def setDistance(self, distance: float) -> None: ...
    def distance(self) -> float: ...
    def setTargetLayer(self, layer: QgsMapLayer|None) -> None: ...
    def targetLayer(self) -> QgsMapLayer|None: ...
    def setLabeledLayer(self, layer: QgsMapLayer|None) -> None: ...
    def labeledLayer(self) -> QgsMapLayer|None: ...
    def __repr__(self) -> typing.Any: ...
    def prepare(self, context: QgsRenderContext) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def isAvailable(self) -> bool: ...
    def description(self) -> str: ...
    def displayType(self) -> str: ...
    def id(self) -> str: ...
    def clone(self) -> 'QgsLabelingEngineRuleMinimumDistanceLabelToLabel|None': ...


class QgsLabelingEngineRuleAvoidLabelOverlapWithFeature(QgsAbstractLabelingEngineRule):

    def __init__(self) -> None: ...

    def setTargetLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def targetLayer(self) -> QgsVectorLayer|None: ...
    def setLabeledLayer(self, layer: QgsMapLayer|None) -> None: ...
    def labeledLayer(self) -> QgsMapLayer|None: ...
    def __repr__(self) -> typing.Any: ...
    def resolveReferences(self, project: 'QgsProject|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def prepare(self, context: QgsRenderContext) -> bool: ...
    def description(self) -> str: ...
    def displayType(self) -> str: ...
    def id(self) -> str: ...
    def clone(self) -> 'QgsLabelingEngineRuleAvoidLabelOverlapWithFeature|None': ...


class QgsLabelingEngineRuleRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def removeRule(self, id: str|None) -> None: ...
    def addRule(self, rule: QgsAbstractLabelingEngineRule|None) -> bool: ...
    def create(self, id: str|None) -> QgsAbstractLabelingEngineRule|None: ...
    def isAvailable(self, id: str|None) -> bool: ...
    def displayType(self, id: str|None) -> str: ...
    def ruleIds(self) -> list[str]: ...


class QgsLayerTreeModelLegendNode(QtCore.QObject):

    class NodeTypes(enum.IntEnum):
        SimpleLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        SymbolLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        RasterSymbolLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        ImageLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        WmsLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        DataDefinedSizeLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        EmbeddedWidget = ... # type: QgsLayerTreeModelLegendNode.NodeTypes
        ColorRampLegend = ... # type: QgsLayerTreeModelLegendNode.NodeTypes

    class CustomRole(enum.IntEnum):
        RuleKey = ... # type: QgsLayerTreeModelLegendNode.CustomRole
        ParentRuleKey = ... # type: QgsLayerTreeModelLegendNode.CustomRole
        NodeType = ... # type: QgsLayerTreeModelLegendNode.CustomRole
        IsDataDefinedSize = ... # type: QgsLayerTreeModelLegendNode.CustomRole

    class ItemContext(PyQt6.sip.wrapper):

        columnLeft = ... # type: float
        columnRight = ... # type: float
        context = ... # type: QgsRenderContext
        labelXOffset = ... # type: float
        maxSiblingSymbolWidth = ... # type: float
        painter = ... # type: QtGui.QPainter
        patchShape = ... # type: 'QgsLegendPatchShape'
        patchSize = ... # type: QtCore.QSizeF
        point = ... # type: QtCore.QPointF
        screenProperties = ... # type: QgsScreenProperties
        textDocument = ... # type: 'QgsTextDocument'
        textDocumentMetrics = ... # type: 'QgsTextDocumentMetrics'
        top = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerTreeModelLegendNode.ItemContext') -> None: ...

    class ItemMetrics(PyQt6.sip.wrapper):

        labelSize = ... # type: QtCore.QSizeF
        symbolSize = ... # type: QtCore.QSizeF

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerTreeModelLegendNode.ItemMetrics') -> None: ...

    def __init__(self, nodeL: 'QgsLayerTreeLayer|None', parent: QtCore.QObject|None = ...) -> None: ...

    def createTemporaryRenderContext(self) -> QgsRenderContext|None: ...
    sizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    dataChanged: typing.ClassVar[QtCore.pyqtSignal]
    def toggleAllItems(self) -> None: ...
    def uncheckAllItems(self) -> None: ...
    def checkAllItems(self) -> None: ...
    def __repr__(self) -> typing.Any: ...
    def drawSymbolText(self, settings: QgsLegendSettings, ctx: 'QgsLayerTreeModelLegendNode.ItemContext|None', symbolSize: QtCore.QSizeF) -> QtCore.QSizeF: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: 'QgsLayerTreeModelLegendNode.ItemContext|None', itemHeight: float) -> QtCore.QSizeF: ...
    def exportToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def draw(self, settings: QgsLegendSettings, ctx: 'QgsLayerTreeModelLegendNode.ItemContext') -> 'QgsLayerTreeModelLegendNode.ItemMetrics': ...
    def invalidateMapBasedData(self) -> None: ...
    def isScaleOK(self, scale: float) -> bool: ...
    def columnBreak(self) -> bool: ...
    def setColumnBreak(self, breakBeforeNode: bool) -> None: ...
    def setUserPatchSize(self, size: QtCore.QSizeF) -> None: ...
    def userPatchSize(self) -> QtCore.QSizeF: ...
    def setUserLabel(self, userLabel: str|None) -> None: ...
    def userLabel(self) -> str: ...
    def setEmbeddedInParent(self, embedded: bool) -> None: ...
    def isEmbeddedInParent(self) -> bool: ...
    def setData(self, value: typing.Any, role: int) -> bool: ...
    def data(self, role: int) -> typing.Any: ...
    def flags(self) -> QtCore.Qt.ItemFlag: ...
    def model(self) -> 'QgsLayerTreeModel|None': ...
    def layerNode(self) -> 'QgsLayerTreeLayer|None': ...


class QgsColorRampLegendNode(QgsLayerTreeModelLegendNode):

    @typing.overload
    def __init__(self, nodeLayer: 'QgsLayerTreeLayer|None', ramp: QgsColorRamp|None, minimumLabel: str|None, maximumLabel: str|None, parent: QtCore.QObject|None = ..., key: str|None = ..., parentKey: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, nodeLayer: 'QgsLayerTreeLayer|None', ramp: QgsColorRamp|None, settings: 'QgsColorRampLegendNodeSettings', minimumValue: float, maximumValue: float, parent: QtCore.QObject|None = ..., key: str|None = ..., parentKey: str|None = ...) -> None: ...

    def maximum(self) -> float: ...
    def minimum(self) -> float: ...
    def setMaximum(self, maximum: float) -> None: ...
    def setMinimum(self, minimum: float) -> None: ...
    def setSettings(self, settings: 'QgsColorRampLegendNodeSettings') -> None: ...
    def settings(self) -> 'QgsColorRampLegendNodeSettings': ...
    def ramp(self) -> QgsColorRamp|None: ...
    def iconSize(self) -> QtCore.QSize: ...
    def setIconSize(self, size: QtCore.QSize) -> None: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbolText(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, symbolSize: QtCore.QSizeF) -> QtCore.QSizeF: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, itemHeight: float) -> QtCore.QSizeF: ...
    def data(self, role: int) -> typing.Any: ...


class QgsColorRampLegendNodeSettings(PyQt6.sip.wrapper):

    class Direction(enum.IntEnum):
        MinimumToMaximum = ... # type: QgsColorRampLegendNodeSettings.Direction
        MaximumToMinimum = ... # type: QgsColorRampLegendNodeSettings.Direction

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsColorRampLegendNodeSettings') -> None: ...

    def setUseContinuousLegend(self, useContinuousLegend: bool) -> None: ...
    def useContinuousLegend(self) -> bool: ...
    def setOrientation(self, orientation: QtCore.Qt.Orientation) -> None: ...
    def orientation(self) -> QtCore.Qt.Orientation: ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def setSuffix(self, suffix: str|None) -> None: ...
    def suffix(self) -> str: ...
    def setPrefix(self, prefix: str|None) -> None: ...
    def prefix(self) -> str: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def setNumericFormat(self, format: 'QgsNumericFormat|None') -> None: ...
    def numericFormat(self) -> 'QgsNumericFormat|None': ...
    def setMaximumLabel(self, label: str|None) -> None: ...
    def maximumLabel(self) -> str: ...
    def setMinimumLabel(self, label: str|None) -> None: ...
    def minimumLabel(self) -> str: ...
    def setDirection(self, direction: 'QgsColorRampLegendNodeSettings.Direction') -> None: ...
    def direction(self) -> 'QgsColorRampLegendNodeSettings.Direction': ...


class QgsLayerTreeNode(QtCore.QObject):

    class NodeType(enum.IntEnum):
        NodeGroup = ... # type: QgsLayerTreeNode.NodeType
        NodeLayer = ... # type: QgsLayerTreeNode.NodeType
        NodeCustom = ... # type: QgsLayerTreeNode.NodeType

    @typing.overload
    def __init__(self, t: 'QgsLayerTreeNode.NodeType', checked: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsLayerTreeNode') -> None: ...

    def removeChildrenPrivate(self, from_: int, count: int, destroy: bool = ...) -> None: ...
    def insertChildrenPrivate(self, index: int, nodes: collections.abc.Iterable['QgsLayerTreeNode']) -> None: ...
    def writeCommonXml(self, element: QtXml.QDomElement) -> None: ...
    def readCommonXml(self, element: QtXml.QDomElement) -> None: ...
    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    expandedChanged: typing.ClassVar[QtCore.pyqtSignal]
    customPropertyChanged: typing.ClassVar[QtCore.pyqtSignal]
    visibilityChanged: typing.ClassVar[QtCore.pyqtSignal]
    removedChildren: typing.ClassVar[QtCore.pyqtSignal]
    willRemoveChildren: typing.ClassVar[QtCore.pyqtSignal]
    addedChildren: typing.ClassVar[QtCore.pyqtSignal]
    willAddChildren: typing.ClassVar[QtCore.pyqtSignal]
    def takeChild(self, node: 'QgsLayerTreeNode|None') -> bool: ...
    def customProperties(self) -> list[str]: ...
    def removeCustomProperty(self, key: str|None) -> None: ...
    def customProperty(self, key: str|None, defaultValue: typing.Any = ...) -> typing.Any: ...
    def setCustomProperty(self, key: str|None, value: typing.Any) -> None: ...
    def setExpanded(self, expanded: bool) -> None: ...
    def isExpanded(self) -> bool: ...
    def depth(self) -> int: ...
    def checkedLayers(self) -> list[QgsMapLayer]: ...
    def isItemVisibilityUncheckedRecursive(self) -> bool: ...
    def isItemVisibilityCheckedRecursive(self) -> bool: ...
    def setItemVisibilityCheckedParentRecursive(self, checked: bool) -> None: ...
    def setItemVisibilityCheckedRecursive(self, checked: bool) -> None: ...
    def setItemVisibilityChecked(self, checked: bool) -> None: ...
    def itemVisibilityChecked(self) -> bool: ...
    def isVisible(self) -> bool: ...
    def resolveReferences(self, project: 'QgsProject|None', looseMatching: bool = ...) -> None: ...
    def clone(self) -> 'QgsLayerTreeNode|None': ...
    def dump(self) -> str: ...
    def writeXml(self, parentElement: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @typing.overload
    @staticmethod
    def readXml(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsLayerTreeNode|None': ...
    @typing.overload
    @staticmethod
    def readXml(element: QtXml.QDomElement, project: 'QgsProject|None') -> 'QgsLayerTreeNode|None': ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def children(self) -> list['QgsLayerTreeNode']: ...
    def parent(self) -> 'QgsLayerTreeNode|None': ...
    def nodeType(self) -> 'QgsLayerTreeNode.NodeType': ...
    def __getitem__(self, index: int) -> 'QgsLayerTreeNode': ...
    def __len__(self) -> int: ...
    def __repr__(self) -> typing.Any: ...


class QgsLayerTreeGroup(QgsLayerTreeNode):

    def __init__(self, name: str|None = ..., checked: bool = ...) -> None: ...

    def updateChildVisibilityMutuallyExclusive(self) -> None: ...
    def nodeVisibilityChanged(self, node: QgsLayerTreeNode|None) -> None: ...
    def hasWmsTimeDimension(self) -> bool: ...
    def setHasWmsTimeDimension(self, hasWmsTimeDimension: bool) -> None: ...
    def serverProperties(self) -> QgsMapLayerServerProperties|None: ...
    def convertToGroupLayer(self, options: QgsGroupLayer.LayerOptions) -> QgsGroupLayer|None: ...
    def setGroupLayer(self, layer: QgsGroupLayer|None) -> None: ...
    def groupLayer(self) -> QgsGroupLayer|None: ...
    def setIsMutuallyExclusive(self, enabled: bool, initialChildIndex: int = ...) -> None: ...
    def isMutuallyExclusive(self) -> bool: ...
    def setItemVisibilityCheckedRecursive(self, checked: bool) -> None: ...
    def resolveReferences(self, project: 'QgsProject|None', looseMatching: bool = ...) -> None: ...
    def clone(self) -> 'QgsLayerTreeGroup|None': ...
    def dump(self) -> str: ...
    def readChildrenFromXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, parentElement: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @typing.overload
    @staticmethod
    def readXml(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsLayerTreeGroup|None': ...
    @typing.overload
    @staticmethod
    def readXml(element: QtXml.QDomElement, project: 'QgsProject|None', context: QgsReadWriteContext) -> 'QgsLayerTreeGroup|None': ...
    def findGroups(self, recursive: bool = ...) -> list['QgsLayerTreeGroup']: ...
    def findGroup(self, name: str|None) -> 'QgsLayerTreeGroup|None': ...
    def findCustomNodeIds(self) -> list[str]: ...
    def findLayerIds(self) -> list[str]: ...
    def reorderGroupLayersAndCustomNodes(self, order: collections.abc.Iterable[QgsLayerTreeNode]) -> None: ...
    def reorderGroupLayers(self, order: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def findLayersAndCustomNodes(self) -> list[QgsLayerTreeNode]: ...
    def findCustomNode(self, id: str|None) -> 'QgsLayerTreeCustomNode|None': ...
    def findLayers(self) -> list['QgsLayerTreeLayer']: ...
    @typing.overload
    def findLayer(self, layer: QgsMapLayer|None) -> 'QgsLayerTreeLayer|None': ...
    @typing.overload
    def findLayer(self, layerId: str|None) -> 'QgsLayerTreeLayer|None': ...
    def removeAllChildren(self) -> None: ...
    def removeChildrenGroupWithoutLayers(self) -> None: ...
    def removeChildren(self, from_: int, count: int) -> None: ...
    def removeCustomNode(self, customNode: 'QgsLayerTreeCustomNode|None') -> None: ...
    def removeLayer(self, layer: QgsMapLayer|None) -> None: ...
    def removeChildNode(self, node: QgsLayerTreeNode|None) -> None: ...
    def addChildNode(self, node: QgsLayerTreeNode|None) -> None: ...
    def insertChildNode(self, index: int, node: QgsLayerTreeNode|None) -> None: ...
    def insertChildNodes(self, index: int, nodes: collections.abc.Iterable[QgsLayerTreeNode]) -> None: ...
    def addCustomNode(self, id: str|None, name: str|None = ...) -> 'QgsLayerTreeCustomNode|None': ...
    @typing.overload
    def insertCustomNode(self, index: int, id: str|None, name: str|None = ...) -> 'QgsLayerTreeCustomNode|None': ...
    @typing.overload
    def insertCustomNode(self, index: int, node: 'QgsLayerTreeCustomNode|None') -> 'QgsLayerTreeCustomNode|None': ...
    def addLayer(self, layer: QgsMapLayer|None) -> 'QgsLayerTreeLayer|None': ...
    def insertLayer(self, index: int, layer: QgsMapLayer|None) -> 'QgsLayerTreeLayer|None': ...
    def addGroup(self, name: str|None) -> 'QgsLayerTreeGroup|None': ...
    def insertGroup(self, index: int, name: str|None) -> 'QgsLayerTreeGroup|None': ...
    def setName(self, n: str|None) -> None: ...
    def name(self) -> str: ...
    def __repr__(self) -> typing.Any: ...


class QgsLayerTree(QgsLayerTreeGroup):

    def __init__(self) -> None: ...

    hasCustomLayerOrderChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerOrderChanged: typing.ClassVar[QtCore.pyqtSignal]
    customLayerOrderChanged: typing.ClassVar[QtCore.pyqtSignal]
    def clear(self) -> None: ...
    def clone(self) -> 'QgsLayerTree|None': ...
    def writeXml(self, parentElement: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def readLayerOrderFromXml(self, doc: QtXml.QDomElement) -> None: ...
    @staticmethod
    def readXml(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsLayerTree'|None: ...
    def layerAndCustomNodeOrder(self) -> list[QgsLayerTreeNode]: ...
    def setHasCustomLayerOrder(self, hasCustomLayerOrder: bool) -> None: ...
    def hasCustomLayerOrder(self) -> bool: ...
    def layerOrder(self) -> list[QgsMapLayer]: ...
    def setCustomLayerOrderByIds(self, customLayerOrder: collections.abc.Iterable[str|None]) -> None: ...
    def setCustomLayerOrder(self, customLayerOrder: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def customLayerOrder(self) -> list[QgsMapLayer]: ...
    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def isCustomNode(node: QgsLayerTreeNode|None) -> bool: ...
    @staticmethod
    def isLayer(node: QgsLayerTreeNode|None) -> bool: ...
    @staticmethod
    def isGroup(node: QgsLayerTreeNode|None) -> bool: ...


class QgsLayerTreeFilterSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, settings: QgsMapSettings) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsLayerTreeFilterSettings') -> None: ...

    def layers(self) -> list[QgsMapLayer]: ...
    def combinedVisibleExtentForLayer(self, layer: QgsMapLayer|None) -> QgsGeometry: ...
    def addVisibleExtentForLayer(self, layer: QgsMapLayer|None, polygon: QgsReferencedGeometry) -> None: ...
    def setFlags(self, flags: Qgis.LayerTreeFilterFlag) -> None: ...
    def flags(self) -> Qgis.LayerTreeFilterFlag: ...
    def setFilterPolygon(self, polygon: QgsGeometry) -> None: ...
    def filterPolygon(self) -> QgsGeometry: ...
    def layerFilterExpression(self, layerId: str|None) -> str: ...
    def setLayerFilterExpressionsFromLayerTree(self, tree: QgsLayerTree|None) -> None: ...
    def setLayerFilterExpressions(self, expressions: dict[str|None, str|None]) -> None: ...
    def layerFilterExpressions(self) -> dict[str, str]: ...
    def mapSettings(self) -> QgsMapSettings: ...


class QgsLayerTreeCustomNode(QgsLayerTreeNode):

    def __init__(self, nodeId: str|None, nodeName: str|None = ..., checked: bool = ...) -> None: ...

    def resolveReferences(self, project: 'QgsProject|None', looseMatching: bool = ...) -> None: ...
    def clone(self) -> 'QgsLayerTreeCustomNode|None': ...
    def dump(self) -> str: ...
    def writeXml(self, parentElement: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @staticmethod
    def readXml(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsLayerTreeCustomNode|None': ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def nodeId(self) -> str: ...
    def __repr__(self) -> typing.Any: ...


class QgsLayerTreeLayer(QgsLayerTreeNode):

    class LegendNodesSplitBehavior(enum.IntEnum):
        UseDefaultLegendSetting = ... # type: QgsLayerTreeLayer.LegendNodesSplitBehavior
        AllowSplittingLegendNodesOverMultipleColumns = ... # type: QgsLayerTreeLayer.LegendNodesSplitBehavior
        PreventSplittingLegendNodesOverMultipleColumns = ... # type: QgsLayerTreeLayer.LegendNodesSplitBehavior

    @typing.overload
    def __init__(self, layer: QgsMapLayer|None) -> None: ...
    @typing.overload
    def __init__(self, layerId: str|None, name: str|None = ..., source: str|None = ..., provider: str|None = ...) -> None: ...

    def attachToLayer(self) -> None: ...
    layerWillBeUnloaded: typing.ClassVar[QtCore.pyqtSignal]
    layerLoaded: typing.ClassVar[QtCore.pyqtSignal]
    def setLegendSplitBehavior(self, behavior: 'QgsLayerTreeLayer.LegendNodesSplitBehavior') -> None: ...
    def legendSplitBehavior(self) -> 'QgsLayerTreeLayer.LegendNodesSplitBehavior': ...
    def setPatchSize(self, size: QtCore.QSizeF) -> None: ...
    def patchSize(self) -> QtCore.QSizeF: ...
    def setPatchShape(self, shape: 'QgsLegendPatchShape') -> None: ...
    def patchShape(self) -> 'QgsLegendPatchShape': ...
    def labelExpression(self) -> str: ...
    def setLabelExpression(self, expression: str|None) -> None: ...
    def resolveReferences(self, project: 'QgsProject|None', looseMatching: bool = ...) -> None: ...
    def clone(self) -> 'QgsLayerTreeLayer|None': ...
    def dump(self) -> str: ...
    def writeXml(self, parentElement: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @typing.overload
    @staticmethod
    def readXml(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsLayerTreeLayer|None': ...
    @typing.overload
    @staticmethod
    def readXml(element: QtXml.QDomElement, project: 'QgsProject|None', context: QgsReadWriteContext) -> 'QgsLayerTreeLayer|None': ...
    def useLayerName(self) -> bool: ...
    def setUseLayerName(self, use: bool = ...) -> None: ...
    def setName(self, n: str|None) -> None: ...
    def name(self) -> str: ...
    def layer(self) -> QgsMapLayer|None: ...
    def layerId(self) -> str: ...
    def __repr__(self) -> typing.Any: ...


class QgsLayerTreeModel(QtCore.QAbstractItemModel):

    class Flag(enum.IntEnum):
        ShowLegend = ... # type: QgsLayerTreeModel.Flag
        ShowLegendAsTree = ... # type: QgsLayerTreeModel.Flag
        DeferredLegendInvalidation = ... # type: QgsLayerTreeModel.Flag
        UseEmbeddedWidgets = ... # type: QgsLayerTreeModel.Flag
        UseTextFormatting = ... # type: QgsLayerTreeModel.Flag
        AllowNodeReorder = ... # type: QgsLayerTreeModel.Flag
        AllowNodeRename = ... # type: QgsLayerTreeModel.Flag
        AllowNodeChangeVisibility = ... # type: QgsLayerTreeModel.Flag
        AllowLegendChangeState = ... # type: QgsLayerTreeModel.Flag
        ActionHierarchical = ... # type: QgsLayerTreeModel.Flag
        UseThreadedHitTest = ... # type: QgsLayerTreeModel.Flag

    def __init__(self, rootNode: QgsLayerTree|None, parent: QtCore.QObject|None = ...) -> None: ...

    def legendInvalidateMapBasedData(self) -> None: ...
    def legendCleanup(self) -> None: ...
    def legendIconEmbeddedInParent(self, nodeLayer: QgsLayerTreeLayer|None) -> QtGui.QIcon: ...
    def legendEmbeddedInParent(self, nodeLayer: QgsLayerTreeLayer|None) -> bool: ...
    def legendNodeFlags(self, node: QgsLayerTreeModelLegendNode|None) -> QtCore.Qt.ItemFlag: ...
    def legendNodeData(self, node: QgsLayerTreeModelLegendNode|None, role: int) -> typing.Any: ...
    def legendParent(self, legendNode: QgsLayerTreeModelLegendNode|None) -> QtCore.QModelIndex: ...
    def legendNodeIndex(self, row: int, column: int, node: QgsLayerTreeModelLegendNode|None) -> QtCore.QModelIndex: ...
    def legendRootIndex(self, row: int, column: int, nL: QgsLayerTreeLayer|None) -> QtCore.QModelIndex: ...
    def legendNodeRowCount(self, node: QgsLayerTreeModelLegendNode|None) -> int: ...
    def legendRootRowCount(self, nL: QgsLayerTreeLayer|None) -> int: ...
    def indexOfParentLayerTreeNode(self, parentNode: QgsLayerTreeNode|None) -> QtCore.QModelIndex: ...
    def filterLegendNodes(self, nodes: collections.abc.Iterable[QgsLayerTreeModelLegendNode]) -> list[QgsLayerTreeModelLegendNode]: ...
    @staticmethod
    def iconGroup() -> QtGui.QIcon: ...
    def refreshScaleBasedLayers(self, index: QtCore.QModelIndex = ..., previousScale: float = ...) -> None: ...
    def recursivelyEmitDataChanged(self, index: QtCore.QModelIndex = ...) -> None: ...
    def disconnectFromRootNode(self) -> None: ...
    def connectToRootNode(self) -> None: ...
    def disconnectFromLayers(self, parentGroup: QgsLayerTreeGroup|None) -> None: ...
    def connectToLayers(self, parentGroup: QgsLayerTreeGroup|None) -> None: ...
    def disconnectFromLayer(self, nodeLayer: QgsLayerTreeLayer|None) -> None: ...
    def connectToLayer(self, nodeLayer: QgsLayerTreeLayer|None) -> None: ...
    def addLegendToLayer(self, nodeL: QgsLayerTreeLayer|None) -> None: ...
    def removeLegendFromLayer(self, nodeLayer: QgsLayerTreeLayer|None) -> None: ...
    def invalidateLegendMapBasedData(self) -> None: ...
    def legendNodeDataChanged(self) -> None: ...
    def layerNeedsUpdate(self) -> None: ...
    def layerFlagsChanged(self) -> None: ...
    def layerLegendChanged(self) -> None: ...
    def nodeLayerWillBeUnloaded(self) -> None: ...
    def nodeLayerLoaded(self) -> None: ...
    def nodeCustomPropertyChanged(self, node: QgsLayerTreeNode|None, key: str|None) -> None: ...
    def nodeNameChanged(self, node: QgsLayerTreeNode|None, name: str|None) -> None: ...
    def nodeVisibilityChanged(self, node: QgsLayerTreeNode|None) -> None: ...
    def nodeRemovedChildren(self) -> None: ...
    def nodeWillRemoveChildren(self, node: QgsLayerTreeNode|None, indexFrom: int, indexTo: int) -> None: ...
    def nodeAddedChildren(self, node: QgsLayerTreeNode|None, indexFrom: int, indexTo: int) -> None: ...
    def nodeWillAddChildren(self, node: QgsLayerTreeNode|None, indexFrom: int, indexTo: int) -> None: ...
    hitTestCompleted: typing.ClassVar[QtCore.pyqtSignal]
    hitTestStarted: typing.ClassVar[QtCore.pyqtSignal]
    messageEmitted: typing.ClassVar[QtCore.pyqtSignal]
    def hitTestInProgress(self) -> bool: ...
    def waitForHitTestBlocking(self) -> None: ...
    @staticmethod
    def scaleIconSize(standardSize: int) -> int: ...
    def targetScreenProperties(self) -> set[QgsScreenProperties]: ...
    def addTargetScreenProperties(self, properties: QgsScreenProperties) -> None: ...
    def setLayerStyleOverrides(self, overrides: dict[str|None, str|None]) -> None: ...
    def layerStyleOverrides(self) -> dict[str, str]: ...
    def legendMapViewData(self) -> typing.Tuple[float, int, float]: ...
    def setLegendMapViewData(self, mapUnitsPerPixel: float, dpi: int, scale: float) -> None: ...
    def filterSettings(self) -> QgsLayerTreeFilterSettings|None: ...
    def setFilterSettings(self, settings: QgsLayerTreeFilterSettings|None = ...) -> None: ...
    def legendFilterMapSettings(self) -> QgsMapSettings|None: ...
    @deprecated("""""")
    def setLegendFilter(self, settings: QgsMapSettings|None, useExtent: bool = ..., polygon: QgsGeometry = ..., useExpressions: bool = ...) -> None: ...
    @deprecated("""""")
    def setLegendFilterByMap(self, settings: QgsMapSettings|None) -> None: ...
    def legendFilterByScale(self) -> float: ...
    def setLegendFilterByScale(self, scale: float) -> None: ...
    def autoCollapseLegendNodes(self) -> int: ...
    def setAutoCollapseLegendNodes(self, nodeCount: int) -> None: ...
    def layerTreeNodeFont(self, nodeType: int) -> QtGui.QFont: ...
    def setLayerTreeNodeFont(self, nodeType: int, font: QtGui.QFont) -> None: ...
    def setCurrentIndex(self, currentIndex: QtCore.QModelIndex) -> None: ...
    def currentIndex(self) -> QtCore.QModelIndex: ...
    def refreshLayerLegend(self, nodeLayer: QgsLayerTreeLayer|None) -> None: ...
    def setRootGroup(self, newRootGroup: QgsLayerTree|None) -> None: ...
    def rootGroup(self) -> QgsLayerTree|None: ...
    def findLegendNode(self, layerId: str|None, ruleKey: str|None) -> QgsLayerTreeModelLegendNode|None: ...
    def legendNodeEmbeddedInParent(self, nodeLayer: QgsLayerTreeLayer|None) -> QgsLayerTreeModelLegendNode|None: ...
    def layerOriginalLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def layerLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None, skipNodeEmbeddedInParent: bool = ...) -> list[QgsLayerTreeModelLegendNode]: ...
    def legendNode2index(self, legendNode: QgsLayerTreeModelLegendNode|None) -> QtCore.QModelIndex: ...
    @staticmethod
    def index2legendNode(index: QtCore.QModelIndex) -> QgsLayerTreeModelLegendNode|None: ...
    def indexes2nodes(self, list: collections.abc.Iterable[QtCore.QModelIndex], skipInternal: bool = ...) -> list[QgsLayerTreeNode]: ...
    def node2index(self, node: QgsLayerTreeNode|None) -> QtCore.QModelIndex: ...
    def index2node(self, index: QtCore.QModelIndex) -> QgsLayerTreeNode|None: ...
    def testFlag(self, f: 'QgsLayerTreeModel.Flag') -> bool: ...
    def setFlag(self, f: 'QgsLayerTreeModel.Flag', on: bool = ...) -> None: ...
    def setFlags(self, f: 'QgsLayerTreeModel.Flag') -> None: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def mimeTypes(self) -> list[str]: ...
    def supportedDropActions(self) -> QtCore.Qt.DropAction: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    @typing.overload
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    @typing.overload
    def flags(self) -> 'QgsLayerTreeModel.Flag': ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...


class QgsSymbolLegendNode(QgsLayerTreeModelLegendNode):

    MAXIMUM_SIZE = ... # type: float
    MINIMUM_SIZE = ... # type: float

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, item: 'QgsLegendSymbolItem', parent: QtCore.QObject|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def createSymbolScope(self) -> QgsExpressionContextScope|None: ...
    def evaluateLabel(self, context: QgsExpressionContext = ..., label: str|None = ...) -> str: ...
    def setCustomSymbol(self, symbol: 'QgsSymbol|None') -> None: ...
    def customSymbol(self) -> 'QgsSymbol|None': ...
    def setPatchShape(self, shape: 'QgsLegendPatchShape') -> None: ...
    def patchShape(self) -> 'QgsLegendPatchShape': ...
    def symbolLabel(self) -> str: ...
    def setTextOnSymbolTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textOnSymbolTextFormat(self) -> 'QgsTextFormat': ...
    def setTextOnSymbolLabel(self, label: str|None) -> None: ...
    def textOnSymbolLabel(self) -> str: ...
    def setSymbol(self, symbol: 'QgsSymbol|None') -> None: ...
    def symbol(self) -> 'QgsSymbol|None': ...
    @typing.overload
    def minimumIconSize(self) -> QtCore.QSize: ...
    @typing.overload
    def minimumIconSize(self, context: QgsRenderContext|None) -> QtCore.QSize: ...
    def iconSize(self) -> QtCore.QSize: ...
    def setIconSize(self, sz: QtCore.QSize) -> None: ...
    def invalidateMapBasedData(self) -> None: ...
    def isScaleOK(self, scale: float) -> bool: ...
    def setUserLabel(self, userLabel: str|None) -> None: ...
    def setEmbeddedInParent(self, embedded: bool) -> None: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, itemHeight: float) -> QtCore.QSizeF: ...
    def setData(self, value: typing.Any, role: int) -> bool: ...
    def data(self, role: int) -> typing.Any: ...
    def flags(self) -> QtCore.Qt.ItemFlag: ...


class QgsSimpleLegendNode(QgsLayerTreeModelLegendNode):

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, label: str|None, icon: QtGui.QIcon = ..., parent: QtCore.QObject|None = ..., key: str|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def data(self, role: int) -> typing.Any: ...


class QgsImageLegendNode(QgsLayerTreeModelLegendNode):

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, img: QtGui.QImage, parent: QtCore.QObject|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, itemHeight: float) -> QtCore.QSizeF: ...
    def data(self, role: int) -> typing.Any: ...


class QgsRasterSymbolLegendNode(QgsLayerTreeModelLegendNode):

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, label: str|None, parent: QtCore.QObject|None = ..., isCheckable: bool = ..., ruleKey: str|None = ..., parentRuleKey: str|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def isCheckable(self) -> bool: ...
    def ruleKey(self) -> str: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, itemHeight: float) -> QtCore.QSizeF: ...
    def setData(self, value: typing.Any, role: int) -> bool: ...
    def data(self, role: int) -> typing.Any: ...
    def flags(self) -> QtCore.Qt.ItemFlag: ...


class QgsWmsLegendNode(QgsLayerTreeModelLegendNode):

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, parent: QtCore.QObject|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def getLegendGraphicBlocking(self) -> QtGui.QImage: ...
    def invalidateMapBasedData(self) -> None: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, itemHeight: float) -> QtCore.QSizeF: ...
    def data(self, role: int) -> typing.Any: ...


class QgsDataDefinedSizeLegendNode(QgsLayerTreeModelLegendNode):

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, settings: QgsDataDefinedSizeLegend, parent: QtCore.QObject|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def draw(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext) -> QgsLayerTreeModelLegendNode.ItemMetrics: ...
    def data(self, role: int) -> typing.Any: ...


class QgsVectorLabelLegendNode(QgsLayerTreeModelLegendNode):

    def __init__(self, nodeLayer: QgsLayerTreeLayer|None, labelSettings: QgsPalLayerSettings, parent: QtCore.QObject|None = ...) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def exportSymbolToJson(self, settings: QgsLegendSettings, context: QgsRenderContext) -> dict[str, QtCore.QJsonValue]: ...
    def drawSymbol(self, settings: QgsLegendSettings, ctx: QgsLayerTreeModelLegendNode.ItemContext|None, itemHeight: float) -> QtCore.QSizeF: ...
    def data(self, role: int) -> typing.Any: ...


class QgsLayerTreeRegistryBridge(QtCore.QObject):

    class InsertionPoint(PyQt6.sip.wrapper):

        group = ... # type: QgsLayerTreeGroup
        position = ... # type: int

        @typing.overload
        def __init__(self, group: QgsLayerTreeGroup|None, position: int) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerTreeRegistryBridge.InsertionPoint') -> None: ...

    def __init__(self, root: QgsLayerTreeGroup|None, project: 'QgsProject|None', parent: QtCore.QObject|None = ...) -> None: ...

    def removeLayersFromRegistry(self, layerIds: collections.abc.Iterable[str|None]) -> None: ...
    def groupRemovedChildren(self) -> None: ...
    def groupWillRemoveChildren(self, node: QgsLayerTreeNode|None, indexFrom: int, indexTo: int) -> None: ...
    def layersWillBeRemoved(self, layerIds: collections.abc.Iterable[str|None]) -> None: ...
    def layersAdded(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    addedLayersToLayerTree: typing.ClassVar[QtCore.pyqtSignal]
    def layerInsertionMethod(self) -> Qgis.LayerTreeInsertionMethod: ...
    def setLayerInsertionMethod(self, method: Qgis.LayerTreeInsertionMethod) -> None: ...
    def layerInsertionPoint(self) -> 'QgsLayerTreeRegistryBridge.InsertionPoint': ...
    @typing.overload
    @deprecated("""""")
    def setLayerInsertionPoint(self, parentGroup: QgsLayerTreeGroup|None, index: int) -> None: ...
    @typing.overload
    def setLayerInsertionPoint(self, insertionPoint: 'QgsLayerTreeRegistryBridge.InsertionPoint') -> None: ...
    def newLayersVisible(self) -> bool: ...
    def setNewLayersVisible(self, enabled: bool) -> None: ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...


class QgsLayerTreeFilterProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setLayerChecked(self, layer: QgsMapLayer|None, checked: bool) -> None: ...
    def isLayerChecked(self, layer: QgsMapLayer|None) -> bool: ...
    def setFilterText(self, filterText: str|None = ...) -> None: ...
    def nodeShown(self, node: QgsLayerTreeNode|None) -> bool: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def sibling(self, row: int, column: int, idx: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def flags(self, idx: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def setFilters(self, filters: Qgis.LayerFilter) -> None: ...
    def setShowPrivateLayers(self, showPrivate: bool) -> None: ...
    def showPrivateLayers(self) -> bool: ...
    def setLayerTreeModel(self, layerTreeModel: QgsLayerTreeModel|None) -> None: ...
    def layerTreeModel(self) -> QgsLayerTreeModel|None: ...
    def mapLayer(self, idx: QtCore.QModelIndex) -> QgsMapLayer|None: ...
    def checkedLayers(self) -> list[QgsMapLayer]: ...
    def setCheckedLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...


class QgsLayerTreeUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerTreeUtils') -> None: ...

    @staticmethod
    def insertLayerAtOptimalPlacement(group: QgsLayerTreeGroup|None, layer: QgsMapLayer|None) -> QgsLayerTreeLayer|None: ...
    @staticmethod
    def firstGroupWithoutCustomProperty(group: QgsLayerTreeGroup|None, property: str|None) -> QgsLayerTreeGroup|None: ...
    @staticmethod
    def countMapLayerInTree(tree: QgsLayerTreeNode|None, layer: QgsMapLayer|None) -> int: ...
    @staticmethod
    def collectMapLayersRecursive(nodes: collections.abc.Iterable[QgsLayerTreeNode]) -> set[QgsMapLayer]: ...
    @staticmethod
    def insertLayerBelow(group: QgsLayerTreeGroup|None, refLayer: QgsMapLayer|None, layerToInsert: QgsMapLayer|None) -> QgsLayerTreeLayer|None: ...
    @staticmethod
    def hasLegendFilterExpression(group: QgsLayerTreeGroup) -> bool: ...
    @staticmethod
    def legendFilterByExpression(layer: QgsLayerTreeLayer) -> typing.Tuple[str, bool]: ...
    @staticmethod
    def setLegendFilterByExpression(layer: QgsLayerTreeLayer, expr: str|None, enabled: bool = ...) -> None: ...
    @staticmethod
    def invisibleLayerList(node: QgsLayerTreeNode|None) -> list[str]: ...
    @staticmethod
    def updateEmbeddedGroupsProjectPath(group: QgsLayerTreeGroup|None, project: 'QgsProject|None') -> None: ...
    @staticmethod
    def replaceChildrenOfEmbeddedGroups(group: QgsLayerTreeGroup|None) -> None: ...
    @staticmethod
    def storeOriginalLayersProperties(group: QgsLayerTreeGroup|None, doc: QtXml.QDomDocument|None) -> None: ...
    @staticmethod
    def removeInvalidLayers(group: QgsLayerTreeGroup|None) -> None: ...
    @staticmethod
    def layersModified(layerNodes: collections.abc.Iterable[QgsLayerTreeLayer]) -> bool: ...
    @staticmethod
    def layersEditable(layerNodes: collections.abc.Iterable[QgsLayerTreeLayer], ignoreLayersWhichCannotBeToggled: bool = ...) -> bool: ...
    @staticmethod
    def checkStateFromXml(txt: str|None) -> QtCore.Qt.CheckState: ...
    @staticmethod
    def checkStateToXml(state: QtCore.Qt.CheckState) -> str: ...
    @staticmethod
    def writeOldLegend(doc: QtXml.QDomDocument, root: QgsLayerTreeGroup|None, hasCustomOrder: bool, order: collections.abc.Iterable[QgsMapLayer]) -> QtXml.QDomElement: ...
    @staticmethod
    def readOldLegendLayerOrder(legendElem: QtXml.QDomElement, order: collections.abc.Iterable[str|None]) -> typing.Tuple[bool, bool]: ...
    @staticmethod
    def readOldLegend(root: QgsLayerTreeGroup|None, legendElem: QtXml.QDomElement) -> bool: ...


class QgsLegendPatchShape(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, type: Qgis.SymbolType, geometry: QgsGeometry, preserveAspectRatio: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLegendPatchShape') -> None: ...

    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def toQPolygonF(self, type: Qgis.SymbolType, size: QtCore.QSizeF) -> typing.Any: ...
    def scaledGeometry(self, size: QtCore.QSizeF) -> QgsGeometry: ...
    def setScaleToOutputSize(self, scale: bool) -> None: ...
    def scaleToOutputSize(self) -> bool: ...
    def setPreserveAspectRatio(self, preserve: bool) -> None: ...
    def preserveAspectRatio(self) -> bool: ...
    def setGeometry(self, geometry: QgsGeometry) -> None: ...
    def geometry(self) -> QgsGeometry: ...
    def setSymbolType(self, type: Qgis.SymbolType) -> None: ...
    def symbolType(self) -> Qgis.SymbolType: ...
    def isNull(self) -> bool: ...


class QgsAbstractLayoutIterator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractLayoutIterator') -> None: ...

    def filePath(self, baseFilePath: str|None, extension: str|None) -> str: ...
    def next(self) -> bool: ...
    def count(self) -> int: ...
    def endRender(self) -> bool: ...
    def beginRender(self) -> bool: ...
    def layout(self) -> 'QgsLayout|None': ...


class QgsReportSectionContext(PyQt6.sip.wrapper):

    currentLayer = ... # type: QgsVectorLayer
    feature = ... # type: QgsFeature
    fieldFilters = ... # type: dict[str|None, typing.Any]

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsReportSectionContext') -> None: ...


class QgsAbstractReportSection(QgsAbstractLayoutIterator):

    class SubSection(enum.IntEnum):
        Header = ... # type: QgsAbstractReportSection.SubSection
        Body = ... # type: QgsAbstractReportSection.SubSection
        Children = ... # type: QgsAbstractReportSection.SubSection
        Footer = ... # type: QgsAbstractReportSection.SubSection
        End = ... # type: QgsAbstractReportSection.SubSection

    def __init__(self, parentSection: 'QgsAbstractReportSection|None' = ...) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setParentSection(self, parent: 'QgsAbstractReportSection|None') -> None: ...
    def copyCommonProperties(self, destination: 'QgsAbstractReportSection|None') -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def reloadSettings(self) -> None: ...
    def readXml(self, sectionElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def context(self) -> QgsReportSectionContext: ...
    def setContext(self, context: QgsReportSectionContext) -> None: ...
    def removeChildAt(self, index: int) -> None: ...
    def removeChild(self, section: 'QgsAbstractReportSection|None') -> None: ...
    def insertChild(self, index: int, section: 'QgsAbstractReportSection|None') -> None: ...
    def appendChild(self, section: 'QgsAbstractReportSection|None') -> None: ...
    def childSection(self, index: int) -> 'QgsAbstractReportSection|None': ...
    def childSections(self) -> list['QgsAbstractReportSection']: ...
    def row(self) -> int: ...
    def childCount(self) -> int: ...
    def setFooter(self, footer: 'QgsLayout|None') -> None: ...
    def footer(self) -> 'QgsLayout|None': ...
    def setFooterEnabled(self, enabled: bool) -> None: ...
    def footerEnabled(self) -> bool: ...
    def setHeader(self, header: 'QgsLayout|None') -> None: ...
    def header(self) -> 'QgsLayout|None': ...
    def setHeaderEnabled(self, enabled: bool) -> None: ...
    def headerEnabled(self) -> bool: ...
    def nextBody(self) -> typing.Tuple['QgsLayout|None', bool]: ...
    def prepareFooter(self) -> bool: ...
    def prepareHeader(self) -> bool: ...
    def reset(self) -> None: ...
    def endRender(self) -> bool: ...
    def next(self) -> bool: ...
    def beginRender(self) -> bool: ...
    def layout(self) -> 'QgsLayout|None': ...
    def filePath(self, baseFilePath: str|None, extension: str|None) -> str: ...
    def count(self) -> int: ...
    def project(self) -> 'QgsProject|None': ...
    def parentSection(self) -> 'QgsAbstractReportSection|None': ...
    def clone(self) -> 'QgsAbstractReportSection|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def description(self) -> str: ...
    def type(self) -> str: ...


class QgsLayoutUndoObjectInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutUndoObjectInterface') -> None: ...

    def createCommand(self, text: str|None, id: int = ..., parent: QtGui.QUndoCommand|None = ...) -> 'QgsAbstractLayoutUndoCommand|None': ...


class QgsLayout(QtWidgets.QGraphicsScene, QgsExpressionContextGenerator, QgsLayoutUndoObjectInterface):

    class UndoCommand(enum.IntEnum):
        UndoLayoutDpi = ... # type: QgsLayout.UndoCommand
        UndoNone = ... # type: QgsLayout.UndoCommand

    class ZValues(enum.IntEnum):
        ZPage = ... # type: QgsLayout.ZValues
        ZItem = ... # type: QgsLayout.ZValues
        ZGrid = ... # type: QgsLayout.ZValues
        ZGuide = ... # type: QgsLayout.ZValues
        ZSmartGuide = ... # type: QgsLayout.ZValues
        ZMouseHandles = ... # type: QgsLayout.ZValues
        ZViewTool = ... # type: QgsLayout.ZValues
        ZSnapIndicator = ... # type: QgsLayout.ZValues

    def __init__(self, project: 'QgsProject|None') -> None: ...

    itemAdded: typing.ClassVar[QtCore.pyqtSignal]
    backgroundTaskCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    refreshed: typing.ClassVar[QtCore.pyqtSignal]
    selectedItemChanged: typing.ClassVar[QtCore.pyqtSignal]
    variablesChanged: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def updateBounds(self) -> None: ...
    def refresh(self) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def ungroupItems(self, group: 'QgsLayoutItemGroup|None') -> list['QgsLayoutItem']: ...
    def groupItems(self, items: collections.abc.Iterable['QgsLayoutItem']) -> 'QgsLayoutItemGroup|None': ...
    def createCommand(self, text: str|None, id: int = ..., parent: QtGui.QUndoCommand|None = ...) -> 'QgsAbstractLayoutUndoCommand|None': ...
    def undoStack(self) -> 'QgsLayoutUndoStack|None': ...
    def addItemsFromXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext, position: QtCore.QPointF|None = ..., pasteInPlace: bool = ...) -> list['QgsLayoutItem']: ...
    def readXml(self, layoutElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def loadFromTemplate(self, document: QtXml.QDomDocument, context: QgsReadWriteContext, clearExisting: bool = ...) -> typing.Tuple[list['QgsLayoutItem'], bool]: ...
    def saveAsTemplate(self, path: str|None, context: QgsReadWriteContext) -> bool: ...
    def multiFrames(self) -> list['QgsLayoutMultiFrame']: ...
    def removeMultiFrame(self, multiFrame: 'QgsLayoutMultiFrame|None') -> None: ...
    def addMultiFrame(self, multiFrame: 'QgsLayoutMultiFrame|None') -> None: ...
    def removeLayoutItem(self, item: 'QgsLayoutItem|None') -> None: ...
    def addLayoutItem(self, item: 'QgsLayoutItem|None') -> None: ...
    def pageItemBounds(self, page: int, visibleOnly: bool = ...) -> QtCore.QRectF: ...
    def layoutBounds(self, ignorePages: bool = ..., margin: float = ...) -> QtCore.QRectF: ...
    def pageCollection(self) -> 'QgsLayoutPageCollection|None': ...
    def setReferenceMap(self, map: 'QgsLayoutItemMap|None') -> None: ...
    def referenceMap(self) -> 'QgsLayoutItemMap|None': ...
    def customProperties(self) -> list[str]: ...
    def removeCustomProperty(self, key: str|None) -> None: ...
    def customProperty(self, key: str|None, defaultValue: typing.Any = ...) -> typing.Any: ...
    def setCustomProperty(self, key: str|None, value: typing.Any) -> None: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def guides(self) -> 'QgsLayoutGuideCollection': ...
    def reloadSettings(self) -> None: ...
    def gridSettings(self) -> 'QgsLayoutGridSettings': ...
    def snapper(self) -> 'QgsLayoutSnapper': ...
    def reportContext(self) -> 'QgsLayoutReportContext': ...
    def renderContext(self) -> 'QgsLayoutRenderContext': ...
    @typing.overload
    def convertFromLayoutUnits(self, length: float, unit: Qgis.LayoutUnit) -> 'QgsLayoutMeasurement': ...
    @typing.overload
    def convertFromLayoutUnits(self, size: QtCore.QSizeF, unit: Qgis.LayoutUnit) -> 'QgsLayoutSize': ...
    @typing.overload
    def convertFromLayoutUnits(self, point: QtCore.QPointF, unit: Qgis.LayoutUnit) -> 'QgsLayoutPoint': ...
    @typing.overload
    def convertToLayoutUnits(self, measurement: 'QgsLayoutMeasurement') -> float: ...
    @typing.overload
    def convertToLayoutUnits(self, size: 'QgsLayoutSize') -> QtCore.QSizeF: ...
    @typing.overload
    def convertToLayoutUnits(self, point: 'QgsLayoutPoint') -> QtCore.QPointF: ...
    def units(self) -> Qgis.LayoutUnit: ...
    def setUnits(self, units: Qgis.LayoutUnit) -> None: ...
    @typing.overload
    def layoutItemAt(self, position: QtCore.QPointF, ignoreLocked: bool = ..., searchTolerance: float = ...) -> 'QgsLayoutItem|None': ...
    @typing.overload
    def layoutItemAt(self, position: QtCore.QPointF, belowItem: 'QgsLayoutItem|None', ignoreLocked: bool = ..., searchTolerance: float = ...) -> 'QgsLayoutItem|None': ...
    def multiFrameByUuid(self, uuid: str|None, includeTemplateUuids: bool = ...) -> 'QgsLayoutMultiFrame|None': ...
    def itemById(self, id: str|None) -> 'QgsLayoutItem|None': ...
    def itemByTemplateUuid(self, uuid: str|None) -> 'QgsLayoutItem|None': ...
    def itemByUuid(self, uuid: str|None, includeTemplateUuids: bool = ...) -> 'QgsLayoutItem|None': ...
    def updateZValues(self, addUndoCommands: bool = ...) -> None: ...
    def moveItemToBottom(self, item: 'QgsLayoutItem|None', deferUpdate: bool = ...) -> bool: ...
    def moveItemToTop(self, item: 'QgsLayoutItem|None', deferUpdate: bool = ...) -> bool: ...
    def lowerItem(self, item: 'QgsLayoutItem|None', deferUpdate: bool = ...) -> bool: ...
    def raiseItem(self, item: 'QgsLayoutItem|None', deferUpdate: bool = ...) -> bool: ...
    def deselectAll(self) -> None: ...
    def setSelectedItem(self, item: 'QgsLayoutItem|None') -> None: ...
    def selectedLayoutItems(self, includeLockedItems: bool = ...) -> list['QgsLayoutItem']: ...
    def itemsModel(self) -> 'QgsLayoutModel|None': ...
    def project(self) -> 'QgsProject|None': ...
    def clear(self) -> None: ...
    def initializeDefaults(self) -> None: ...
    def clone(self) -> 'QgsLayout|None': ...


class QgsLayoutAligner(PyQt6.sip.wrapper):

    class Resize(enum.IntEnum):
        ResizeNarrowest = ... # type: QgsLayoutAligner.Resize
        ResizeWidest = ... # type: QgsLayoutAligner.Resize
        ResizeShortest = ... # type: QgsLayoutAligner.Resize
        ResizeTallest = ... # type: QgsLayoutAligner.Resize
        ResizeToSquare = ... # type: QgsLayoutAligner.Resize

    class Distribution(enum.IntEnum):
        DistributeLeft = ... # type: QgsLayoutAligner.Distribution
        DistributeHCenter = ... # type: QgsLayoutAligner.Distribution
        DistributeHSpace = ... # type: QgsLayoutAligner.Distribution
        DistributeRight = ... # type: QgsLayoutAligner.Distribution
        DistributeTop = ... # type: QgsLayoutAligner.Distribution
        DistributeVCenter = ... # type: QgsLayoutAligner.Distribution
        DistributeVSpace = ... # type: QgsLayoutAligner.Distribution
        DistributeBottom = ... # type: QgsLayoutAligner.Distribution

    class Alignment(enum.IntEnum):
        AlignLeft = ... # type: QgsLayoutAligner.Alignment
        AlignHCenter = ... # type: QgsLayoutAligner.Alignment
        AlignRight = ... # type: QgsLayoutAligner.Alignment
        AlignTop = ... # type: QgsLayoutAligner.Alignment
        AlignVCenter = ... # type: QgsLayoutAligner.Alignment
        AlignBottom = ... # type: QgsLayoutAligner.Alignment

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutAligner') -> None: ...

    @staticmethod
    def resizeItems(layout: QgsLayout|None, items: collections.abc.Iterable['QgsLayoutItem'], resize: 'QgsLayoutAligner.Resize') -> None: ...
    @staticmethod
    def distributeItems(layout: QgsLayout|None, items: collections.abc.Iterable['QgsLayoutItem'], distribution: 'QgsLayoutAligner.Distribution') -> None: ...
    @staticmethod
    def alignItems(layout: QgsLayout|None, items: collections.abc.Iterable['QgsLayoutItem'], alignment: 'QgsLayoutAligner.Alignment') -> None: ...


class QgsLayoutSerializableObject(QgsLayoutUndoObjectInterface):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutSerializableObject') -> None: ...

    def createCommand(self, text: str|None, id: int, parent: QtGui.QUndoCommand|None = ...) -> 'QgsAbstractLayoutUndoCommand|None': ...
    def readXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def layout(self) -> QgsLayout|None: ...
    def stringType(self) -> str: ...


class QgsLayoutAtlas(QtCore.QObject, QgsAbstractLayoutIterator, QgsLayoutSerializableObject, QgsExpressionContextGenerator):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    renderEnded: typing.ClassVar[QtCore.pyqtSignal]
    renderBegun: typing.ClassVar[QtCore.pyqtSignal]
    featureChanged: typing.ClassVar[QtCore.pyqtSignal]
    numberFeaturesChanged: typing.ClassVar[QtCore.pyqtSignal]
    messagePushed: typing.ClassVar[QtCore.pyqtSignal]
    coverageLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    toggled: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def refreshCurrentFeature(self) -> None: ...
    @typing.overload
    def seekTo(self, feature: int) -> bool: ...
    @typing.overload
    def seekTo(self, feature: QgsFeature) -> bool: ...
    def first(self) -> bool: ...
    def last(self) -> bool: ...
    def previous(self) -> bool: ...
    def next(self) -> bool: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def currentFeatureNumber(self) -> int: ...
    def filePath(self, baseFilePath: str|None, extension: str|None) -> str: ...
    def count(self) -> int: ...
    def endRender(self) -> bool: ...
    def beginRender(self) -> bool: ...
    def updateFeatures(self) -> int: ...
    def setFilterExpression(self, expression: str|None) -> typing.Tuple[bool, str]: ...
    def filterExpression(self) -> str: ...
    def setFilterFeatures(self, filtered: bool) -> None: ...
    def filterFeatures(self) -> bool: ...
    def setSortExpression(self, expression: str|None) -> None: ...
    def sortExpression(self) -> str: ...
    def setSortAscending(self, ascending: bool) -> None: ...
    def sortAscending(self) -> bool: ...
    def setSortFeatures(self, enabled: bool) -> None: ...
    def sortFeatures(self) -> bool: ...
    def nameForPage(self, page: int) -> str: ...
    def setPageNameExpression(self, expression: str|None) -> None: ...
    def pageNameExpression(self) -> str: ...
    def setCoverageLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def coverageLayer(self) -> QgsVectorLayer|None: ...
    def currentFilename(self) -> str: ...
    def setFilenameExpression(self, expression: str|None) -> typing.Tuple[bool, str]: ...
    def filenameExpression(self) -> str: ...
    def setLimitCoverageLayerRenderToCurrentFeature(self, limit: bool) -> None: ...
    def limitCoverageLayerRenderToCurrentFeature(self) -> bool: ...
    def setHideCoverage(self, hide: bool) -> None: ...
    def hideCoverage(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def readXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def layout(self) -> QgsLayout|None: ...
    def stringType(self) -> str: ...


class QgsLayoutEffect(QtWidgets.QGraphicsEffect):

    def __init__(self) -> None: ...

    def draw(self, painter: QtGui.QPainter|None) -> None: ...
    @deprecated("""""")
    def compositionMode(self) -> QtGui.QPainter.CompositionMode: ...
    @deprecated("""""")
    def setCompositionMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...


class QgsLayoutExporter(PyQt6.sip.wrapper):

    class ExportResult(enum.IntEnum):
        Success = ... # type: QgsLayoutExporter.ExportResult
        Canceled = ... # type: QgsLayoutExporter.ExportResult
        MemoryError = ... # type: QgsLayoutExporter.ExportResult
        FileError = ... # type: QgsLayoutExporter.ExportResult
        PrintError = ... # type: QgsLayoutExporter.ExportResult
        SvgLayerError = ... # type: QgsLayoutExporter.ExportResult
        IteratorError = ... # type: QgsLayoutExporter.ExportResult

    class PageExportDetails(PyQt6.sip.wrapper):

        baseName = ... # type: str|None
        directory = ... # type: str|None
        extension = ... # type: str|None
        page = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutExporter.PageExportDetails') -> None: ...

    class ImageExportSettings(PyQt6.sip.wrapper):

        cropMargins = ... # type: QgsMargins
        cropToContents = ... # type: bool
        dpi = ... # type: float
        exportMetadata = ... # type: bool
        flags = ... # type: Qgis.LayoutRenderFlag
        generateWorldFile = ... # type: bool
        imageSize = ... # type: QtCore.QSize
        pages = ... # type: collections.abc.Iterable[int]
        predefinedMapScales = ... # type: collections.abc.Iterable[float]
        quality = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutExporter.ImageExportSettings') -> None: ...

    class PdfExportSettings(PyQt6.sip.wrapper):

        appendGeoreference = ... # type: bool
        dpi = ... # type: float
        exportLayersAsSeperateFiles = ... # type: bool
        exportMetadata = ... # type: bool
        exportThemes = ... # type: collections.abc.Iterable[str|None]
        flags = ... # type: Qgis.LayoutRenderFlag
        forceVectorOutput = ... # type: bool
        includeGeoPdfFeatures = ... # type: bool
        predefinedMapScales = ... # type: collections.abc.Iterable[float]
        rasterizeWholeImage = ... # type: bool
        simplifyGeometries = ... # type: bool
        textRenderFormat = ... # type: Qgis.TextRenderFormat
        useIso32000ExtensionFormatGeoreferencing = ... # type: bool
        useOgcBestPracticeFormatGeoreferencing = ... # type: bool
        writeGeoPdf = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutExporter.PdfExportSettings') -> None: ...

    class PrintExportSettings(PyQt6.sip.wrapper):

        dpi = ... # type: float
        flags = ... # type: Qgis.LayoutRenderFlag
        predefinedMapScales = ... # type: collections.abc.Iterable[float]
        rasterizeWholeImage = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutExporter.PrintExportSettings') -> None: ...

    class SvgExportSettings(PyQt6.sip.wrapper):

        cropMargins = ... # type: QgsMargins
        cropToContents = ... # type: bool
        dpi = ... # type: float
        exportAsLayers = ... # type: bool
        exportLabelsToSeparateLayers = ... # type: bool
        exportMetadata = ... # type: bool
        flags = ... # type: Qgis.LayoutRenderFlag
        forceVectorOutput = ... # type: bool
        predefinedMapScales = ... # type: collections.abc.Iterable[float]
        simplifyGeometries = ... # type: bool
        textRenderFormat = ... # type: Qgis.TextRenderFormat

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutExporter.SvgExportSettings') -> None: ...

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutExporter') -> None: ...

    def generateFileName(self, details: 'QgsLayoutExporter.PageExportDetails') -> str: ...
    @staticmethod
    def containsAdvancedEffects(layout: QgsLayout|None) -> bool: ...
    @staticmethod
    def requiresRasterization(layout: QgsLayout|None) -> bool: ...
    @typing.overload
    def computeWorldFileParameters(self, dpi: float = ...) -> typing.Tuple[float, float, float, float, float, float]: ...
    @typing.overload
    def computeWorldFileParameters(self, region: QtCore.QRectF, dpi: float = ...) -> typing.Tuple[float, float, float, float, float, float]: ...
    def georeferenceOutput(self, file: str|None, referenceMap: 'QgsLayoutItemMap|None' = ..., exportRegion: QtCore.QRectF = ..., dpi: float = ...) -> bool: ...
    def labelingResults(self) -> typing.Any: ...
    def errorMessage(self) -> str: ...
    def errorFile(self) -> str: ...
    @typing.overload
    def exportToSvg(self, filePath: str|None, settings: 'QgsLayoutExporter.SvgExportSettings') -> 'QgsLayoutExporter.ExportResult': ...
    @typing.overload
    @staticmethod
    def exportToSvg(iterator: QgsAbstractLayoutIterator|None, baseFilePath: str|None, settings: 'QgsLayoutExporter.SvgExportSettings', feedback: QgsFeedback|None = ...) -> typing.Tuple['QgsLayoutExporter.ExportResult', str]: ...
    @typing.overload
    def print(self, printer: QtPrintSupport.QPrinter, settings: 'QgsLayoutExporter.PrintExportSettings') -> 'QgsLayoutExporter.ExportResult': ...
    @typing.overload
    @staticmethod
    def print(iterator: QgsAbstractLayoutIterator|None, printer: QtPrintSupport.QPrinter, settings: 'QgsLayoutExporter.PrintExportSettings', feedback: QgsFeedback|None = ...) -> typing.Tuple['QgsLayoutExporter.ExportResult', str]: ...
    @staticmethod
    def exportToPdfs(iterator: QgsAbstractLayoutIterator|None, baseFilePath: str|None, settings: 'QgsLayoutExporter.PdfExportSettings', feedback: QgsFeedback|None = ...) -> typing.Tuple['QgsLayoutExporter.ExportResult', str]: ...
    @typing.overload
    def exportToPdf(self, filePath: str|None, settings: 'QgsLayoutExporter.PdfExportSettings') -> 'QgsLayoutExporter.ExportResult': ...
    @typing.overload
    @staticmethod
    def exportToPdf(iterator: QgsAbstractLayoutIterator|None, fileName: str|None, settings: 'QgsLayoutExporter.PdfExportSettings', feedback: QgsFeedback|None = ...) -> typing.Tuple['QgsLayoutExporter.ExportResult', str]: ...
    @typing.overload
    def exportToImage(self, filePath: str|None, settings: 'QgsLayoutExporter.ImageExportSettings') -> 'QgsLayoutExporter.ExportResult': ...
    @typing.overload
    @staticmethod
    def exportToImage(iterator: QgsAbstractLayoutIterator|None, baseFilePath: str|None, extension: str|None, settings: 'QgsLayoutExporter.ImageExportSettings', feedback: QgsFeedback|None = ...) -> typing.Tuple['QgsLayoutExporter.ExportResult', str]: ...
    def renderRegionToImage(self, region: QtCore.QRectF, imageSize: QtCore.QSize = ..., dpi: float = ...) -> QtGui.QImage: ...
    def renderRegion(self, painter: QtGui.QPainter|None, region: QtCore.QRectF) -> None: ...
    def renderPageToImage(self, page: int, imageSize: QtCore.QSize = ..., dpi: float = ...) -> QtGui.QImage: ...
    def renderPage(self, painter: QtGui.QPainter|None, page: int) -> None: ...
    def layout(self) -> QgsLayout|None: ...


class QgsLayoutObject(QtCore.QObject, QgsExpressionContextGenerator):

    class PropertyValueType(enum.IntEnum):
        EvaluatedValue = ... # type: QgsLayoutObject.PropertyValueType
        OriginalValue = ... # type: QgsLayoutObject.PropertyValueType

    class DataDefinedProperty(enum.IntEnum):
        NoProperty = ... # type: QgsLayoutObject.DataDefinedProperty
        AllProperties = ... # type: QgsLayoutObject.DataDefinedProperty
        TestProperty = ... # type: QgsLayoutObject.DataDefinedProperty
        PresetPaperSize = ... # type: QgsLayoutObject.DataDefinedProperty
        PaperWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        PaperHeight = ... # type: QgsLayoutObject.DataDefinedProperty
        NumPages = ... # type: QgsLayoutObject.DataDefinedProperty
        PaperOrientation = ... # type: QgsLayoutObject.DataDefinedProperty
        PageNumber = ... # type: QgsLayoutObject.DataDefinedProperty
        PositionX = ... # type: QgsLayoutObject.DataDefinedProperty
        PositionY = ... # type: QgsLayoutObject.DataDefinedProperty
        ItemWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        ItemHeight = ... # type: QgsLayoutObject.DataDefinedProperty
        ItemRotation = ... # type: QgsLayoutObject.DataDefinedProperty
        Transparency = ... # type: QgsLayoutObject.DataDefinedProperty
        Opacity = ... # type: QgsLayoutObject.DataDefinedProperty
        BlendMode = ... # type: QgsLayoutObject.DataDefinedProperty
        ExcludeFromExports = ... # type: QgsLayoutObject.DataDefinedProperty
        FrameColor = ... # type: QgsLayoutObject.DataDefinedProperty
        BackgroundColor = ... # type: QgsLayoutObject.DataDefinedProperty
        MarginLeft = ... # type: QgsLayoutObject.DataDefinedProperty
        MarginTop = ... # type: QgsLayoutObject.DataDefinedProperty
        MarginRight = ... # type: QgsLayoutObject.DataDefinedProperty
        MarginBottom = ... # type: QgsLayoutObject.DataDefinedProperty
        MapRotation = ... # type: QgsLayoutObject.DataDefinedProperty
        MapScale = ... # type: QgsLayoutObject.DataDefinedProperty
        MapXMin = ... # type: QgsLayoutObject.DataDefinedProperty
        MapYMin = ... # type: QgsLayoutObject.DataDefinedProperty
        MapXMax = ... # type: QgsLayoutObject.DataDefinedProperty
        MapYMax = ... # type: QgsLayoutObject.DataDefinedProperty
        MapAtlasMargin = ... # type: QgsLayoutObject.DataDefinedProperty
        MapLayers = ... # type: QgsLayoutObject.DataDefinedProperty
        MapStylePreset = ... # type: QgsLayoutObject.DataDefinedProperty
        MapLabelMargin = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridEnabled = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridIntervalX = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridIntervalY = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridOffsetX = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridOffsetY = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameSize = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameMargin = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridLabelDistance = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridCrossSize = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameLineThickness = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridAnnotationDisplayLeft = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridAnnotationDisplayRight = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridAnnotationDisplayTop = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridAnnotationDisplayBottom = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameDivisionsLeft = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameDivisionsRight = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameDivisionsTop = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridFrameDivisionsBottom = ... # type: QgsLayoutObject.DataDefinedProperty
        MapGridDrawAnnotation = ... # type: QgsLayoutObject.DataDefinedProperty
        MapCrs = ... # type: QgsLayoutObject.DataDefinedProperty
        StartDateTime = ... # type: QgsLayoutObject.DataDefinedProperty
        EndDateTime = ... # type: QgsLayoutObject.DataDefinedProperty
        MapZRangeLower = ... # type: QgsLayoutObject.DataDefinedProperty
        MapZRangeUpper = ... # type: QgsLayoutObject.DataDefinedProperty
        PictureSource = ... # type: QgsLayoutObject.DataDefinedProperty
        PictureSvgBackgroundColor = ... # type: QgsLayoutObject.DataDefinedProperty
        PictureSvgStrokeColor = ... # type: QgsLayoutObject.DataDefinedProperty
        PictureSvgStrokeWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        SourceUrl = ... # type: QgsLayoutObject.DataDefinedProperty
        LegendTitle = ... # type: QgsLayoutObject.DataDefinedProperty
        LegendColumnCount = ... # type: QgsLayoutObject.DataDefinedProperty
        LegendAutoWrapWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarLeftSegments = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarRightSegments = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarSegmentWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarMinimumWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarMaximumWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarHeight = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarRightSegmentSubdivisions = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarSubdivisionHeight = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarFillColor = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarFillColor2 = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarLineColor = ... # type: QgsLayoutObject.DataDefinedProperty
        ScalebarLineWidth = ... # type: QgsLayoutObject.DataDefinedProperty
        AttributeTableSourceLayer = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileTolerance = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileDistanceMajorInterval = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileDistanceMinorInterval = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileDistanceLabelInterval = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileElevationMajorInterval = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileElevationMinorInterval = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileElevationLabelInterval = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileMinimumDistance = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileMaximumDistance = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileMinimumElevation = ... # type: QgsLayoutObject.DataDefinedProperty
        ElevationProfileMaximumElevation = ... # type: QgsLayoutObject.DataDefinedProperty

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readObjectPropertiesFromElement(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeObjectPropertiesToElement(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def refresh(self) -> None: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def customProperties(self) -> list[str]: ...
    def removeCustomProperty(self, key: str|None) -> None: ...
    def customProperty(self, key: str|None, defaultValue: typing.Any = ...) -> typing.Any: ...
    def setCustomProperty(self, key: str|None, value: typing.Any) -> None: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def layout(self) -> QgsLayout|None: ...
    @staticmethod
    def propertyAssociatesWithParentMultiframe(property: 'QgsLayoutObject.DataDefinedProperty') -> bool: ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...


class QgsLayoutItem(QgsLayoutObject, QtWidgets.QGraphicsRectItem, QgsLayoutUndoObjectInterface):

    class ExportLayerBehavior(enum.IntEnum):
        CanGroupWithAnyOtherItem = ... # type: QgsLayoutItem.ExportLayerBehavior
        CanGroupWithItemsOfSameType = ... # type: QgsLayoutItem.ExportLayerBehavior
        MustPlaceInOwnLayer = ... # type: QgsLayoutItem.ExportLayerBehavior
        ItemContainsSubLayers = ... # type: QgsLayoutItem.ExportLayerBehavior

    class Flag(enum.IntEnum):
        FlagOverridesPaint = ... # type: QgsLayoutItem.Flag
        FlagProvidesClipPath = ... # type: QgsLayoutItem.Flag
        FlagDisableSceneCaching = ... # type: QgsLayoutItem.Flag

    class UndoCommand(enum.IntEnum):
        UndoNone = ... # type: QgsLayoutItem.UndoCommand
        UndoIncrementalMove = ... # type: QgsLayoutItem.UndoCommand
        UndoIncrementalResize = ... # type: QgsLayoutItem.UndoCommand
        UndoStrokeColor = ... # type: QgsLayoutItem.UndoCommand
        UndoStrokeWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoBackgroundColor = ... # type: QgsLayoutItem.UndoCommand
        UndoOpacity = ... # type: QgsLayoutItem.UndoCommand
        UndoMarginLeft = ... # type: QgsLayoutItem.UndoCommand
        UndoMarginTop = ... # type: QgsLayoutItem.UndoCommand
        UndoMarginBottom = ... # type: QgsLayoutItem.UndoCommand
        UndoMarginRight = ... # type: QgsLayoutItem.UndoCommand
        UndoSetId = ... # type: QgsLayoutItem.UndoCommand
        UndoRotation = ... # type: QgsLayoutItem.UndoCommand
        UndoExportLayerName = ... # type: QgsLayoutItem.UndoCommand
        UndoShapeStyle = ... # type: QgsLayoutItem.UndoCommand
        UndoShapeCornerRadius = ... # type: QgsLayoutItem.UndoCommand
        UndoNodeMove = ... # type: QgsLayoutItem.UndoCommand
        UndoAtlasMargin = ... # type: QgsLayoutItem.UndoCommand
        UndoMapRotation = ... # type: QgsLayoutItem.UndoCommand
        UndoZoomContent = ... # type: QgsLayoutItem.UndoCommand
        UndoOverviewStyle = ... # type: QgsLayoutItem.UndoCommand
        UndoGridFramePenColor = ... # type: QgsLayoutItem.UndoCommand
        UndoMapGridFrameFill1Color = ... # type: QgsLayoutItem.UndoCommand
        UndoMapGridFrameFill2Color = ... # type: QgsLayoutItem.UndoCommand
        UndoMapAnnotationDistance = ... # type: QgsLayoutItem.UndoCommand
        UndoMapGridAnnotationFontColor = ... # type: QgsLayoutItem.UndoCommand
        UndoMapGridLineSymbol = ... # type: QgsLayoutItem.UndoCommand
        UndoMapGridMarkerSymbol = ... # type: QgsLayoutItem.UndoCommand
        UndoMapGridIntervalRange = ... # type: QgsLayoutItem.UndoCommand
        UndoMapLabelMargin = ... # type: QgsLayoutItem.UndoCommand
        UndoPictureRotation = ... # type: QgsLayoutItem.UndoCommand
        UndoPictureFillColor = ... # type: QgsLayoutItem.UndoCommand
        UndoPictureStrokeColor = ... # type: QgsLayoutItem.UndoCommand
        UndoPictureStrokeWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoPictureNorthOffset = ... # type: QgsLayoutItem.UndoCommand
        UndoLabelText = ... # type: QgsLayoutItem.UndoCommand
        UndoLabelFont = ... # type: QgsLayoutItem.UndoCommand
        UndoLabelMargin = ... # type: QgsLayoutItem.UndoCommand
        UndoLabelFontColor = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendText = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendColumnCount = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendSymbolWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendSymbolHeight = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendMaxSymbolSize = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendMinSymbolSize = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendWmsLegendWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendWmsLegendHeight = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendTitleSpaceBottom = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendGroupSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendGroupIndent = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendSubgroupIndent = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendLayerSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendSymbolSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendIconSymbolSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendFontColor = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendBoxSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendColumnSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendLineSpacing = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendRasterStrokeWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendRasterStrokeColor = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendTitleFont = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendGroupFont = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendLayerFont = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendItemFont = ... # type: QgsLayoutItem.UndoCommand
        UndoLegendAutoWrapAfter = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarLineWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarSegmentSize = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarSegmentsLeft = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarSegments = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarHeight = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarSubdivisions = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarSubdivisionsHeight = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarFontColor = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarFillColor = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarFillColor2 = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarStrokeColor = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarUnitText = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarMapUnitsSegment = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarLabelBarSize = ... # type: QgsLayoutItem.UndoCommand
        UndoScaleBarBoxContentSpace = ... # type: QgsLayoutItem.UndoCommand
        UndoArrowStrokeWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoArrowHeadWidth = ... # type: QgsLayoutItem.UndoCommand
        UndoArrowHeadFillColor = ... # type: QgsLayoutItem.UndoCommand
        UndoArrowHeadStrokeColor = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileTolerance = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileChartBackground = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileChartBorder = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileDistanceMajorGridlines = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileDistanceMinorGridlines = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileDistanceFormat = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileDistanceFont = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileDistanceLabels = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileElevationMajorGridlines = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileElevationMinorGridlines = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileElevationFormat = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileElevationFont = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileElevationLabels = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileMinimumDistance = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileMaximumDistance = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileMinimumElevation = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileMaximumElevation = ... # type: QgsLayoutItem.UndoCommand
        UndoElevationProfileSubsectionLines = ... # type: QgsLayoutItem.UndoCommand
        UndoCustomCommand = ... # type: QgsLayoutItem.UndoCommand

    class ReferencePoint(enum.IntEnum):
        UpperLeft = ... # type: QgsLayoutItem.ReferencePoint
        UpperMiddle = ... # type: QgsLayoutItem.ReferencePoint
        UpperRight = ... # type: QgsLayoutItem.ReferencePoint
        MiddleLeft = ... # type: QgsLayoutItem.ReferencePoint
        Middle = ... # type: QgsLayoutItem.ReferencePoint
        MiddleRight = ... # type: QgsLayoutItem.ReferencePoint
        LowerLeft = ... # type: QgsLayoutItem.ReferencePoint
        LowerMiddle = ... # type: QgsLayoutItem.ReferencePoint
        LowerRight = ... # type: QgsLayoutItem.ReferencePoint

    class ExportLayerDetail(PyQt6.sip.wrapper):

        compositionMode = ... # type: QtGui.QPainter.CompositionMode
        groupName = ... # type: str|None
        mapLayerId = ... # type: str|None
        mapTheme = ... # type: str|None
        name = ... # type: str|None
        opacity = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutItem.ExportLayerDetail') -> None: ...

    def __init__(self, layout: QgsLayout|None, manageZValue: bool = ...) -> None: ...

    def applyDataDefinedSize(self, size: 'QgsLayoutSize') -> 'QgsLayoutSize': ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def topLeftToReferencePoint(self, point: 'QgsLayoutPoint') -> 'QgsLayoutPoint': ...
    def positionAtReferencePoint(self, reference: 'QgsLayoutItem.ReferencePoint') -> QtCore.QPointF: ...
    def adjustPointForReferencePosition(self, point: QtCore.QPointF, size: QtCore.QSizeF, reference: 'QgsLayoutItem.ReferencePoint') -> QtCore.QPointF: ...
    def refreshBlendMode(self) -> None: ...
    def refreshBackgroundColor(self, updateItem: bool = ...) -> None: ...
    def refreshFrame(self, updateItem: bool = ...) -> None: ...
    def refreshOpacity(self, updateItem: bool = ...) -> None: ...
    def refreshItemRotation(self, origin: QtCore.QPointF|None = ...) -> None: ...
    def refreshItemPosition(self) -> None: ...
    def refreshItemSize(self) -> None: ...
    def applyItemSizeConstraint(self, targetSize: QtCore.QSizeF) -> QtCore.QSizeF: ...
    def setMinimumSize(self, size: 'QgsLayoutSize') -> None: ...
    def setFixedSize(self, size: 'QgsLayoutSize') -> None: ...
    def drawRefreshingOverlay(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None) -> None: ...
    def drawBackground(self, context: QgsRenderContext) -> None: ...
    def drawFrame(self, context: QgsRenderContext) -> None: ...
    def framePath(self) -> QtGui.QPainterPath: ...
    def draw(self, context: 'QgsLayoutItemRenderContext') -> None: ...
    def drawDebugRect(self, painter: QtGui.QPainter|None) -> None: ...
    clipPathChanged: typing.ClassVar[QtCore.pyqtSignal]
    backgroundTaskCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    sizePositionChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockChanged: typing.ClassVar[QtCore.pyqtSignal]
    frameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def rotateItem(self, angle: float, transformOrigin: QtCore.QPointF) -> None: ...
    def setItemRotation(self, rotation: float, adjustPosition: bool = ...) -> None: ...
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def redraw(self) -> None: ...
    def invalidateCache(self) -> None: ...
    def refresh(self) -> None: ...
    def isRefreshing(self) -> bool: ...
    def clipPath(self) -> QgsGeometry: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def shouldDrawItem(self) -> bool: ...
    def cancelCommand(self) -> None: ...
    def endCommand(self) -> None: ...
    def beginCommand(self, commandText: str|None, command: 'QgsLayoutItem.UndoCommand' = ...) -> None: ...
    def zoomContent(self, factor: float, point: QtCore.QPointF) -> None: ...
    def setMoveContentPreviewOffset(self, dx: float, dy: float) -> None: ...
    def moveContent(self, dx: float, dy: float) -> None: ...
    def rectWithFrame(self) -> QtCore.QRectF: ...
    def estimatedFrameBleed(self) -> float: ...
    def requiresRasterization(self) -> bool: ...
    def containsAdvancedEffects(self) -> bool: ...
    def setExcludeFromExports(self, exclude: bool) -> None: ...
    def excludeFromExports(self) -> bool: ...
    def setItemOpacity(self, opacity: float) -> None: ...
    def itemOpacity(self) -> float: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def backgroundColor(self, useDataDefined: bool = ...) -> QtGui.QColor: ...
    def setBackgroundEnabled(self, drawBackground: bool) -> None: ...
    def hasBackground(self) -> bool: ...
    def setFrameJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def frameJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def frameStrokeWidth(self) -> 'QgsLayoutMeasurement': ...
    def setFrameStrokeWidth(self, width: 'QgsLayoutMeasurement') -> None: ...
    def frameStrokeColor(self) -> QtGui.QColor: ...
    def setFrameStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setFrameEnabled(self, drawFrame: bool) -> None: ...
    def frameEnabled(self) -> bool: ...
    def createCommand(self, text: str|None, id: int, parent: QtGui.QUndoCommand|None = ...) -> 'QgsAbstractLayoutUndoCommand|None': ...
    def finalizeRestoreFromXml(self) -> None: ...
    def readXml(self, itemElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def itemRotation(self) -> float: ...
    def sizeWithUnits(self) -> 'QgsLayoutSize': ...
    def pagePositionWithUnits(self) -> 'QgsLayoutPoint': ...
    def pagePos(self) -> QtCore.QPointF: ...
    def page(self) -> int: ...
    def positionWithUnits(self) -> 'QgsLayoutPoint': ...
    def attemptMoveBy(self, deltaX: float, deltaY: float) -> None: ...
    def attemptSetSceneRect(self, rect: QtCore.QRectF, includesFrame: bool = ...) -> None: ...
    def attemptMove(self, point: 'QgsLayoutPoint', useReferencePoint: bool = ..., includesFrame: bool = ..., page: int = ...) -> None: ...
    def attemptResize(self, size: 'QgsLayoutSize', includesFrame: bool = ...) -> None: ...
    def minimumSize(self) -> 'QgsLayoutSize': ...
    def fixedSize(self) -> 'QgsLayoutSize': ...
    def referencePoint(self) -> 'QgsLayoutItem.ReferencePoint': ...
    def setReferencePoint(self, point: 'QgsLayoutItem.ReferencePoint') -> None: ...
    def paint(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None, pWidget: QtWidgets.QWidget|None) -> None: ...
    def exportLayerDetails(self) -> 'QgsLayoutItem.ExportLayerDetail': ...
    def nextExportPart(self) -> bool: ...
    def stopLayeredExport(self) -> None: ...
    def startLayeredExport(self) -> None: ...
    @deprecated("""""")
    def numberExportLayers(self) -> int: ...
    def exportLayerBehavior(self) -> 'QgsLayoutItem.ExportLayerBehavior': ...
    def setParentGroup(self, group: 'QgsLayoutItemGroup|None') -> None: ...
    def parentGroup(self) -> 'QgsLayoutItemGroup|None': ...
    def isGroupMember(self) -> bool: ...
    def isLocked(self) -> bool: ...
    def setLocked(self, locked: bool) -> None: ...
    def setVisibility(self, visible: bool) -> None: ...
    def setSelected(self, selected: bool) -> None: ...
    def displayName(self) -> str: ...
    def setId(self, id: str|None) -> None: ...
    def id(self) -> str: ...
    def itemFlags(self) -> 'QgsLayoutItem.Flag': ...
    def uuid(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    def cleanup(self) -> None: ...


class QgsLayoutFrame(QgsLayoutItem):

    def __init__(self, layout: QgsLayout|None, multiFrame: 'QgsLayoutMultiFrame|None') -> None: ...

    def readPropertiesFromElement(self, itemElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def drawBackground(self, context: QgsRenderContext) -> None: ...
    def drawFrame(self, context: QgsRenderContext) -> None: ...
    def draw(self, context: 'QgsLayoutItemRenderContext') -> None: ...
    def exportLayerBehavior(self) -> QgsLayoutItem.ExportLayerBehavior: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def isEmpty(self) -> bool: ...
    def setHideBackgroundIfEmpty(self, hideBackgroundIfEmpty: bool) -> None: ...
    def hideBackgroundIfEmpty(self) -> bool: ...
    def setHidePageIfEmpty(self, hidePageIfEmpty: bool) -> None: ...
    def hidePageIfEmpty(self) -> bool: ...
    def extent(self) -> QtCore.QRectF: ...
    def fixedSize(self) -> 'QgsLayoutSize': ...
    def minimumSize(self) -> 'QgsLayoutSize': ...
    def multiFrame(self) -> 'QgsLayoutMultiFrame|None': ...
    def setContentSection(self, section: QtCore.QRectF) -> None: ...
    def cleanup(self) -> None: ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutFrame|None': ...


class QgsLayoutGridSettings(QgsLayoutSerializableObject):

    class Style(enum.IntEnum):
        StyleLines = ... # type: QgsLayoutGridSettings.Style
        StyleDots = ... # type: QgsLayoutGridSettings.Style
        StyleCrosses = ... # type: QgsLayoutGridSettings.Style

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutGridSettings') -> None: ...

    def readXml(self, gridElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def loadFromSettings(self) -> None: ...
    def style(self) -> 'QgsLayoutGridSettings.Style': ...
    def setStyle(self, style: 'QgsLayoutGridSettings.Style') -> None: ...
    def pen(self) -> QtGui.QPen: ...
    def setPen(self, pen: QtGui.QPen|QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def offset(self) -> 'QgsLayoutPoint': ...
    def setOffset(self, offset: 'QgsLayoutPoint') -> None: ...
    def resolution(self) -> 'QgsLayoutMeasurement': ...
    def setResolution(self, resolution: 'QgsLayoutMeasurement') -> None: ...
    def layout(self) -> QgsLayout|None: ...
    def stringType(self) -> str: ...


class QgsLayoutGuide(QtCore.QObject):

    def __init__(self, orientation: QtCore.Qt.Orientation, position: 'QgsLayoutMeasurement', page: 'QgsLayoutItemPage|None') -> None: ...

    positionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLayoutPosition(self, position: float) -> None: ...
    def layoutPosition(self) -> float: ...
    def item(self) -> QtWidgets.QGraphicsLineItem|None: ...
    def update(self) -> None: ...
    def setPage(self, page: 'QgsLayoutItemPage|None') -> None: ...
    def page(self) -> 'QgsLayoutItemPage|None': ...
    def setPosition(self, position: 'QgsLayoutMeasurement') -> None: ...
    def position(self) -> 'QgsLayoutMeasurement': ...
    def orientation(self) -> QtCore.Qt.Orientation: ...
    def setLayout(self, layout: QgsLayout|None) -> None: ...
    def layout(self) -> QgsLayout|None: ...


class QgsLayoutGuideCollection(QtCore.QAbstractTableModel, QgsLayoutSerializableObject):

    class CustomRole(enum.IntEnum):
        Orientation = ... # type: QgsLayoutGuideCollection.CustomRole
        Position = ... # type: QgsLayoutGuideCollection.CustomRole
        Units = ... # type: QgsLayoutGuideCollection.CustomRole
        Page = ... # type: QgsLayoutGuideCollection.CustomRole
        LayoutPosition = ... # type: QgsLayoutGuideCollection.CustomRole

    def __init__(self, layout: QgsLayout|None, pageCollection: 'QgsLayoutPageCollection|None') -> None: ...

    def readXml(self, collectionElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setVisible(self, visible: bool) -> None: ...
    def visible(self) -> bool: ...
    def guidesOnPage(self, page: int) -> list[QgsLayoutGuide]: ...
    @typing.overload
    def guides(self) -> list[QgsLayoutGuide]: ...
    @typing.overload
    def guides(self, orientation: QtCore.Qt.Orientation, page: int = ...) -> list[QgsLayoutGuide]: ...
    def update(self) -> None: ...
    def applyGuidesToAllOtherPages(self, sourcePage: int) -> None: ...
    def clear(self) -> None: ...
    def setGuideLayoutPosition(self, guide: QgsLayoutGuide|None, position: float) -> None: ...
    def removeGuide(self, guide: QgsLayoutGuide|None) -> None: ...
    def addGuide(self, guide: QgsLayoutGuide|None) -> None: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, a0: QtCore.QModelIndex) -> int: ...
    def rowCount(self, a0: QtCore.QModelIndex) -> int: ...
    def layout(self) -> QgsLayout|None: ...
    def stringType(self) -> str: ...


class QgsLayoutGuideProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None, orientation: QtCore.Qt.Orientation, page: int) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setPage(self, page: int) -> None: ...


class QgsLayoutItemRenderContext(PyQt6.sip.wrapper):

    def __init__(self, context: QgsRenderContext, viewScaleFactor: float = ...) -> None: ...

    def viewScaleFactor(self) -> float: ...
    def renderContext(self) -> QgsRenderContext: ...


class QgsLayoutMultiFrame(QgsLayoutObject, QgsLayoutUndoObjectInterface):

    class UndoCommand(enum.IntEnum):
        UndoHtmlBreakDistance = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoHtmlSource = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoHtmlStylesheet = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableCellStyle = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableMaximumFeatures = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableMargin = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableHeaderFontColor = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableContentFontColor = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableGridStrokeWidth = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableGridColor = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoTableBackgroundColor = ... # type: QgsLayoutMultiFrame.UndoCommand
        UndoNone = ... # type: QgsLayoutMultiFrame.UndoCommand

    class ResizeMode(enum.IntEnum):
        UseExistingFrames = ... # type: QgsLayoutMultiFrame.ResizeMode
        ExtendToNextPage = ... # type: QgsLayoutMultiFrame.ResizeMode
        RepeatOnEveryPage = ... # type: QgsLayoutMultiFrame.ResizeMode
        RepeatUntilFinished = ... # type: QgsLayoutMultiFrame.ResizeMode

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    contentsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def recalculateFrameRects(self) -> None: ...
    def recalculateFrameSizes(self) -> None: ...
    def update(self) -> None: ...
    def refresh(self) -> None: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def cancelCommand(self) -> None: ...
    def endCommand(self) -> None: ...
    def beginCommand(self, commandText: str|None, command: 'QgsLayoutMultiFrame.UndoCommand' = ...) -> None: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def createCommand(self, text: str|None, id: int, parent: QtGui.QUndoCommand|None = ...) -> 'QgsAbstractLayoutUndoCommand|None': ...
    def displayName(self) -> str: ...
    def createNewFrame(self, currentFrame: QgsLayoutFrame|None, pos: QtCore.QPointF, size: QtCore.QSizeF) -> QgsLayoutFrame|None: ...
    def frameIndex(self, frame: QgsLayoutFrame|None) -> int: ...
    def frame(self, index: int) -> QgsLayoutFrame|None: ...
    def frameCount(self) -> int: ...
    def frames(self) -> list[QgsLayoutFrame]: ...
    def readXml(self, itemElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext, includeFrames: bool = ...) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext, includeFrames: bool = ...) -> bool: ...
    def resizeMode(self) -> 'QgsLayoutMultiFrame.ResizeMode': ...
    def setResizeMode(self, mode: 'QgsLayoutMultiFrame.ResizeMode') -> None: ...
    def deleteFrames(self) -> None: ...
    def removeFrame(self, index: int, removeEmptyPages: bool = ...) -> None: ...
    def findNearbyPageBreak(self, yPos: float) -> float: ...
    def addFrame(self, frame: QgsLayoutFrame|None, recalcFrameSizes: bool = ...) -> None: ...
    def render(self, context: QgsLayoutItemRenderContext, renderExtent: QtCore.QRectF, frameIndex: int) -> None: ...
    def minFrameSize(self, frameIndex: int = ...) -> QtCore.QSizeF: ...
    def fixedFrameSize(self, frameIndex: int = ...) -> QtCore.QSizeF: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    def totalSize(self) -> QtCore.QSizeF: ...
    def uuid(self) -> str: ...


class QgsLayoutTable(QgsLayoutMultiFrame):

    class CellStyleGroup(enum.IntEnum):
        OddColumns = ... # type: QgsLayoutTable.CellStyleGroup
        EvenColumns = ... # type: QgsLayoutTable.CellStyleGroup
        OddRows = ... # type: QgsLayoutTable.CellStyleGroup
        EvenRows = ... # type: QgsLayoutTable.CellStyleGroup
        FirstColumn = ... # type: QgsLayoutTable.CellStyleGroup
        LastColumn = ... # type: QgsLayoutTable.CellStyleGroup
        HeaderRow = ... # type: QgsLayoutTable.CellStyleGroup
        FirstRow = ... # type: QgsLayoutTable.CellStyleGroup
        LastRow = ... # type: QgsLayoutTable.CellStyleGroup

    class WrapBehavior(enum.IntEnum):
        TruncateText = ... # type: QgsLayoutTable.WrapBehavior
        WrapText = ... # type: QgsLayoutTable.WrapBehavior

    class EmptyTableMode(enum.IntEnum):
        HeadersOnly = ... # type: QgsLayoutTable.EmptyTableMode
        HideTable = ... # type: QgsLayoutTable.EmptyTableMode
        ShowMessage = ... # type: QgsLayoutTable.EmptyTableMode

    class HeaderMode(enum.IntEnum):
        FirstFrame = ... # type: QgsLayoutTable.HeaderMode
        AllFrames = ... # type: QgsLayoutTable.HeaderMode
        NoHeaders = ... # type: QgsLayoutTable.HeaderMode

    class HeaderHAlignment(enum.IntEnum):
        FollowColumn = ... # type: QgsLayoutTable.HeaderHAlignment
        HeaderLeft = ... # type: QgsLayoutTable.HeaderHAlignment
        HeaderCenter = ... # type: QgsLayoutTable.HeaderHAlignment
        HeaderRight = ... # type: QgsLayoutTable.HeaderHAlignment

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def verticalAlignmentForCell(self, row: int, column: int) -> QtCore.Qt.AlignmentFlag: ...
    def horizontalAlignmentForCell(self, row: int, column: int) -> QtCore.Qt.AlignmentFlag: ...
    def textFormatForHeader(self, column: int) -> 'QgsTextFormat': ...
    def textFormatForCell(self, row: int, column: int) -> 'QgsTextFormat': ...
    def contentsContainsRow(self, contents: typing.Any, row: collections.abc.Iterable[typing.Any]) -> bool: ...
    def recalculateTableSize(self) -> None: ...
    def drawHorizontalGridLines(self, context: QgsLayoutItemRenderContext, firstRow: int, lastRow: int, drawHeaderLines: bool) -> None: ...
    def rowRange(self, context: QgsRenderContext, frameIndex: int) -> tuple[int, int]: ...
    @typing.overload
    def rowsVisible(self, context: QgsRenderContext, frameHeight: float, firstRow: int, includeHeader: bool, includeEmptyRows: bool) -> int: ...
    @typing.overload
    def rowsVisible(self, context: QgsRenderContext, frameIndex: int, firstRow: int, includeEmptyRows: bool) -> int: ...
    def totalHeight(self) -> float: ...
    def totalWidth(self) -> float: ...
    def calculateMaxRowHeights(self) -> bool: ...
    def calculateMaxColumnWidths(self) -> bool: ...
    def recalculateFrameSizes(self) -> None: ...
    def refreshAttributes(self) -> None: ...
    def refresh(self) -> None: ...
    def render(self, context: QgsLayoutItemRenderContext, renderExtent: QtCore.QRectF, frameIndex: int) -> None: ...
    def totalSize(self) -> QtCore.QSizeF: ...
    def readPropertiesFromElement(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def minFrameSize(self, frameIndex: int = ...) -> QtCore.QSizeF: ...
    def fixedFrameSize(self, frameIndex: int = ...) -> QtCore.QSizeF: ...
    def contents(self) -> typing.Any: ...
    def columnSpan(self, row: int, column: int) -> int: ...
    def rowSpan(self, row: int, column: int) -> int: ...
    def scopeForCell(self, row: int, column: int) -> QgsExpressionContextScope|None: ...
    def conditionalCellStyle(self, row: int, column: int) -> QgsConditionalStyle: ...
    def getTableContents(self, contents: typing.Any) -> bool: ...
    def cellStyle(self, group: 'QgsLayoutTable.CellStyleGroup') -> 'QgsLayoutTableStyle|None': ...
    def setCellStyle(self, group: 'QgsLayoutTable.CellStyleGroup', style: 'QgsLayoutTableStyle') -> None: ...
    def setSortColumns(self, sortColumns: collections.abc.Iterable['QgsLayoutTableColumn']) -> None: ...
    def sortColumns(self) -> list['QgsLayoutTableColumn']: ...
    def setColumns(self, columns: collections.abc.Iterable['QgsLayoutTableColumn']) -> None: ...
    def columns(self) -> list['QgsLayoutTableColumn']: ...
    def wrapBehavior(self) -> 'QgsLayoutTable.WrapBehavior': ...
    def setWrapBehavior(self, behavior: 'QgsLayoutTable.WrapBehavior') -> None: ...
    def backgroundColor(self) -> QtGui.QColor: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def verticalGrid(self) -> bool: ...
    def setVerticalGrid(self, verticalGrid: bool) -> None: ...
    def horizontalGrid(self) -> bool: ...
    def setHorizontalGrid(self, horizontalGrid: bool) -> None: ...
    def gridColor(self) -> QtGui.QColor: ...
    def setGridColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def gridStrokeWidth(self) -> float: ...
    def setGridStrokeWidth(self, width: float) -> None: ...
    def showGrid(self) -> bool: ...
    def setShowGrid(self, showGrid: bool) -> None: ...
    def contentTextFormat(self) -> 'QgsTextFormat': ...
    def setContentTextFormat(self, format: 'QgsTextFormat') -> None: ...
    @deprecated("""""")
    def contentFontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setContentFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def contentFont(self) -> QtGui.QFont: ...
    @deprecated("""""")
    def setContentFont(self, font: QtGui.QFont) -> None: ...
    def headerMode(self) -> 'QgsLayoutTable.HeaderMode': ...
    def setHeaderMode(self, mode: 'QgsLayoutTable.HeaderMode') -> None: ...
    def headerHAlignment(self) -> 'QgsLayoutTable.HeaderHAlignment': ...
    def setHeaderHAlignment(self, alignment: 'QgsLayoutTable.HeaderHAlignment') -> None: ...
    def headerTextFormat(self) -> 'QgsTextFormat': ...
    def setHeaderTextFormat(self, format: 'QgsTextFormat') -> None: ...
    @deprecated("""""")
    def headerFontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setHeaderFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def headerFont(self) -> QtGui.QFont: ...
    @deprecated("""""")
    def setHeaderFont(self, font: QtGui.QFont) -> None: ...
    def showEmptyRows(self) -> bool: ...
    def setShowEmptyRows(self, showEmpty: bool) -> None: ...
    def emptyTableMessage(self) -> str: ...
    def setEmptyTableMessage(self, message: str|None) -> None: ...
    def emptyTableBehavior(self) -> 'QgsLayoutTable.EmptyTableMode': ...
    def setEmptyTableBehavior(self, mode: 'QgsLayoutTable.EmptyTableMode') -> None: ...
    def cellMargin(self) -> float: ...
    def setCellMargin(self, margin: float) -> None: ...


class QgsLayoutItemAttributeTable(QgsLayoutTable):

    class ContentSource(enum.IntEnum):
        LayerAttributes = ... # type: QgsLayoutItemAttributeTable.ContentSource
        AtlasFeature = ... # type: QgsLayoutItemAttributeTable.ContentSource
        RelationChildren = ... # type: QgsLayoutItemAttributeTable.ContentSource

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setUseConditionalStyling(self, enabled: bool) -> None: ...
    def useConditionalStyling(self) -> bool: ...
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def scopeForCell(self, row: int, column: int) -> QgsExpressionContextScope|None: ...
    def textFormatForCell(self, row: int, column: int) -> 'QgsTextFormat': ...
    def conditionalCellStyle(self, row: int, column: int) -> QgsConditionalStyle: ...
    def getTableContents(self, contents: typing.Any) -> bool: ...
    def wrapString(self) -> str: ...
    def setWrapString(self, wrapString: str|None) -> None: ...
    def setDisplayedFields(self, fields: collections.abc.Iterable[str|None], refresh: bool = ...) -> None: ...
    def setFeatureFilter(self, expression: str|None) -> None: ...
    def featureFilter(self) -> str: ...
    def setFilterFeatures(self, filter: bool) -> None: ...
    def filterFeatures(self) -> bool: ...
    def filterToAtlasFeature(self) -> bool: ...
    def setFilterToAtlasFeature(self, filterToAtlas: bool) -> None: ...
    def displayOnlyVisibleFeatures(self) -> bool: ...
    def setDisplayOnlyVisibleFeatures(self, visibleOnly: bool) -> None: ...
    def uniqueRowsOnly(self) -> bool: ...
    def setUniqueRowsOnly(self, uniqueOnly: bool) -> None: ...
    def maximumNumberOfFeatures(self) -> int: ...
    def setMaximumNumberOfFeatures(self, features: int) -> None: ...
    def map(self) -> 'QgsLayoutItemMap|None': ...
    def setMap(self, map: 'QgsLayoutItemMap|None') -> None: ...
    def resetColumns(self) -> None: ...
    def relationId(self) -> str: ...
    def setRelationId(self, id: str|None) -> None: ...
    def vectorLayer(self) -> QgsVectorLayer|None: ...
    def setVectorLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def sourceLayer(self) -> QgsVectorLayer|None: ...
    def source(self) -> 'QgsLayoutItemAttributeTable.ContentSource': ...
    def setSource(self, source: 'QgsLayoutItemAttributeTable.ContentSource') -> None: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemAttributeTable|None': ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemChart(QgsLayoutItem):

    class SeriesDetails(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, name: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutItemChart.SeriesDetails') -> None: ...

        def __ne__(self, other: object): ...
        def setFilterExpression(self, filterExpression: str|None) -> None: ...
        def filterExpression(self) -> str: ...
        def setYExpression(self, yExpression: str|None) -> None: ...
        def yExpression(self) -> str: ...
        def setXExpression(self, xExpression: str|None) -> None: ...
        def xExpression(self) -> str: ...
        def setName(self, name: str|None) -> None: ...
        def name(self) -> str: ...
        def __eq__(self, other: object): ...

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def refresh(self) -> None: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def paint(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None, pWidget: QtWidgets.QWidget|None) -> None: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemChart|None': ...
    def filterToAtlasFeature(self) -> bool: ...
    def setFilterToAtlasFeature(self, filterToAtlas: bool) -> None: ...
    def filterOnlyVisibleFeatures(self) -> bool: ...
    def setFilterOnlyVisibleFeatures(self, visibleOnly: bool) -> None: ...
    def map(self) -> 'QgsLayoutItemMap|None': ...
    def setMap(self, map: 'QgsLayoutItemMap|None') -> None: ...
    def seriesList(self) -> list['QgsLayoutItemChart.SeriesDetails']: ...
    def setSeriesList(self, seriesList: collections.abc.Iterable['QgsLayoutItemChart.SeriesDetails']) -> None: ...
    def sortExpression(self) -> str: ...
    def setSortExpression(self, expression: str|None) -> None: ...
    def sortAscending(self) -> bool: ...
    def setSortAscending(self, ascending: bool) -> None: ...
    def sortFeatures(self) -> bool: ...
    def setSortFeatures(self, sorted: bool) -> None: ...
    def sourceLayer(self) -> QgsVectorLayer|None: ...
    def setSourceLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def plot(self) -> 'QgsPlot|None': ...
    def setPlot(self, plot: 'QgsPlot|None') -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemElevationProfile(QgsLayoutItem):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    previewRefreshed: typing.ClassVar[QtCore.pyqtSignal]
    def invalidateCache(self) -> None: ...
    def refresh(self) -> None: ...
    def setSubsectionsSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def subsectionsSymbol(self) -> 'QgsLineSymbol|None': ...
    def setDistanceUnit(self, unit: Qgis.DistanceUnit) -> None: ...
    def distanceUnit(self) -> Qgis.DistanceUnit: ...
    def paint(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None, pWidget: QtWidgets.QWidget|None) -> None: ...
    def profileRequest(self) -> QgsProfileRequest: ...
    def setAtlasDriven(self, enabled: bool) -> None: ...
    def atlasDriven(self) -> bool: ...
    def tolerance(self) -> float: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def profileCurve(self) -> QgsCurve|None: ...
    def setProfileCurve(self, curve: QgsCurve|None) -> None: ...
    def setSources(self, sources: collections.abc.Iterable[QgsAbstractProfileSource]) -> None: ...
    def sources(self) -> list[QgsAbstractProfileSource]: ...
    def setLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def layers(self) -> list[QgsMapLayer]: ...
    def plot(self) -> 'Qgs2DXyPlot|None': ...
    def containsAdvancedEffects(self) -> bool: ...
    def requiresRasterization(self) -> bool: ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemElevationProfile|None': ...


class QgsLayoutItemGroup(QgsLayoutItem):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, itemElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def rectWithFrame(self) -> QtCore.QRectF: ...
    def exportLayerBehavior(self) -> QgsLayoutItem.ExportLayerBehavior: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def paint(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None, pWidget: QtWidgets.QWidget|None) -> None: ...
    def attemptResize(self, size: 'QgsLayoutSize', includesFrame: bool = ...) -> None: ...
    def attemptMove(self, point: 'QgsLayoutPoint', useReferencePoint: bool = ..., includesFrame: bool = ..., page: int = ...) -> None: ...
    def setVisibility(self, visible: bool) -> None: ...
    def items(self) -> list[QgsLayoutItem]: ...
    def removeItems(self) -> None: ...
    def addItem(self, item: QgsLayoutItem|None) -> None: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemGroup|None': ...
    def displayName(self) -> str: ...
    def type(self) -> int: ...
    def cleanup(self) -> None: ...


class QgsLayoutItemHtml(QgsLayoutMultiFrame):

    class ContentMode(enum.IntEnum):
        Url = ... # type: QgsLayoutItemHtml.ContentMode
        ManualHtml = ... # type: QgsLayoutItemHtml.ContentMode

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def recalculateFrameSizes(self) -> None: ...
    def loadHtml(self, useCache: bool = ..., context: QgsExpressionContext|None = ...) -> None: ...
    def findNearbyPageBreak(self, yPos: float) -> float: ...
    def render(self, context: QgsLayoutItemRenderContext, renderExtent: QtCore.QRectF, frameIndex: int) -> None: ...
    def totalSize(self) -> QtCore.QSizeF: ...
    def displayName(self) -> str: ...
    def userStylesheetEnabled(self) -> bool: ...
    def setUserStylesheetEnabled(self, enabled: bool) -> None: ...
    def userStylesheet(self) -> str: ...
    def setUserStylesheet(self, stylesheet: str|None) -> None: ...
    def maxBreakDistance(self) -> float: ...
    def setMaxBreakDistance(self, distance: float) -> None: ...
    def setUseSmartBreaks(self, useSmartBreaks: bool) -> None: ...
    def useSmartBreaks(self) -> bool: ...
    def setEvaluateExpressions(self, evaluateExpressions: bool) -> None: ...
    def evaluateExpressions(self) -> bool: ...
    def html(self) -> str: ...
    def setHtml(self, html: str|None) -> None: ...
    def url(self) -> QtCore.QUrl: ...
    def setUrl(self, url: QtCore.QUrl) -> None: ...
    def contentMode(self) -> 'QgsLayoutItemHtml.ContentMode': ...
    def setContentMode(self, mode: 'QgsLayoutItemHtml.ContentMode') -> None: ...
    @staticmethod
    def createFromLabel(label: 'QgsLayoutItemLabel|None') -> 'QgsLayoutItemHtml|None': ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemHtml|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemLabel(QgsLayoutItem):

    class Mode(enum.IntEnum):
        ModeFont = ... # type: QgsLayoutItemLabel.Mode
        ModeHtml = ... # type: QgsLayoutItemLabel.Mode

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def convertToStaticText(self) -> None: ...
    def refresh(self) -> None: ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def setFrameStrokeWidth(self, strokeWidth: 'QgsLayoutMeasurement') -> None: ...
    def setFrameEnabled(self, drawFrame: bool) -> None: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    @deprecated("""""")
    def fontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setMarginY(self, margin: float) -> None: ...
    def setMarginX(self, margin: float) -> None: ...
    def setMargin(self, margin: float) -> None: ...
    def marginY(self) -> float: ...
    def marginX(self) -> float: ...
    def setVAlign(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def setHAlign(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def hAlign(self) -> QtCore.Qt.AlignmentFlag: ...
    def vAlign(self) -> QtCore.Qt.AlignmentFlag: ...
    @deprecated("""""")
    def setFont(self, font: QtGui.QFont) -> None: ...
    @deprecated("""""")
    def font(self) -> QtGui.QFont: ...
    def setMode(self, mode: 'QgsLayoutItemLabel.Mode') -> None: ...
    def mode(self) -> 'QgsLayoutItemLabel.Mode': ...
    def currentText(self) -> str: ...
    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...
    def sizeForText(self) -> QtCore.QSizeF: ...
    @typing.overload
    def adjustSizeToText(self) -> None: ...
    @typing.overload
    def adjustSizeToText(self, referencePoint: QgsLayoutItem.ReferencePoint) -> None: ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemLabel|None': ...


class QgsLegendModel(QgsLayerTreeModel):

    @typing.overload
    def __init__(self, rootNode: QgsLayerTree|None, parent: QtCore.QObject|None = ..., layout: 'QgsLayoutItemLegend|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, rootNode: QgsLayerTree|None, layout: 'QgsLayoutItemLegend|None') -> None: ...

    refreshLegend: typing.ClassVar[QtCore.pyqtSignal]
    def clearCachedData(self, node: QgsLayerTreeNode|None) -> None: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...


class QgsLayoutItemLegend(QgsLayoutItem):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def invalidateCache(self) -> None: ...
    def refresh(self) -> None: ...
    def isRefreshing(self) -> bool: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def exportLayerBehavior(self) -> QgsLayoutItem.ExportLayerBehavior: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def paint(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None, pWidget: QtWidgets.QWidget|None) -> None: ...
    def legendSettings(self) -> QgsLegendSettings: ...
    def updateFilterByMap(self, redraw: bool = ...) -> None: ...
    def updateLegend(self) -> None: ...
    def themeName(self) -> str: ...
    def filterByMapItems(self) -> list['QgsLayoutItemMap']: ...
    def setFilterByMapItems(self, maps: collections.abc.Iterable['QgsLayoutItemMap']) -> None: ...
    def linkedMap(self) -> 'QgsLayoutItemMap|None': ...
    def setLinkedMap(self, map: 'QgsLayoutItemMap|None') -> None: ...
    def setAutoWrapLinesAfter(self, length: float) -> None: ...
    def autoWrapLinesAfter(self) -> float: ...
    def setRasterStrokeWidth(self, width: float) -> None: ...
    def rasterStrokeWidth(self) -> float: ...
    def setRasterStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def rasterStrokeColor(self) -> QtGui.QColor: ...
    def setDrawRasterStroke(self, enabled: bool) -> None: ...
    def drawRasterStroke(self) -> bool: ...
    def setEqualColumnWidth(self, equalize: bool) -> None: ...
    def equalColumnWidth(self) -> bool: ...
    def setSplitLayer(self, enabled: bool) -> None: ...
    def splitLayer(self) -> bool: ...
    def setColumnCount(self, count: int) -> None: ...
    def columnCount(self) -> int: ...
    def wrapString(self) -> str: ...
    def setWrapString(self, string: str|None) -> None: ...
    def setWmsLegendHeight(self, height: float) -> None: ...
    def wmsLegendHeight(self) -> float: ...
    def setWmsLegendWidth(self, width: float) -> None: ...
    def wmsLegendWidth(self) -> float: ...
    def setSymbolHeight(self, height: float) -> None: ...
    def symbolHeight(self) -> float: ...
    def symbolAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setSymbolAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def setMinimumSymbolSize(self, size: float) -> None: ...
    def minimumSymbolSize(self) -> float: ...
    def setMaximumSymbolSize(self, size: float) -> None: ...
    def maximumSymbolSize(self) -> float: ...
    def setSymbolWidth(self, width: float) -> None: ...
    def symbolWidth(self) -> float: ...
    @deprecated("""""")
    def setFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fontColor(self) -> QtGui.QColor: ...
    def setColumnSpace(self, spacing: float) -> None: ...
    def columnSpace(self) -> float: ...
    def setBoxSpace(self, space: float) -> None: ...
    def boxSpace(self) -> float: ...
    @deprecated("""""")
    def setLineSpacing(self, spacing: float) -> None: ...
    @deprecated("""""")
    def lineSpacing(self) -> float: ...
    @typing.overload
    def setStyleMargin(self, component: Qgis.LegendComponent, margin: float) -> None: ...
    @typing.overload
    def setStyleMargin(self, component: Qgis.LegendComponent, side: QgsLegendStyle.Side, margin: float) -> None: ...
    @deprecated("""""")
    def setStyleFont(self, component: Qgis.LegendComponent, font: QtGui.QFont) -> None: ...
    @deprecated("""""")
    def styleFont(self, component: Qgis.LegendComponent) -> QtGui.QFont: ...
    def setStyle(self, component: Qgis.LegendComponent, style: QgsLegendStyle) -> None: ...
    def style(self, s: Qgis.LegendComponent) -> QgsLegendStyle: ...
    def rstyle(self, s: Qgis.LegendComponent) -> QgsLegendStyle: ...
    def setTitleAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def titleAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def title(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    def legendFilterOutAtlas(self) -> bool: ...
    def setLegendFilterOutAtlas(self, doFilter: bool) -> None: ...
    def legendFilterByMapEnabled(self) -> bool: ...
    def setLegendFilterByMapEnabled(self, enabled: bool) -> None: ...
    def syncMode(self) -> Qgis.LegendSyncMode: ...
    def resetManualLayers(self, mode: Qgis.LegendSyncMode) -> None: ...
    def setSyncMode(self, mode: Qgis.LegendSyncMode) -> None: ...
    @deprecated("""""")
    def autoUpdateModel(self) -> bool: ...
    @deprecated("""""")
    def setAutoUpdateModel(self, autoUpdate: bool) -> None: ...
    def model(self) -> QgsLegendModel|None: ...
    def resizeToContents(self) -> bool: ...
    def setResizeToContents(self, enabled: bool) -> None: ...
    def adjustBoxSize(self) -> None: ...
    def containsAdvancedEffects(self) -> bool: ...
    def requiresRasterization(self) -> bool: ...
    def displayName(self) -> str: ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemLegend|None': ...


class QgsLayoutItemManualTable(QgsLayoutTable):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def columnSpan(self, row: int, column: int) -> int: ...
    def rowSpan(self, row: int, column: int) -> int: ...
    def verticalAlignmentForCell(self, row: int, column: int) -> QtCore.Qt.AlignmentFlag: ...
    def horizontalAlignmentForCell(self, row: int, column: int) -> QtCore.Qt.AlignmentFlag: ...
    def textFormatForCell(self, row: int, column: int) -> 'QgsTextFormat': ...
    def textFormatForHeader(self, column: int) -> 'QgsTextFormat': ...
    def calculateMaxRowHeights(self) -> bool: ...
    def readPropertiesFromElement(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setHeaders(self, headers: collections.abc.Iterable['QgsLayoutTableColumn']) -> None: ...
    def headers(self) -> list['QgsLayoutTableColumn']: ...
    def setIncludeTableHeader(self, included: bool) -> None: ...
    def includeTableHeader(self) -> bool: ...
    def setColumnWidths(self, widths: collections.abc.Iterable[float]) -> None: ...
    def columnWidths(self) -> list[float]: ...
    def setRowHeights(self, heights: collections.abc.Iterable[float]) -> None: ...
    def rowHeights(self) -> list[float]: ...
    def tableContents(self) -> typing.Any: ...
    def setTableContents(self, contents: typing.Any) -> None: ...
    def conditionalCellStyle(self, row: int, column: int) -> QgsConditionalStyle: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemManualTable|None': ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemMapAtlasClippingSettings(QtCore.QObject):

    def __init__(self, map: 'QgsLayoutItemMap|None' = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setLayersToClip(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def layersToClip(self) -> list[QgsMapLayer]: ...
    def setRestrictToLayers(self, enabled: bool) -> None: ...
    def restrictToLayers(self) -> bool: ...
    def setClipItemShape(self, clipItemShape: bool) -> None: ...
    def clipItemShape(self) -> bool: ...
    def setForceLabelsInsideFeature(self, forceInside: bool) -> None: ...
    def forceLabelsInsideFeature(self) -> bool: ...
    def setFeatureClippingType(self, type: QgsMapClippingRegion.FeatureClippingType) -> None: ...
    def featureClippingType(self) -> QgsMapClippingRegion.FeatureClippingType: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...


class QgsLayoutItemMapItemClipPathSettings(QtCore.QObject):

    def __init__(self, map: 'QgsLayoutItemMap|None' = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def finalizeRestoreFromXml(self) -> None: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setForceLabelsInsideClipPath(self, forceInside: bool) -> None: ...
    def forceLabelsInsideClipPath(self) -> bool: ...
    def setFeatureClippingType(self, type: QgsMapClippingRegion.FeatureClippingType) -> None: ...
    def featureClippingType(self) -> QgsMapClippingRegion.FeatureClippingType: ...
    def sourceItem(self) -> QgsLayoutItem|None: ...
    def setSourceItem(self, item: QgsLayoutItem|None) -> None: ...
    def toMapClippingRegion(self) -> QgsMapClippingRegion: ...
    def clipPathInMapItemCoordinates(self) -> QgsGeometry: ...
    def clippedMapExtent(self) -> QgsGeometry: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def isActive(self) -> bool: ...


class QgsLayoutItemMap(QgsLayoutItem, QgsTemporalRangeObject):

    class MapItemFlag(enum.IntEnum):
        ShowPartialLabels = ... # type: QgsLayoutItemMap.MapItemFlag
        ShowUnplacedLabels = ... # type: QgsLayoutItemMap.MapItemFlag

    class AtlasScalingMode(enum.IntEnum):
        Fixed = ... # type: QgsLayoutItemMap.AtlasScalingMode
        Predefined = ... # type: QgsLayoutItemMap.AtlasScalingMode
        Auto = ... # type: QgsLayoutItemMap.AtlasScalingMode

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def updateBoundingRect(self) -> None: ...
    def invalidateCache(self) -> None: ...
    def refresh(self) -> None: ...
    previewRefreshed: typing.ClassVar[QtCore.pyqtSignal]
    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    themeChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerStyleOverridesChanged: typing.ClassVar[QtCore.pyqtSignal]
    preparedForAtlas: typing.ClassVar[QtCore.pyqtSignal]
    mapRotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    extentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def requestedExtent(self) -> QgsRectangle: ...
    def mapToItemCoords(self, mapCoords: QtCore.QPointF) -> QtCore.QPointF: ...
    def transformedMapPolygon(self) -> QtGui.QPolygonF: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def isDrawing(self) -> bool: ...
    def framePath(self) -> QtGui.QPainterPath: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def estimatedFrameBleed(self) -> float: ...
    def setZRange(self, range: QgsDoubleRange) -> None: ...
    def zRange(self) -> QgsDoubleRange: ...
    def zRangeEnabled(self) -> bool: ...
    def setZRangeEnabled(self, enabled: bool) -> None: ...
    def itemClippingSettings(self) -> QgsLayoutItemMapItemClipPathSettings|None: ...
    def atlasClippingSettings(self) -> QgsLayoutItemMapAtlasClippingSettings|None: ...
    def layoutToMapCoordsTransform(self) -> QtGui.QTransform: ...
    def removeRenderedFeatureHandler(self, handler: QgsRenderedFeatureHandlerInterface|None) -> None: ...
    def addRenderedFeatureHandler(self, handler: QgsRenderedFeatureHandlerInterface|None) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def previewLabelingResults(self) -> QgsLabelingResults|None: ...
    def renderingErrors(self) -> list['QgsMapRendererJob.Error']: ...
    def isLabelBlockingItem(self, item: QgsLayoutItem|None) -> bool: ...
    def removeLabelBlockingItem(self, item: QgsLayoutItem|None) -> None: ...
    def addLabelBlockingItem(self, item: QgsLayoutItem|None) -> None: ...
    def layersToRender(self, context: QgsExpressionContext|None = ..., includeInvalidLayers: bool = ...) -> list[QgsMapLayer]: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def mapSettings(self, extent: QgsRectangle, size: QtCore.QSizeF, dpi: float, includeLayerSettings: bool) -> QgsMapSettings: ...
    def mapUnitsToLayoutUnits(self) -> float: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def setLabelMargin(self, margin: 'QgsLayoutMeasurement') -> None: ...
    def labelMargin(self) -> 'QgsLayoutMeasurement': ...
    def overview(self) -> 'QgsLayoutItemMapOverview|None': ...
    def overviews(self) -> 'QgsLayoutItemMapOverviewStack|None': ...
    def grid(self) -> 'QgsLayoutItemMapGrid|None': ...
    def grids(self) -> 'QgsLayoutItemMapGridStack|None': ...
    def setAtlasMargin(self, margin: float) -> None: ...
    def atlasMargin(self, valueType: QgsLayoutObject.PropertyValueType = ...) -> float: ...
    def setAtlasScalingMode(self, mode: 'QgsLayoutItemMap.AtlasScalingMode') -> None: ...
    def atlasScalingMode(self) -> 'QgsLayoutItemMap.AtlasScalingMode': ...
    def setAtlasDriven(self, enabled: bool) -> None: ...
    def atlasDriven(self) -> bool: ...
    def drawAnnotations(self) -> bool: ...
    def setDrawAnnotations(self, draw: bool) -> None: ...
    def mapRotation(self, valueType: QgsLayoutObject.PropertyValueType = ...) -> float: ...
    def setMapRotation(self, rotation: float) -> None: ...
    def containsAdvancedEffects(self) -> bool: ...
    def requiresRasterization(self) -> bool: ...
    def containsWmsLayer(self) -> bool: ...
    def zoomContent(self, factor: float, point: QtCore.QPointF) -> None: ...
    def setMoveContentPreviewOffset(self, dx: float, dy: float) -> None: ...
    def moveContent(self, dx: float, dy: float) -> None: ...
    def setFollowVisibilityPresetName(self, name: str|None) -> None: ...
    def followVisibilityPresetName(self) -> str: ...
    def setFollowVisibilityPreset(self, follow: bool) -> None: ...
    def followVisibilityPreset(self) -> bool: ...
    def storeCurrentLayerStyles(self) -> None: ...
    def setLayerStyleOverrides(self, overrides: dict[str|None, str|None]) -> None: ...
    def layerStyleOverrides(self) -> dict[str, str]: ...
    def setKeepLayerStyles(self, enabled: bool) -> None: ...
    def keepLayerStyles(self) -> bool: ...
    def setLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def layers(self) -> list[QgsMapLayer]: ...
    def setKeepLayerSet(self, enabled: bool) -> None: ...
    def keepLayerSet(self) -> bool: ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def presetCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def visibleExtentPolygon(self) -> QtGui.QPolygonF: ...
    def extent(self) -> QgsRectangle: ...
    def zoomToExtent(self, extent: QgsRectangle) -> None: ...
    def setExtent(self, extent: QgsRectangle) -> None: ...
    def setScale(self, scale: float, forceUpdate: bool = ...) -> None: ...
    def scale(self) -> float: ...
    def setFrameStrokeWidth(self, width: 'QgsLayoutMeasurement') -> None: ...
    def exportLayerDetails(self) -> QgsLayoutItem.ExportLayerDetail: ...
    def exportLayerBehavior(self) -> QgsLayoutItem.ExportLayerBehavior: ...
    def nextExportPart(self) -> bool: ...
    def stopLayeredExport(self) -> None: ...
    def startLayeredExport(self) -> None: ...
    @deprecated("""""")
    def numberExportLayers(self) -> int: ...
    def paint(self, painter: QtGui.QPainter|None, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None, pWidget: QtWidgets.QWidget|None) -> None: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemMap|None': ...
    def displayName(self) -> str: ...
    def assignFreeId(self) -> None: ...
    def setMapFlags(self, flags: 'QgsLayoutItemMap.MapItemFlag') -> None: ...
    def mapFlags(self) -> 'QgsLayoutItemMap.MapItemFlag': ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemMapItemStack(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, map: QgsLayoutItemMap|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutItemMapItemStack') -> None: ...

    def removeItems(self) -> None: ...
    def asList(self) -> list['QgsLayoutItemMapItem']: ...
    def moveItemDown(self, itemId: str|None) -> None: ...
    def moveItemUp(self, itemId: str|None) -> None: ...
    def removeItem(self, itemId: str|None) -> None: ...
    def addItem(self, item: 'QgsLayoutItemMapItem|None') -> None: ...
    @typing.overload
    def item(self, index: int) -> 'QgsLayoutItemMapItem|None': ...
    @typing.overload
    def item(self, itemId: str|None) -> 'QgsLayoutItemMapItem|None': ...
    def hasEnabledItems(self) -> bool: ...
    def containsAdvancedEffects(self) -> bool: ...
    def drawItems(self, painter: QtGui.QPainter|None, ignoreStacking: bool = ...) -> None: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def size(self) -> int: ...


class QgsLayoutItemMapGridStack(QgsLayoutItemMapItemStack):

    @typing.overload
    def __init__(self, map: QgsLayoutItemMap|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutItemMapGridStack') -> None: ...

    def calculateMaxGridExtension(self) -> typing.Tuple[float, float, float, float]: ...
    def maxGridExtension(self) -> float: ...
    def readXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def asList(self) -> list['QgsLayoutItemMapGrid']: ...
    def __getitem__(self, index: int) -> 'QgsLayoutItemMapGrid': ...
    @typing.overload
    def grid(self, gridId: str|None) -> 'QgsLayoutItemMapGrid|None': ...
    @typing.overload
    def grid(self, index: int) -> 'QgsLayoutItemMapGrid|None': ...
    def moveGridDown(self, gridId: str|None) -> None: ...
    def moveGridUp(self, gridId: str|None) -> None: ...
    def removeGrid(self, gridId: str|None) -> None: ...
    def addGrid(self, grid: 'QgsLayoutItemMapGrid|None') -> None: ...


class QgsLayoutItemMapItem(QgsLayoutObject):

    class StackingPosition(enum.IntEnum):
        StackBelowMap = ... # type: QgsLayoutItemMapItem.StackingPosition
        StackBelowMapLayer = ... # type: QgsLayoutItemMapItem.StackingPosition
        StackAboveMapLayer = ... # type: QgsLayoutItemMapItem.StackingPosition
        StackBelowMapLabels = ... # type: QgsLayoutItemMapItem.StackingPosition
        StackAboveMapLabels = ... # type: QgsLayoutItemMapItem.StackingPosition

    def __init__(self, name: str|None, map: QgsLayoutItemMap|None) -> None: ...

    def createExpressionContext(self) -> QgsExpressionContext: ...
    def mapLayer(self) -> QgsMapLayer|None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def setStackingLayer(self, layer: QgsMapLayer|None) -> None: ...
    def stackingLayer(self) -> QgsMapLayer|None: ...
    def setStackingPosition(self, position: 'QgsLayoutItemMapItem.StackingPosition') -> None: ...
    def stackingPosition(self) -> 'QgsLayoutItemMapItem.StackingPosition': ...
    def usesAdvancedEffects(self) -> bool: ...
    def enabled(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def name(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def id(self) -> str: ...
    def map(self) -> QgsLayoutItemMap|None: ...
    def setMap(self, map: QgsLayoutItemMap|None) -> None: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, painter: QtGui.QPainter|None) -> None: ...


class QgsLayoutItemMapGrid(QgsLayoutItemMapItem):

    def __init__(self, name: str|None, map: QgsLayoutItemMap|None) -> None: ...

    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def copyProperties(self, other: 'QgsLayoutItemMapGrid|None') -> None: ...
    def refresh(self) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def setHorizontalAlignment(self, alignment: Qgis.TextHorizontalAlignment) -> None: ...
    def horizontalAlignment(self) -> Qgis.TextHorizontalAlignment: ...
    def frameFillColor2(self) -> QtGui.QColor: ...
    def setFrameFillColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def frameFillColor1(self) -> QtGui.QColor: ...
    def setFrameFillColor1(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def framePenColor(self) -> QtGui.QColor: ...
    def setFramePenColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def framePenSize(self) -> float: ...
    def setFramePenSize(self, width: float) -> None: ...
    def frameMargin(self) -> float: ...
    def setFrameMargin(self, margin: float) -> None: ...
    def rotatedAnnotationsMarginToCorner(self) -> float: ...
    def setRotatedAnnotationsMarginToCorner(self, margin: float) -> None: ...
    def rotatedAnnotationsMinimumAngle(self) -> float: ...
    def setRotatedAnnotationsMinimumAngle(self, angle: float) -> None: ...
    def rotatedAnnotationsLengthMode(self) -> Qgis.MapGridTickLengthMode: ...
    def setRotatedAnnotationsLengthMode(self, mode: Qgis.MapGridTickLengthMode) -> None: ...
    def rotatedAnnotationsEnabled(self) -> bool: ...
    def setRotatedAnnotationsEnabled(self, state: bool) -> None: ...
    def rotatedTicksMarginToCorner(self) -> float: ...
    def setRotatedTicksMarginToCorner(self, margin: float) -> None: ...
    def rotatedTicksMinimumAngle(self) -> float: ...
    def setRotatedTicksMinimumAngle(self, angle: float) -> None: ...
    def rotatedTicksLengthMode(self) -> Qgis.MapGridTickLengthMode: ...
    def setRotatedTicksLengthMode(self, mode: Qgis.MapGridTickLengthMode) -> None: ...
    def rotatedTicksEnabled(self) -> bool: ...
    def setRotatedTicksEnabled(self, state: bool) -> None: ...
    def frameWidth(self) -> float: ...
    def setFrameWidth(self, width: float) -> None: ...
    def testFrameSideFlag(self, flag: Qgis.MapGridFrameSideFlag) -> bool: ...
    def frameSideFlags(self) -> Qgis.MapGridFrameSideFlag: ...
    def setFrameSideFlag(self, flag: Qgis.MapGridFrameSideFlag, on: bool = ...) -> None: ...
    def setFrameSideFlags(self, flags: Qgis.MapGridFrameSideFlag) -> None: ...
    def frameDivisions(self, side: Qgis.MapGridBorderSide) -> Qgis.MapGridComponentVisibility: ...
    def setFrameDivisions(self, divisions: Qgis.MapGridComponentVisibility, side: Qgis.MapGridBorderSide) -> None: ...
    def frameStyle(self) -> Qgis.MapGridFrameStyle: ...
    def setFrameStyle(self, style: Qgis.MapGridFrameStyle) -> None: ...
    def annotationExpression(self) -> str: ...
    def setAnnotationExpression(self, expression: str|None) -> None: ...
    def annotationFormat(self) -> Qgis.MapGridAnnotationFormat: ...
    def setAnnotationFormat(self, format: Qgis.MapGridAnnotationFormat) -> None: ...
    def annotationDirection(self, border: Qgis.MapGridBorderSide) -> Qgis.MapGridAnnotationDirection: ...
    @typing.overload
    def setAnnotationDirection(self, direction: Qgis.MapGridAnnotationDirection, side: Qgis.MapGridBorderSide) -> None: ...
    @typing.overload
    def setAnnotationDirection(self, direction: Qgis.MapGridAnnotationDirection) -> None: ...
    def annotationFrameDistance(self) -> float: ...
    def setAnnotationFrameDistance(self, distance: float) -> None: ...
    def annotationPosition(self, side: Qgis.MapGridBorderSide) -> Qgis.MapGridAnnotationPosition: ...
    def setAnnotationPosition(self, position: Qgis.MapGridAnnotationPosition, side: Qgis.MapGridBorderSide) -> None: ...
    def annotationDisplay(self, border: Qgis.MapGridBorderSide) -> Qgis.MapGridComponentVisibility: ...
    def setAnnotationDisplay(self, display: Qgis.MapGridComponentVisibility, border: Qgis.MapGridBorderSide) -> None: ...
    def annotationPrecision(self) -> int: ...
    def setAnnotationPrecision(self, precision: int) -> None: ...
    @deprecated("""""")
    def annotationFontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setAnnotationFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def annotationFont(self) -> QtGui.QFont: ...
    @deprecated("""""")
    def setAnnotationFont(self, font: QtGui.QFont) -> None: ...
    def annotationTextFormat(self) -> 'QgsTextFormat': ...
    def setAnnotationTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def annotationEnabled(self) -> bool: ...
    def setAnnotationEnabled(self, enabled: bool) -> None: ...
    def markerSymbol(self) -> 'QgsMarkerSymbol|None': ...
    def setMarkerSymbol(self, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def lineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def setGridLineColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setGridLineWidth(self, width: float) -> None: ...
    def crossLength(self) -> float: ...
    def setCrossLength(self, length: float) -> None: ...
    def style(self) -> Qgis.MapGridStyle: ...
    def setStyle(self, style: Qgis.MapGridStyle) -> None: ...
    def setMaximumIntervalWidth(self, width: float) -> None: ...
    def maximumIntervalWidth(self) -> float: ...
    def setMinimumIntervalWidth(self, width: float) -> None: ...
    def minimumIntervalWidth(self) -> float: ...
    def offsetY(self) -> float: ...
    def setOffsetY(self, offset: float) -> None: ...
    def offsetX(self) -> float: ...
    def setOffsetX(self, offset: float) -> None: ...
    def intervalY(self) -> float: ...
    def setIntervalY(self, interval: float) -> None: ...
    def intervalX(self) -> float: ...
    def setIntervalX(self, interval: float) -> None: ...
    def units(self) -> Qgis.MapGridUnit: ...
    def setUnits(self, unit: Qgis.MapGridUnit) -> None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def calculateMaxExtension(self) -> typing.Tuple[float, float, float, float]: ...
    def maxExtension(self) -> float: ...
    def usesAdvancedEffects(self) -> bool: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def readXml(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, painter: QtGui.QPainter|None) -> None: ...


class QgsLayoutItemMapOverviewStack(QgsLayoutItemMapItemStack):

    @typing.overload
    def __init__(self, map: QgsLayoutItemMap|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutItemMapOverviewStack') -> None: ...

    def modifyMapLayerList(self, layers: collections.abc.Iterable[QgsMapLayer]) -> list[QgsMapLayer]: ...
    def readXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def asList(self) -> list['QgsLayoutItemMapOverview']: ...
    def __getitem__(self, index: int) -> 'QgsLayoutItemMapOverview': ...
    @typing.overload
    def overview(self, overviewId: str|None) -> 'QgsLayoutItemMapOverview|None': ...
    @typing.overload
    def overview(self, index: int) -> 'QgsLayoutItemMapOverview|None': ...
    def moveOverviewDown(self, overviewId: str|None) -> None: ...
    def moveOverviewUp(self, overviewId: str|None) -> None: ...
    def removeOverview(self, overviewId: str|None) -> None: ...
    def addOverview(self, overview: 'QgsLayoutItemMapOverview|None') -> None: ...


class QgsLayoutItemMapOverview(QgsLayoutItemMapItem):

    def __init__(self, name: str|None, map: QgsLayoutItemMap|None) -> None: ...

    def overviewExtentChanged(self) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def mapLayer(self) -> QgsMapLayer|None: ...
    def asMapLayer(self) -> QgsVectorLayer|None: ...
    def connectSignals(self) -> None: ...
    def setCentered(self, centered: bool) -> None: ...
    def centered(self) -> bool: ...
    def setInverted(self, inverted: bool) -> None: ...
    def inverted(self) -> bool: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def frameSymbol(self) -> 'QgsFillSymbol|None': ...
    def setFrameSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def linkedMap(self) -> QgsLayoutItemMap|None: ...
    def setLinkedMap(self, map: QgsLayoutItemMap|None) -> None: ...
    def usesAdvancedEffects(self) -> bool: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def readXml(self, itemElem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, painter: QtGui.QPainter|None) -> None: ...


class QgsLayoutItemMarker(QgsLayoutItem):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def finalizeRestoreFromXml(self) -> None: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def fixedSize(self) -> 'QgsLayoutSize': ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def setNorthOffset(self, offset: float) -> None: ...
    def northOffset(self) -> float: ...
    def setNorthMode(self, mode: 'QgsLayoutNorthArrowHandler.NorthMode') -> None: ...
    def northMode(self) -> 'QgsLayoutNorthArrowHandler.NorthMode': ...
    def northArrowRotation(self) -> float: ...
    def linkedMap(self) -> QgsLayoutItemMap|None: ...
    def setLinkedMap(self, map: QgsLayoutItemMap|None) -> None: ...
    def symbol(self) -> 'QgsMarkerSymbol|None': ...
    def setSymbol(self, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemMarker|None': ...


class QgsLayoutNodesItem(QgsLayoutItem):

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, polygon: QtGui.QPolygonF, layout: QgsLayout|None) -> None: ...

    def updateBoundingRect(self) -> None: ...
    def updateSceneRect(self) -> None: ...
    def computeDistance(self, pt1: QtCore.QPointF, pt2: QtCore.QPointF) -> float: ...
    def rescaleToFitBoundingBox(self) -> None: ...
    def _writeXmlStyle(self, doc: QtXml.QDomDocument, elmt: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _readXmlStyle(self, elmt: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _draw(self, context: QgsLayoutItemRenderContext, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None = ...) -> None: ...
    def _removeNode(self, nodeIndex: int) -> bool: ...
    def _addNode(self, nodeIndex: int, newNode: QtCore.QPointF, radius: float) -> bool: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def isValid(self) -> bool: ...
    def estimatedFrameBleed(self) -> float: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def deselectNode(self) -> None: ...
    def selectedNode(self) -> int: ...
    def setSelectedNode(self, index: int) -> bool: ...
    def nodesSize(self) -> int: ...
    def removeNode(self, index: int) -> bool: ...
    def nodePosition(self, index: int, position: QtCore.QPointF) -> bool: ...
    def nodeAtPosition(self, point: QtCore.QPointF, searchInRadius: bool = ..., radius: float = ...) -> int: ...
    def moveNode(self, index: int, node: QtCore.QPointF) -> bool: ...
    def setDisplayNodes(self, display: bool = ...) -> None: ...
    def addNode(self, point: QtCore.QPointF, checkArea: bool = ..., radius: float = ...) -> bool: ...
    def nodes(self) -> QtGui.QPolygonF: ...
    def setNodes(self, nodes: QtGui.QPolygonF) -> None: ...


class QgsLayoutItemPage(QgsLayoutItem):

    class UndoCommand(enum.IntEnum):
        UndoPageSymbol = ... # type: QgsLayoutItemPage.UndoCommand

    class Orientation(enum.IntEnum):
        Portrait = ... # type: QgsLayoutItemPage.Orientation
        Landscape = ... # type: QgsLayoutItemPage.Orientation

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, itemElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def drawBackground(self, context: QgsRenderContext) -> None: ...
    def drawFrame(self, context: QgsRenderContext) -> None: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def redraw(self) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def exportLayerBehavior(self) -> QgsLayoutItem.ExportLayerBehavior: ...
    def createCommand(self, text: str|None, id: int, parent: QtGui.QUndoCommand|None = ...) -> 'QgsAbstractLayoutUndoCommand|None': ...
    def attemptResize(self, size: 'QgsLayoutSize', includesFrame: bool = ...) -> None: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    @staticmethod
    def decodePageOrientation(string: str|None) -> typing.Tuple['QgsLayoutItemPage.Orientation', bool]: ...
    def pageStyleSymbol(self) -> 'QgsFillSymbol|None': ...
    def setPageStyleSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def orientation(self) -> 'QgsLayoutItemPage.Orientation': ...
    def pageSize(self) -> 'QgsLayoutSize': ...
    def pageLayout(self) -> QtGui.QPageLayout: ...
    @typing.overload
    def setPageSize(self, size: 'QgsLayoutSize') -> None: ...
    @typing.overload
    def setPageSize(self, size: str|None, orientation: 'QgsLayoutItemPage.Orientation' = ...) -> bool: ...
    def displayName(self) -> str: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemPage|None': ...


class QgsLayoutItemPicture(QgsLayoutItem):

    class NorthMode(enum.IntEnum):
        GridNorth = ... # type: QgsLayoutItemPicture.NorthMode
        TrueNorth = ... # type: QgsLayoutItemPicture.NorthMode

    class ResizeMode(enum.IntEnum):
        Zoom = ... # type: QgsLayoutItemPicture.ResizeMode
        Stretch = ... # type: QgsLayoutItemPicture.ResizeMode
        Clip = ... # type: QgsLayoutItemPicture.ResizeMode
        ZoomResizeFrame = ... # type: QgsLayoutItemPicture.ResizeMode
        FrameToImageSize = ... # type: QgsLayoutItemPicture.ResizeMode

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def applyItemSizeConstraint(self, targetSize: QtCore.QSizeF) -> QtCore.QSizeF: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    pictureRotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def recalculateSize(self) -> None: ...
    def refreshPicture(self, context: QgsExpressionContext|None = ...) -> None: ...
    def setResizeMode(self, mode: 'QgsLayoutItemPicture.ResizeMode') -> None: ...
    def setPictureRotation(self, rotation: float) -> None: ...
    def setSvgDynamicParameters(self, parameters: dict[str|None, QgsProperty]) -> None: ...
    def svgDynamicParameters(self) -> dict[str, QgsProperty]: ...
    def evaluatedPath(self) -> str: ...
    def isMissingImage(self) -> bool: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def setMode(self, mode: Qgis.PictureFormat) -> None: ...
    def originalMode(self) -> Qgis.PictureFormat: ...
    def mode(self) -> Qgis.PictureFormat: ...
    def setSvgStrokeWidth(self, width: float) -> None: ...
    def svgStrokeWidth(self) -> float: ...
    def setSvgStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def svgStrokeColor(self) -> QtGui.QColor: ...
    def setSvgFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def svgFillColor(self) -> QtGui.QColor: ...
    def pictureAnchor(self) -> QgsLayoutItem.ReferencePoint: ...
    def setPictureAnchor(self, anchor: QgsLayoutItem.ReferencePoint) -> None: ...
    def resizeMode(self) -> 'QgsLayoutItemPicture.ResizeMode': ...
    def setNorthOffset(self, offset: float) -> None: ...
    def northOffset(self) -> float: ...
    def setNorthMode(self, mode: 'QgsLayoutItemPicture.NorthMode') -> None: ...
    def northMode(self) -> 'QgsLayoutItemPicture.NorthMode': ...
    def linkedMap(self) -> QgsLayoutItemMap|None: ...
    def setLinkedMap(self, map: QgsLayoutItemMap|None) -> None: ...
    def pictureRotation(self) -> float: ...
    def picturePath(self) -> str: ...
    def setPicturePath(self, path: str|None, format: Qgis.PictureFormat = ...) -> None: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemPicture|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemPolygon(QgsLayoutNodesItem):

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, polygon: QtGui.QPolygonF, layout: QgsLayout|None) -> None: ...

    def _writeXmlStyle(self, doc: QtXml.QDomDocument, elmt: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _readXmlStyle(self, elmt: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _draw(self, context: QgsLayoutItemRenderContext, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None = ...) -> None: ...
    def _removeNode(self, nodeIndex: int) -> bool: ...
    def _addNode(self, indexPoint: int, newPoint: QtCore.QPointF, radius: float) -> bool: ...
    def setSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def symbol(self) -> 'QgsFillSymbol|None': ...
    def isValid(self) -> bool: ...
    def clipPath(self) -> QgsGeometry: ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemPolygon|None': ...


class QgsLayoutItemPolyline(QgsLayoutNodesItem):

    class MarkerMode(enum.IntEnum):
        NoMarker = ... # type: QgsLayoutItemPolyline.MarkerMode
        ArrowHead = ... # type: QgsLayoutItemPolyline.MarkerMode
        SvgMarker = ... # type: QgsLayoutItemPolyline.MarkerMode

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, polyline: QtGui.QPolygonF, layout: QgsLayout|None) -> None: ...

    def updateBoundingRect(self) -> None: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def _writeXmlStyle(self, doc: QtXml.QDomDocument, elmt: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _readXmlStyle(self, elmt: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def _draw(self, context: QgsLayoutItemRenderContext, itemStyle: QtWidgets.QStyleOptionGraphicsItem|None = ...) -> None: ...
    def _removeNode(self, nodeIndex: int) -> bool: ...
    def _addNode(self, indexPoint: int, newPoint: QtCore.QPointF, radius: float) -> bool: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def arrowHeadStrokeWidth(self) -> float: ...
    def setArrowHeadStrokeWidth(self, width: float) -> None: ...
    def setArrowHeadFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def arrowHeadFillColor(self) -> QtGui.QColor: ...
    def setArrowHeadStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def arrowHeadStrokeColor(self) -> QtGui.QColor: ...
    def endSvgMarkerPath(self) -> str: ...
    def setEndSvgMarkerPath(self, path: str|None) -> None: ...
    def startSvgMarkerPath(self) -> str: ...
    def setStartSvgMarkerPath(self, path: str|None) -> None: ...
    def arrowHeadWidth(self) -> float: ...
    def setArrowHeadWidth(self, width: float) -> None: ...
    def setEndMarker(self, mode: 'QgsLayoutItemPolyline.MarkerMode') -> None: ...
    def endMarker(self) -> 'QgsLayoutItemPolyline.MarkerMode': ...
    def setStartMarker(self, mode: 'QgsLayoutItemPolyline.MarkerMode') -> None: ...
    def startMarker(self) -> 'QgsLayoutItemPolyline.MarkerMode': ...
    def setSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def symbol(self) -> 'QgsLineSymbol|None': ...
    def isValid(self) -> bool: ...
    def shape(self) -> QtGui.QPainterPath: ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemPolyline|None': ...


class QgsLayoutItemAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: int, visibleName: str|None, visiblePluralName: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutItemAbstractMetadata') -> None: ...

    def resolvePaths(self, properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    def createItem(self, layout: QgsLayout|None) -> QgsLayoutItem|None: ...
    def visiblePluralName(self) -> str: ...
    def visibleName(self) -> str: ...
    def type(self) -> int: ...


class QgsLayoutMultiFrameAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: int, visibleName: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutMultiFrameAbstractMetadata') -> None: ...

    def resolvePaths(self, properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    def createMultiFrame(self, layout: QgsLayout|None) -> QgsLayoutMultiFrame|None: ...
    def visibleName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemRegistry(QtCore.QObject):

    class ItemType(enum.IntEnum):
        LayoutItem = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutGroup = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutPage = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutMap = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutPicture = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutLabel = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutLegend = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutShape = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutPolygon = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutPolyline = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutScaleBar = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutFrame = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutHtml = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutAttributeTable = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutTextTable = ... # type: QgsLayoutItemRegistry.ItemType
        Layout3DMap = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutManualTable = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutMarker = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutElevationProfile = ... # type: QgsLayoutItemRegistry.ItemType
        LayoutChart = ... # type: QgsLayoutItemRegistry.ItemType
        PluginItem = ... # type: QgsLayoutItemRegistry.ItemType

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    multiFrameTypeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    multiFrameTypeAdded: typing.ClassVar[QtCore.pyqtSignal]
    typeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    typeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def itemTypes(self) -> dict[int, str]: ...
    def resolvePaths(self, type: int, properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    def createMultiFrame(self, type: int, layout: QgsLayout|None) -> QgsLayoutMultiFrame|None: ...
    def createItem(self, type: int, layout: QgsLayout|None) -> QgsLayoutItem|None: ...
    def addLayoutMultiFrameType(self, metadata: QgsLayoutMultiFrameAbstractMetadata|None) -> bool: ...
    @typing.overload
    def removeLayoutMultiFrameType(self, typeId: int) -> bool: ...
    @typing.overload
    def removeLayoutMultiFrameType(self, metadata: QgsLayoutMultiFrameAbstractMetadata|None) -> bool: ...
    @typing.overload
    def removeLayoutItemType(self, typeId: int) -> bool: ...
    @typing.overload
    def removeLayoutItemType(self, metadata: QgsLayoutItemAbstractMetadata|None) -> bool: ...
    def addLayoutItemType(self, metadata: QgsLayoutItemAbstractMetadata|None) -> bool: ...
    def multiFrameMetadata(self, type: int) -> QgsLayoutMultiFrameAbstractMetadata|None: ...
    def itemMetadata(self, type: int) -> QgsLayoutItemAbstractMetadata|None: ...
    def populate(self) -> bool: ...


class QgsLayoutItemScaleBar(QgsLayoutItem):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def exportLayerBehavior(self) -> QgsLayoutItem.ExportLayerBehavior: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def finalizeRestoreFromXml(self) -> None: ...
    def refreshDataDefinedProperty(self, property: QgsLayoutObject.DataDefinedProperty = ...) -> None: ...
    def update(self) -> None: ...
    def setMethod(self, method: Qgis.ScaleCalculationMethod) -> None: ...
    def method(self) -> Qgis.ScaleCalculationMethod: ...
    def setNumericFormat(self, format: 'QgsNumericFormat|None') -> None: ...
    def numericFormat(self) -> 'QgsNumericFormat|None': ...
    def style(self) -> str: ...
    def setStyle(self, name: str|None) -> None: ...
    def resizeToMinimumWidth(self) -> None: ...
    def applyDefaultSize(self, units: Qgis.DistanceUnit = ...) -> None: ...
    def guessUnits(self) -> Qgis.DistanceUnit: ...
    def applyDefaultRendererSettings(self, renderer: 'QgsScaleBarRenderer|None') -> bool: ...
    def applyDefaultSettings(self) -> None: ...
    @deprecated("""""")
    def setLineCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    @deprecated("""""")
    def lineCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    @deprecated("""""")
    def setLineJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    @deprecated("""""")
    def lineJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setUnits(self, units: Qgis.DistanceUnit) -> None: ...
    def units(self) -> Qgis.DistanceUnit: ...
    def setAlignment(self, alignment: Qgis.ScaleBarAlignment) -> None: ...
    def alignment(self) -> Qgis.ScaleBarAlignment: ...
    def setLabelHorizontalPlacement(self, placement: Qgis.ScaleBarDistanceLabelHorizontalPlacement) -> None: ...
    def labelHorizontalPlacement(self) -> Qgis.ScaleBarDistanceLabelHorizontalPlacement: ...
    def setLabelVerticalPlacement(self, placement: Qgis.ScaleBarDistanceLabelVerticalPlacement) -> None: ...
    def labelVerticalPlacement(self) -> Qgis.ScaleBarDistanceLabelVerticalPlacement: ...
    def setBoxContentSpace(self, space: float) -> None: ...
    def boxContentSpace(self) -> float: ...
    def setLabelBarSpace(self, space: float) -> None: ...
    def labelBarSpace(self) -> float: ...
    def linkedMap(self) -> QgsLayoutItemMap|None: ...
    def setLinkedMap(self, map: QgsLayoutItemMap|None) -> None: ...
    def setHeight(self, height: float) -> None: ...
    def height(self) -> float: ...
    @deprecated("""""")
    def brush2(self) -> QtGui.QBrush: ...
    @deprecated("""""")
    def brush(self) -> QtGui.QBrush: ...
    @deprecated("""""")
    def pen(self) -> QtGui.QPen: ...
    @deprecated("""""")
    def setLineWidth(self, width: float) -> None: ...
    @deprecated("""""")
    def lineWidth(self) -> float: ...
    @deprecated("""""")
    def setLineColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def lineColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFillColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fillColor2(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fillColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFont(self, font: QtGui.QFont) -> None: ...
    @deprecated("""""")
    def font(self) -> QtGui.QFont: ...
    def setAlternateFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def alternateFillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def fillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setSubdivisionLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def subdivisionLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setDivisionLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def divisionLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def lineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def setUnitLabel(self, label: str|None) -> None: ...
    def unitLabel(self) -> str: ...
    def setMapUnitsPerScaleBarUnit(self, units: float) -> None: ...
    def mapUnitsPerScaleBarUnit(self) -> float: ...
    def setMaximumBarWidth(self, maxWidth: float) -> None: ...
    def maximumBarWidth(self) -> float: ...
    def setMinimumBarWidth(self, minWidth: float) -> None: ...
    def minimumBarWidth(self) -> float: ...
    def setSegmentSizeMode(self, mode: Qgis.ScaleBarSegmentSizeMode) -> None: ...
    def segmentSizeMode(self) -> Qgis.ScaleBarSegmentSizeMode: ...
    def setUnitsPerSegment(self, units: float) -> None: ...
    def unitsPerSegment(self) -> float: ...
    def setSubdivisionsHeight(self, height: float) -> None: ...
    def subdivisionsHeight(self) -> float: ...
    def setNumberOfSubdivisions(self, subdivisions: int) -> None: ...
    def numberOfSubdivisions(self) -> int: ...
    def setNumberOfSegmentsLeft(self, segments: int) -> None: ...
    def numberOfSegmentsLeft(self) -> int: ...
    def setNumberOfSegments(self, segments: int) -> None: ...
    def numberOfSegments(self) -> int: ...
    def minimumSize(self) -> 'QgsLayoutSize': ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemScaleBar|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...


class QgsLayoutItemShape(QgsLayoutItem):

    class Shape(enum.IntEnum):
        Ellipse = ... # type: QgsLayoutItemShape.Shape
        Rectangle = ... # type: QgsLayoutItemShape.Shape
        Triangle = ... # type: QgsLayoutItemShape.Shape

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def draw(self, context: QgsLayoutItemRenderContext) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def estimatedFrameBleed(self) -> float: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def clipPath(self) -> QgsGeometry: ...
    def cornerRadius(self) -> 'QgsLayoutMeasurement': ...
    def setCornerRadius(self, radius: 'QgsLayoutMeasurement') -> None: ...
    def symbol(self) -> 'QgsFillSymbol|None': ...
    def setSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def setShapeType(self, type: 'QgsLayoutItemShape.Shape') -> None: ...
    def shapeType(self) -> 'QgsLayoutItemShape.Shape': ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def displayName(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def type(self) -> int: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemShape|None': ...


class QgsLayoutItemTextTable(QgsLayoutTable):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    def getTableContents(self, contents: typing.Any) -> bool: ...
    def setContents(self, contents: collections.abc.Iterable[collections.abc.Iterable[str|None]]) -> None: ...
    def addRow(self, row: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def create(layout: QgsLayout|None) -> 'QgsLayoutItemTextTable|None': ...
    def displayName(self) -> str: ...
    def type(self) -> int: ...


class QgsLayoutManager(QgsProjectStoredObjectManagerBase):

    def __init__(self, project: 'QgsProject|None' = ...) -> None: ...

    def setupObjectConnections(self, layout: 'QgsMasterLayoutInterface|None') -> None: ...
    layoutRenamed: typing.ClassVar[QtCore.pyqtSignal]
    layoutAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layoutRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layoutAdded: typing.ClassVar[QtCore.pyqtSignal]
    layoutAboutToBeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def generateUniqueTitle(self, type: 'QgsMasterLayoutInterface.Type' = ...) -> str: ...
    def duplicateLayout(self, layout: 'QgsMasterLayoutInterface|None', newName: str|None) -> 'QgsMasterLayoutInterface|None': ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...
    def layoutByName(self, name: str|None) -> 'QgsMasterLayoutInterface|None': ...
    def printLayouts(self) -> list['QgsPrintLayout']: ...
    def layouts(self) -> list['QgsMasterLayoutInterface']: ...
    def clear(self) -> None: ...
    def removeLayout(self, layout: 'QgsMasterLayoutInterface|None') -> bool: ...
    def addLayout(self, layout: 'QgsMasterLayoutInterface|None') -> bool: ...


class QgsLayoutManagerModel(QgsProjectStoredObjectManagerModelBase):

    class CustomRole(enum.IntEnum):
        Layout = ... # type: QgsLayoutManagerModel.CustomRole

    def __init__(self, manager: QgsLayoutManager|None, parent: QtCore.QObject|None = ...) -> None: ...

    def allowEmptyLayout(self) -> bool: ...
    def setAllowEmptyLayout(self, allowEmpty: bool) -> None: ...
    def indexFromLayout(self, layout: 'QgsMasterLayoutInterface|None') -> QtCore.QModelIndex: ...
    def layoutFromIndex(self, index: QtCore.QModelIndex) -> 'QgsMasterLayoutInterface|None': ...


class QgsLayoutManagerProxyModel(QgsProjectStoredObjectManagerProxyModelBase):

    class Filter(enum.IntEnum):
        FilterPrintLayouts = ... # type: QgsLayoutManagerProxyModel.Filter
        FilterReports = ... # type: QgsLayoutManagerProxyModel.Filter

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def filterAcceptsRowInternal(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setFilters(self, filters: 'QgsLayoutManagerProxyModel.Filter') -> None: ...
    def filters(self) -> 'QgsLayoutManagerProxyModel.Filter': ...


class QgsLayoutMeasurement(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, length: float, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutMeasurement') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __itruediv__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __truediv__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __imul__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __mul__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __isub__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __sub__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __iadd__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __add__(self, v: float) -> 'QgsLayoutMeasurement': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def decodeMeasurement(string: str|None) -> 'QgsLayoutMeasurement': ...
    def encodeMeasurement(self) -> str: ...
    def setUnits(self, units: Qgis.LayoutUnit) -> None: ...
    def units(self) -> Qgis.LayoutUnit: ...
    def setLength(self, length: float) -> None: ...
    def length(self) -> float: ...


class QgsLayoutMeasurementConverter(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutMeasurementConverter') -> None: ...

    @typing.overload
    def convert(self, measurement: QgsLayoutMeasurement, targetUnits: Qgis.LayoutUnit) -> QgsLayoutMeasurement: ...
    @typing.overload
    def convert(self, size: 'QgsLayoutSize', targetUnits: Qgis.LayoutUnit) -> 'QgsLayoutSize': ...
    @typing.overload
    def convert(self, point: 'QgsLayoutPoint', targetUnits: Qgis.LayoutUnit) -> 'QgsLayoutPoint': ...
    def dpi(self) -> float: ...
    def setDpi(self, dpi: float) -> None: ...


class QgsLayoutModel(QtCore.QAbstractItemModel):

    class Columns(enum.IntEnum):
        Visibility = ... # type: QgsLayoutModel.Columns
        LockStatus = ... # type: QgsLayoutModel.Columns
        ItemId = ... # type: QgsLayoutModel.Columns

    def __init__(self, layout: QgsLayout|None, parent: QtCore.QObject|None = ...) -> None: ...

    def indexForItem(self, item: QgsLayoutItem|None, column: int = ...) -> QtCore.QModelIndex: ...
    def itemFromIndex(self, index: QtCore.QModelIndex) -> QgsLayoutItem|None: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def mimeTypes(self) -> list[str]: ...
    def supportedDropActions(self) -> QtCore.Qt.DropAction: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...


class QgsLayoutProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, layout: QgsLayout|None, parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def itemFlags(self) -> QgsLayoutItem.Flag: ...
    def setItemFlags(self, flags: QgsLayoutItem.Flag) -> None: ...
    def allowEmptyItem(self) -> bool: ...
    def setAllowEmptyItem(self, allowEmpty: bool) -> None: ...
    def layout(self) -> QgsLayout|None: ...
    def itemFromSourceIndex(self, sourceIndex: QtCore.QModelIndex) -> QgsLayoutItem|None: ...
    def sourceLayerModel(self) -> QgsLayoutModel|None: ...
    def exceptedItemList(self) -> list[QgsLayoutItem]: ...
    def setExceptedItemList(self, items: collections.abc.Iterable[QgsLayoutItem]) -> None: ...
    def setFilterType(self, filter: QgsLayoutItemRegistry.ItemType) -> None: ...
    def filterType(self) -> QgsLayoutItemRegistry.ItemType: ...


class QgsLayoutNorthArrowHandler(QtCore.QObject):

    class NorthMode(enum.IntEnum):
        GridNorth = ... # type: QgsLayoutNorthArrowHandler.NorthMode
        TrueNorth = ... # type: QgsLayoutNorthArrowHandler.NorthMode

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    arrowRotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setNorthOffset(self, offset: float) -> None: ...
    def northOffset(self) -> float: ...
    def setNorthMode(self, mode: 'QgsLayoutNorthArrowHandler.NorthMode') -> None: ...
    def northMode(self) -> 'QgsLayoutNorthArrowHandler.NorthMode': ...
    def linkedMap(self) -> QgsLayoutItemMap|None: ...
    def setLinkedMap(self, map: QgsLayoutItemMap|None) -> None: ...
    def arrowRotation(self) -> float: ...


class QgsLayoutPageCollection(QtCore.QObject, QgsLayoutSerializableObject):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    pageAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def redraw(self) -> None: ...
    def applyPropertiesToAllOtherPages(self, sourcePage: int) -> None: ...
    def guides(self) -> QgsLayoutGuideCollection: ...
    def readXml(self, collectionElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def resizeToContents(self, margins: QgsMargins, marginUnits: Qgis.LayoutUnit) -> None: ...
    def pageShadowWidth(self) -> float: ...
    def spaceBetweenPages(self) -> float: ...
    def positionOnPage(self, point: QtCore.QPointF) -> QtCore.QPointF: ...
    def pagePositionToAbsolute(self, page: int, position: 'QgsLayoutPoint') -> 'QgsLayoutPoint': ...
    def pagePositionToLayoutPosition(self, page: int, position: 'QgsLayoutPoint') -> QtCore.QPointF: ...
    def pageAtPoint(self, point: QtCore.QPointF) -> QgsLayoutItemPage|None: ...
    def predictPageNumberForPoint(self, point: QtCore.QPointF) -> int: ...
    def pageNumberForPoint(self, point: QtCore.QPointF) -> int: ...
    def hasUniformPageSizes(self) -> bool: ...
    def maximumPageSize(self) -> QtCore.QSizeF: ...
    def maximumPageWidth(self) -> float: ...
    def reflow(self) -> None: ...
    def endPageSizeChange(self) -> None: ...
    def beginPageSizeChange(self) -> None: ...
    @deprecated("""""")
    def pageStyleSymbol(self) -> 'QgsFillSymbol|None': ...
    def setPageStyleSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def takePage(self, page: QgsLayoutItemPage|None) -> QgsLayoutItemPage|None: ...
    def clear(self) -> None: ...
    @typing.overload
    def deletePage(self, pageNumber: int) -> None: ...
    @typing.overload
    def deletePage(self, page: QgsLayoutItemPage|None) -> None: ...
    def insertPage(self, page: QgsLayoutItemPage|None, beforePage: int) -> None: ...
    def extendByNewPage(self) -> QgsLayoutItemPage|None: ...
    def addPage(self, page: QgsLayoutItemPage|None) -> None: ...
    def shouldExportPage(self, page: int) -> bool: ...
    def itemsOnPage(self, page: int) -> list[QgsLayoutItem]: ...
    def pageIsEmpty(self, page: int) -> bool: ...
    def visiblePageNumbers(self, region: QtCore.QRectF) -> list[int]: ...
    def visiblePages(self, region: QtCore.QRectF) -> list[QgsLayoutItemPage]: ...
    def pageNumber(self, page: QgsLayoutItemPage|None) -> int: ...
    def page(self, pageNumber: int) -> QgsLayoutItemPage|None: ...
    def pageCount(self) -> int: ...
    def pages(self) -> list[QgsLayoutItemPage]: ...
    def layout(self) -> QgsLayout|None: ...
    def stringType(self) -> str: ...


class QgsLayoutPoint(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, x: float, y: float, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, point: QtCore.QPointF, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutPoint') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __itruediv__(self, v: float) -> 'QgsLayoutPoint': ...
    def __truediv__(self, v: float) -> 'QgsLayoutPoint': ...
    def __imul__(self, v: float) -> 'QgsLayoutPoint': ...
    def __mul__(self, v: float) -> 'QgsLayoutPoint': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def decodePoint(string: str|None) -> 'QgsLayoutPoint': ...
    def encodePoint(self) -> str: ...
    def toQPointF(self) -> QtCore.QPointF: ...
    def isNull(self) -> bool: ...
    def setUnits(self, units: Qgis.LayoutUnit) -> None: ...
    def units(self) -> Qgis.LayoutUnit: ...
    def setY(self, y: float) -> None: ...
    def y(self) -> float: ...
    def setX(self, x: float) -> None: ...
    def x(self) -> float: ...
    def setPoint(self, x: float, y: float) -> None: ...


class QgsLayoutRenderContext(QtCore.QObject):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    predefinedScalesChanged: typing.ClassVar[QtCore.pyqtSignal]
    dpiChanged: typing.ClassVar[QtCore.pyqtSignal]
    flagsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setFeatureFilterProvider(self, featureFilterProvider: QgsFeatureFilterProvider|None) -> None: ...
    def featureFilterProvider(self) -> QgsFeatureFilterProvider|None: ...
    def predefinedScales(self) -> list[float]: ...
    def setPredefinedScales(self, scales: collections.abc.Iterable[float]) -> None: ...
    def setExportThemes(self, themes: collections.abc.Iterable[str|None]) -> None: ...
    def exportThemes(self) -> list[str]: ...
    def setMaskSettings(self, settings: QgsMaskRenderSettings) -> None: ...
    def maskSettings(self) -> QgsMaskRenderSettings: ...
    def simplifyMethod(self) -> QgsVectorSimplifyMethod: ...
    def setSimplifyMethod(self, method: QgsVectorSimplifyMethod) -> None: ...
    def setTextRenderFormat(self, format: Qgis.TextRenderFormat) -> None: ...
    def textRenderFormat(self) -> Qgis.TextRenderFormat: ...
    @deprecated("""""")
    def currentExportLayer(self) -> int: ...
    @deprecated("""""")
    def setCurrentExportLayer(self, layer: int = ...) -> None: ...
    def pagesVisible(self) -> bool: ...
    def setPagesVisible(self, visible: bool) -> None: ...
    def setBoundingBoxesVisible(self, visible: bool) -> None: ...
    def boundingBoxesVisible(self) -> bool: ...
    def setGridVisible(self, visible: bool) -> None: ...
    def gridVisible(self) -> bool: ...
    def isPreviewRender(self) -> bool: ...
    def measurementConverter(self) -> QgsLayoutMeasurementConverter: ...
    def selectionColor(self) -> QtGui.QColor: ...
    def setSelectionColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def dpi(self) -> float: ...
    def setDpi(self, dpi: float) -> None: ...
    def setRasterizedRenderingPolicy(self, policy: Qgis.RasterizedRenderingPolicy) -> None: ...
    def rasterizedRenderingPolicy(self) -> Qgis.RasterizedRenderingPolicy: ...
    def renderContextFlags(self) -> Qgis.RenderContextFlag: ...
    def testFlag(self, flag: Qgis.LayoutRenderFlag) -> bool: ...
    def flags(self) -> Qgis.LayoutRenderFlag: ...
    def setFlag(self, flag: Qgis.LayoutRenderFlag, on: bool = ...) -> None: ...
    def setFlags(self, flags: Qgis.LayoutRenderFlag) -> None: ...


class QgsLayoutReportContext(QtCore.QObject):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    layerChanged: typing.ClassVar[QtCore.pyqtSignal]
    @deprecated("""""")
    def predefinedScales(self) -> list[float]: ...
    @deprecated("""""")
    def setPredefinedScales(self, scales: collections.abc.Iterable[float]) -> None: ...
    def setLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def layer(self) -> QgsVectorLayer|None: ...
    def currentGeometry(self, crs: 'QgsCoordinateReferenceSystem' = ...) -> QgsGeometry: ...
    def feature(self) -> QgsFeature: ...
    def setFeature(self, feature: QgsFeature) -> None: ...


class QgsLayoutSize(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, width: float, height: float, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, size: QtCore.QSizeF, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, units: Qgis.LayoutUnit = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutSize') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __itruediv__(self, v: float) -> 'QgsLayoutSize': ...
    def __truediv__(self, v: float) -> 'QgsLayoutSize': ...
    def __imul__(self, v: float) -> 'QgsLayoutSize': ...
    def __mul__(self, v: float) -> 'QgsLayoutSize': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @staticmethod
    def decodeSize(string: str|None) -> 'QgsLayoutSize': ...
    def encodeSize(self) -> str: ...
    def toQSizeF(self) -> QtCore.QSizeF: ...
    def isEmpty(self) -> bool: ...
    def setUnits(self, units: Qgis.LayoutUnit) -> None: ...
    def units(self) -> Qgis.LayoutUnit: ...
    def setHeight(self, height: float) -> None: ...
    def height(self) -> float: ...
    def setWidth(self, width: float) -> None: ...
    def width(self) -> float: ...
    def setSize(self, width: float, height: float) -> None: ...


class QgsLayoutSnapper(QgsLayoutSerializableObject):

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutSnapper') -> None: ...

    def readXml(self, gridElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def snapPointsToItems(self, points: collections.abc.Iterable[float], orientation: QtCore.Qt.Orientation, scaleFactor: float, ignoreItems: collections.abc.Iterable[QgsLayoutItem], snapLine: QtWidgets.QGraphicsLineItem|None = ...) -> typing.Tuple[float, bool]: ...
    def snapPointToItems(self, original: float, orientation: QtCore.Qt.Orientation, scaleFactor: float, ignoreItems: collections.abc.Iterable[QgsLayoutItem], snapLine: QtWidgets.QGraphicsLineItem|None = ...) -> typing.Tuple[float, bool]: ...
    def snapPointsToGuides(self, points: collections.abc.Iterable[float], orientation: QtCore.Qt.Orientation, scaleFactor: float) -> typing.Tuple[float, bool]: ...
    def snapPointToGuides(self, original: float, orientation: QtCore.Qt.Orientation, scaleFactor: float) -> typing.Tuple[float, bool]: ...
    def snapPointsToGrid(self, points: collections.abc.Iterable[QtCore.QPointF], scaleFactor: float) -> typing.Tuple[QtCore.QPointF, bool, bool]: ...
    def snapPointToGrid(self, point: QtCore.QPointF, scaleFactor: float) -> typing.Tuple[QtCore.QPointF, bool, bool]: ...
    def snapRect(self, rect: QtCore.QRectF, scaleFactor: float, horizontalSnapLine: QtWidgets.QGraphicsLineItem|None = ..., verticalSnapLine: QtWidgets.QGraphicsLineItem|None = ..., ignoreItems: collections.abc.Iterable[QgsLayoutItem] = ...) -> typing.Tuple[QtCore.QRectF, bool]: ...
    def snapPoint(self, point: QtCore.QPointF, scaleFactor: float, horizontalSnapLine: QtWidgets.QGraphicsLineItem|None = ..., verticalSnapLine: QtWidgets.QGraphicsLineItem|None = ..., ignoreItems: collections.abc.Iterable[QgsLayoutItem] = ...) -> typing.Tuple[QtCore.QPointF, bool]: ...
    def setSnapToItems(self, enabled: bool) -> None: ...
    def snapToItems(self) -> bool: ...
    def setSnapToGuides(self, enabled: bool) -> None: ...
    def snapToGuides(self) -> bool: ...
    def setSnapToGrid(self, enabled: bool) -> None: ...
    def snapToGrid(self) -> bool: ...
    def snapTolerance(self) -> int: ...
    def setSnapTolerance(self, snapTolerance: int) -> None: ...
    def layout(self) -> QgsLayout|None: ...
    def stringType(self) -> str: ...


class QgsLayoutTableStyle(PyQt6.sip.wrapper):

    cellBackgroundColor = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    enabled = ... # type: bool

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutTableStyle') -> None: ...

    def readXml(self, styleElem: QtXml.QDomElement) -> bool: ...
    def writeXml(self, styleElem: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...


class QgsLayoutTableColumn(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, heading: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutTableColumn') -> None: ...

    def __ne__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def __eq__(self, other: object): ...
    @deprecated("""""")
    def clone(self) -> 'QgsLayoutTableColumn|None': ...
    @deprecated("""""")
    def setSortByRank(self, rank: int) -> None: ...
    @deprecated("""""")
    def sortByRank(self) -> int: ...
    def setSortOrder(self, order: QtCore.Qt.SortOrder) -> None: ...
    def sortOrder(self) -> QtCore.Qt.SortOrder: ...
    def setAttribute(self, attribute: str|None) -> None: ...
    def attribute(self) -> str: ...
    def setVAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def vAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setHAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def hAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setHeading(self, heading: str|None) -> None: ...
    def heading(self) -> str: ...
    def setWidth(self, width: float) -> None: ...
    def width(self) -> float: ...
    def readXml(self, columnElem: QtXml.QDomElement) -> bool: ...
    def writeXml(self, columnElem: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...


class QgsAbstractLayoutUndoCommand(QtGui.QUndoCommand):

    def __init__(self, text: str|None, id: int = ..., parent: QtGui.QUndoCommand|None = ...) -> None: ...

    def setAfterState(self, stateDoc: QtXml.QDomDocument) -> None: ...
    def restoreState(self, stateDoc: QtXml.QDomDocument) -> None: ...
    def saveState(self, stateDoc: QtXml.QDomDocument) -> None: ...
    def containsChange(self) -> bool: ...
    def afterState(self) -> QtXml.QDomDocument: ...
    def beforeState(self) -> QtXml.QDomDocument: ...
    def saveAfterState(self) -> None: ...
    def saveBeforeState(self) -> None: ...
    def id(self) -> int: ...
    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsLayoutUndoStack(QtCore.QObject):

    def __init__(self, layout: QgsLayout|None) -> None: ...

    undoRedoOccurredForItems: typing.ClassVar[QtCore.pyqtSignal]
    def push(self, command: QtGui.QUndoCommand|None) -> None: ...
    def isBlocked(self) -> bool: ...
    def blockCommands(self, blocked: bool) -> None: ...
    def notifyUndoRedoOccurred(self, item: QgsLayoutItem|None) -> None: ...
    def stack(self) -> QtGui.QUndoStack|None: ...
    def cancelCommand(self) -> None: ...
    def endCommand(self) -> None: ...
    def beginCommand(self, object: QgsLayoutUndoObjectInterface|None, commandText: str|None, id: int = ...) -> None: ...
    def endMacro(self) -> None: ...
    def beginMacro(self, commandText: str|None) -> None: ...


class QgsLayoutUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutUtils') -> None: ...

    @staticmethod
    def predefinedScales(layout: QgsLayout|None) -> list[float]: ...
    @staticmethod
    def itemIsAClippingSource(item: QgsLayoutItem|None) -> bool: ...
    @staticmethod
    def calculatePrettySize(minimumSize: float, maximumSize: float) -> float: ...
    @staticmethod
    def mapLayerFromString(string: str|None, project: 'QgsProject|None') -> QgsMapLayer|None: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def scaleFactorFromItemStyle(style: QtWidgets.QStyleOptionGraphicsItem|None) -> float: ...
    @typing.overload
    @staticmethod
    def scaleFactorFromItemStyle(style: QtWidgets.QStyleOptionGraphicsItem|None, painter: QtGui.QPainter|None) -> float: ...
    @staticmethod
    def decodePaperOrientation(string: str|None) -> typing.Tuple[QgsLayoutItemPage.Orientation, bool]: ...
    @staticmethod
    def largestRotatedRectWithinBounds(originalRect: QtCore.QRectF, boundsRect: QtCore.QRectF, rotation: float) -> QtCore.QRectF: ...
    @typing.overload
    @staticmethod
    def drawText(painter: QtGui.QPainter|None, position: QtCore.QPointF, text: str|None, font: QtGui.QFont, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def drawText(painter: QtGui.QPainter|None, rectangle: QtCore.QRectF, text: str|None, font: QtGui.QFont, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., halignment: QtCore.Qt.AlignmentFlag = ..., valignment: QtCore.Qt.AlignmentFlag = ..., flags: int = ...) -> None: ...
    @staticmethod
    def textHeightMM(font: QtGui.QFont, text: str|None, multiLineHeight: float = ...) -> float: ...
    @staticmethod
    def textWidthMM(font: QtGui.QFont, text: str|None) -> float: ...
    @staticmethod
    def fontHeightCharacterMM(font: QtGui.QFont, character: str) -> float: ...
    @staticmethod
    def fontHeightMM(font: QtGui.QFont) -> float: ...
    @staticmethod
    def fontDescentMM(font: QtGui.QFont) -> float: ...
    @staticmethod
    def fontAscentMM(font: QtGui.QFont) -> float: ...
    @staticmethod
    def scaledFontPixelSize(font: QtGui.QFont) -> QtGui.QFont: ...
    @staticmethod
    def relativePosition(position: float, beforeMin: float, beforeMax: float, afterMin: float, afterMax: float) -> float: ...
    @staticmethod
    def relativeResizeRect(rectToResize: QtCore.QRectF, boundsBefore: QtCore.QRectF, boundsAfter: QtCore.QRectF) -> None: ...
    @staticmethod
    def createRenderContextForLayout(layout: QgsLayout|None, painter: QtGui.QPainter|None, dpi: float = ...) -> QgsRenderContext: ...
    @staticmethod
    def createRenderContextForMap(map: QgsLayoutItemMap|None, painter: QtGui.QPainter|None, dpi: float = ...) -> QgsRenderContext: ...
    @staticmethod
    def snappedAngle(angle: float) -> float: ...
    @staticmethod
    def normalizedAngle(angle: float, allowNegative: bool = ...) -> float: ...
    @staticmethod
    def rotate(angle: float) -> typing.Tuple[float, float]: ...


class QgsMasterLayoutInterface(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        PrintLayout = ... # type: QgsMasterLayoutInterface.Type
        Report = ... # type: QgsMasterLayoutInterface.Type

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMasterLayoutInterface') -> None: ...

    def layoutAccept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def updateSettings(self) -> None: ...
    def readLayoutXml(self, layoutElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeLayoutXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def layoutProject(self) -> 'QgsProject|None': ...
    def setName(self, name: str|None) -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def name(self) -> str: ...
    def layoutType(self) -> 'QgsMasterLayoutInterface.Type': ...
    def clone(self) -> 'QgsMasterLayoutInterface|None': ...


class QgsPageSize(PyQt6.sip.wrapper):

    displayName = ... # type: str|None
    name = ... # type: str|None
    size = ... # type: QgsLayoutSize

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, size: QgsLayoutSize, displayName: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, size: QgsLayoutSize) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPageSize') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsPageSizeRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPageSizeRegistry') -> None: ...

    def decodePageSize(self, string: str|None, size: QgsPageSize) -> bool: ...
    @typing.overload
    def find(self, name: str|None) -> list[QgsPageSize]: ...
    @typing.overload
    def find(self, size: QgsLayoutSize) -> str: ...
    def entries(self) -> list[QgsPageSize]: ...
    def add(self, size: QgsPageSize) -> None: ...


class QgsPrintLayout(QgsLayout, QgsMasterLayoutInterface):

    def __init__(self, project: 'QgsProject|None') -> None: ...

    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def layoutAccept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def updateSettings(self) -> None: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    def readLayoutXml(self, layoutElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeLayoutXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, layoutElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def atlas(self) -> QgsLayoutAtlas|None: ...
    def icon(self) -> QtGui.QIcon: ...
    def layoutType(self) -> QgsMasterLayoutInterface.Type: ...
    def layoutProject(self) -> 'QgsProject|None': ...
    def clone(self) -> 'QgsPrintLayout|None': ...


class QgsReport(QtCore.QObject, QgsAbstractReportSection, QgsMasterLayoutInterface):

    def __init__(self, project: 'QgsProject|None') -> None: ...

    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def layoutAccept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def updateSettings(self) -> None: ...
    def readLayoutXml(self, layoutElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeLayoutXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def clone(self) -> 'QgsReport|None': ...
    def layoutProject(self) -> 'QgsProject|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def description(self) -> str: ...
    def type(self) -> str: ...
    def layoutType(self) -> QgsMasterLayoutInterface.Type: ...


class QgsReportSectionFieldGroup(QgsAbstractReportSection):

    class SectionVisibility(enum.IntEnum):
        IncludeWhenFeaturesFound = ... # type: QgsReportSectionFieldGroup.SectionVisibility
        AlwaysInclude = ... # type: QgsReportSectionFieldGroup.SectionVisibility

    def __init__(self, parentSection: QgsAbstractReportSection|None = ...) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def reloadSettings(self) -> None: ...
    def setParentSection(self, parentSection: QgsAbstractReportSection|None) -> None: ...
    def reset(self) -> None: ...
    def nextBody(self) -> typing.Tuple[QgsLayout|None, bool]: ...
    def prepareFooter(self) -> bool: ...
    def prepareHeader(self) -> bool: ...
    def beginRender(self) -> bool: ...
    def clone(self) -> 'QgsReportSectionFieldGroup|None': ...
    def setFooterVisibility(self, visibility: 'QgsReportSectionFieldGroup.SectionVisibility') -> None: ...
    def footerVisibility(self) -> 'QgsReportSectionFieldGroup.SectionVisibility': ...
    def setHeaderVisibility(self, visibility: 'QgsReportSectionFieldGroup.SectionVisibility') -> None: ...
    def headerVisibility(self) -> 'QgsReportSectionFieldGroup.SectionVisibility': ...
    def setSortAscending(self, sortAscending: bool) -> None: ...
    def sortAscending(self) -> bool: ...
    def setField(self, field: str|None) -> None: ...
    def field(self) -> str: ...
    def setLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def layer(self) -> QgsVectorLayer|None: ...
    def setBodyEnabled(self, enabled: bool) -> None: ...
    def bodyEnabled(self) -> bool: ...
    def setBody(self, body: QgsLayout|None) -> None: ...
    def body(self) -> QgsLayout|None: ...
    def icon(self) -> QtGui.QIcon: ...
    def description(self) -> str: ...
    def type(self) -> str: ...


class QgsReportSectionLayout(QgsAbstractReportSection):

    def __init__(self, parentSection: QgsAbstractReportSection|None = ...) -> None: ...

    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def reloadSettings(self) -> None: ...
    def nextBody(self) -> typing.Tuple[QgsLayout|None, bool]: ...
    def beginRender(self) -> bool: ...
    def clone(self) -> 'QgsReportSectionLayout|None': ...
    def setBodyEnabled(self, enabled: bool) -> None: ...
    def bodyEnabled(self) -> bool: ...
    def setBody(self, body: QgsLayout|None) -> None: ...
    def body(self) -> QgsLayout|None: ...
    def icon(self) -> QtGui.QIcon: ...
    def description(self) -> str: ...
    def type(self) -> str: ...


class QgsLocator(QtCore.QObject):

    CORE_FILTERS = ... # type: collections.abc.Iterable[str|None]

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    finished: typing.ClassVar[QtCore.pyqtSignal]
    searchPrepared: typing.ClassVar[QtCore.pyqtSignal]
    foundResult: typing.ClassVar[QtCore.pyqtSignal]
    def completionList(self) -> list[str]: ...
    def clearPreviousResults(self) -> None: ...
    def isRunning(self) -> bool: ...
    def cancelWithoutBlocking(self) -> None: ...
    def cancel(self) -> None: ...
    def fetchResults(self, string: str|None, context: 'QgsLocatorContext', feedback: QgsFeedback|None = ...) -> None: ...
    def prefixedFilters(self) -> typing.Any: ...
    def filters(self, prefix: str|None = ...) -> list[QgsLocatorFilter]: ...
    def deregisterFilter(self, filter: QgsLocatorFilter|None) -> None: ...
    def registerFilter(self, filter: QgsLocatorFilter|None) -> None: ...


class QgsLocatorContext(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject
    targetExtent = ... # type: QgsRectangle
    targetExtentCrs = ... # type: 'QgsCoordinateReferenceSystem'
    transformContext = ... # type: 'QgsCoordinateTransformContext'
    usingPrefix = ... # type: bool

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLocatorContext') -> None: ...


class QgsLocatorResult(PyQt6.sip.wrapper):

    class ResultAction(PyQt6.sip.wrapper):

        iconPath = ... # type: str|None
        id = ... # type: int
        text = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, id: int, text: str|None, iconPath: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLocatorResult.ResultAction') -> None: ...

    actions = ... # type: collections.abc.Iterable['QgsLocatorResult.ResultAction']
    description = ... # type: str|None
    displayString = ... # type: str|None
    filter = ... # type: QgsLocatorFilter
    group = ... # type: str|None
    groupScore = ... # type: float
    icon = ... # type: QtGui.QIcon
    score = ... # type: float
    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, filter: QgsLocatorFilter|None, displayString: str|None, userData: typing.Any = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLocatorResult') -> None: ...

    def setUserData(self, userData: typing.Any) -> None: ...
    def _userData(self) -> typing.Any: ...


class QgsLocatorModel(QtCore.QAbstractTableModel):

    class CustomRole(enum.IntEnum):
        ResultData = ... # type: QgsLocatorModel.CustomRole
        ResultType = ... # type: QgsLocatorModel.CustomRole
        ResultFilterPriority = ... # type: QgsLocatorModel.CustomRole
        ResultScore = ... # type: QgsLocatorModel.CustomRole
        ResultFilterName = ... # type: QgsLocatorModel.CustomRole
        ResultFilterGroupSorting = ... # type: QgsLocatorModel.CustomRole
        ResultFilterGroupTitle = ... # type: QgsLocatorModel.CustomRole
        ResultFilterGroupScore = ... # type: QgsLocatorModel.CustomRole
        ResultActions = ... # type: QgsLocatorModel.CustomRole

    NoGroup = ... # type: int
    UnorderedGroup = ... # type: int

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def addResult(self, result: QgsLocatorResult) -> None: ...
    def roleNames(self) -> dict[int, QtCore.QByteArray]: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def deferredClear(self) -> None: ...
    def clear(self) -> None: ...


class QgsLocatorAutomaticModel(QgsLocatorModel):

    def __init__(self, locator: QgsLocator|None) -> None: ...

    def createContext(self) -> QgsLocatorContext: ...
    def search(self, string: str|None) -> None: ...
    def locator(self) -> QgsLocator|None: ...


class QgsLocatorProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...


class QgsLocatorModelBridge(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def selectionChanged(self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection) -> None: ...
    def updateCanvasCrs(self, crs: 'QgsCoordinateReferenceSystem') -> None: ...
    def updateCanvasExtent(self, extent: QgsRectangle) -> None: ...
    def invalidateResults(self) -> None: ...
    resultsCleared: typing.ClassVar[QtCore.pyqtSignal]
    isRunningChanged: typing.ClassVar[QtCore.pyqtSignal]
    resultAdded: typing.ClassVar[QtCore.pyqtSignal]
    def setTransformContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def transformContext(self) -> 'QgsCoordinateTransformContext': ...
    def triggerResult(self, index: QtCore.QModelIndex, actionId: int = ...) -> None: ...
    def isRunning(self) -> bool: ...
    def hasQueueRequested(self) -> bool: ...
    def proxyModel(self) -> QgsLocatorProxyModel|None: ...
    def locator(self) -> QgsLocator|None: ...
    def performSearch(self, text: str|None) -> None: ...


class QgsMapRendererCache(QtCore.QObject):

    def __init__(self) -> None: ...

    def invalidateCacheForLayer(self, layer: QgsMapLayer|None) -> None: ...
    def clearCacheImage(self, cacheKey: str|None) -> None: ...
    def dependentLayers(self, cacheKey: str|None) -> list[QgsMapLayer]: ...
    def transformedCacheImage(self, cacheKey: str|None, mtp: QgsMapToPixel) -> QtGui.QImage: ...
    def cacheImage(self, cacheKey: str|None) -> QtGui.QImage: ...
    def hasAnyCacheImage(self, cacheKey: str|None, minimumScaleThreshold: float = ..., maximumScaleThreshold: float = ...) -> bool: ...
    def hasCacheImage(self, cacheKey: str|None) -> bool: ...
    def setCacheImageWithParameters(self, cacheKey: str|None, image: QtGui.QImage, extent: QgsRectangle, mapToPixel: QgsMapToPixel, dependentLayers: collections.abc.Iterable[QgsMapLayer] = ...) -> None: ...
    def setCacheImage(self, cacheKey: str|None, image: QtGui.QImage, dependentLayers: collections.abc.Iterable[QgsMapLayer] = ...) -> None: ...
    def updateParameters(self, extent: QgsRectangle, mtp: QgsMapToPixel) -> bool: ...
    @deprecated("""""")
    def init(self, extent: QgsRectangle, scale: float) -> bool: ...
    def clear(self) -> None: ...


class QgsMapRendererJob(QtCore.QObject):

    class Error(PyQt6.sip.wrapper):

        layerID = ... # type: str|None
        message = ... # type: str|None

        @typing.overload
        def __init__(self, lid: str|None, msg: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMapRendererJob.Error') -> None: ...

    def __init__(self, settings: QgsMapSettings) -> None: ...

    def labelingHasNonDefaultCompositionModes(self) -> bool: ...
    finished: typing.ClassVar[QtCore.pyqtSignal]
    layerRendered: typing.ClassVar[QtCore.pyqtSignal]
    layerRenderingStarted: typing.ClassVar[QtCore.pyqtSignal]
    renderingLayersFinished: typing.ClassVar[QtCore.pyqtSignal]
    def mapSettings(self) -> QgsMapSettings: ...
    def renderingTime(self) -> int: ...
    def setCache(self, cache: QgsMapRendererCache|None) -> None: ...
    def errors(self) -> list['QgsMapRendererJob.Error']: ...
    def featureFilterProvider(self) -> QgsFeatureFilterProvider|None: ...
    def setFeatureFilterProvider(self, f: QgsFeatureFilterProvider|None) -> None: ...
    def takeRenderedItemResults(self) -> 'QgsRenderedItemResults|None': ...
    def takeLabelingResults(self) -> QgsLabelingResults|None: ...
    def layersRedrawnFromCache(self) -> list[str]: ...
    def usedCachedLabels(self) -> bool: ...
    def isActive(self) -> bool: ...
    def waitForFinished(self) -> None: ...
    def cancelWithoutBlocking(self) -> None: ...
    def cancel(self) -> None: ...
    def start(self) -> None: ...


class QgsMapRendererAbstractCustomPainterJob(QgsMapRendererJob):

    def __init__(self, settings: QgsMapSettings) -> None: ...

    def preparePainter(self, painter: QtGui.QPainter|None, backgroundColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...


class QgsMapRendererCustomPainterJob(QgsMapRendererAbstractCustomPainterJob):

    def __init__(self, settings: QgsMapSettings, painter: QtGui.QPainter|None) -> None: ...

    def renderPrepared(self) -> None: ...
    def prepare(self) -> None: ...
    def renderSynchronously(self) -> None: ...
    def waitForFinishedWithEventLoop(self, flags: QtCore.QEventLoop.ProcessEventsFlag = ...) -> None: ...
    def takeLabelingResults(self) -> QgsLabelingResults|None: ...
    def usedCachedLabels(self) -> bool: ...
    def isActive(self) -> bool: ...
    def waitForFinished(self) -> None: ...
    def cancelWithoutBlocking(self) -> None: ...
    def cancel(self) -> None: ...


class QgsMapRendererQImageJob(QgsMapRendererJob):

    def __init__(self, settings: QgsMapSettings) -> None: ...

    def renderedImage(self) -> QtGui.QImage: ...


class QgsMapRendererParallelJob(QgsMapRendererQImageJob):

    def __init__(self, settings: QgsMapSettings) -> None: ...

    def renderedImage(self) -> QtGui.QImage: ...
    def takeLabelingResults(self) -> QgsLabelingResults|None: ...
    def usedCachedLabels(self) -> bool: ...
    def isActive(self) -> bool: ...
    def waitForFinished(self) -> None: ...
    def cancelWithoutBlocking(self) -> None: ...
    def cancel(self) -> None: ...


class QgsMapRendererSequentialJob(QgsMapRendererQImageJob):

    def __init__(self, settings: QgsMapSettings) -> None: ...

    def internalFinished(self) -> None: ...
    def renderedImage(self) -> QtGui.QImage: ...
    def takeLabelingResults(self) -> QgsLabelingResults|None: ...
    def usedCachedLabels(self) -> bool: ...
    def isActive(self) -> bool: ...
    def waitForFinished(self) -> None: ...
    def cancelWithoutBlocking(self) -> None: ...
    def cancel(self) -> None: ...


class QgsMapRendererTask(QgsTask):

    class ErrorType(enum.IntEnum):
        ImageAllocationFail = ... # type: QgsMapRendererTask.ErrorType
        ImageSaveFail = ... # type: QgsMapRendererTask.ErrorType
        ImageUnsupportedFormat = ... # type: QgsMapRendererTask.ErrorType

    @typing.overload
    def __init__(self, ms: QgsMapSettings, fileName: str|None, fileFormat: str|None = ..., forceRaster: bool = ..., flags: QgsTask.Flag = ...) -> None: ...
    @typing.overload
    def __init__(self, ms: QgsMapSettings, p: QtGui.QPainter|None) -> None: ...

    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    renderingComplete: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    def setExportMetadata(self, exportMetadata: bool) -> None: ...
    def setSaveWorldFile(self, save: bool) -> None: ...
    def addDecorations(self, decorations: collections.abc.Iterable[QgsMapDecoration]) -> None: ...
    def addAnnotations(self, annotations: collections.abc.Iterable[QgsAnnotation]) -> None: ...


class QgsRenderedItemResults(PyQt6.sip.wrapper):

    def __init__(self, extent: QgsRectangle = ...) -> None: ...

    def eraseResultsFromLayers(self, layerIds: collections.abc.Iterable[str|None]) -> None: ...
    @typing.overload
    def transferResults(self, other: 'QgsRenderedItemResults|None', layerIds: collections.abc.Iterable[str|None]) -> None: ...
    @typing.overload
    def transferResults(self, other: 'QgsRenderedItemResults|None') -> None: ...
    def appendResults(self, results: collections.abc.Iterable[QgsRenderedItemDetails], context: QgsRenderContext) -> None: ...
    def renderedAnnotationItemsInBounds(self, bounds: QgsRectangle) -> list[QgsRenderedAnnotationItemDetails]: ...
    def renderedItems(self) -> list[QgsRenderedItemDetails]: ...


class QgsMesh3DAveragingMethod(PyQt6.sip.wrapper):

    class Method(enum.IntEnum):
        MultiLevelsAveragingMethod = ... # type: QgsMesh3DAveragingMethod.Method
        SigmaAveragingMethod = ... # type: QgsMesh3DAveragingMethod.Method
        RelativeHeightAveragingMethod = ... # type: QgsMesh3DAveragingMethod.Method
        ElevationAveragingMethod = ... # type: QgsMesh3DAveragingMethod.Method

    @typing.overload
    def __init__(self, method: 'QgsMesh3DAveragingMethod.Method') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMesh3DAveragingMethod') -> None: ...

    def method(self) -> 'QgsMesh3DAveragingMethod.Method': ...
    def clone(self) -> 'QgsMesh3DAveragingMethod|None': ...
    @typing.overload
    @staticmethod
    def equals(a: 'QgsMesh3DAveragingMethod|None', b: 'QgsMesh3DAveragingMethod|None') -> bool: ...
    @typing.overload
    def equals(self, other: 'QgsMesh3DAveragingMethod|None') -> bool: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    @staticmethod
    def createFromXml(elem: QtXml.QDomElement) -> 'QgsMesh3DAveragingMethod|None': ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def calculate(self, block3d: 'QgsMesh3DDataBlock', feedback: QgsFeedback|None = ...) -> 'QgsMeshDataBlock': ...


class QgsMeshMultiLevelsAveragingMethod(QgsMesh3DAveragingMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, startLevel: int, endLevel: int, countedFromTop: bool) -> None: ...
    @typing.overload
    def __init__(self, verticalLevel: int, countedFromTop: bool) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshMultiLevelsAveragingMethod') -> None: ...

    def isSingleLevel(self) -> bool: ...
    def countedFromTop(self) -> bool: ...
    def endVerticalLevel(self) -> int: ...
    def startVerticalLevel(self) -> int: ...
    def clone(self) -> QgsMesh3DAveragingMethod|None: ...
    def equals(self, other: QgsMesh3DAveragingMethod|None) -> bool: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...


class QgsMeshSigmaAveragingMethod(QgsMesh3DAveragingMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, startFraction: float, endFraction: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshSigmaAveragingMethod') -> None: ...

    def endFraction(self) -> float: ...
    def startFraction(self) -> float: ...
    def clone(self) -> QgsMesh3DAveragingMethod|None: ...
    def equals(self, other: QgsMesh3DAveragingMethod|None) -> bool: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...


class QgsMeshRelativeHeightAveragingMethod(QgsMesh3DAveragingMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, startHeight: float, endHeight: float, countedFromTop: bool) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRelativeHeightAveragingMethod') -> None: ...

    def countedFromTop(self) -> bool: ...
    def endHeight(self) -> float: ...
    def startHeight(self) -> float: ...
    def clone(self) -> QgsMesh3DAveragingMethod|None: ...
    def equals(self, other: QgsMesh3DAveragingMethod|None) -> bool: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...


class QgsMeshElevationAveragingMethod(QgsMesh3DAveragingMethod):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, startElevation: float, endElevation: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshElevationAveragingMethod') -> None: ...

    def endElevation(self) -> float: ...
    def startElevation(self) -> float: ...
    def clone(self) -> QgsMesh3DAveragingMethod|None: ...
    def equals(self, other: QgsMesh3DAveragingMethod|None) -> bool: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...


class QgsMeshEditingError(PyQt6.sip.wrapper):

    elementIndex = ... # type: int
    errorType = ... # type: Qgis.MeshEditingErrorType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, type: Qgis.MeshEditingErrorType, elementIndex: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshEditingError') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsMeshEditor(QtCore.QObject):

    def __init__(self, meshLayer: 'QgsMeshLayer|None') -> None: ...

    meshEdited: typing.ClassVar[QtCore.pyqtSignal]
    def addVertexWithDelaunayRefinement(self, vertex: QgsPoint, tolerance: float) -> None: ...
    def maximumVerticesPerFace(self) -> int: ...
    def validVerticesCount(self) -> int: ...
    def validFacesCount(self) -> int: ...
    def edgeIsClose(self, point: QgsPointXY, tolerance: float) -> typing.Tuple[bool, int, int]: ...
    def checkConsistency(self, error: QgsMeshEditingError) -> bool: ...
    def isVertexFree(self, vertexIndex: int) -> bool: ...
    def isVertexOnBoundary(self, vertexIndex: int) -> bool: ...
    def freeVerticesIndexes(self) -> list[int]: ...
    def reindex(self, renumbering: bool) -> bool: ...
    def isModified(self) -> bool: ...
    def extent(self) -> QgsRectangle: ...
    def stopEditing(self) -> None: ...
    def advancedEdit(self, editing: 'QgsMeshAdvancedEditing|None') -> None: ...
    def changeCoordinates(self, verticesIndexes: collections.abc.Iterable[int], newCoordinates: collections.abc.Iterable[QgsPoint]) -> None: ...
    def changeXYValues(self, verticesIndexes: collections.abc.Iterable[int], newValues: collections.abc.Iterable[QgsPointXY]) -> None: ...
    def changeZValues(self, verticesIndexes: collections.abc.Iterable[int], newValues: collections.abc.Iterable[float]) -> None: ...
    def removeVerticesFillHoles(self, verticesToRemoveIndexes: collections.abc.Iterable[int]) -> list[int]: ...
    def removeVerticesWithoutFillHoles(self, verticesToRemoveIndexes: collections.abc.Iterable[int]) -> QgsMeshEditingError: ...
    def addPointsAsVertices(self, point: collections.abc.Iterable[QgsPoint], tolerance: float) -> int: ...
    def splitFaces(self, faceIndexes: collections.abc.Iterable[int]) -> int: ...
    def faceCanBeSplit(self, faceIndex: int) -> bool: ...
    def merge(self, vertexIndex1: int, vertexIndex2: int) -> None: ...
    def canBeMerged(self, vertexIndex1: int, vertexIndex2: int) -> bool: ...
    def flipEdge(self, vertexIndex1: int, vertexIndex2: int) -> None: ...
    def edgeCanBeFlipped(self, vertexIndex1: int, vertexIndex2: int) -> bool: ...
    def removeFaces(self, facesToRemove: collections.abc.Iterable[int]) -> QgsMeshEditingError: ...
    def addFace(self, vertexIndexes: collections.abc.Iterable[int]) -> QgsMeshEditingError: ...
    def isFaceGeometricallyCompatible(self, face: collections.abc.Iterable[int]) -> bool: ...
    def faceCanBeAdded(self, face: collections.abc.Iterable[int]) -> bool: ...
    def fixError(self, error: QgsMeshEditingError) -> bool: ...
    def initializeWithErrorsFix(self) -> QgsMeshEditingError: ...
    def initialize(self) -> QgsMeshEditingError: ...
    def createZValueDatasetGroup(self) -> 'QgsMeshDatasetGroup'|None: ...


class QgsMesh(PyQt6.sip.wrapper):

    class ElementType(enum.IntEnum):
        Vertex = ... # type: QgsMesh.ElementType
        Edge = ... # type: QgsMesh.ElementType
        Face = ... # type: QgsMesh.ElementType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMesh') -> None: ...

    @staticmethod
    def compareFaces(face1: collections.abc.Iterable[int], face2: collections.abc.Iterable[int]) -> bool: ...
    def clear(self) -> None: ...
    def edge(self, index: int) -> tuple[int, int]: ...
    def face(self, index: int) -> list[int]: ...
    def vertex(self, index: int) -> QgsPoint: ...
    def edgeCount(self) -> int: ...
    def faceCount(self) -> int: ...
    def vertexCount(self) -> int: ...
    def contains(self, type: 'QgsMesh.ElementType') -> bool: ...


class QgsMeshDataSourceInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDataSourceInterface') -> None: ...

    def saveMeshFrame(self, mesh: QgsMesh) -> bool: ...
    def populateMesh(self, mesh: QgsMesh|None) -> None: ...
    def maximumVerticesCountPerFace(self) -> int: ...
    def edgeCount(self) -> int: ...
    def faceCount(self) -> int: ...
    def vertexCount(self) -> int: ...
    def contains(self, type: QgsMesh.ElementType) -> bool: ...


class QgsMeshDatasetSourceInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetSourceInterface') -> None: ...

    def datasetIndexInTimeInterval(self, referenceTime: QtCore.QDateTime|datetime.datetime, groupIndex: int, time1: int, time2: int) -> list['QgsMeshDatasetIndex']: ...
    def datasetIndexAtTime(self, referenceTime: QtCore.QDateTime|datetime.datetime, groupIndex: int, time: int, method: 'QgsMeshDataProviderTemporalCapabilities.MatchingTemporalDatasetMethod') -> 'QgsMeshDatasetIndex': ...
    @typing.overload
    @deprecated("""""")
    def persistDatasetGroup(self, path: str|None, meta: 'QgsMeshDatasetGroupMetadata', datasetValues: collections.abc.Iterable['QgsMeshDataBlock'], datasetActive: collections.abc.Iterable['QgsMeshDataBlock'], times: collections.abc.Iterable[float]) -> bool: ...
    @typing.overload
    def persistDatasetGroup(self, outputFilePath: str|None, outputDriver: str|None, meta: 'QgsMeshDatasetGroupMetadata', datasetValues: collections.abc.Iterable['QgsMeshDataBlock'], datasetActive: collections.abc.Iterable['QgsMeshDataBlock'], times: collections.abc.Iterable[float]) -> bool: ...
    @typing.overload
    def persistDatasetGroup(self, outputFilePath: str|None, outputDriver: str|None, source: 'QgsMeshDatasetSourceInterface|None', datasetGroupIndex: int) -> bool: ...
    def areFacesActive(self, index: 'QgsMeshDatasetIndex', faceIndex: int, count: int) -> 'QgsMeshDataBlock': ...
    def isFaceActive(self, index: 'QgsMeshDatasetIndex', faceIndex: int) -> bool: ...
    def dataset3dValues(self, index: 'QgsMeshDatasetIndex', faceIndex: int, count: int) -> 'QgsMesh3DDataBlock': ...
    def datasetValues(self, index: 'QgsMeshDatasetIndex', valueIndex: int, count: int) -> 'QgsMeshDataBlock': ...
    def datasetValue(self, index: 'QgsMeshDatasetIndex', valueIndex: int) -> 'QgsMeshDatasetValue': ...
    def datasetMetadata(self, index: 'QgsMeshDatasetIndex') -> 'QgsMeshDatasetMetadata': ...
    @typing.overload
    def datasetGroupMetadata(self, groupIndex: int) -> 'QgsMeshDatasetGroupMetadata': ...
    @typing.overload
    def datasetGroupMetadata(self, index: 'QgsMeshDatasetIndex') -> 'QgsMeshDatasetGroupMetadata': ...
    @typing.overload
    def datasetCount(self, groupIndex: int) -> int: ...
    @typing.overload
    def datasetCount(self, index: 'QgsMeshDatasetIndex') -> int: ...
    def datasetGroupCount(self) -> int: ...
    def extraDatasets(self) -> list[str]: ...
    def addDataset(self, uri: str|None) -> bool: ...


class QgsDataProvider(QtCore.QObject):

    class ProviderProperty(enum.IntEnum):
        EvaluateDefaultValues = ... # type: QgsDataProvider.ProviderProperty
        CustomData = ... # type: QgsDataProvider.ProviderProperty

    class ProviderOptions(PyQt6.sip.wrapper):

        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDataProvider.ProviderOptions') -> None: ...

    def __init__(self, uri: str|None = ..., providerOptions: 'QgsDataProvider.ProviderOptions' = ..., flags: Qgis.DataProviderReadFlag = ...) -> None: ...

    def setError(self, error: QgsError) -> None: ...
    def appendError(self, message: QgsErrorMessage) -> None: ...
    notify: typing.ClassVar[QtCore.pyqtSignal]
    dataChanged: typing.ClassVar[QtCore.pyqtSignal]
    fullExtentCalculated: typing.ClassVar[QtCore.pyqtSignal]
    def styleStorageCapabilities(self) -> Qgis.ProviderStyleStorageCapability: ...
    @staticmethod
    def sublayerSeparator() -> str: ...
    def writeLayerMetadata(self, metadata: 'QgsLayerMetadata') -> bool: ...
    def layerMetadata(self) -> 'QgsLayerMetadata': ...
    def setListening(self, isListening: bool) -> None: ...
    def providerProperty(self, property: 'QgsDataProvider.ProviderProperty', defaultValue: typing.Any = ...) -> typing.Any: ...
    def setProviderProperty(self, property: 'QgsDataProvider.ProviderProperty', value: typing.Any) -> None: ...
    def leaveUpdateMode(self) -> bool: ...
    def enterUpdateMode(self) -> bool: ...
    def invalidateConnections(self, connection: str|None) -> None: ...
    def error(self) -> QgsError: ...
    def dataTimestamp(self) -> QtCore.QDateTime: ...
    def timestamp(self) -> QtCore.QDateTime: ...
    def reloadData(self) -> None: ...
    def fileRasterFilters(self) -> str: ...
    def fileVectorFilters(self) -> str: ...
    def description(self) -> str: ...
    def name(self) -> str: ...
    def setSubLayerVisibility(self, name: str|None, vis: bool) -> None: ...
    def setLayerOrder(self, layers: collections.abc.Iterable[str|None]) -> None: ...
    def subLayerCount(self) -> int: ...
    def subLayerStyles(self) -> list[str]: ...
    def subLayers(self) -> list[str]: ...
    def subsetString(self) -> str: ...
    def supportsSubsetString(self) -> bool: ...
    def setSubsetString(self, subset: str|None, updateFeatureCount: bool = ...) -> bool: ...
    def subsetStringHelpUrl(self) -> str: ...
    def subsetStringDialect(self) -> str: ...
    def updateExtents(self) -> None: ...
    def isValid(self) -> bool: ...
    def extent3D(self) -> QgsBox3D: ...
    def extent(self) -> QgsRectangle: ...
    def elevationProperties(self) -> QgsDataProviderElevationProperties|None: ...
    def temporalCapabilities(self) -> QgsDataProviderTemporalCapabilities|None: ...
    def flags(self) -> Qgis.DataProviderFlag: ...
    def uri(self) -> QgsDataSourceUri: ...
    @typing.overload
    def setUri(self, uri: QgsDataSourceUri) -> None: ...
    @typing.overload
    def setUri(self, uri: str|None) -> None: ...
    def metadata(self) -> dict[str, typing.Any]: ...
    def htmlMetadata(self) -> str: ...
    def dataComment(self) -> str: ...
    def dataSourceUri(self, expandAuthConfig: bool = ...) -> str: ...
    def setDataSourceUri(self, uri: str|None) -> None: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...


class QgsMeshDataProvider(QgsDataProvider, QgsMeshDataSourceInterface, QgsMeshDatasetSourceInterface):

    def __init__(self, uri: str|None, providerOptions: QgsDataProvider.ProviderOptions, a2: Qgis.DataProviderReadFlag = ...) -> None: ...

    datasetGroupsAdded: typing.ClassVar[QtCore.pyqtSignal]
    def removeDatasetGroup(self, index: int) -> bool: ...
    def close(self) -> None: ...
    def driverMetadata(self) -> 'QgsMeshDriverMetadata': ...
    def setTemporalUnit(self, unit: Qgis.TemporalUnit) -> None: ...
    def temporalCapabilities(self) -> 'QgsMeshDataProviderTemporalCapabilities|None': ...


class QgsMeshDataProviderTemporalCapabilities(QgsDataProviderTemporalCapabilities):

    class MatchingTemporalDatasetMethod(enum.IntEnum):
        FindClosestDatasetBeforeStartRangeTime = ... # type: QgsMeshDataProviderTemporalCapabilities.MatchingTemporalDatasetMethod
        FindClosestDatasetFromStartRangeTime = ... # type: QgsMeshDataProviderTemporalCapabilities.MatchingTemporalDatasetMethod

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDataProviderTemporalCapabilities') -> None: ...

    def firstTimeStepDuration(self, group: int) -> int: ...
    def clear(self) -> None: ...
    def datasetTime(self, index: 'QgsMeshDatasetIndex') -> int: ...
    def temporalUnit(self) -> Qgis.TemporalUnit: ...
    def setTemporalUnit(self, temporalUnit: Qgis.TemporalUnit) -> None: ...
    @typing.overload
    def timeExtent(self) -> QgsDateTimeRange: ...
    @typing.overload
    def timeExtent(self, reference: QtCore.QDateTime|datetime.datetime) -> QgsDateTimeRange: ...
    def referenceTime(self) -> QtCore.QDateTime: ...
    def hasReferenceTime(self) -> bool: ...
    def datasetIndexClosestFromRelativeTime(self, group: int, timeSinceGlobalReference: int) -> 'QgsMeshDatasetIndex': ...
    def datasetIndexClosestBeforeRelativeTime(self, group: int, timeSinceGlobalReference: int) -> 'QgsMeshDatasetIndex': ...


class QgsMeshDatasetIndex(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, group: int = ..., dataset: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetIndex') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def isValid(self) -> bool: ...
    def dataset(self) -> int: ...
    def group(self) -> int: ...


class QgsMeshDatasetValue(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, x: float, y: float) -> None: ...
    @typing.overload
    def __init__(self, scalar: float) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetValue') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def y(self) -> float: ...
    def x(self) -> float: ...
    def scalar(self) -> float: ...
    def setY(self, y: float) -> None: ...
    def setX(self, x: float) -> None: ...
    def set(self, scalar: float) -> None: ...


class QgsMeshDataBlock(PyQt6.sip.wrapper):

    class DataType(enum.IntEnum):
        ActiveFlagInteger = ... # type: QgsMeshDataBlock.DataType
        ScalarDouble = ... # type: QgsMeshDataBlock.DataType
        Vector2DDouble = ... # type: QgsMeshDataBlock.DataType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, type: 'QgsMeshDataBlock.DataType', count: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDataBlock') -> None: ...

    def setValid(self, valid: bool) -> None: ...
    def setValues(self, vals: collections.abc.Iterable[float]) -> None: ...
    def values(self) -> list[float]: ...
    def setActive(self, vals: collections.abc.Iterable[int]) -> None: ...
    @typing.overload
    def active(self, index: int) -> bool: ...
    @typing.overload
    def active(self) -> list[int]: ...
    def value(self, index: int) -> QgsMeshDatasetValue: ...
    def isValid(self) -> bool: ...
    def count(self) -> int: ...
    def type(self) -> 'QgsMeshDataBlock.DataType': ...


class QgsMesh3DDataBlock(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsMesh3DDataBlock') -> None: ...
    @typing.overload
    def __init__(self, count: int, isVector: bool) -> None: ...

    def setValues(self, doubleBuffer: collections.abc.Iterable[float]) -> None: ...
    def value(self, volumeIndex: int) -> QgsMeshDatasetValue: ...
    def values(self) -> list[float]: ...
    def setFaceToVolumeIndex(self, faceToVolumeIndex: collections.abc.Iterable[int]) -> None: ...
    def faceToVolumeIndex(self) -> list[int]: ...
    def setVerticalLevels(self, verticalLevels: collections.abc.Iterable[float]) -> None: ...
    def verticalLevels(self) -> list[float]: ...
    def setVerticalLevelsCount(self, verticalLevelsCount: collections.abc.Iterable[int]) -> None: ...
    def verticalLevelsCount(self) -> list[int]: ...
    def volumesCount(self) -> int: ...
    def lastVolumeIndex(self) -> int: ...
    def firstVolumeIndex(self) -> int: ...
    def count(self) -> int: ...
    def isVector(self) -> bool: ...
    def isValid(self) -> bool: ...
    def setValid(self, valid: bool) -> None: ...


class QgsMeshDatasetGroupMetadata(PyQt6.sip.wrapper):

    class DataType(enum.IntEnum):
        DataOnFaces = ... # type: QgsMeshDatasetGroupMetadata.DataType
        DataOnVertices = ... # type: QgsMeshDatasetGroupMetadata.DataType
        DataOnVolumes = ... # type: QgsMeshDatasetGroupMetadata.DataType
        DataOnEdges = ... # type: QgsMeshDatasetGroupMetadata.DataType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, uri: str|None, isScalar: bool, dataType: 'QgsMeshDatasetGroupMetadata.DataType', minimum: float, maximum: float, maximumVerticalLevels: int, referenceTime: QtCore.QDateTime|datetime.datetime, isTemporal: bool, extraOptions: dict[str|None, str|None]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetGroupMetadata') -> None: ...

    def referenceTime(self) -> QtCore.QDateTime: ...
    def maximumVerticalLevelsCount(self) -> int: ...
    def maximum(self) -> float: ...
    def minimum(self) -> float: ...
    def dataType(self) -> 'QgsMeshDatasetGroupMetadata.DataType': ...
    def isTemporal(self) -> bool: ...
    def isScalar(self) -> bool: ...
    def isVector(self) -> bool: ...
    def extraOptions(self) -> dict[str, str]: ...
    def uri(self) -> str: ...
    def parentQuantityName(self) -> str: ...
    def name(self) -> str: ...


class QgsMeshDatasetMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, time: float, isValid: bool, minimum: float, maximum: float, maximumVerticalLevels: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetMetadata') -> None: ...

    def maximumVerticalLevelsCount(self) -> int: ...
    def maximum(self) -> float: ...
    def minimum(self) -> float: ...
    def isValid(self) -> bool: ...
    def time(self) -> float: ...


class QgsMeshDataset(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDataset') -> None: ...

    def valuesCount(self) -> int: ...
    def metadata(self) -> QgsMeshDatasetMetadata: ...
    def isActive(self, faceIndex: int) -> bool: ...
    def areFacesActive(self, faceIndex: int, count: int) -> QgsMeshDataBlock: ...
    def datasetValues(self, isScalar: bool, valueIndex: int, count: int) -> QgsMeshDataBlock: ...
    def datasetValue(self, valueIndex: int) -> QgsMeshDatasetValue: ...


class QgsMeshDatasetGroup(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        Unknown = ... # type: QgsMeshDatasetGroup.Type
        Persistent = ... # type: QgsMeshDatasetGroup.Type
        Memory = ... # type: QgsMeshDatasetGroup.Type
        Virtual = ... # type: QgsMeshDatasetGroup.Type

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, dataType: QgsMeshDatasetGroupMetadata.DataType) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetGroup') -> None: ...

    def setReferenceTime(self, referenceTime: QtCore.QDateTime|datetime.datetime) -> None: ...
    def description(self) -> str: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def datasetGroupNamesDependentOn(self) -> list[str]: ...
    def setStatisticObsolete(self) -> None: ...
    def calculateStatistic(self) -> None: ...
    def checkValueCountPerDataset(self, count: int) -> bool: ...
    def setIsScalar(self, isScalar: bool) -> None: ...
    def isScalar(self) -> bool: ...
    def extraMetadata(self) -> dict[str, str]: ...
    def addExtraMetadata(self, key: str|None, value: str|None) -> None: ...
    def setDataType(self, dataType: QgsMeshDatasetGroupMetadata.DataType) -> None: ...
    def dataType(self) -> QgsMeshDatasetGroupMetadata.DataType: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def setMinimumMaximum(self, min: float, max: float) -> None: ...
    def maximum(self) -> float: ...
    def minimum(self) -> float: ...
    def type(self) -> 'QgsMeshDatasetGroup.Type': ...
    def dataset(self, index: int) -> QgsMeshDataset|None: ...
    def datasetCount(self) -> int: ...
    def datasetMetadata(self, datasetIndex: int) -> QgsMeshDatasetMetadata: ...
    def groupMetadata(self) -> QgsMeshDatasetGroupMetadata: ...
    def initialize(self) -> None: ...


class QgsMeshDatasetGroupTreeItem(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, defaultName: str|None, sourceName: str|None, isVector: bool, index: int) -> None: ...
    @typing.overload
    def __init__(self, itemElement: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDatasetGroupTreeItem') -> None: ...

    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def setPersistentDatasetGroup(self, uri: str|None) -> None: ...
    def setDatasetGroup(self, datasetGroup: QgsMeshDatasetGroup|None) -> None: ...
    def description(self) -> str: ...
    def groupIndexDependencies(self) -> list[int]: ...
    def datasetGroupType(self) -> QgsMeshDatasetGroup.Type: ...
    def defaultName(self) -> str: ...
    def setIsEnabled(self, isEnabled: bool) -> None: ...
    def isEnabled(self) -> bool: ...
    def datasetGroupIndex(self) -> int: ...
    def isVector(self) -> bool: ...
    def providerName(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def row(self) -> int: ...
    def parentItem(self) -> 'QgsMeshDatasetGroupTreeItem|None': ...
    def enabledDatasetGroupIndexes(self) -> list[int]: ...
    def totalChildCount(self) -> int: ...
    def childCount(self) -> int: ...
    def childFromDatasetGroupIndex(self, index: int) -> 'QgsMeshDatasetGroupTreeItem|None': ...
    def child(self, row: int) -> 'QgsMeshDatasetGroupTreeItem|None': ...
    def removeChild(self, item: 'QgsMeshDatasetGroupTreeItem|None') -> None: ...
    def appendChild(self, item: 'QgsMeshDatasetGroupTreeItem|None') -> None: ...
    def clone(self) -> 'QgsMeshDatasetGroupTreeItem|None': ...


class QgsMeshLayer(QgsMapLayer, QgsAbstractProfileSource):

    class LayerOptions(PyQt6.sip.wrapper):

        loadDefaultStyle = ... # type: bool
        skipCrsValidation = ... # type: bool
        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, transformContext: 'QgsCoordinateTransformContext' = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMeshLayer.LayerOptions') -> None: ...

    def __init__(self, path: str|None = ..., baseName: str|None = ..., providerLib: str|None = ..., options: 'QgsMeshLayer.LayerOptions' = ...) -> None: ...

    reloaded: typing.ClassVar[QtCore.pyqtSignal]
    timeSettingsChanged: typing.ClassVar[QtCore.pyqtSignal]
    activeVectorDatasetGroupChanged: typing.ClassVar[QtCore.pyqtSignal]
    activeScalarDatasetGroupChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTransformContext(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
    def loadNamedStyle(self, uri: str|None, categories: QgsMapLayer.StyleCategory = ..., flags: Qgis.LoadStyleFlag = ...) -> typing.Tuple[str, bool]: ...
    def extraDatasetUris(self) -> list[str]: ...
    def datasetsPathUnique(self, path: str|None) -> bool: ...
    def activeScalarDatasetIndex(self, rendererContext: QgsRenderContext) -> QgsMeshDatasetIndex: ...
    def minimumMaximumActiveScalarDataset(self, extent: QgsRectangle, datasetIndex: QgsMeshDatasetIndex) -> typing.Tuple[bool, float, float]: ...
    def setLabeling(self, labeling: 'QgsAbstractMeshLayerLabeling|None') -> None: ...
    def labeling(self) -> 'QgsAbstractMeshLayerLabeling|None': ...
    def setLabelsEnabled(self, enabled: bool) -> None: ...
    def labelsEnabled(self) -> bool: ...
    def meshEdgeCount(self) -> int: ...
    def meshFaceCount(self) -> int: ...
    def meshVertexCount(self) -> int: ...
    def contains(self, type: QgsMesh.ElementType) -> bool: ...
    def isModified(self) -> bool: ...
    def meshEditor(self) -> QgsMeshEditor|None: ...
    def reindex(self, transform: 'QgsCoordinateTransform', renumber: bool) -> bool: ...
    def stopFrameEditing(self, transform: 'QgsCoordinateTransform') -> None: ...
    def rollBackFrameEditing(self, transform: 'QgsCoordinateTransform', continueEditing: bool = ...) -> bool: ...
    def commitFrameEditing(self, transform: 'QgsCoordinateTransform', continueEditing: bool = ...) -> bool: ...
    @typing.overload
    def startFrameEditing(self, transform: 'QgsCoordinateTransform') -> bool: ...
    @typing.overload
    def startFrameEditing(self, transform: 'QgsCoordinateTransform', fixErrors: bool) -> typing.Tuple[bool, QgsMeshEditingError]: ...
    def datasetRelativeTimeInMilliseconds(self, index: QgsMeshDatasetIndex) -> int: ...
    def datasetRelativeTime(self, index: QgsMeshDatasetIndex) -> QgsInterval: ...
    def firstValidTimeStep(self) -> QgsInterval: ...
    def resetDatasetGroupTreeItem(self) -> None: ...
    def setDatasetGroupTreeRootItem(self, rootItem: QgsMeshDatasetGroupTreeItem|None) -> None: ...
    def datasetGroupTreeRootItem(self) -> QgsMeshDatasetGroupTreeItem|None: ...
    def selectFacesByExpression(self, expression: QgsExpression) -> list[int]: ...
    def selectVerticesByExpression(self, expression: QgsExpression) -> list[int]: ...
    def closestElement(self, elementType: QgsMesh.ElementType, point: QgsPointXY, searchRadius: float) -> typing.Tuple[int, QgsPointXY]: ...
    def snapOnElement(self, elementType: QgsMesh.ElementType, point: QgsPointXY, searchRadius: float) -> QgsPointXY: ...
    def setTemporalMatchingMethod(self, matchingMethod: QgsMeshDataProviderTemporalCapabilities.MatchingTemporalDatasetMethod) -> None: ...
    def setReferenceTime(self, referenceTime: QtCore.QDateTime|datetime.datetime) -> None: ...
    def staticVectorDatasetIndex(self, group: int = ...) -> QgsMeshDatasetIndex: ...
    def staticScalarDatasetIndex(self, group: int = ...) -> QgsMeshDatasetIndex: ...
    def activeVectorDatasetAtTime(self, timeRange: QgsDateTimeRange, group: int = ...) -> QgsMeshDatasetIndex: ...
    def activeScalarDatasetAtTime(self, timeRange: QgsDateTimeRange, group: int = ...) -> QgsMeshDatasetIndex: ...
    def datasetIndexInRelativeTimeInterval(self, startRelativeTime: QgsInterval, endRelativeTime: QgsInterval, datasetGroupIndex: int) -> list[QgsMeshDatasetIndex]: ...
    def datasetIndexAtRelativeTime(self, relativeTime: QgsInterval, datasetGroupIndex: int) -> QgsMeshDatasetIndex: ...
    def datasetIndexAtTime(self, timeRange: QgsDateTimeRange, datasetGroupIndex: int) -> QgsMeshDatasetIndex: ...
    def dataset1dValue(self, index: QgsMeshDatasetIndex, point: QgsPointXY, searchRadius: float) -> QgsMeshDatasetValue: ...
    def dataset3dValue(self, index: QgsMeshDatasetIndex, point: QgsPointXY) -> QgsMesh3DDataBlock: ...
    def areFacesActive(self, index: QgsMeshDatasetIndex, faceIndex: int, count: int) -> QgsMeshDataBlock: ...
    def isFaceActive(self, index: QgsMeshDatasetIndex, faceIndex: int) -> bool: ...
    def dataset3dValues(self, index: QgsMeshDatasetIndex, faceIndex: int, count: int) -> QgsMesh3DDataBlock: ...
    def datasetValues(self, index: QgsMeshDatasetIndex, valueIndex: int, count: int) -> QgsMeshDataBlock: ...
    @typing.overload
    def datasetValue(self, index: QgsMeshDatasetIndex, valueIndex: int) -> QgsMeshDatasetValue: ...
    @typing.overload
    def datasetValue(self, index: QgsMeshDatasetIndex, point: QgsPointXY, searchRadius: float = ...) -> QgsMeshDatasetValue: ...
    def datasetMetadata(self, index: QgsMeshDatasetIndex) -> QgsMeshDatasetMetadata: ...
    def datasetCount(self, index: QgsMeshDatasetIndex) -> int: ...
    def datasetGroupMetadata(self, index: QgsMeshDatasetIndex) -> QgsMeshDatasetGroupMetadata: ...
    def enabledDatasetGroupsIndexes(self) -> list[int]: ...
    def datasetGroupsIndexes(self) -> list[int]: ...
    def extraDatasetGroupCount(self) -> int: ...
    def datasetGroupCount(self) -> int: ...
    def formatTime(self, hours: float) -> str: ...
    def setTimeSettings(self, settings: 'QgsMeshTimeSettings') -> None: ...
    def timeSettings(self) -> 'QgsMeshTimeSettings': ...
    def setRendererSettings(self, settings: 'QgsMeshRendererSettings', repaint: bool = ...) -> None: ...
    def rendererSettings(self) -> 'QgsMeshRendererSettings': ...
    def updateTriangularMesh(self, transform: 'QgsCoordinateTransform' = ...) -> None: ...
    def saveDataset(self, path: str|None, datasetGroupIndex: int, driver: str|None) -> bool: ...
    def removeDatasets(self, name: str|None) -> bool: ...
    @typing.overload
    def addDatasets(self, path: str|None, defaultReferenceTime: QtCore.QDateTime|datetime.datetime = ...) -> bool: ...
    @typing.overload
    def addDatasets(self, datasetGroup: QgsMeshDatasetGroup|None) -> bool: ...
    def loadDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def supportsEditing(self) -> bool: ...
    def isEditable(self) -> bool: ...
    def htmlMetadata(self) -> str: ...
    def subLayers(self) -> list[str]: ...
    def reload(self) -> None: ...
    def elevationProperties(self) -> QgsMapLayerElevationProperties|None: ...
    def temporalProperties(self) -> QgsMapLayerTemporalProperties|None: ...
    def writeXml(self, layer_node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def readXml(self, layer_node: QtXml.QDomNode, context: QgsReadWriteContext) -> bool: ...
    def decodedSource(self, source: str|None, provider: str|None, context: QgsReadWriteContext) -> str: ...
    def encodedSource(self, source: str|None, context: QgsReadWriteContext) -> str: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def createProfileGenerator(self, request: QgsProfileRequest) -> QgsAbstractProfileGenerator|None: ...
    def profileSourceName(self) -> str: ...
    def profileSourceId(self) -> str: ...
    def profileSource(self) -> QgsAbstractProfileSource|None: ...
    def createMapRenderer(self, rendererContext: QgsRenderContext) -> QgsMapLayerRenderer|None: ...
    def extent(self) -> QgsRectangle: ...
    def clone(self) -> 'QgsMeshLayer|None': ...
    def dataProvider(self) -> QgsMeshDataProvider|None: ...
    def __repr__(self) -> typing.Any: ...


class QgsMeshLayerElevationProperties(QgsMapLayerElevationProperties):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def setElevationLimit(self, limit: float) -> None: ...
    def elevationLimit(self) -> float: ...
    def setProfileSymbology(self, symbology: Qgis.ProfileSurfaceSymbology) -> None: ...
    def profileSymbology(self) -> Qgis.ProfileSurfaceSymbology: ...
    def setProfileFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def profileFillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setProfileLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def profileLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setFixedRangePerGroup(self, ranges: dict[int, QgsDoubleRange]) -> None: ...
    def fixedRangePerGroup(self) -> dict[int, QgsDoubleRange]: ...
    def setFixedRange(self, range: QgsDoubleRange) -> None: ...
    def fixedRange(self) -> QgsDoubleRange: ...
    def setMode(self, mode: Qgis.MeshElevationMode) -> None: ...
    def mode(self) -> Qgis.MeshElevationMode: ...
    def flags(self) -> QgsMapLayerElevationProperties.Flag: ...
    def showByDefaultInElevationProfilePlots(self) -> bool: ...
    def significantZValues(self, layer: QgsMapLayer|None) -> list[float]: ...
    def calculateZRange(self, layer: QgsMapLayer|None) -> QgsDoubleRange: ...
    def isVisibleInZRange(self, range: QgsDoubleRange, layer: QgsMapLayer|None = ...) -> bool: ...
    def clone(self) -> 'QgsMeshLayerElevationProperties|None': ...
    def htmlSummary(self) -> str: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def hasElevation(self) -> bool: ...


class QgsMeshLayerTemporalProperties(QgsMapLayerTemporalProperties):

    def __init__(self, parent: QtCore.QObject|None = ..., enabled: bool = ...) -> None: ...

    def setAlwaysLoadReferenceTimeFromSource(self, autoReloadFromProvider: bool) -> None: ...
    def alwaysLoadReferenceTimeFromSource(self) -> bool: ...
    def setIsValid(self, isValid: bool) -> None: ...
    def isValid(self) -> bool: ...
    def setMatchingMethod(self, matchingMethod: QgsMeshDataProviderTemporalCapabilities.MatchingTemporalDatasetMethod) -> None: ...
    def matchingMethod(self) -> QgsMeshDataProviderTemporalCapabilities.MatchingTemporalDatasetMethod: ...
    def setReferenceTime(self, referenceTime: QtCore.QDateTime|datetime.datetime, capabilities: QgsDataProviderTemporalCapabilities|None) -> None: ...
    def referenceTime(self) -> QtCore.QDateTime: ...
    def timeExtent(self) -> QgsDateTimeRange: ...
    def setDefaultsFromDataProviderTemporalCapabilities(self, capabilities: QgsDataProviderTemporalCapabilities|None) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...


class QgsMeshRendererMeshSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererMeshSettings') -> None: ...

    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def setLineWidthUnit(self, lineWidthUnit: Qgis.RenderUnit) -> None: ...
    def lineWidthUnit(self) -> Qgis.RenderUnit: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setLineWidth(self, lineWidth: float) -> None: ...
    def lineWidth(self) -> float: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def isEnabled(self) -> bool: ...


class QgsMeshRendererScalarSettings(PyQt6.sip.wrapper):

    class DataResamplingMethod(enum.IntEnum):
        NoResampling = ... # type: QgsMeshRendererScalarSettings.DataResamplingMethod
        NeighbourAverage = ... # type: QgsMeshRendererScalarSettings.DataResamplingMethod

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererScalarSettings') -> None: ...

    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> QtXml.QDomElement: ...
    def extent(self) -> Qgis.MeshRangeExtent: ...
    def setExtent(self, extent: Qgis.MeshRangeExtent) -> None: ...
    def limits(self) -> Qgis.MeshRangeLimit: ...
    def setLimits(self, limits: Qgis.MeshRangeLimit) -> None: ...
    def setEdgeStrokeWidthUnit(self, edgeStrokeWidthUnit: Qgis.RenderUnit) -> None: ...
    def edgeStrokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setEdgeStrokeWidth(self, strokeWidth: 'QgsInterpolatedLineWidth') -> None: ...
    def edgeStrokeWidth(self) -> 'QgsInterpolatedLineWidth': ...
    def setDataResamplingMethod(self, dataResamplingMethod: 'QgsMeshRendererScalarSettings.DataResamplingMethod') -> None: ...
    def dataResamplingMethod(self) -> 'QgsMeshRendererScalarSettings.DataResamplingMethod': ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setClassificationMinimumMaximum(self, minimum: float, maximum: float) -> None: ...
    def classificationMaximum(self) -> float: ...
    def classificationMinimum(self) -> float: ...
    def setColorRampShader(self, shader: 'QgsColorRampShader') -> None: ...
    def colorRampShader(self) -> 'QgsColorRampShader': ...


class QgsMeshRendererVectorArrowSettings(PyQt6.sip.wrapper):

    class ArrowScalingMethod(enum.IntEnum):
        MinMax = ... # type: QgsMeshRendererVectorArrowSettings.ArrowScalingMethod
        Scaled = ... # type: QgsMeshRendererVectorArrowSettings.ArrowScalingMethod
        Fixed = ... # type: QgsMeshRendererVectorArrowSettings.ArrowScalingMethod

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererVectorArrowSettings') -> None: ...

    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def setArrowHeadLengthRatio(self, arrowHeadLengthRatio: float) -> None: ...
    def arrowHeadLengthRatio(self) -> float: ...
    def setArrowHeadWidthRatio(self, arrowHeadWidthRatio: float) -> None: ...
    def arrowHeadWidthRatio(self) -> float: ...
    def setFixedShaftLength(self, fixedShaftLength: float) -> None: ...
    def fixedShaftLength(self) -> float: ...
    def setScaleFactor(self, scaleFactor: float) -> None: ...
    def scaleFactor(self) -> float: ...
    def setMaxShaftLength(self, maxShaftLength: float) -> None: ...
    def maxShaftLength(self) -> float: ...
    def setMinShaftLength(self, minShaftLength: float) -> None: ...
    def minShaftLength(self) -> float: ...
    def setShaftLengthMethod(self, shaftLengthMethod: 'QgsMeshRendererVectorArrowSettings.ArrowScalingMethod') -> None: ...
    def shaftLengthMethod(self) -> 'QgsMeshRendererVectorArrowSettings.ArrowScalingMethod': ...


class QgsMeshRendererVectorStreamlineSettings(PyQt6.sip.wrapper):

    class SeedingStartPointsMethod(enum.IntEnum):
        MeshGridded = ... # type: QgsMeshRendererVectorStreamlineSettings.SeedingStartPointsMethod
        Random = ... # type: QgsMeshRendererVectorStreamlineSettings.SeedingStartPointsMethod

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererVectorStreamlineSettings') -> None: ...

    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def setSeedingDensity(self, seedingDensity: float) -> None: ...
    def seedingDensity(self) -> float: ...
    def setSeedingMethod(self, seedingMethod: 'QgsMeshRendererVectorStreamlineSettings.SeedingStartPointsMethod') -> None: ...
    def seedingMethod(self) -> 'QgsMeshRendererVectorStreamlineSettings.SeedingStartPointsMethod': ...


class QgsMeshRendererVectorTracesSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererVectorTracesSettings') -> None: ...

    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def setMaximumTailLengthUnit(self, maximumTailLengthUnit: Qgis.RenderUnit) -> None: ...
    def maximumTailLengthUnit(self) -> Qgis.RenderUnit: ...
    def setParticlesCount(self, value: int) -> None: ...
    def particlesCount(self) -> int: ...
    def setMaximumTailLength(self, maximumTailLength: float) -> None: ...
    def maximumTailLength(self) -> float: ...


class QgsMeshRendererVectorWindBarbSettings(PyQt6.sip.wrapper):

    class WindSpeedUnit(enum.Enum):
        MetersPerSecond = ... # type: QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit
        KilometersPerHour = ... # type: QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit
        Knots = ... # type: QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit
        MilesPerHour = ... # type: QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit
        FeetPerSecond = ... # type: QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit
        OtherUnit = ... # type: QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererVectorWindBarbSettings') -> None: ...

    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def setMagnitudeUnits(self, units: 'QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit') -> None: ...
    def magnitudeUnits(self) -> 'QgsMeshRendererVectorWindBarbSettings.WindSpeedUnit': ...
    def setShaftLengthUnits(self, shaftLengthUnit: Qgis.RenderUnit) -> None: ...
    def shaftLengthUnits(self) -> Qgis.RenderUnit: ...
    def setShaftLength(self, shaftLength: float) -> None: ...
    def shaftLength(self) -> float: ...
    def setMagnitudeMultiplier(self, magnitudeMultiplier: float) -> None: ...
    def magnitudeMultiplier(self) -> float: ...


class QgsMeshRendererVectorSettings(PyQt6.sip.wrapper):

    class Symbology(enum.IntEnum):
        Arrows = ... # type: QgsMeshRendererVectorSettings.Symbology
        Streamlines = ... # type: QgsMeshRendererVectorSettings.Symbology
        Traces = ... # type: QgsMeshRendererVectorSettings.Symbology
        WindBarbs = ... # type: QgsMeshRendererVectorSettings.Symbology

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshRendererVectorSettings') -> None: ...

    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> QtXml.QDomElement: ...
    def setWindBarbSettings(self, windBarbSettings: QgsMeshRendererVectorWindBarbSettings) -> None: ...
    def windBarbSettings(self) -> QgsMeshRendererVectorWindBarbSettings: ...
    def setTracesSettings(self, tracesSettings: QgsMeshRendererVectorTracesSettings) -> None: ...
    def tracesSettings(self) -> QgsMeshRendererVectorTracesSettings: ...
    def setStreamLinesSettings(self, streamLinesSettings: QgsMeshRendererVectorStreamlineSettings) -> None: ...
    def streamLinesSettings(self) -> QgsMeshRendererVectorStreamlineSettings: ...
    def setArrowsSettings(self, arrowSettings: QgsMeshRendererVectorArrowSettings) -> None: ...
    def arrowSettings(self) -> QgsMeshRendererVectorArrowSettings: ...
    def vectorStrokeColoring(self) -> 'QgsInterpolatedLineColor': ...
    def setColorRampShader(self, colorRampShader: 'QgsColorRampShader') -> None: ...
    def colorRampShader(self) -> 'QgsColorRampShader': ...
    def setColoringMethod(self, coloringMethod: 'QgsInterpolatedLineColor.ColoringMethod') -> None: ...
    def coloringMethod(self) -> 'QgsInterpolatedLineColor.ColoringMethod': ...
    def setSymbology(self, symbology: 'QgsMeshRendererVectorSettings.Symbology') -> None: ...
    def symbology(self) -> 'QgsMeshRendererVectorSettings.Symbology': ...
    def setUserGridCellHeight(self, height: int) -> None: ...
    def userGridCellHeight(self) -> int: ...
    def setUserGridCellWidth(self, width: int) -> None: ...
    def userGridCellWidth(self) -> int: ...
    def setOnUserDefinedGrid(self, enabled: bool) -> None: ...
    def isOnUserDefinedGrid(self) -> bool: ...
    def setFilterMax(self, filterMax: float) -> None: ...
    def filterMax(self) -> float: ...
    def setFilterMin(self, filterMin: float) -> None: ...
    def filterMin(self) -> float: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setLineWidth(self, lineWidth: float) -> None: ...
    def lineWidth(self) -> float: ...


class QgsMeshRendererSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsMeshRendererSettings') -> None: ...

    def hasSettings(self, datasetGroupIndex: int) -> bool: ...
    def setActiveVectorDatasetGroup(self, activeVectorDatasetGroup: int) -> None: ...
    def activeVectorDatasetGroup(self) -> int: ...
    def setActiveScalarDatasetGroup(self, activeScalarDatasetGroup: int) -> None: ...
    def activeScalarDatasetGroup(self) -> int: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> QtXml.QDomElement: ...
    def setAveragingMethod(self, method: QgsMesh3DAveragingMethod|None) -> None: ...
    def averagingMethod(self) -> QgsMesh3DAveragingMethod|None: ...
    def removeVectorSettings(self, groupIndex: int) -> bool: ...
    def hasVectorSettings(self, groupIndex: int) -> bool: ...
    def setVectorSettings(self, groupIndex: int, settings: QgsMeshRendererVectorSettings) -> None: ...
    def vectorSettings(self, groupIndex: int) -> QgsMeshRendererVectorSettings: ...
    def removeScalarSettings(self, groupIndex: int) -> bool: ...
    def hasScalarSettings(self, groupIndex: int) -> bool: ...
    def setScalarSettings(self, groupIndex: int, settings: QgsMeshRendererScalarSettings) -> None: ...
    def scalarSettings(self, groupIndex: int) -> QgsMeshRendererScalarSettings: ...
    def setEdgeMeshSettings(self, settings: QgsMeshRendererMeshSettings) -> None: ...
    def edgeMeshSettings(self) -> QgsMeshRendererMeshSettings: ...
    def setTriangularMeshSettings(self, settings: QgsMeshRendererMeshSettings) -> None: ...
    def triangularMeshSettings(self) -> QgsMeshRendererMeshSettings: ...
    def setNativeMeshSettings(self, settings: QgsMeshRendererMeshSettings) -> None: ...
    def nativeMeshSettings(self) -> QgsMeshRendererMeshSettings: ...


class QgsMeshSpatialIndex(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, mesh: QgsMesh, feedback: QgsFeedback|None = ..., elementType: QgsMesh.ElementType = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsMeshSpatialIndex') -> None: ...

    def removeFace(self, faceIndex: int, mesh: QgsMesh) -> None: ...
    def addFace(self, faceIndex: int, mesh: QgsMesh) -> None: ...
    def elementType(self) -> QgsMesh.ElementType: ...
    def nearestNeighbor(self, point: QgsPointXY, neighbors: int) -> list[int]: ...
    def intersects(self, rectangle: QgsRectangle) -> list[int]: ...


class QgsMeshTimeSettings(PyQt6.sip.wrapper):

    class TimeUnit(enum.IntEnum):
        seconds = ... # type: QgsMeshTimeSettings.TimeUnit
        minutes = ... # type: QgsMeshTimeSettings.TimeUnit
        hours = ... # type: QgsMeshTimeSettings.TimeUnit
        days = ... # type: QgsMeshTimeSettings.TimeUnit

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshTimeSettings') -> None: ...

    def setAbsoluteTimeFormat(self, absoluteTimeFormat: str|None) -> None: ...
    def absoluteTimeFormat(self) -> str: ...
    def setRelativeTimeFormat(self, relativeTimeFormat: str|None) -> None: ...
    def relativeTimeFormat(self) -> str: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...


class QgsMeshVectorTraceAnimationGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, layer: QgsMeshLayer|None, rendererContext: QgsRenderContext) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsMeshVectorTraceAnimationGenerator') -> None: ...

    def setTailPersitence(self, p: float) -> None: ...
    def setMinimumTailLength(self, l: int) -> None: ...
    def setTailFactor(self, fct: float) -> None: ...
    def setParticlesSize(self, width: float) -> None: ...
    def setParticlesColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setParticlesLifeTime(self, particleLifeTime: float) -> None: ...
    def setMaxSpeedPixel(self, max: int) -> None: ...
    def setFPS(self, FPS: int) -> None: ...
    def imageRendered(self) -> QtGui.QImage: ...
    def seedRandomParticles(self, count: int) -> None: ...


class QgsMeshCalculator(PyQt6.sip.wrapper):

    class Result(enum.IntEnum):
        Success = ... # type: QgsMeshCalculator.Result
        Canceled = ... # type: QgsMeshCalculator.Result
        CreateOutputError = ... # type: QgsMeshCalculator.Result
        InputLayerError = ... # type: QgsMeshCalculator.Result
        ParserError = ... # type: QgsMeshCalculator.Result
        InvalidDatasets = ... # type: QgsMeshCalculator.Result
        EvaluateError = ... # type: QgsMeshCalculator.Result
        MemoryError = ... # type: QgsMeshCalculator.Result

    @typing.overload
    @deprecated("""""")
    def __init__(self, formulaString: str|None, outputFile: str|None, outputExtent: QgsRectangle, startTime: float, endTime: float, layer: QgsMeshLayer|None) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, formulaString: str|None, outputFile: str|None, outputMask: QgsGeometry, startTime: float, endTime: float, layer: QgsMeshLayer|None) -> None: ...
    @typing.overload
    def __init__(self, formulaString: str|None, outputDriver: str|None, outputGroupName: str|None, outputFile: str|None, outputExtent: QgsRectangle, startTime: float, endTime: float, layer: QgsMeshLayer|None) -> None: ...
    @typing.overload
    def __init__(self, formulaString: str|None, outputDriver: str|None, outputGroupName: str|None, outputFile: str|None, outputMask: QgsGeometry, startTime: float, endTime: float, layer: QgsMeshLayer|None) -> None: ...
    @typing.overload
    def __init__(self, formulaString: str|None, outputGroupName: str|None, outputExtent: QgsRectangle, destination: QgsMeshDatasetGroup.Type, layer: QgsMeshLayer|None, startTime: float, endTime: float) -> None: ...
    @typing.overload
    def __init__(self, formulaString: str|None, outputGroupName: str|None, outputMask: QgsGeometry, destination: QgsMeshDatasetGroup.Type, layer: QgsMeshLayer|None, startTime: float, endTime: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshCalculator') -> None: ...

    @staticmethod
    def expressionIsValid(formulaString: str|None, layer: QgsMeshLayer|None) -> typing.Tuple['QgsMeshCalculator.Result', 'QgsMeshDriverMetadata.MeshDriverCapability']: ...
    @staticmethod
    @deprecated("""""")
    def expression_valid(formulaString: str|None, layer: QgsMeshLayer|None) -> 'QgsMeshCalculator.Result': ...
    def processCalculation(self, feedback: QgsFeedback|None = ...) -> 'QgsMeshCalculator.Result': ...


class QgsTopologicalMesh(PyQt6.sip.wrapper):

    class TopologicalFaces(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsTopologicalMesh.TopologicalFaces') -> None: ...

        def vertexToFace(self, vertexIndex: int) -> int: ...
        def clear(self) -> None: ...

    class Changes(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsTopologicalMesh.Changes') -> None: ...

        def clearChanges(self) -> None: ...
        def isEmpty(self) -> bool: ...
        def nativeFacesIndexesGeometryChanged(self) -> list[int]: ...
        def oldVerticesXYValues(self) -> list[QgsPointXY]: ...
        def newVerticesXYValues(self) -> list[QgsPointXY]: ...
        def newVerticesZValues(self) -> list[float]: ...
        def changedCoordinatesVerticesIndexes(self) -> list[int]: ...
        def verticesToRemoveIndexes(self) -> list[int]: ...
        def addedVertices(self) -> list[QgsPoint]: ...
        def removedFaceIndexes(self) -> list[int]: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTopologicalMesh') -> None: ...

    @typing.overload
    @staticmethod
    def vertexPositionInFace(vertexIndex: int, face: collections.abc.Iterable[int]) -> int: ...
    @typing.overload
    @staticmethod
    def vertexPositionInFace(mesh: QgsMesh, vertexIndex: int, faceIndex: int) -> int: ...
    @staticmethod
    def checkTopology(mesh: QgsMesh, maxVerticesPerFace: int) -> QgsMeshEditingError: ...
    def checkConsistency(self) -> QgsMeshEditingError: ...
    def renumber(self) -> bool: ...
    def reindex(self) -> None: ...
    @staticmethod
    def counterClockwiseFaces(face: collections.abc.Iterable[int], mesh: QgsMesh|None) -> QgsMeshEditingError: ...
    def reverseChanges(self, changes: 'QgsTopologicalMesh.Changes') -> None: ...
    def applyChanges(self, changes: 'QgsTopologicalMesh.Changes') -> None: ...
    def changeXYValue(self, verticesIndexes: collections.abc.Iterable[int], newValues: collections.abc.Iterable[QgsPointXY]) -> 'QgsTopologicalMesh.Changes': ...
    def changeZValue(self, verticesIndexes: collections.abc.Iterable[int], newValues: collections.abc.Iterable[float]) -> 'QgsTopologicalMesh.Changes': ...
    def removeVertices(self, vertices: collections.abc.Iterable[int]) -> 'QgsTopologicalMesh.Changes': ...
    def removeVertexFillHole(self, vertexIndex: int) -> 'QgsTopologicalMesh.Changes': ...
    def addFreeVertex(self, vertex: QgsPoint) -> 'QgsTopologicalMesh.Changes': ...
    def insertVertexInFacesEdge(self, faceIndex: int, position: int, vertex: QgsPoint) -> 'QgsTopologicalMesh.Changes': ...
    def addVertexInFace(self, faceIndex: int, vertex: QgsPoint) -> 'QgsTopologicalMesh.Changes': ...
    def splitFace(self, faceIndex: int) -> 'QgsTopologicalMesh.Changes': ...
    def canBeSplit(self, faceIndex: int) -> bool: ...
    def merge(self, vertexIndex1: int, vertexIndex2: int) -> 'QgsTopologicalMesh.Changes': ...
    def canBeMerged(self, vertexIndex1: int, vertexIndex2: int) -> bool: ...
    def delaunayConditionForEdge(self, vertexIndex1: int, vertexIndex2: int) -> bool: ...
    def flipEdge(self, vertexIndex1: int, vertexIndex2: int) -> 'QgsTopologicalMesh.Changes': ...
    def edgeCanBeFlipped(self, vertexIndex1: int, vertexIndex2: int) -> bool: ...
    def removeFaces(self, facesIndexes: collections.abc.Iterable[int]) -> 'QgsTopologicalMesh.Changes': ...
    def facesCanBeRemoved(self, facesIndexes: collections.abc.Iterable[int]) -> QgsMeshEditingError: ...
    def addFaces(self, topologicFaces: 'QgsTopologicalMesh.TopologicalFaces') -> 'QgsTopologicalMesh.Changes': ...
    def facesCanBeAdded(self, topologicalFaces: 'QgsTopologicalMesh.TopologicalFaces') -> QgsMeshEditingError: ...
    def freeVerticesIndexes(self) -> list[int]: ...
    def isVertexFree(self, vertexIndex: int) -> bool: ...
    def isVertexOnBoundary(self, vertexIndex: int) -> bool: ...
    def firstFaceLinked(self, vertexIndex: int) -> int: ...
    def mesh(self) -> QgsMesh|None: ...
    def facesAroundVertex(self, vertexIndex: int) -> list[int]: ...
    def neighborsOfFace(self, faceIndex: int) -> list[int]: ...
    @staticmethod
    def createTopologicalMesh(mesh: QgsMesh|None, maxVerticesPerFace: int, error: QgsMeshEditingError) -> 'QgsTopologicalMesh': ...


class QgsMeshAdvancedEditing(QgsTopologicalMesh.Changes):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshAdvancedEditing') -> None: ...

    def text(self) -> str: ...
    def isFinished(self) -> bool: ...
    def clear(self) -> None: ...
    def message(self) -> str: ...
    def setInputFaces(self, faceIndexes: collections.abc.Iterable[int]) -> None: ...
    def setInputVertices(self, verticesIndexes: collections.abc.Iterable[int]) -> None: ...


class QgsMeshEditRefineFaces(QgsMeshAdvancedEditing):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshEditRefineFaces') -> None: ...

    def text(self) -> str: ...


class QgsMeshTransformVerticesByExpression(QgsMeshAdvancedEditing):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshTransformVerticesByExpression') -> None: ...

    def setZFromTerrain(self, enable: bool) -> None: ...
    def transformedVertex(self, layer: QgsMeshLayer|None, vertexIndex: int) -> QgsPoint: ...
    def calculate(self, layer: QgsMeshLayer|None, project: 'QgsProject|None' = ...) -> bool: ...
    def setExpressions(self, expressionX: str|None, expressionY: str|None, expressionZ: str|None) -> None: ...
    def text(self) -> str: ...


class QgsMeshEditForceByLine(QgsMeshAdvancedEditing):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshEditForceByLine') -> None: ...

    def setInterpolateZValueOnMesh(self, interpolateZValueOnMesh: bool) -> None: ...
    def setDefaultZValue(self, defaultZValue: float) -> None: ...
    def setAddVertexOnIntersection(self, addVertex: bool) -> None: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def setInputLine(self, pt1: QgsPoint, pt2: QgsPoint, tolerance: float, newVertexOnIntersection: bool) -> None: ...


class QgsMeshEditForceByPolylines(QgsMeshEditForceByLine):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshEditForceByPolylines') -> None: ...

    def addLinesFromGeometries(self, geometries: collections.abc.Iterable[QgsGeometry]) -> None: ...
    def addLineFromGeometry(self, geom: QgsGeometry) -> None: ...
    def isFinished(self) -> bool: ...
    def text(self) -> str: ...


class QgsAbstractMeshLayerLabeling(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def defaultSettingsForLayer(layer: QgsMeshLayer|None) -> QgsPalLayerSettings: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def toSld(self, parent: QtXml.QDomNode, props: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsAbstractMeshLayerLabeling|None': ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def setSettings(self, settings: QgsPalLayerSettings|None, providerId: str|None = ...) -> None: ...
    def settings(self, providerId: str|None = ...) -> QgsPalLayerSettings: ...
    def subProviders(self) -> list[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> 'QgsAbstractMeshLayerLabeling|None': ...
    def type(self) -> str: ...


class QgsMeshLayerSimpleLabeling(QgsAbstractMeshLayerLabeling):

    def __init__(self, settings: QgsPalLayerSettings, labelFaces: bool = ...) -> None: ...

    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsMeshLayerSimpleLabeling|None': ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def setSettings(self, settings: QgsPalLayerSettings|None, providerId: str|None = ...) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def settings(self, providerId: str|None = ...) -> QgsPalLayerSettings: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> 'QgsMeshLayerSimpleLabeling|None': ...
    def type(self) -> str: ...


class QgsMeshUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshUtils') -> None: ...

    @staticmethod
    def exportRasterBlock(layer: QgsMeshLayer, datasetIndex: QgsMeshDatasetIndex, destinationCrs: 'QgsCoordinateReferenceSystem', transformContext: 'QgsCoordinateTransformContext', mapUnitsPerPixel: float, extent: QgsRectangle, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...


class QgsVideoExporter(QtCore.QObject):

    def __init__(self, filename: str|None, size: QtCore.QSize, framesPerSecond: float) -> None: ...

    finished: typing.ClassVar[QtCore.pyqtSignal]
    def writeVideo(self) -> None: ...
    def errorString(self) -> str: ...
    def error(self) -> QtMultimedia.QMediaRecorder.Error: ...
    def videoCodec(self) -> QtMultimedia.QMediaFormat.VideoCodec: ...
    def setVideoCodec(self, codec: QtMultimedia.QMediaFormat.VideoCodec) -> None: ...
    def fileFormat(self) -> QtMultimedia.QMediaFormat.FileFormat: ...
    def setFileFormat(self, format: QtMultimedia.QMediaFormat.FileFormat) -> None: ...
    def inputFiles(self) -> list[str]: ...
    def setInputFilesByPattern(self, directory: str|None, pattern: str|None) -> None: ...
    def setInputFiles(self, files: collections.abc.Iterable[str|None]) -> None: ...
    def size(self) -> QtCore.QSize: ...
    def frameDuration(self) -> int: ...
    def framesPerSecond(self) -> float: ...
    def feedback(self) -> QgsFeedback|None: ...
    def setFeedback(self, feedback: QgsFeedback|None) -> None: ...
    @staticmethod
    def isAvailable() -> bool: ...


class QgsGeometryPaintDevice(QtGui.QPaintDevice):

    def __init__(self, usePathStroker: bool = ...) -> None: ...

    @staticmethod
    def painterPathToGeometry(path: QtGui.QPainterPath) -> QgsGeometry: ...
    def geometry(self) -> QgsAbstractGeometry: ...
    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def paintEngine(self) -> QtGui.QPaintEngine|None: ...
    def setSimplificationTolerance(self, tolerance: float) -> None: ...
    def setStrokedPathSegments(self, segments: int) -> None: ...


class QgsMaskPaintDevice(QtGui.QPaintDevice):

    @deprecated("""""")
    def __init__(self, usePathStroker: bool = ...) -> None: ...

    @deprecated("""""")
    def maskPainterPath(self) -> QtGui.QPainterPath: ...
    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def paintEngine(self) -> QtGui.QPaintEngine|None: ...


class QgsNullPaintDevice(QtGui.QPaintDevice):

    def __init__(self) -> None: ...

    def setOutputDpi(self, dpi: int) -> None: ...
    def setOutputSize(self, size: QtCore.QSize) -> None: ...
    def metric(self, metric: QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def paintEngine(self) -> QtGui.QPaintEngine|None: ...


@deprecated("")
class QgsPaintEngineHack(QtGui.QPaintEngine):

    def __init__(self) -> None: ...

    @staticmethod
    def fixEngineFlags(engine: QtGui.QPaintEngine|None) -> None: ...
    def fixFlags(self) -> None: ...


class QgsPainting(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPainting') -> None: ...

    @staticmethod
    def drawPicture(painter: QtGui.QPainter|None, point: QtCore.QPointF, picture: QtGui.QPicture) -> None: ...
    @staticmethod
    def applyScaleFixForQPictureDpi(painter: QtGui.QPainter|None) -> None: ...
    @staticmethod
    def qtDefaultDpiY() -> int: ...
    @staticmethod
    def qtDefaultDpiX() -> int: ...
    @staticmethod
    def drawTriangleUsingTexture(painter: QtGui.QPainter|None, triangle: QtGui.QPolygonF, textureImage: QtGui.QImage, textureX1: float, textureY1: float, textureX2: float, textureY2: float, textureX3: float, textureY3: float) -> bool: ...
    @staticmethod
    def triangleToTriangleTransform(inX1: float, inY1: float, inX2: float, inY2: float, inX3: float, inY3: float, outX1: float, outY1: float, outX2: float, outY2: float, outX3: float, outY3: float) -> typing.Tuple[QtGui.QTransform, bool]: ...
    @staticmethod
    def isClippingMode(mode: Qgis.BlendMode) -> bool: ...
    @staticmethod
    def getBlendModeEnum(blendMode: QtGui.QPainter.CompositionMode) -> Qgis.BlendMode: ...
    @staticmethod
    def getCompositionMode(blendMode: Qgis.BlendMode) -> QtGui.QPainter.CompositionMode: ...


class QgsPdfRenderer(PyQt6.sip.wrapper):

    def __init__(self, path: str|None) -> None: ...

    def render(self, painter: QtGui.QPainter|None, painterRect: QtCore.QRectF, pageIndex: int) -> bool: ...
    def pageMediaBox(self, pageNumber: int) -> QtCore.QRectF: ...
    def pageCount(self) -> int: ...
    def path(self) -> str: ...


class QgsPlot(PyQt6.sip.wrapper):

    class DataDefinedProperty(enum.IntEnum):
        MarginLeft = ... # type: QgsPlot.DataDefinedProperty
        MarginTop = ... # type: QgsPlot.DataDefinedProperty
        MarginRight = ... # type: QgsPlot.DataDefinedProperty
        MarginBottom = ... # type: QgsPlot.DataDefinedProperty
        XAxisMajorInterval = ... # type: QgsPlot.DataDefinedProperty
        XAxisMinorInterval = ... # type: QgsPlot.DataDefinedProperty
        XAxisLabelInterval = ... # type: QgsPlot.DataDefinedProperty
        YAxisMajorInterval = ... # type: QgsPlot.DataDefinedProperty
        YAxisMinorInterval = ... # type: QgsPlot.DataDefinedProperty
        YAxisLabelInterval = ... # type: QgsPlot.DataDefinedProperty
        XAxisMinimum = ... # type: QgsPlot.DataDefinedProperty
        XAxisMaximum = ... # type: QgsPlot.DataDefinedProperty
        YAxisMinimum = ... # type: QgsPlot.DataDefinedProperty
        YAxisMaximum = ... # type: QgsPlot.DataDefinedProperty

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPlot') -> None: ...

    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    def initFromPlot(self, plot: 'QgsPlot|None') -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def setDataDefinedProperty(self, key: 'QgsPlot.DataDefinedProperty', property: QgsProperty) -> None: ...
    def type(self) -> str: ...


class Qgs2DPlot(QgsPlot):

    def __init__(self) -> None: ...

    def applyDataDefinedProperties(self, context: QgsRenderContext, margins: QgsMargins) -> None: ...
    def copyCommonProperties(self, other: 'Qgs2DPlot|None') -> None: ...
    def setMargins(self, margins: QgsMargins) -> None: ...
    def margins(self) -> QgsMargins: ...
    def interiorPlotArea(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotData: 'QgsPlotData' = ...) -> QtCore.QRectF: ...
    def setSize(self, size: QtCore.QSizeF) -> None: ...
    def size(self) -> QtCore.QSizeF: ...
    def renderContent(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotArea: QtCore.QRectF, plotData: 'QgsPlotData' = ...) -> None: ...
    def render(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotData: 'QgsPlotData' = ...) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...


class Qgs2DXyPlot(Qgs2DPlot):

    def __init__(self) -> None: ...

    def applyDataDefinedProperties(self, context: QgsRenderContext) -> typing.Tuple[float, float, float, float, float, float, float, float, float, float]: ...
    def copyCommonProperties(self, other: 'Qgs2DXyPlot|None') -> None: ...
    def setFlipAxes(self, flipAxes: bool) -> None: ...
    def flipAxes(self) -> bool: ...
    def setChartBorderSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def chartBorderSymbol(self) -> 'QgsFillSymbol|None': ...
    def setChartBackgroundSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def chartBackgroundSymbol(self) -> 'QgsFillSymbol|None': ...
    def yAxis(self) -> 'QgsPlotAxis': ...
    def xAxis(self) -> 'QgsPlotAxis': ...
    def setYMaximum(self, maximum: float) -> None: ...
    def yMaximum(self) -> float: ...
    def setXMaximum(self, maximum: float) -> None: ...
    def xMaximum(self) -> float: ...
    def setYMinimum(self, minimum: float) -> None: ...
    def yMinimum(self) -> float: ...
    def setXMinimum(self, minimum: float) -> None: ...
    def xMinimum(self) -> float: ...
    def calculateOptimisedIntervals(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext') -> None: ...
    def interiorPlotArea(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotData: 'QgsPlotData' = ...) -> QtCore.QRectF: ...
    def render(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotData: 'QgsPlotData' = ...) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...


class QgsBarChartPlot(Qgs2DXyPlot):

    def __init__(self) -> None: ...

    def initFromPlot(self, plot: QgsPlot|None) -> None: ...
    @staticmethod
    def createDataGatherer(plot: QgsPlot|None) -> 'QgsVectorLayerAbstractPlotDataGatherer|None': ...
    @staticmethod
    def create() -> 'QgsBarChartPlot|None': ...
    def fillSymbolCount(self) -> int: ...
    def setFillSymbolAt(self, index: int, symbol: 'QgsFillSymbol|None') -> None: ...
    def fillSymbolAt(self, index: int) -> 'QgsFillSymbol|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def renderContent(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotArea: QtCore.QRectF, plotData: 'QgsPlotData' = ...) -> None: ...
    def type(self) -> str: ...


class QgsLineChartPlot(Qgs2DXyPlot):

    def __init__(self) -> None: ...

    def initFromPlot(self, plot: QgsPlot|None) -> None: ...
    @staticmethod
    def createDataGatherer(plot: QgsPlot|None) -> 'QgsVectorLayerAbstractPlotDataGatherer|None': ...
    @staticmethod
    def create() -> 'QgsLineChartPlot|None': ...
    def lineSymbolCount(self) -> int: ...
    def setLineSymbolAt(self, index: int, symbol: 'QgsLineSymbol|None') -> None: ...
    def lineSymbolAt(self, index: int) -> 'QgsLineSymbol|None': ...
    def markerSymbolCount(self) -> int: ...
    def setMarkerSymbolAt(self, index: int, symbol: 'QgsMarkerSymbol|None') -> None: ...
    def markerSymbolAt(self, index: int) -> 'QgsMarkerSymbol|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def renderContent(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotArea: QtCore.QRectF, plotData: 'QgsPlotData' = ...) -> None: ...
    def type(self) -> str: ...


class QgsPieChartPlot(Qgs2DPlot):

    def __init__(self) -> None: ...

    def initFromPlot(self, plot: QgsPlot|None) -> None: ...
    @staticmethod
    def createDataGatherer(plot: QgsPlot|None) -> 'QgsVectorLayerAbstractPlotDataGatherer|None': ...
    @staticmethod
    def create() -> 'QgsPieChartPlot|None': ...
    def setLabelType(self, type: Qgis.PieChartLabelType) -> None: ...
    def labelType(self) -> Qgis.PieChartLabelType: ...
    def setNumericFormat(self, format: 'QgsNumericFormat|None') -> None: ...
    def numericFormat(self) -> 'QgsNumericFormat|None': ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def colorRampCount(self) -> int: ...
    def fillSymbolCount(self) -> int: ...
    def setColorRampAt(self, index: int, ramp: QgsColorRamp|None) -> None: ...
    def colorRampAt(self, index: int) -> QgsColorRamp|None: ...
    def setFillSymbolAt(self, index: int, symbol: 'QgsFillSymbol|None') -> None: ...
    def fillSymbolAt(self, index: int) -> 'QgsFillSymbol|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def renderContent(self, context: QgsRenderContext, plotContext: 'QgsPlotRenderContext', plotArea: QtCore.QRectF, plotData: 'QgsPlotData' = ...) -> None: ...
    def type(self) -> str: ...


class QgsPlotAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, visibleName: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPlotAbstractMetadata') -> None: ...

    def createPlotWidget(self, parent: QtWidgets.QWidget|None = ...) -> QgsPlotWidget|None: ...
    def createPlotDataGatherer(self, plot: QgsPlot|None = ...) -> 'QgsVectorLayerAbstractPlotDataGatherer|None': ...
    def createPlot(self) -> QgsPlot|None: ...
    def visibleName(self) -> str: ...
    def type(self) -> str: ...


class QgsPlotRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    plotAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    plotAdded: typing.ClassVar[QtCore.pyqtSignal]
    def plotTypes(self) -> dict[str, str]: ...
    def createPlot(self, type: str|None) -> QgsPlot|None: ...
    def removePlotType(self, type: str|None) -> bool: ...
    def addPlotType(self, metadata: QgsPlotAbstractMetadata|None) -> bool: ...
    def plotMetadata(self, type: str|None) -> QgsPlotAbstractMetadata|None: ...
    def populate(self) -> bool: ...


class QgsPlotRenderContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPlotRenderContext') -> None: ...


class QgsAbstractPlotSeries(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractPlotSeries') -> None: ...

    def clone(self) -> 'QgsAbstractPlotSeries|None': ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...


class QgsXyPlotSeries(QgsAbstractPlotSeries):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsXyPlotSeries') -> None: ...

    def clone(self) -> QgsAbstractPlotSeries|None: ...
    def clear(self) -> None: ...
    def append(self, x: float, y: float) -> None: ...
    def setData(self, data: typing.Any) -> None: ...
    def data(self) -> typing.Any: ...


class QgsPlotData(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsPlotData') -> None: ...

    def setCategories(self, categories: collections.abc.Iterable[str|None]) -> None: ...
    def categories(self) -> list[str]: ...
    def clearSeries(self) -> None: ...
    def addSeries(self, series: QgsAbstractPlotSeries|None) -> None: ...
    def series(self) -> list[QgsAbstractPlotSeries]: ...


class QgsPlotAxis(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def copyProperties(source: 'QgsPlotAxis', destination: 'QgsPlotAxis') -> None: ...
    def setLabelSuffixPlacement(self, placement: Qgis.PlotAxisSuffixPlacement) -> None: ...
    def labelSuffixPlacement(self) -> Qgis.PlotAxisSuffixPlacement: ...
    def setLabelSuffix(self, suffix: str|None) -> None: ...
    def labelSuffix(self) -> str: ...
    def setNumericFormat(self, format: 'QgsNumericFormat|None') -> None: ...
    def numericFormat(self) -> 'QgsNumericFormat|None': ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def setGridMinorSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def gridMinorSymbol(self) -> 'QgsLineSymbol|None': ...
    def setGridMajorSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def gridMajorSymbol(self) -> 'QgsLineSymbol|None': ...
    def setLabelInterval(self, interval: float) -> None: ...
    def labelInterval(self) -> float: ...
    def setGridIntervalMajor(self, interval: float) -> None: ...
    def gridIntervalMajor(self) -> float: ...
    def setGridIntervalMinor(self, interval: float) -> None: ...
    def gridIntervalMinor(self) -> float: ...
    def setType(self, type: Qgis.PlotAxisType) -> None: ...
    def type(self) -> Qgis.PlotAxisType: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...


class QgsPlotDefaultSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPlotDefaultSettings') -> None: ...

    @staticmethod
    def pieChartNumericFormat() -> 'QgsNumericFormat|None': ...
    @staticmethod
    def pieChartColorRamp() -> QgsColorRamp|None: ...
    @staticmethod
    def pieChartFillSymbol() -> 'QgsFillSymbol|None': ...
    @staticmethod
    def barChartFillSymbol() -> 'QgsFillSymbol|None': ...
    @staticmethod
    def lineChartLineSymbol() -> 'QgsLineSymbol|None': ...
    @staticmethod
    def lineChartMarkerSymbol() -> 'QgsMarkerSymbol|None': ...
    @staticmethod
    def chartBorderSymbol() -> 'QgsFillSymbol|None': ...
    @staticmethod
    def chartBackgroundSymbol() -> 'QgsFillSymbol|None': ...
    @staticmethod
    def axisGridMinorSymbol() -> 'QgsLineSymbol|None': ...
    @staticmethod
    def axisGridMajorSymbol() -> 'QgsLineSymbol|None': ...
    @staticmethod
    def axisLabelNumericFormat() -> 'QgsNumericFormat|None': ...


class QgsVectorLayerAbstractPlotDataGatherer(QgsTask):

    def __init__(self) -> None: ...

    def setExpressionContext(self, context: QgsExpressionContext) -> None: ...
    def setFeatureIterator(self, iterator: QgsFeatureIterator) -> None: ...
    def data(self) -> QgsPlotData: ...


class QgsVectorLayerXyPlotDataGatherer(QgsVectorLayerAbstractPlotDataGatherer):

    class XySeriesDetails(PyQt6.sip.wrapper):

        filterExpression = ... # type: str|None
        name = ... # type: str|None
        xExpression = ... # type: str|None
        yExpression = ... # type: str|None

        @typing.overload
        def __init__(self, name: str|None, xExpression: str|None, yExpression: str|None, filterExpression: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayerXyPlotDataGatherer.XySeriesDetails') -> None: ...

    def __init__(self, xAxisType: Qgis.PlotAxisType = ...) -> None: ...

    def data(self) -> QgsPlotData: ...
    def run(self) -> bool: ...
    def setPredefinedCategories(self, categories: collections.abc.Iterable[str|None]) -> None: ...
    def setSeriesDetails(self, details: collections.abc.Iterable['QgsVectorLayerXyPlotDataGatherer.XySeriesDetails']) -> None: ...


class QgsPointCloudAttribute(PyQt6.sip.wrapper):

    class DataType(enum.IntEnum):
        Char = ... # type: QgsPointCloudAttribute.DataType
        UChar = ... # type: QgsPointCloudAttribute.DataType
        Short = ... # type: QgsPointCloudAttribute.DataType
        UShort = ... # type: QgsPointCloudAttribute.DataType
        Int32 = ... # type: QgsPointCloudAttribute.DataType
        UInt32 = ... # type: QgsPointCloudAttribute.DataType
        Int64 = ... # type: QgsPointCloudAttribute.DataType
        UInt64 = ... # type: QgsPointCloudAttribute.DataType
        Float = ... # type: QgsPointCloudAttribute.DataType
        Double = ... # type: QgsPointCloudAttribute.DataType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, type: 'QgsPointCloudAttribute.DataType') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudAttribute') -> None: ...

    def __repr__(self) -> typing.Any: ...
    @staticmethod
    def isNumeric(type: 'QgsPointCloudAttribute.DataType') -> bool: ...
    def displayType(self) -> str: ...
    def variantType(self) -> QtCore.QMetaType.Type: ...
    def type(self) -> 'QgsPointCloudAttribute.DataType': ...
    def size(self) -> int: ...
    def name(self) -> str: ...


class QgsPointCloudAttributeCollection(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, attributes: collections.abc.Iterable[QgsPointCloudAttribute]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudAttributeCollection') -> None: ...

    def toFields(self) -> QgsFields: ...
    def pointRecordSize(self) -> int: ...
    def indexOf(self, name: str|None) -> int: ...
    def find(self, attributeName: str|None) -> typing.Tuple[QgsPointCloudAttribute|None, int]: ...
    def at(self, index: int) -> QgsPointCloudAttribute: ...
    def count(self) -> int: ...
    def attributes(self) -> list[QgsPointCloudAttribute]: ...
    def extend(self, otherCollection: 'QgsPointCloudAttributeCollection', matchingNames: collections.abc.Iterable[str|None]) -> None: ...
    def push_back(self, attribute: QgsPointCloudAttribute) -> None: ...


class QgsPointCloudRenderer(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def saveCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def restoreCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def copyCommonProperties(self, destination: 'QgsPointCloudRenderer|None') -> None: ...
    def addPointToTriangulation(self, x: float, y: float, z: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, context: 'QgsPointCloudRenderContext') -> None: ...
    @typing.overload
    def drawPoint(self, x: float, y: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, context: 'QgsPointCloudRenderContext') -> None: ...
    @typing.overload
    def drawPoint(self, x: float, y: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, width: int, context: 'QgsPointCloudRenderContext') -> None: ...
    @staticmethod
    def pointZ(context: 'QgsPointCloudRenderContext', ptr: str, i: int) -> float: ...
    @staticmethod
    def pointXY(context: 'QgsPointCloudRenderContext', ptr: str, i: int) -> typing.Tuple[float, float]: ...
    def overviewSwitchingScale(self) -> float: ...
    def setOverviewSwitchingScale(self, value: float) -> None: ...
    def zoomOutBehavior(self) -> Qgis.PointCloudZoomOutRenderBehavior: ...
    def setZoomOutBehavior(self, behavior: Qgis.PointCloudZoomOutRenderBehavior) -> None: ...
    def labelTextFormat(self) -> 'QgsTextFormat': ...
    def setLabelTextFormat(self, textFormat: 'QgsTextFormat') -> None: ...
    def showLabels(self) -> bool: ...
    def setShowLabels(self, show: bool) -> None: ...
    def legendRuleKeys(self) -> list[str]: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def setHorizontalTriangleFilterUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def horizontalTriangleFilterUnit(self) -> Qgis.RenderUnit: ...
    def setHorizontalTriangleFilterThreshold(self, threshold: float) -> None: ...
    def horizontalTriangleFilterThreshold(self) -> float: ...
    def setHorizontalTriangleFilter(self, enabled: bool) -> None: ...
    def horizontalTriangleFilter(self) -> bool: ...
    def setRenderAsTriangles(self, asTriangles: bool) -> None: ...
    def renderAsTriangles(self) -> bool: ...
    def setMaximumScreenErrorUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def maximumScreenErrorUnit(self) -> Qgis.RenderUnit: ...
    def setMaximumScreenError(self, error: float) -> None: ...
    def maximumScreenError(self) -> float: ...
    def setPointSymbol(self, symbol: Qgis.PointCloudSymbol) -> None: ...
    def pointSymbol(self) -> Qgis.PointCloudSymbol: ...
    def setDrawOrder2d(self, order: Qgis.PointCloudDrawOrder) -> None: ...
    def drawOrder2d(self) -> Qgis.PointCloudDrawOrder: ...
    def pointSizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setPointSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def pointSizeUnit(self) -> Qgis.RenderUnit: ...
    def setPointSizeUnit(self, units: Qgis.RenderUnit) -> None: ...
    def pointSize(self) -> float: ...
    def setPointSize(self, size: float) -> None: ...
    def checkLegendItem(self, key: str|None, state: bool = ...) -> None: ...
    def legendItemChecked(self, key: str|None) -> bool: ...
    def stopRender(self, context: 'QgsPointCloudRenderContext') -> None: ...
    def startRender(self, context: 'QgsPointCloudRenderContext') -> None: ...
    def usedAttributes(self, context: 'QgsPointCloudRenderContext') -> set[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def load(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsPointCloudRenderer|None': ...
    def willRenderPoint(self, pointAttributes: dict[str|None, typing.Any]) -> bool: ...
    def renderBlock(self, block: 'QgsPointCloudBlock|None', context: 'QgsPointCloudRenderContext') -> None: ...
    def clone(self) -> 'QgsPointCloudRenderer|None': ...
    def type(self) -> str: ...


class QgsPointCloudAttributeByRampRenderer(QgsPointCloudRenderer):

    def __init__(self) -> None: ...

    def setMaximum(self, maximum: float) -> None: ...
    def maximum(self) -> float: ...
    def setMinimum(self, minimum: float) -> None: ...
    def minimum(self) -> float: ...
    def setColorRampShader(self, shader: 'QgsColorRampShader') -> None: ...
    def colorRampShader(self) -> 'QgsColorRampShader': ...
    def setAttribute(self, attribute: str|None) -> None: ...
    def attribute(self) -> str: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsPointCloudRenderer|None: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def usedAttributes(self, context: 'QgsPointCloudRenderContext') -> set[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def renderBlock(self, block: 'QgsPointCloudBlock|None', context: 'QgsPointCloudRenderContext') -> None: ...
    def clone(self) -> QgsPointCloudRenderer|None: ...
    def type(self) -> str: ...


class QgsPointCloudAttributeModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        AttributeName = ... # type: QgsPointCloudAttributeModel.CustomRole
        AttributeIndex = ... # type: QgsPointCloudAttributeModel.CustomRole
        AttributeSize = ... # type: QgsPointCloudAttributeModel.CustomRole
        AttributeType = ... # type: QgsPointCloudAttributeModel.CustomRole
        IsEmpty = ... # type: QgsPointCloudAttributeModel.CustomRole
        IsNumeric = ... # type: QgsPointCloudAttributeModel.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    @staticmethod
    def iconForAttributeType(type: QgsPointCloudAttribute.DataType) -> QtGui.QIcon: ...
    @staticmethod
    def attributeToolTip(attribute: QgsPointCloudAttribute) -> str: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def allowEmptyAttributeName(self) -> bool: ...
    def indexFromName(self, name: str|None) -> QtCore.QModelIndex: ...
    def setAllowEmptyAttributeName(self, allowEmpty: bool) -> None: ...
    def attributes(self) -> QgsPointCloudAttributeCollection: ...
    def setAttributes(self, attributes: QgsPointCloudAttributeCollection) -> None: ...
    def layer(self) -> 'QgsPointCloudLayer|None': ...
    def setLayer(self, layer: 'QgsPointCloudLayer|None') -> None: ...


class QgsPointCloudAttributeProxyModel(QtCore.QSortFilterProxyModel):

    class Filter(enum.IntEnum):
        Char = ... # type: QgsPointCloudAttributeProxyModel.Filter
        Short = ... # type: QgsPointCloudAttributeProxyModel.Filter
        Int32 = ... # type: QgsPointCloudAttributeProxyModel.Filter
        Float = ... # type: QgsPointCloudAttributeProxyModel.Filter
        Double = ... # type: QgsPointCloudAttributeProxyModel.Filter
        Numeric = ... # type: QgsPointCloudAttributeProxyModel.Filter
        AllTypes = ... # type: QgsPointCloudAttributeProxyModel.Filter

    def __init__(self, source: QgsPointCloudAttributeModel|None, parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def filters(self) -> 'QgsPointCloudAttributeProxyModel.Filter': ...
    def setFilters(self, filters: 'QgsPointCloudAttributeProxyModel.Filter') -> 'QgsPointCloudAttributeProxyModel|None': ...
    def sourceAttributeModel(self) -> QgsPointCloudAttributeModel|None: ...


class QgsPointCloudCategory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, value: int, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, label: str|None, render: bool = ..., pointSize: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudCategory') -> None: ...

    def __ne__(self, other: object): ...
    def setRenderState(self, render: bool) -> None: ...
    def renderState(self) -> bool: ...
    def setLabel(self, label: str|None) -> None: ...
    def setPointSize(self, size: float) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setValue(self, value: int) -> None: ...
    def label(self) -> str: ...
    def pointSize(self) -> float: ...
    def color(self) -> QtGui.QColor: ...
    def value(self) -> int: ...
    def __eq__(self, other: object): ...


class QgsPointCloudClassifiedRenderer(QgsPointCloudRenderer):

    def __init__(self, attributeName: str|None = ..., categories: collections.abc.Iterable[QgsPointCloudCategory] = ...) -> None: ...

    def addCategory(self, category: QgsPointCloudCategory) -> None: ...
    def setCategories(self, categories: collections.abc.Iterable[QgsPointCloudCategory]) -> None: ...
    def categories(self) -> list[QgsPointCloudCategory]: ...
    def setAttribute(self, attribute: str|None) -> None: ...
    def attribute(self) -> str: ...
    @staticmethod
    def defaultCategories() -> list[QgsPointCloudCategory]: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsPointCloudRenderer|None: ...
    def checkLegendItem(self, key: str|None, state: bool = ...) -> None: ...
    def legendItemChecked(self, key: str|None) -> bool: ...
    def legendRuleKeys(self) -> list[str]: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def usedAttributes(self, context: 'QgsPointCloudRenderContext') -> set[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def willRenderPoint(self, pointAttributes: dict[str|None, typing.Any]) -> bool: ...
    def renderBlock(self, block: 'QgsPointCloudBlock|None', context: 'QgsPointCloudRenderContext') -> None: ...
    def clone(self) -> QgsPointCloudRenderer|None: ...
    def type(self) -> str: ...


class QgsPointCloudExtentRenderer(QgsPointCloudRenderer):

    def __init__(self, symbol: 'QgsFillSymbol|None' = ...) -> None: ...

    def renderLabel(self, extent: QtCore.QRectF, text: str|None, context: 'QgsPointCloudRenderContext') -> None: ...
    def setFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def fillSymbol(self) -> 'QgsFillSymbol|None': ...
    @staticmethod
    def defaultFillSymbol() -> 'QgsFillSymbol|None': ...
    def renderExtent(self, extent: QgsGeometry, context: 'QgsPointCloudRenderContext') -> None: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsPointCloudRenderer|None: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def stopRender(self, context: 'QgsPointCloudRenderContext') -> None: ...
    def startRender(self, context: 'QgsPointCloudRenderContext') -> None: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def renderBlock(self, block: 'QgsPointCloudBlock|None', context: 'QgsPointCloudRenderContext') -> None: ...
    def clone(self) -> QgsPointCloudRenderer|None: ...
    def type(self) -> str: ...


class QgsPointCloudBlock(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, count: int, attributes: QgsPointCloudAttributeCollection, data: QtCore.QByteArray|bytes|bytearray|memoryview, scale: QgsVector3D, offset: QgsVector3D) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudBlock') -> None: ...

    def setPointCount(self, size: int) -> None: ...
    def offset(self) -> QgsVector3D: ...
    def scale(self) -> QgsVector3D: ...
    def attributes(self) -> QgsPointCloudAttributeCollection: ...
    def pointRecordSize(self) -> int: ...
    def pointCount(self) -> int: ...
    def data(self) -> str: ...
    def clone(self) -> 'QgsPointCloudBlock|None': ...


class QgsPointCloudLayer(QgsMapLayer, QgsAbstractProfileSource):

    class PointCloudStatisticsCalculationState(enum.IntFlag):
        NotStarted = ... # type: QgsPointCloudLayer.PointCloudStatisticsCalculationState
        Calculating = ... # type: QgsPointCloudLayer.PointCloudStatisticsCalculationState
        Calculated = ... # type: QgsPointCloudLayer.PointCloudStatisticsCalculationState

    class LayerOptions(PyQt6.sip.wrapper):

        loadDefaultStyle = ... # type: bool
        skipCrsValidation = ... # type: bool
        skipIndexGeneration = ... # type: bool
        skipStatisticsCalculation = ... # type: bool
        transformContext = ... # type: 'QgsCoordinateTransformContext'

        @typing.overload
        def __init__(self, transformContext: 'QgsCoordinateTransformContext' = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsPointCloudLayer.LayerOptions') -> None: ...

    def __init__(self, uri: str|None = ..., baseName: str|None = ..., providerLib: str|None = ..., options: 'QgsPointCloudLayer.LayerOptions' = ...) -> None: ...

    chunkAttributeValuesChanged: typing.ClassVar[QtCore.pyqtSignal]
    statisticsCalculationStateChanged: typing.ClassVar[QtCore.pyqtSignal]
    raiseError: typing.ClassVar[QtCore.pyqtSignal]
    subsetStringChanged: typing.ClassVar[QtCore.pyqtSignal]
    def overview(self) -> 'QgsPointCloudIndex': ...
    def isVpc(self) -> bool: ...
    def subIndexes(self) -> list['QgsPointCloudSubIndex']: ...
    def index(self) -> 'QgsPointCloudIndex': ...
    def rollBack(self) -> bool: ...
    def commitError(self) -> str: ...
    def commitChanges(self, stopEditing: bool = ...) -> bool: ...
    def startEditing(self) -> bool: ...
    def statisticsCalculationState(self) -> 'QgsPointCloudLayer.PointCloudStatisticsCalculationState': ...
    def statistics(self) -> 'QgsPointCloudStatistics': ...
    def convertRenderer3DFromRenderer2D(self) -> bool: ...
    def sync3DRendererTo2DRenderer(self) -> bool: ...
    def setSync3DRendererTo2DRenderer(self, sync: bool) -> None: ...
    def subsetString(self) -> str: ...
    def setSubsetString(self, subset: str|None) -> bool: ...
    def setRenderer(self, renderer: QgsPointCloudRenderer|None) -> None: ...
    def renderer(self) -> QgsPointCloudRenderer|None: ...
    def pointCount(self) -> int: ...
    def attributes(self) -> QgsPointCloudAttributeCollection: ...
    def elevationProperties(self) -> QgsMapLayerElevationProperties|None: ...
    def htmlMetadata(self) -> str: ...
    def loadDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def decodedSource(self, source: str|None, dataProvider: str|None, context: QgsReadWriteContext) -> str: ...
    def encodedSource(self, source: str|None, context: QgsReadWriteContext) -> str: ...
    def setTransformContext(self, transformContext: 'QgsCoordinateTransformContext') -> None: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeXml(self, layerNode: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def readXml(self, layerNode: QtXml.QDomNode, context: QgsReadWriteContext) -> bool: ...
    def isModified(self) -> bool: ...
    def isEditable(self) -> bool: ...
    def supportsEditing(self) -> bool: ...
    def dataProvider(self) -> 'QgsPointCloudDataProvider|None': ...
    def createProfileGenerator(self, request: QgsProfileRequest) -> QgsAbstractProfileGenerator|None: ...
    def profileSourceName(self) -> str: ...
    def profileSourceId(self) -> str: ...
    def profileSource(self) -> QgsAbstractProfileSource|None: ...
    def createMapRenderer(self, rendererContext: QgsRenderContext) -> QgsMapLayerRenderer|None: ...
    def extent(self) -> QgsRectangle: ...
    def clone(self) -> 'QgsPointCloudLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsPointCloudLayerElevationProperties(QgsMapLayerElevationProperties):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def setElevationLimit(self, limit: float) -> None: ...
    def elevationLimit(self) -> float: ...
    def setProfileSymbology(self, symbology: Qgis.ProfileSurfaceSymbology) -> None: ...
    def profileSymbology(self) -> Qgis.ProfileSurfaceSymbology: ...
    def setProfileFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def profileFillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setProfileLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def profileLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def type(self) -> Qgis.PointCloudProfileType: ...
    def setType(self, type: Qgis.PointCloudProfileType) -> None: ...
    def setRespectLayerColors(self, enabled: bool) -> None: ...
    def respectLayerColors(self) -> bool: ...
    def pointSizeUnit(self) -> Qgis.RenderUnit: ...
    def setPointSizeUnit(self, units: Qgis.RenderUnit) -> None: ...
    def pointSize(self) -> float: ...
    def setPointSize(self, size: float) -> None: ...
    def setApplyOpacityByDistanceEffect(self, apply: bool) -> None: ...
    def applyOpacityByDistanceEffect(self) -> bool: ...
    def setPointColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def pointColor(self) -> QtGui.QColor: ...
    def setPointSymbol(self, symbol: Qgis.PointCloudSymbol) -> None: ...
    def pointSymbol(self) -> Qgis.PointCloudSymbol: ...
    def setMaximumScreenErrorUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def maximumScreenErrorUnit(self) -> Qgis.RenderUnit: ...
    def setMaximumScreenError(self, error: float) -> None: ...
    def maximumScreenError(self) -> float: ...
    def showByDefaultInElevationProfilePlots(self) -> bool: ...
    def significantZValues(self, layer: QgsMapLayer|None) -> list[float]: ...
    def calculateZRange(self, layer: QgsMapLayer|None) -> QgsDoubleRange: ...
    def isVisibleInZRange(self, range: QgsDoubleRange, layer: QgsMapLayer|None = ...) -> bool: ...
    def htmlSummary(self) -> str: ...
    def clone(self) -> 'QgsPointCloudLayerElevationProperties|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def hasElevation(self) -> bool: ...


class QgsPointCloudNodeId(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, _d: int, _x: int, _y: int, _z: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudNodeId') -> None: ...

    def __ne__(self, other: object): ...
    def z(self) -> int: ...
    def y(self) -> int: ...
    def x(self) -> int: ...
    def d(self) -> int: ...
    def toString(self) -> str: ...
    @staticmethod
    def fromString(str: str|None) -> 'QgsPointCloudNodeId': ...
    def parentNode(self) -> 'QgsPointCloudNodeId': ...
    def __eq__(self, other: object): ...
    def isValid(self) -> bool: ...


class QgsPointCloudNode(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, id: QgsPointCloudNodeId, pointCount: int, childIds: collections.abc.Iterable[QgsPointCloudNodeId], error: float, bounds: QgsBox3D) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudNode') -> None: ...

    @typing.overload
    def bounds(self) -> QgsBox3D: ...
    @typing.overload
    @staticmethod
    def bounds(rootBounds: QgsBox3D, id: QgsPointCloudNodeId) -> QgsBox3D: ...
    def error(self) -> float: ...
    def children(self) -> list[QgsPointCloudNodeId]: ...
    def pointCount(self) -> int: ...
    def id(self) -> QgsPointCloudNodeId: ...


class QgsPointCloudIndex(PyQt6.sip.wrapper):

    def uri(self) -> str: ...
    def updatedNodes(self) -> list[QgsPointCloudNodeId]: ...
    def isModified(self) -> bool: ...
    def commitChanges(self) -> typing.Tuple[bool, str]: ...
    def extraMetadata(self) -> dict[str, typing.Any]: ...
    def subsetString(self) -> str: ...
    def setSubsetString(self, subset: str|None) -> bool: ...
    def span(self) -> int: ...
    def offset(self) -> QgsVector3D: ...
    def scale(self) -> QgsVector3D: ...
    def rootNodeBounds(self) -> QgsBox3D: ...
    def zMax(self) -> float: ...
    def zMin(self) -> float: ...
    def extent(self) -> QgsRectangle: ...
    def updateNodeData(self, data: dict[QgsPointCloudNodeId, QtCore.QByteArray|bytes|bytearray|memoryview]) -> bool: ...
    def attributes(self) -> QgsPointCloudAttributeCollection: ...
    def getNode(self, id: QgsPointCloudNodeId) -> QgsPointCloudNode: ...
    def hasNode(self, id: QgsPointCloudNodeId) -> bool: ...
    def root(self) -> QgsPointCloudNodeId: ...
    def writeStatistics(self, stats: 'QgsPointCloudStatistics') -> bool: ...
    def metadataStatistics(self) -> 'QgsPointCloudStatistics': ...
    def originalMetadata(self) -> dict[str, typing.Any]: ...
    def pointCount(self) -> int: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def accessType(self) -> Qgis.PointCloudAccessType: ...
    def error(self) -> str: ...
    def isValid(self) -> bool: ...
    def load(self, url: str|None, authcfg: str|None = ...) -> None: ...
    def __int__(self) -> bool: ...


class QgsPointCloudSubIndex(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, uri: str|None, geometry: QgsGeometry, extent: QgsRectangle, zRange: QgsDoubleRange, count: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudSubIndex') -> None: ...

    def pointCount(self) -> int: ...
    def polygonBounds(self) -> QgsGeometry: ...
    def zRange(self) -> QgsDoubleRange: ...
    def extent(self) -> QgsRectangle: ...
    def uri(self) -> str: ...
    def setIndex(self, index: QgsPointCloudIndex) -> None: ...
    def index(self) -> QgsPointCloudIndex: ...


class QgsPointCloudDataProvider(QgsDataProvider):

    class PointCloudIndexGenerationState(enum.IntEnum):
        NotIndexed = ... # type: QgsPointCloudDataProvider.PointCloudIndexGenerationState
        Indexing = ... # type: QgsPointCloudDataProvider.PointCloudIndexGenerationState
        Indexed = ... # type: QgsPointCloudDataProvider.PointCloudIndexGenerationState

    class Capability(enum.IntEnum):
        NoCapabilities = ... # type: QgsPointCloudDataProvider.Capability
        ReadLayerMetadata = ... # type: QgsPointCloudDataProvider.Capability
        WriteLayerMetadata = ... # type: QgsPointCloudDataProvider.Capability
        CreateRenderer = ... # type: QgsPointCloudDataProvider.Capability
        ContainSubIndexes = ... # type: QgsPointCloudDataProvider.Capability
        ChangeAttributeValues = ... # type: QgsPointCloudDataProvider.Capability

    def __init__(self, uri: str|None, providerOptions: QgsDataProvider.ProviderOptions, flags: Qgis.DataProviderReadFlag = ...) -> None: ...

    indexGenerationStateChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def translatedDataFormatIds() -> dict[int, str]: ...
    @staticmethod
    def dataFormatIds() -> dict[int, str]: ...
    @staticmethod
    def translatedLasClassificationCodes() -> dict[int, str]: ...
    @staticmethod
    def lasClassificationCodes() -> dict[int, str]: ...
    def setSubsetString(self, subset: str|None, updateFeatureCount: bool = ...) -> bool: ...
    def subsetString(self) -> str: ...
    def subsetStringHelpUrl(self) -> str: ...
    def subsetStringDialect(self) -> str: ...
    def supportsSubsetString(self) -> bool: ...
    def metadataStatistics(self) -> 'QgsPointCloudStatistics': ...
    def createRenderer(self, configuration: dict[str|None, typing.Any] = ...) -> QgsPointCloudRenderer|None: ...
    def originalMetadata(self) -> dict[str, typing.Any]: ...
    def polygonBounds(self) -> QgsGeometry: ...
    def pointCount(self) -> int: ...
    def hasValidIndex(self) -> bool: ...
    def loadSubIndex(self, n: int) -> None: ...
    def subIndexes(self) -> list[QgsPointCloudSubIndex]: ...
    def index(self) -> QgsPointCloudIndex: ...
    def indexingState(self) -> 'QgsPointCloudDataProvider.PointCloudIndexGenerationState': ...
    def generateIndex(self) -> None: ...
    def loadIndex(self) -> None: ...
    def attributes(self) -> QgsPointCloudAttributeCollection: ...
    def capabilities(self) -> 'QgsPointCloudDataProvider.Capability': ...
    def identify(self, maxErrorInMapCoords: float, extentGeometry: QgsGeometry, extentZRange: QgsDoubleRange = ..., pointsLimit: int = ...) -> list: ...


class QgsPointCloudRenderContext(PyQt6.sip.wrapper):

    def __init__(self, context: QgsRenderContext, scale: QgsVector3D, offset: QgsVector3D, zValueScale: float, zValueFixedOffset: float, feedback: QgsFeedback|None = ...) -> None: ...

    def feedback(self) -> QgsFeedback|None: ...
    def zValueFixedOffset(self) -> float: ...
    def zValueScale(self) -> float: ...
    def zOffset(self) -> int: ...
    def yOffset(self) -> int: ...
    def xOffset(self) -> int: ...
    def pointRecordSize(self) -> int: ...
    def setAttributes(self, attributes: QgsPointCloudAttributeCollection) -> None: ...
    def attributes(self) -> QgsPointCloudAttributeCollection: ...
    def incrementPointsRendered(self, count: int) -> None: ...
    def pointsRendered(self) -> int: ...
    def setOffset(self, offset: QgsVector3D) -> None: ...
    def offset(self) -> QgsVector3D: ...
    def setScale(self, scale: QgsVector3D) -> None: ...
    def scale(self) -> QgsVector3D: ...
    def renderContext(self) -> QgsRenderContext: ...


class QgsPointCloudRendererAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None, icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudRendererAbstractMetadata') -> None: ...

    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsPointCloudRenderer|None: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsPointCloudRendererMetadata(QgsPointCloudRendererAbstractMetadata):

    def __init__(self, a0: 'QgsPointCloudRendererMetadata') -> None: ...

    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsPointCloudRenderer|None: ...


class QgsPointCloudRendererRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def classificationAttributeCategories(layer: QgsPointCloudLayer|None) -> list[QgsPointCloudCategory]: ...
    @staticmethod
    def defaultRenderer(layer: QgsPointCloudLayer|None) -> QgsPointCloudRenderer|None: ...
    def renderersList(self) -> list[str]: ...
    def rendererMetadata(self, rendererName: str|None) -> QgsPointCloudRendererAbstractMetadata|None: ...
    def removeRenderer(self, rendererName: str|None) -> bool: ...
    def addRenderer(self, metadata: QgsPointCloudRendererAbstractMetadata|None) -> bool: ...


class QgsPointCloudRgbRenderer(QgsPointCloudRenderer):

    def __init__(self) -> None: ...

    def setBlueContrastEnhancement(self, enhancement: 'QgsContrastEnhancement|None') -> None: ...
    def blueContrastEnhancement(self) -> 'QgsContrastEnhancement|None': ...
    def setGreenContrastEnhancement(self, enhancement: 'QgsContrastEnhancement|None') -> None: ...
    def greenContrastEnhancement(self) -> 'QgsContrastEnhancement|None': ...
    def setRedContrastEnhancement(self, enhancement: 'QgsContrastEnhancement|None') -> None: ...
    def redContrastEnhancement(self) -> 'QgsContrastEnhancement|None': ...
    def setBlueAttribute(self, attribute: str|None) -> None: ...
    def blueAttribute(self) -> str: ...
    def setGreenAttribute(self, attribute: str|None) -> None: ...
    def greenAttribute(self) -> str: ...
    def setRedAttribute(self, attribute: str|None) -> None: ...
    def redAttribute(self) -> str: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsPointCloudRenderer|None: ...
    def usedAttributes(self, context: QgsPointCloudRenderContext) -> set[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def renderBlock(self, block: QgsPointCloudBlock|None, context: QgsPointCloudRenderContext) -> None: ...
    def clone(self) -> QgsPointCloudRenderer|None: ...
    def type(self) -> str: ...


class QgsPointCloudLayerExporter(PyQt6.sip.wrapper):

    class ExportFormat(enum.IntEnum):
        Memory = ... # type: QgsPointCloudLayerExporter.ExportFormat
        Las = ... # type: QgsPointCloudLayerExporter.ExportFormat
        Gpkg = ... # type: QgsPointCloudLayerExporter.ExportFormat
        Shp = ... # type: QgsPointCloudLayerExporter.ExportFormat
        Dxf = ... # type: QgsPointCloudLayerExporter.ExportFormat
        Csv = ... # type: QgsPointCloudLayerExporter.ExportFormat

    def __init__(self, layer: QgsPointCloudLayer|None) -> None: ...

    def lastError(self) -> str: ...
    def takeExportedLayer(self) -> QgsMapLayer|None: ...
    def doExport(self) -> None: ...
    def prepareExport(self) -> None: ...
    def setActionOnExistingFile(self, action: QgsVectorFileWriter.ActionOnExistingFile) -> None: ...
    def pointsLimit(self) -> int: ...
    def setPointsLimit(self, limit: int) -> None: ...
    def format(self) -> 'QgsPointCloudLayerExporter.ExportFormat': ...
    def setFormat(self, format: 'QgsPointCloudLayerExporter.ExportFormat') -> bool: ...
    def crs(self) -> 'QgsCoordinateReferenceSystem': ...
    def setCrs(self, crs: 'QgsCoordinateReferenceSystem', context: 'QgsCoordinateTransformContext' = ...) -> None: ...
    def attributes(self) -> list[str]: ...
    def setAllAttributes(self) -> None: ...
    def setNoAttributes(self) -> None: ...
    def setAttributes(self, attributes: collections.abc.Iterable[str|None]) -> None: ...
    def feedback(self) -> QgsFeedback|None: ...
    def setFeedback(self, feedback: QgsFeedback|None) -> None: ...
    def zRange(self) -> QgsDoubleRange: ...
    def setZRange(self, zRange: QgsDoubleRange) -> None: ...
    @typing.overload
    def setFilterGeometry(self, geometry: QgsAbstractGeometry|None) -> None: ...
    @typing.overload
    def setFilterGeometry(self, layer: QgsMapLayer|None, selectedFeaturesOnly: bool = ...) -> None: ...
    def filterExtent(self) -> QgsRectangle: ...
    def setFilterExtent(self, extent: QgsRectangle) -> None: ...
    def layerName(self) -> str: ...
    def setLayerName(self, name: str|None) -> None: ...
    def fileName(self) -> str: ...
    def setFileName(self, filename: str|None) -> None: ...


class QgsPointCloudLayerExporterTask(QgsTask):

    def __init__(self, exporter: QgsPointCloudLayerExporter|None) -> None: ...

    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    exportComplete: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...


class QgsPointCloudAttributeStatistics(PyQt6.sip.wrapper):

    count = ... # type: int
    maximum = ... # type: float
    mean = ... # type: float
    minimum = ... # type: float
    stDev = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudAttributeStatistics') -> None: ...

    def singleClassCount(self, cls: int) -> int: ...


class QgsPointCloudStatistics(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPointCloudStatistics') -> None: ...

    @staticmethod
    def fromStatisticsJson(stats: QtCore.QByteArray|bytes|bytearray|memoryview) -> 'QgsPointCloudStatistics': ...
    def toStatisticsJson(self) -> QtCore.QByteArray: ...
    def combineWith(self, stats: 'QgsPointCloudStatistics') -> None: ...
    def stDev(self, attribute: str|None) -> float: ...
    def mean(self, attribute: str|None) -> float: ...
    def maximum(self, attribute: str|None) -> float: ...
    def minimum(self, attribute: str|None) -> float: ...
    def classesOf(self, attribute: str|None) -> list[int]: ...
    def statisticsOf(self, attribute: str|None) -> QgsPointCloudAttributeStatistics: ...
    @typing.overload
    def clear(self) -> None: ...
    @typing.overload
    def clear(self, attributes: collections.abc.Iterable[QgsPointCloudAttribute]) -> None: ...
    def sampledPointsCount(self) -> int: ...


class QgsCelestialBody(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCelestialBody') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def authority(self) -> str: ...
    def name(self) -> str: ...
    def isValid(self) -> bool: ...


class QgsCoordinateReferenceSystem(PyQt6.sip.wrapper):

    class CrsType(enum.IntEnum):
        InternalCrsId = ... # type: QgsCoordinateReferenceSystem.CrsType
        PostgisCrsId = ... # type: QgsCoordinateReferenceSystem.CrsType
        EpsgCrsId = ... # type: QgsCoordinateReferenceSystem.CrsType

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, definition: str|None) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, id: int, type: 'QgsCoordinateReferenceSystem.CrsType' = ...) -> None: ...
    @typing.overload
    def __init__(self, srs: 'QgsCoordinateReferenceSystem') -> None: ...

    @staticmethod
    def invalidateCache() -> None: ...
    @staticmethod
    @deprecated("""""")
    def clearRecentCoordinateReferenceSystems() -> None: ...
    @staticmethod
    @deprecated("""""")
    def removeRecentCoordinateReferenceSystem(crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @staticmethod
    @deprecated("""""")
    def pushRecentCoordinateReferenceSystem(crs: 'QgsCoordinateReferenceSystem') -> None: ...
    @staticmethod
    @deprecated("""""")
    def recentCoordinateReferenceSystems() -> list['QgsCoordinateReferenceSystem']: ...
    @staticmethod
    @deprecated("""""")
    def recentProjections() -> list[str]: ...
    def __repr__(self) -> typing.Any: ...
    def geographicCrsAuthId(self) -> str: ...
    def hasVerticalAxis(self) -> bool: ...
    def verticalCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def horizontalCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def toGeocentricCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def toGeographicCrs(self) -> 'QgsCoordinateReferenceSystem': ...
    def nativeFormat(self) -> Qgis.CrsDefinitionFormat: ...
    def setNativeFormat(self, format: Qgis.CrsDefinitionFormat) -> None: ...
    def saveAsUserCrs(self, name: str|None, nativeFormat: Qgis.CrsDefinitionFormat = ...) -> int: ...
    @staticmethod
    def syncDatabase() -> int: ...
    def validationHint(self) -> str: ...
    def setValidationHint(self, html: str|None) -> None: ...
    def updateDefinition(self) -> None: ...
    def toOgcUrn(self) -> str: ...
    def toOgcUri(self) -> str: ...
    def bounds(self) -> QgsRectangle: ...
    def mapUnits(self) -> Qgis.DistanceUnit: ...
    def axisOrdering(self) -> list[Qgis.CrsAxisDirection]: ...
    def hasAxisInverted(self) -> bool: ...
    def operation(self) -> 'QgsProjOperation': ...
    def factors(self, point: QgsPoint) -> 'QgsProjectionFactors': ...
    def coordinateEpoch(self) -> float: ...
    def setCoordinateEpoch(self, epoch: float) -> None: ...
    def celestialBodyName(self) -> str: ...
    def datumEnsemble(self) -> 'QgsDatumEnsemble': ...
    def isDynamic(self) -> bool: ...
    def isGeographic(self) -> bool: ...
    def isDeprecated(self) -> bool: ...
    def type(self) -> Qgis.CrsType: ...
    def toJsonString(self, multiline: bool = ..., indentationWidth: int = ..., schema: str|None = ...) -> typing.Any: ...
    def toProj(self) -> str: ...
    @deprecated("""""")
    def toProj4(self) -> str: ...
    def toWkt(self, variant: Qgis.CrsWktVariant = ..., multiline: bool = ..., indentationWidth: int = ...) -> str: ...
    def ellipsoidAcronym(self) -> str: ...
    def projectionAcronym(self) -> str: ...
    def userFriendlyIdentifier(self, type: Qgis.CrsIdentifierType = ...) -> str: ...
    def description(self) -> str: ...
    def authid(self) -> str: ...
    def postgisSrid(self) -> int: ...
    def srsid(self) -> int: ...
    def writeXml(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument) -> bool: ...
    def readXml(self, node: QtXml.QDomNode) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    @deprecated("""""")
    def findMatchingProj(self) -> int: ...
    def validate(self) -> None: ...
    def isValid(self) -> bool: ...
    @staticmethod
    @deprecated("""""")
    def setupESRIWktFix() -> None: ...
    def createFromUserInput(self, definition: str|None) -> bool: ...
    def createFromString(self, definition: str|None) -> bool: ...
    def createFromProj(self, projString: str|None) -> bool: ...
    @deprecated("""""")
    def createFromProj4(self, projString: str|None) -> bool: ...
    def createFromSrsId(self, srsId: int) -> bool: ...
    def createFromWkt(self, wkt: str|None) -> bool: ...
    @deprecated("""""")
    def createFromSrid(self, srid: int) -> bool: ...
    def createFromOgcWmsCrs(self, crs: str|None) -> bool: ...
    @deprecated("""""")
    def createFromId(self, id: int, type: 'QgsCoordinateReferenceSystem.CrsType' = ...) -> bool: ...
    @staticmethod
    def createGeocentricCrs(ellipsoid: str|None) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def createCompoundCrs(horizontalCrs: 'QgsCoordinateReferenceSystem', verticalCrs: 'QgsCoordinateReferenceSystem') -> typing.Tuple['QgsCoordinateReferenceSystem', str]: ...
    @staticmethod
    def fromSrsId(srsId: int) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def fromWkt(wkt: str|None) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def fromProj(proj: str|None) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    @deprecated("""""")
    def fromProj4(proj4: str|None) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def fromEpsgId(epsg: int) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def fromOgcWmsCrs(ogcCrs: str|None) -> 'QgsCoordinateReferenceSystem': ...
    @staticmethod
    def validSrsIds() -> typing.Any: ...


class QgsCoordinateReferenceSystemRegistry(QtCore.QObject):

    class UserCrsDetails(PyQt6.sip.wrapper):

        crs = ... # type: QgsCoordinateReferenceSystem
        id = ... # type: int
        name = ... # type: str|None
        proj = ... # type: str|None
        wkt = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCoordinateReferenceSystemRegistry.UserCrsDetails') -> None: ...

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    recentCrsCleared: typing.ClassVar[QtCore.pyqtSignal]
    recentCrsRemoved: typing.ClassVar[QtCore.pyqtSignal]
    recentCrsPushed: typing.ClassVar[QtCore.pyqtSignal]
    crsDefinitionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    userCrsRemoved: typing.ClassVar[QtCore.pyqtSignal]
    userCrsAdded: typing.ClassVar[QtCore.pyqtSignal]
    userCrsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def clearRecent(self) -> None: ...
    def removeRecent(self, crs: QgsCoordinateReferenceSystem) -> None: ...
    def pushRecent(self, crs: QgsCoordinateReferenceSystem) -> None: ...
    def recentCrs(self) -> list[QgsCoordinateReferenceSystem]: ...
    def authorities(self) -> set[str]: ...
    def celestialBodies(self) -> list[QgsCelestialBody]: ...
    def projOperations(self) -> dict[str, 'QgsProjOperation']: ...
    def removeUserCrs(self, id: int) -> bool: ...
    def updateUserCrs(self, id: int, crs: QgsCoordinateReferenceSystem, name: str|None, nativeFormat: Qgis.CrsDefinitionFormat = ...) -> bool: ...
    def addUserCrs(self, crs: QgsCoordinateReferenceSystem, name: str|None, nativeFormat: Qgis.CrsDefinitionFormat = ...) -> int: ...
    def userCrsList(self) -> list['QgsCoordinateReferenceSystemRegistry.UserCrsDetails']: ...


class QgsCoordinateReferenceSystemUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCoordinateReferenceSystemUtils') -> None: ...

    @staticmethod
    def translateProjection(projection: str|None) -> str: ...
    @staticmethod
    def crsTypeToString(type: Qgis.CrsType) -> str: ...
    @staticmethod
    def axisDirectionToAbbreviatedString(axis: Qgis.CrsAxisDirection) -> str: ...
    @staticmethod
    def defaultCoordinateOrderForCrs(crs: QgsCoordinateReferenceSystem) -> Qgis.CoordinateOrder: ...


class QgsCoordinateTransform(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem, context: 'QgsCoordinateTransformContext', flags: Qgis.CoordinateTransformationFlag = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem, project: 'QgsProject|None', flags: Qgis.CoordinateTransformationFlag = ...) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem, sourceDatumTransformId: int, destinationDatumTransformId: int) -> None: ...
    @typing.overload
    def __init__(self, o: 'QgsCoordinateTransform') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def scaleFactor(self, referenceExtent: QgsRectangle) -> float: ...
    @staticmethod
    def invalidateCache() -> None: ...
    @deprecated("""""")
    def setDestinationDatumTransformId(self, datumId: int) -> None: ...
    @deprecated("""""")
    def destinationDatumTransformId(self) -> int: ...
    @deprecated("""""")
    def setSourceDatumTransformId(self, datumId: int) -> None: ...
    @deprecated("""""")
    def sourceDatumTransformId(self) -> int: ...
    def fallbackOperationOccurred(self) -> bool: ...
    def disableFallbackOperationHandler(self, disabled: bool) -> None: ...
    def setBallparkTransformsAreAppropriate(self, appropriate: bool) -> None: ...
    def allowFallbackTransforms(self) -> bool: ...
    def setAllowFallbackTransforms(self, allowed: bool) -> None: ...
    def setCoordinateOperation(self, operation: str|None) -> None: ...
    def instantiatedCoordinateOperationDetails(self) -> 'QgsDatumTransform.TransformDetails': ...
    def coordinateOperation(self) -> str: ...
    def hasVerticalComponent(self) -> bool: ...
    def isShortCircuited(self) -> bool: ...
    def transformCoords(self, numPoint: int, direction: Qgis.TransformDirection = ...) -> typing.Tuple[float, float, float]: ...
    def transformPolygon(self, polygon: QtGui.QPolygonF, direction: Qgis.TransformDirection = ...) -> None: ...
    def transformInPlace(self, direction: Qgis.TransformDirection = ...) -> typing.Tuple[float, float, float]: ...
    def transformBoundingBox(self, rectangle: QgsRectangle, direction: Qgis.TransformDirection = ..., handle180Crossover: bool = ...) -> QgsRectangle: ...
    @typing.overload
    def transform(self, point: QgsPointXY, direction: Qgis.TransformDirection = ...) -> QgsPointXY: ...
    @typing.overload
    def transform(self, x: float, y: float, direction: Qgis.TransformDirection = ...) -> QgsPointXY: ...
    @typing.overload
    def transform(self, point: QgsVector3D, direction: Qgis.TransformDirection = ...) -> QgsVector3D: ...
    @typing.overload
    def transform(self, rectangle: QgsRectangle, direction: Qgis.TransformDirection = ...) -> QgsRectangle: ...
    def destinationCrs(self) -> QgsCoordinateReferenceSystem: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    def context(self) -> 'QgsCoordinateTransformContext': ...
    def setContext(self, context: 'QgsCoordinateTransformContext') -> None: ...
    def setDestinationCrs(self, crs: QgsCoordinateReferenceSystem) -> None: ...
    def setSourceCrs(self, crs: QgsCoordinateReferenceSystem) -> None: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def isTransformationPossible(source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsCoordinateTransformContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, rhs: 'QgsCoordinateTransformContext') -> None: ...

    def writeSettings(self) -> None: ...
    def readSettings(self) -> None: ...
    def writeXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> typing.Tuple[bool, list[str]]: ...
    def mustReverseCoordinateOperation(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> bool: ...
    def allowFallbackTransform(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> bool: ...
    def calculateCoordinateOperation(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> str: ...
    @deprecated("""""")
    def calculateDatumTransforms(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> 'QgsDatumTransform.TransformPair': ...
    def hasTransform(self, source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> bool: ...
    def removeCoordinateOperation(self, sourceCrs: QgsCoordinateReferenceSystem, destinationCrs: QgsCoordinateReferenceSystem) -> None: ...
    @deprecated("""""")
    def removeSourceDestinationDatumTransform(self, sourceCrs: QgsCoordinateReferenceSystem, destinationCrs: QgsCoordinateReferenceSystem) -> None: ...
    def addCoordinateOperation(self, sourceCrs: QgsCoordinateReferenceSystem, destinationCrs: QgsCoordinateReferenceSystem, coordinateOperationProjString: str|None, allowFallback: bool = ...) -> bool: ...
    @deprecated("""""")
    def addSourceDestinationDatumTransform(self, sourceCrs: QgsCoordinateReferenceSystem, destinationCrs: QgsCoordinateReferenceSystem, sourceTransformId: int, destinationTransformId: int) -> bool: ...
    def coordinateOperations(self) -> typing.Any: ...
    @deprecated("""""")
    def sourceDestinationDatumTransforms(self) -> typing.Any: ...
    def clear(self) -> None: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsDatumEnsembleMember(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDatumEnsembleMember') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def code(self) -> str: ...
    def authority(self) -> str: ...
    def remarks(self) -> str: ...
    def scope(self) -> str: ...
    def name(self) -> str: ...


class QgsDatumEnsemble(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDatumEnsemble') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def members(self) -> list[QgsDatumEnsembleMember]: ...
    def remarks(self) -> str: ...
    def scope(self) -> str: ...
    def code(self) -> str: ...
    def authority(self) -> str: ...
    def accuracy(self) -> float: ...
    def name(self) -> str: ...
    def isValid(self) -> bool: ...


class QgsDatumTransform(PyQt6.sip.wrapper):

    class TransformPair(PyQt6.sip.wrapper):

        destinationTransformId = ... # type: int
        sourceTransformId = ... # type: int

        @typing.overload
        def __init__(self, sourceTransformId: int = ..., destinationTransformId: int = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDatumTransform.TransformPair') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    class TransformInfo(PyQt6.sip.wrapper):

        datumTransformId = ... # type: int
        deprecated = ... # type: bool
        destinationCrsAuthId = ... # type: str|None
        destinationCrsDescription = ... # type: str|None
        epsgCode = ... # type: int
        preferred = ... # type: bool
        remarks = ... # type: str|None
        scope = ... # type: str|None
        sourceCrsAuthId = ... # type: str|None
        sourceCrsDescription = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDatumTransform.TransformInfo') -> None: ...

    class GridDetails(PyQt6.sip.wrapper):

        directDownload = ... # type: bool
        fullName = ... # type: str|None
        isAvailable = ... # type: bool
        openLicense = ... # type: bool
        packageName = ... # type: str|None
        shortName = ... # type: str|None
        url = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDatumTransform.GridDetails') -> None: ...

    class SingleOperationDetails(PyQt6.sip.wrapper):

        areaOfUse = ... # type: str|None
        authority = ... # type: str|None
        code = ... # type: str|None
        remarks = ... # type: str|None
        scope = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDatumTransform.SingleOperationDetails') -> None: ...

    class TransformDetails(PyQt6.sip.wrapper):

        accuracy = ... # type: float
        areaOfUse = ... # type: str|None
        authority = ... # type: str|None
        bounds = ... # type: QgsRectangle
        code = ... # type: str|None
        grids = ... # type: collections.abc.Iterable['QgsDatumTransform.GridDetails']
        isAvailable = ... # type: bool
        name = ... # type: str|None
        operationDetails = ... # type: collections.abc.Iterable['QgsDatumTransform.SingleOperationDetails']
        proj = ... # type: str|None
        remarks = ... # type: str|None
        scope = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsDatumTransform.TransformDetails') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDatumTransform') -> None: ...

    @staticmethod
    @deprecated("""""")
    def datumTransformInfo(datumTransformId: int) -> 'QgsDatumTransform.TransformInfo': ...
    @staticmethod
    @deprecated("""""")
    def projStringToDatumTransformId(string: str|None) -> int: ...
    @staticmethod
    @deprecated("""""")
    def datumTransformToProj(datumTransformId: int) -> str: ...
    @staticmethod
    @deprecated("""""")
    def datumTransformations(source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem) -> list['QgsDatumTransform.TransformPair']: ...
    @staticmethod
    def operations(source: QgsCoordinateReferenceSystem, destination: QgsCoordinateReferenceSystem, includeSuperseded: bool = ...) -> list['QgsDatumTransform.TransformDetails']: ...


class QgsEllipsoidUtils(PyQt6.sip.wrapper):

    class EllipsoidParameters(PyQt6.sip.wrapper):

        crs = ... # type: QgsCoordinateReferenceSystem
        inverseFlattening = ... # type: float
        semiMajor = ... # type: float
        semiMinor = ... # type: float
        useCustomParameters = ... # type: bool
        valid = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsEllipsoidUtils.EllipsoidParameters') -> None: ...

    class EllipsoidDefinition(PyQt6.sip.wrapper):

        acronym = ... # type: str|None
        celestialBodyName = ... # type: str|None
        description = ... # type: str|None
        parameters = ... # type: 'QgsEllipsoidUtils.EllipsoidParameters'

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsEllipsoidUtils.EllipsoidDefinition') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEllipsoidUtils') -> None: ...

    @staticmethod
    def celestialBodies() -> list[QgsCelestialBody]: ...
    @staticmethod
    def acronyms() -> list[str]: ...
    @staticmethod
    def definitions() -> list['QgsEllipsoidUtils.EllipsoidDefinition']: ...
    @staticmethod
    def ellipsoidParameters(ellipsoid: str|None) -> 'QgsEllipsoidUtils.EllipsoidParameters': ...


class QgsProjOperation(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjOperation') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def details(self) -> str: ...
    def description(self) -> str: ...
    def id(self) -> str: ...
    def isValid(self) -> bool: ...


class QgsProjUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjUtils') -> None: ...

    @staticmethod
    def searchPaths() -> list[str]: ...
    @staticmethod
    def ignfDatabaseDate() -> QtCore.QDate: ...
    @staticmethod
    def ignfDatabaseVersion() -> str: ...
    @staticmethod
    def esriDatabaseDate() -> QtCore.QDate: ...
    @staticmethod
    def esriDatabaseVersion() -> str: ...
    @staticmethod
    def epsgRegistryDate() -> QtCore.QDate: ...
    @staticmethod
    def epsgRegistryVersion() -> str: ...
    @staticmethod
    def projVersionMinor() -> int: ...
    @staticmethod
    def projVersionMajor() -> int: ...


class QgsProjectionFactors(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectionFactors') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def dyDphi(self) -> float: ...
    def dyDlam(self) -> float: ...
    def dxDphi(self) -> float: ...
    def dxDlam(self) -> float: ...
    def tissotSemiminor(self) -> float: ...
    def tissotSemimajor(self) -> float: ...
    def meridianConvergence(self) -> float: ...
    def meridianParallelAngle(self) -> float: ...
    def angularDistortion(self) -> float: ...
    def arealScale(self) -> float: ...
    def parallelScale(self) -> float: ...
    def meridionalScale(self) -> float: ...
    def isValid(self) -> bool: ...


class QgsAbstractMetadataBase(PyQt6.sip.wrapper):

    class Address(PyQt6.sip.wrapper):

        address = ... # type: str|None
        administrativeArea = ... # type: str|None
        city = ... # type: str|None
        country = ... # type: str|None
        postalCode = ... # type: str|None
        type = ... # type: str|None

        @typing.overload
        def __init__(self, type: str|None = ..., address: str|None = ..., city: str|None = ..., administrativeArea: str|None = ..., postalCode: str|None = ..., country: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractMetadataBase.Address') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    class Contact(PyQt6.sip.wrapper):

        addresses = ... # type: collections.abc.Iterable['QgsAbstractMetadataBase.Address']
        email = ... # type: str|None
        fax = ... # type: str|None
        name = ... # type: str|None
        organization = ... # type: str|None
        position = ... # type: str|None
        role = ... # type: str|None
        voice = ... # type: str|None

        @typing.overload
        def __init__(self, name: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractMetadataBase.Contact') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    class Link(PyQt6.sip.wrapper):

        description = ... # type: str|None
        format = ... # type: str|None
        mimeType = ... # type: str|None
        name = ... # type: str|None
        size = ... # type: str|None
        type = ... # type: str|None
        url = ... # type: str|None

        @typing.overload
        def __init__(self, name: str|None = ..., type: str|None = ..., url: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractMetadataBase.Link') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractMetadataBase') -> None: ...

    def equals(self, other: 'QgsAbstractMetadataBase') -> bool: ...
    def registerTranslations(self, translationContext: QgsTranslationContext|None) -> None: ...
    def combine(self, other: 'QgsAbstractMetadataBase|None') -> None: ...
    def writeMetadataXml(self, metadataElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> bool: ...
    def readMetadataXml(self, metadataElement: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> bool: ...
    def setDateTime(self, type: Qgis.MetadataDateType, date: QtCore.QDateTime|datetime.datetime) -> None: ...
    def dateTime(self, type: Qgis.MetadataDateType) -> QtCore.QDateTime: ...
    def addLink(self, link: 'QgsAbstractMetadataBase.Link') -> None: ...
    def setLinks(self, links: collections.abc.Iterable['QgsAbstractMetadataBase.Link']) -> None: ...
    def links(self) -> list['QgsAbstractMetadataBase.Link']: ...
    def addContact(self, contact: 'QgsAbstractMetadataBase.Contact') -> None: ...
    def setContacts(self, contacts: collections.abc.Iterable['QgsAbstractMetadataBase.Contact']) -> None: ...
    def contacts(self) -> list['QgsAbstractMetadataBase.Contact']: ...
    def setCategories(self, categories: collections.abc.Iterable[str|None]) -> None: ...
    def categories(self) -> list[str]: ...
    def keywordVocabularies(self) -> list[str]: ...
    def removeKeywords(self, vocabulary: str|None) -> bool: ...
    def addKeywords(self, vocabulary: str|None, keywords: collections.abc.Iterable[str|None]) -> None: ...
    def setKeywords(self, keywords: dict[str|None, collections.abc.Iterable[str|None]]) -> None: ...
    @typing.overload
    def keywords(self) -> dict[str, list[str]]: ...
    @typing.overload
    def keywords(self, vocabulary: str|None) -> list[str]: ...
    def addHistoryItem(self, text: str|None) -> None: ...
    def setHistory(self, history: collections.abc.Iterable[str|None]) -> None: ...
    def history(self) -> list[str]: ...
    def setAbstract(self, abstract: str|None) -> None: ...
    def abstract(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def setType(self, type: str|None) -> None: ...
    def type(self) -> str: ...
    def setLanguage(self, language: str|None) -> None: ...
    def language(self) -> str: ...
    def setParentIdentifier(self, parentIdentifier: str|None) -> None: ...
    def parentIdentifier(self) -> str: ...
    def setIdentifier(self, identifier: str|None) -> None: ...
    def identifier(self) -> str: ...
    def clone(self) -> 'QgsAbstractMetadataBase|None': ...


class QgsLayerMetadata(QgsAbstractMetadataBase):

    class SpatialExtent(PyQt6.sip.wrapper):

        bounds = ... # type: QgsBox3D
        extentCrs = ... # type: QgsCoordinateReferenceSystem

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerMetadata.SpatialExtent') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    class Extent(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerMetadata.Extent') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def setTemporalExtents(self, extents: collections.abc.Iterable[QgsDateTimeRange]) -> None: ...
        def temporalExtents(self) -> list[QgsDateTimeRange]: ...
        def setSpatialExtents(self, extents: collections.abc.Iterable['QgsLayerMetadata.SpatialExtent']) -> None: ...
        def spatialExtents(self) -> list['QgsLayerMetadata.SpatialExtent']: ...

    class Constraint(PyQt6.sip.wrapper):

        constraint = ... # type: str|None
        type = ... # type: str|None

        @typing.overload
        def __init__(self, constraint: str|None = ..., type: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayerMetadata.Constraint') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerMetadata') -> None: ...

    def __ne__(self, other: object): ...
    def matches(self, searchReList: collections.abc.Iterable[QtCore.QRegularExpression]) -> bool: ...
    def contains(self, searchString: str|None) -> bool: ...
    def __eq__(self, other: object): ...
    def registerTranslations(self, translationContext: QgsTranslationContext|None) -> None: ...
    def combine(self, other: QgsAbstractMetadataBase|None) -> None: ...
    def writeMetadataXml(self, metadataElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> bool: ...
    def readMetadataXml(self, metadataElement: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> bool: ...
    def readFromLayer(self, layer: QgsMapLayer|None) -> None: ...
    def saveToLayer(self, layer: QgsMapLayer|None) -> None: ...
    def setCrs(self, crs: QgsCoordinateReferenceSystem) -> None: ...
    def crs(self) -> QgsCoordinateReferenceSystem: ...
    def setExtent(self, extent: 'QgsLayerMetadata.Extent') -> None: ...
    def extent(self) -> 'QgsLayerMetadata.Extent': ...
    def setEncoding(self, encoding: str|None) -> None: ...
    def encoding(self) -> str: ...
    def setLicenses(self, licenses: collections.abc.Iterable[str|None]) -> None: ...
    def licenses(self) -> list[str]: ...
    def setRights(self, rights: collections.abc.Iterable[str|None]) -> None: ...
    def rights(self) -> list[str]: ...
    def setConstraints(self, constraints: collections.abc.Iterable['QgsLayerMetadata.Constraint']) -> None: ...
    def addConstraint(self, constraint: 'QgsLayerMetadata.Constraint') -> None: ...
    def constraints(self) -> list['QgsLayerMetadata.Constraint']: ...
    def setFees(self, fees: str|None) -> None: ...
    def fees(self) -> str: ...
    def clone(self) -> 'QgsLayerMetadata|None': ...


class QgsLayerMetadataFormatter(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, metadata: QgsLayerMetadata) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerMetadataFormatter') -> None: ...

    def linksSectionHtml(self) -> str: ...
    def historySectionHtml(self) -> str: ...
    def identificationSectionHtml(self) -> str: ...
    def extentSectionHtml(self, showSpatialExtent: bool = ...) -> str: ...
    def contactsSectionHtml(self) -> str: ...
    def accessSectionHtml(self) -> str: ...


class QgsAbstractMetadataBaseValidator(PyQt6.sip.wrapper):

    class ValidationResult(PyQt6.sip.wrapper):

        note = ... # type: str|None
        section = ... # type: str|None

        @typing.overload
        def __init__(self, section: str|None, note: str|None, identifier: typing.Any = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractMetadataBaseValidator.ValidationResult') -> None: ...

        def setIdentifier(self, identifier: typing.Any) -> None: ...
        def _identifier(self) -> typing.Any: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractMetadataBaseValidator') -> None: ...

    def validate(self, metadata: QgsAbstractMetadataBase|None) -> typing.Tuple[bool, list['QgsAbstractMetadataBaseValidator.ValidationResult']]: ...


class QgsNativeMetadataBaseValidator(QgsAbstractMetadataBaseValidator):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNativeMetadataBaseValidator') -> None: ...

    def validate(self, metadata: QgsAbstractMetadataBase|None) -> typing.Tuple[bool, list[QgsAbstractMetadataBaseValidator.ValidationResult]]: ...


class QgsNativeMetadataValidator(QgsNativeMetadataBaseValidator):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNativeMetadataValidator') -> None: ...

    def validate(self, metadata: QgsAbstractMetadataBase|None) -> typing.Tuple[bool, list[QgsAbstractMetadataBaseValidator.ValidationResult]]: ...


class QgsNativeProjectMetadataValidator(QgsNativeMetadataBaseValidator):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNativeProjectMetadataValidator') -> None: ...

    def validate(self, metadata: QgsAbstractMetadataBase|None) -> typing.Tuple[bool, list[QgsAbstractMetadataBaseValidator.ValidationResult]]: ...


class QgsMetadataUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMetadataUtils') -> None: ...

    @staticmethod
    def convertFromEsri(document: QtXml.QDomDocument) -> QgsLayerMetadata: ...


class QgsProjectMetadata(QgsAbstractMetadataBase):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectMetadata') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def registerTranslations(self, translationContext: QgsTranslationContext|None) -> None: ...
    def combine(self, other: QgsAbstractMetadataBase|None) -> None: ...
    def writeMetadataXml(self, metadataElement: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> bool: ...
    def readMetadataXml(self, metadataElement: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> bool: ...
    def setCreationDateTime(self, creationDateTime: QtCore.QDateTime|datetime.datetime) -> None: ...
    def creationDateTime(self) -> QtCore.QDateTime: ...
    def setAuthor(self, author: str|None) -> None: ...
    def author(self) -> str: ...
    def clone(self) -> 'QgsProjectMetadata|None': ...


class QgsMetadataSearchContext(PyQt6.sip.wrapper):

    transformContext = ... # type: QgsCoordinateTransformContext

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMetadataSearchContext') -> None: ...


class QgsLayerMetadataProviderResult(QgsLayerMetadata):

    @typing.overload
    def __init__(self, metadata: QgsLayerMetadata) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerMetadataProviderResult') -> None: ...

    def setStandardUri(self, standardUri: str|None) -> None: ...
    def standardUri(self) -> str: ...
    def setLayerType(self, layerType: Qgis.LayerType) -> None: ...
    def layerType(self) -> Qgis.LayerType: ...
    def setDataProviderName(self, dataProviderName: str|None) -> None: ...
    def dataProviderName(self) -> str: ...
    def setUri(self, Uri: str|None) -> None: ...
    def uri(self) -> str: ...
    def setAuthid(self, authid: str|None) -> None: ...
    def authid(self) -> str: ...
    def setGeometryType(self, geometryType: Qgis.GeometryType) -> None: ...
    def geometryType(self) -> Qgis.GeometryType: ...
    def setGeographicExtent(self, geographicExtent: QgsPolygon) -> None: ...
    def geographicExtent(self) -> QgsPolygon: ...


class QgsLayerMetadataSearchResults(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerMetadataSearchResults') -> None: ...

    def addError(self, error: str|None) -> None: ...
    def errors(self) -> list[str]: ...
    def addMetadata(self, metadata: QgsLayerMetadataProviderResult) -> None: ...
    def metadata(self) -> list[QgsLayerMetadataProviderResult]: ...


class QgsAbstractLayerMetadataProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractLayerMetadataProvider') -> None: ...

    def search(self, searchContext: QgsMetadataSearchContext, searchString: str|None = ..., geographicExtent: QgsRectangle = ..., feedback: QgsFeedback|None = ...) -> QgsLayerMetadataSearchResults: ...
    def id(self) -> str: ...


class QgsLayerMetadataProviderRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def search(self, searchContext: QgsMetadataSearchContext, searchString: str|None = ..., geographicExtent: QgsRectangle = ..., feedback: QgsFeedback|None = ...) -> QgsLayerMetadataSearchResults: ...
    def layerMetadataProviderFromId(self, id: str|None) -> QgsAbstractLayerMetadataProvider|None: ...
    def layerMetadataProviders(self) -> list[QgsAbstractLayerMetadataProvider]: ...
    def unregisterLayerMetadataProvider(self, metadataProvider: QgsAbstractLayerMetadataProvider|None) -> None: ...
    def registerLayerMetadataProvider(self, metadataProvider: QgsAbstractLayerMetadataProvider|None) -> None: ...


class QgsBlockingNetworkRequest(QtCore.QObject):

    class RequestFlag(enum.IntFlag):
        EmptyResponseIsValid = ... # type: QgsBlockingNetworkRequest.RequestFlag

    class ErrorCode(enum.IntEnum):
        NoError = ... # type: QgsBlockingNetworkRequest.ErrorCode
        NetworkError = ... # type: QgsBlockingNetworkRequest.ErrorCode
        TimeoutError = ... # type: QgsBlockingNetworkRequest.ErrorCode
        ServerExceptionError = ... # type: QgsBlockingNetworkRequest.ErrorCode

    def __init__(self, flags: Qgis.NetworkRequestFlag = ...) -> None: ...

    finished: typing.ClassVar[QtCore.pyqtSignal]
    uploadProgress: typing.ClassVar[QtCore.pyqtSignal]
    downloadFinished: typing.ClassVar[QtCore.pyqtSignal]
    downloadProgress: typing.ClassVar[QtCore.pyqtSignal]
    def abort(self) -> None: ...
    def setAuthCfg(self, authCfg: str|None) -> None: ...
    def authCfg(self) -> str: ...
    def reply(self) -> 'QgsNetworkReplyContent': ...
    def errorMessage(self) -> str: ...
    def deleteResource(self, request: QtNetwork.QNetworkRequest, feedback: QgsFeedback|None = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    @typing.overload
    def put(self, request: QtNetwork.QNetworkRequest, data: QtCore.QIODevice|None, feedback: QgsFeedback|None = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    @typing.overload
    def put(self, request: QtNetwork.QNetworkRequest, data: QtCore.QByteArray|bytes|bytearray|memoryview, feedback: QgsFeedback|None = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    def head(self, request: QtNetwork.QNetworkRequest, forceRefresh: bool = ..., feedback: QgsFeedback|None = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    @typing.overload
    def post(self, request: QtNetwork.QNetworkRequest, data: QtCore.QIODevice|None, forceRefresh: bool = ..., feedback: QgsFeedback|None = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    @typing.overload
    def post(self, request: QtNetwork.QNetworkRequest, data: QtCore.QByteArray|bytes|bytearray|memoryview, forceRefresh: bool = ..., feedback: QgsFeedback|None = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    def get(self, request: QtNetwork.QNetworkRequest, forceRefresh: bool = ..., feedback: QgsFeedback|None = ..., requestFlags: 'QgsBlockingNetworkRequest.RequestFlag' = ...) -> 'QgsBlockingNetworkRequest.ErrorCode': ...
    def flags(self) -> Qgis.NetworkRequestFlag: ...


class QgsFileDownloader(QtCore.QObject):

    def __init__(self, url: QtCore.QUrl, outputFileName: str|None, authcfg: str|None = ..., delayStart: bool = ..., httpMethod: Qgis.HttpMethod = ..., data: QtCore.QByteArray|bytes|bytearray|memoryview = ...) -> None: ...

    def startDownload(self) -> None: ...
    def cancelDownload(self) -> None: ...
    downloadProgress: typing.ClassVar[QtCore.pyqtSignal]
    downloadError: typing.ClassVar[QtCore.pyqtSignal]
    downloadCanceled: typing.ClassVar[QtCore.pyqtSignal]
    downloadExited: typing.ClassVar[QtCore.pyqtSignal]
    downloadCompleted: typing.ClassVar[QtCore.pyqtSignal]


class QgsNetworkRequestParameters(PyQt6.sip.wrapper):

    class RequestAttributes(enum.IntEnum):
        AttributeInitiatorClass = ... # type: QgsNetworkRequestParameters.RequestAttributes
        AttributeInitiatorRequestId = ... # type: QgsNetworkRequestParameters.RequestAttributes
        AttributeOriginalHeaders = ... # type: QgsNetworkRequestParameters.RequestAttributes

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, operation: QtNetwork.QNetworkAccessManager.Operation, request: QtNetwork.QNetworkRequest, requestId: int, content: QtCore.QByteArray|bytes|bytearray|memoryview = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNetworkRequestParameters') -> None: ...

    def initiatorRequestId(self) -> typing.Any: ...
    def initiatorClassName(self) -> str: ...
    def content(self) -> QtCore.QByteArray: ...
    def requestId(self) -> int: ...
    def originatingThreadId(self) -> str: ...
    def request(self) -> QtNetwork.QNetworkRequest: ...
    def operation(self) -> QtNetwork.QNetworkAccessManager.Operation: ...


class QgsNetworkAccessManager(QtNetwork.QNetworkAccessManager):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def createRequest(self, op: QtNetwork.QNetworkAccessManager.Operation, req: QtNetwork.QNetworkRequest, outgoingData: QtCore.QIODevice|None = ...) -> QtNetwork.QNetworkReply|None: ...
    cookiesChanged: typing.ClassVar[QtCore.pyqtSignal]
    authBrowserAborted: typing.ClassVar[QtCore.pyqtSignal]
    requestEncounteredSslErrors: typing.ClassVar[QtCore.pyqtSignal]
    requestAuthDetailsAdded: typing.ClassVar[QtCore.pyqtSignal]
    requestRequiresAuth: typing.ClassVar[QtCore.pyqtSignal]
    downloadProgress: typing.ClassVar[QtCore.pyqtSignal]
    requestTimedOut: typing.ClassVar[QtCore.pyqtSignal]
    finished: typing.ClassVar[QtCore.pyqtSignal]
    requestCreated: typing.ClassVar[QtCore.pyqtSignal]
    requestAboutToBeCreated: typing.ClassVar[QtCore.pyqtSignal]
    def preprocessRequest(self, req: QtNetwork.QNetworkRequest|None) -> None: ...
    def abortAuthBrowser(self) -> None: ...
    def requestAuthCloseBrowser(self) -> None: ...
    def requestAuthOpenBrowser(self, url: QtCore.QUrl) -> None: ...
    @staticmethod
    def removeReplyPreprocessor(id: str|None) -> None: ...
    @staticmethod
    def setReplyPreprocessor(a0: typing.Callable[..., None]) -> str: ...
    @staticmethod
    def removeAdvancedRequestPreprocessor(id: str|None) -> None: ...
    @staticmethod
    def setAdvancedRequestPreprocessor(a0: typing.Callable[..., None]) -> str: ...
    @staticmethod
    def removeRequestPreprocessor(id: str|None) -> None: ...
    @staticmethod
    def setRequestPreprocessor(a0: typing.Callable[..., None]) -> str: ...
    @staticmethod
    def blockingPost(request: QtNetwork.QNetworkRequest, data: QtCore.QByteArray|bytes|bytearray|memoryview, authCfg: str|None = ..., forceRefresh: bool = ..., feedback: QgsFeedback|None = ..., flags: Qgis.NetworkRequestFlag = ...) -> 'QgsNetworkReplyContent': ...
    @staticmethod
    def blockingGet(request: QtNetwork.QNetworkRequest, authCfg: str|None = ..., forceRefresh: bool = ..., feedback: QgsFeedback|None = ..., flags: Qgis.NetworkRequestFlag = ...) -> 'QgsNetworkReplyContent': ...
    @staticmethod
    def setTimeout(time: int) -> None: ...
    @staticmethod
    def timeout() -> int: ...
    def useSystemProxy(self) -> bool: ...
    def setupDefaultProxyAndCache(self, connectionType: QtCore.Qt.ConnectionType = ...) -> None: ...
    @staticmethod
    def cacheLoadControlFromName(name: str|None) -> QtNetwork.QNetworkRequest.CacheLoadControl: ...
    @staticmethod
    def cacheLoadControlName(control: QtNetwork.QNetworkRequest.CacheLoadControl) -> str: ...
    def setFallbackProxyAndExcludes(self, proxy: QtNetwork.QNetworkProxy, excludes: collections.abc.Iterable[str|None], noProxyURLs: collections.abc.Iterable[str|None]) -> None: ...
    def noProxyList(self) -> list[str]: ...
    def excludeList(self) -> list[str]: ...
    def fallbackProxy(self) -> QtNetwork.QNetworkProxy: ...
    def proxyFactories(self) -> list[QtNetwork.QNetworkProxyFactory]: ...
    def removeProxyFactory(self, factory: QtNetwork.QNetworkProxyFactory|None) -> None: ...
    def insertProxyFactory(self, factory: QtNetwork.QNetworkProxyFactory|None) -> None: ...
    @staticmethod
    def instance(connectionType: QtCore.Qt.ConnectionType = ...) -> 'QgsNetworkAccessManager|None': ...


class QgsNetworkContentFetcher(QtCore.QObject):

    def __init__(self) -> None: ...

    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    downloadProgress: typing.ClassVar[QtCore.pyqtSignal]
    finished: typing.ClassVar[QtCore.pyqtSignal]
    def wasCanceled(self) -> bool: ...
    def cancel(self) -> None: ...
    def contentAsString(self) -> str: ...
    def contentDispositionFilename(self) -> str: ...
    def reply(self) -> QtNetwork.QNetworkReply|None: ...
    @typing.overload
    def fetchContent(self, url: QtCore.QUrl, authcfg: str|None = ..., headers: 'QgsHttpHeaders' = ...) -> None: ...
    @typing.overload
    def fetchContent(self, request: QtNetwork.QNetworkRequest, authcfg: str|None = ...) -> None: ...


class QgsFetchedContent(QtCore.QObject):

    class ContentStatus(enum.IntEnum):
        NotStarted = ... # type: QgsFetchedContent.ContentStatus
        Downloading = ... # type: QgsFetchedContent.ContentStatus
        Finished = ... # type: QgsFetchedContent.ContentStatus
        Failed = ... # type: QgsFetchedContent.ContentStatus

    def __init__(self, url: str|None, file: QtCore.QTemporaryFile|None = ..., status: 'QgsFetchedContent.ContentStatus' = ..., authConfig: str|None = ..., headers: 'QgsHttpHeaders' = ...) -> None: ...

    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    fetched: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    def download(self, redownload: bool = ...) -> None: ...
    def authConfig(self) -> str: ...
    def error(self) -> QtNetwork.QNetworkReply.NetworkError: ...
    def status(self) -> 'QgsFetchedContent.ContentStatus': ...
    def filePath(self) -> str: ...


class QgsNetworkContentFetcherRegistry(QtCore.QObject):

    def __init__(self) -> None: ...

    def localPath(self, filePathOrUrl: str|None) -> str: ...
    def fetch(self, url: str|None, fetchingMode: Qgis.ActionStart = ..., authConfig: str|None = ..., headers: 'QgsHttpHeaders' = ...) -> QgsFetchedContent|None: ...


class QgsNetworkContentFetcherTask(QgsTask):

    @typing.overload
    def __init__(self, url: QtCore.QUrl, authcfg: str|None = ..., flags: QgsTask.Flag = ..., description: str|None = ..., headers: 'QgsHttpHeaders' = ...) -> None: ...
    @typing.overload
    def __init__(self, request: QtNetwork.QNetworkRequest, authcfg: str|None = ..., flags: QgsTask.Flag = ..., description: str|None = ..., headers: 'QgsHttpHeaders' = ...) -> None: ...

    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    fetched: typing.ClassVar[QtCore.pyqtSignal]
    def contentAsString(self) -> str: ...
    def contentDispositionFilename(self) -> str: ...
    def reply(self) -> QtNetwork.QNetworkReply|None: ...
    def cancel(self) -> None: ...
    def run(self) -> bool: ...


class QgsNetworkReplyContent(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, reply: QtNetwork.QNetworkReply|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNetworkReplyContent') -> None: ...

    @staticmethod
    def extractFileNameFromContentDispositionHeader(header: str|None) -> str: ...
    @staticmethod
    def extractFilenameFromContentDispositionHeader(reply: QtNetwork.QNetworkReply|None) -> str: ...
    def content(self) -> QtCore.QByteArray: ...
    def setContent(self, content: QtCore.QByteArray|bytes|bytearray|memoryview) -> None: ...
    def request(self) -> QtNetwork.QNetworkRequest: ...
    def requestId(self) -> int: ...
    def rawHeader(self, headerName: QtCore.QByteArray|bytes|bytearray|memoryview) -> QtCore.QByteArray: ...
    def rawHeaderList(self) -> list[QtCore.QByteArray]: ...
    def hasRawHeader(self, headerName: QtCore.QByteArray|bytes|bytearray|memoryview) -> bool: ...
    def errorString(self) -> str: ...
    def error(self) -> QtNetwork.QNetworkReply.NetworkError: ...
    def attribute(self, code: QtNetwork.QNetworkRequest.Attribute) -> typing.Any: ...
    def clear(self) -> None: ...


class QgsNewsFeedModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        Key = ... # type: QgsNewsFeedModel.CustomRole
        Title = ... # type: QgsNewsFeedModel.CustomRole
        Content = ... # type: QgsNewsFeedModel.CustomRole
        ImageUrl = ... # type: QgsNewsFeedModel.CustomRole
        Image = ... # type: QgsNewsFeedModel.CustomRole
        Link = ... # type: QgsNewsFeedModel.CustomRole
        Sticky = ... # type: QgsNewsFeedModel.CustomRole
        Published = ... # type: QgsNewsFeedModel.CustomRole

    def __init__(self, parser: 'QgsNewsFeedParser|None', parent: QtCore.QObject|None = ...) -> None: ...

    def roleNames(self) -> dict[int, QtCore.QByteArray]: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...


class QgsNewsFeedProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parser: 'QgsNewsFeedParser|None', parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...


class QgsNewsFeedParser(QtCore.QObject):

    class Entry(PyQt6.sip.wrapper):

        content = ... # type: str|None
        expiry = ... # type: QtCore.QDateTime|datetime.datetime
        image = ... # type: QtGui.QPixmap
        imageUrl = ... # type: str|None
        key = ... # type: int
        link = ... # type: QtCore.QUrl
        published = ... # type: QtCore.QDateTime|datetime.datetime
        sticky = ... # type: bool
        title = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsNewsFeedParser.Entry') -> None: ...

    def __init__(self, feedUrl: QtCore.QUrl, authcfg: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    isFetchingChanged: typing.ClassVar[QtCore.pyqtSignal]
    enabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    imageFetched: typing.ClassVar[QtCore.pyqtSignal]
    entryDismissed: typing.ClassVar[QtCore.pyqtSignal]
    entryUpdated: typing.ClassVar[QtCore.pyqtSignal]
    entryAdded: typing.ClassVar[QtCore.pyqtSignal]
    fetched: typing.ClassVar[QtCore.pyqtSignal]
    def fetch(self) -> None: ...
    @staticmethod
    def keyForFeed(baseUrl: str|None) -> str: ...
    def authcfg(self) -> str: ...
    def dismissAll(self) -> None: ...
    def dismissEntry(self, key: int) -> None: ...
    def entries(self) -> list['QgsNewsFeedParser.Entry']: ...
    def isFetching(self) -> bool: ...


class QgsHttpHeaders(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, headers: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, settings: 'QgsSettings', key: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None) -> None: ...
    @typing.overload
    def __init__(self, element: QtXml.QDomElement) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHttpHeaders') -> None: ...

    def toSpacedString(self) -> str: ...
    def keys(self) -> list[str]: ...
    def insert(self, key: str|None, value: typing.Any) -> None: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __getitem__(self, key: str|None) -> typing.Any: ...
    def sanitizeKey(self, key: str|None) -> str: ...
    def setFromDomElement(self, element: QtXml.QDomElement) -> None: ...
    def setFromMap(self, map: dict[str|None, typing.Any]) -> None: ...
    def setFromUrlQuery(self, uri: QtCore.QUrlQuery) -> None: ...
    def setFromSettings(self, settings: 'QgsSettings', key: str|None = ...) -> None: ...
    @deprecated("""""")
    def updateDomElement(self, el: QtXml.QDomElement) -> bool: ...
    def updateMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def updateUrlQuery(self, uri: QtCore.QUrlQuery) -> bool: ...
    def updateNetworkRequest(self, request: QtNetwork.QNetworkRequest) -> bool: ...
    @deprecated("""""")
    def updateSettings(self, settings: 'QgsSettings', key: str|None = ...) -> bool: ...
    def headers(self) -> dict[str, typing.Any]: ...


class QgsNumericFormat(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNumericFormat') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def writeXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> None: ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> 'QgsNumericFormat|None': ...
    def clone(self) -> 'QgsNumericFormat|None': ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def suggestSampleValue(self) -> float: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsBasicNumericFormat(QgsNumericFormat):

    class RoundingType(enum.IntEnum):
        DecimalPlaces = ... # type: QgsBasicNumericFormat.RoundingType
        SignificantFigures = ... # type: QgsBasicNumericFormat.RoundingType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBasicNumericFormat') -> None: ...

    def setConfiguration(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def setDecimalSeparator(self, character: str) -> None: ...
    def decimalSeparator(self) -> str: ...
    def setThousandsSeparator(self, character: str) -> None: ...
    def thousandsSeparator(self) -> str: ...
    def setRoundingType(self, type: 'QgsBasicNumericFormat.RoundingType') -> None: ...
    def roundingType(self) -> 'QgsBasicNumericFormat.RoundingType': ...
    def setShowTrailingZeros(self, show: bool) -> None: ...
    def showTrailingZeros(self) -> bool: ...
    def setShowPlusSign(self, show: bool) -> None: ...
    def showPlusSign(self) -> bool: ...
    def setShowThousandsSeparator(self, show: bool) -> None: ...
    def showThousandsSeparator(self) -> bool: ...
    def setNumberDecimalPlaces(self, places: int) -> None: ...
    def numberDecimalPlaces(self) -> int: ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsBearingNumericFormat(QgsBasicNumericFormat):

    class FormatDirectionOption(enum.IntEnum):
        UseRange0To180WithEWDirectionalSuffix = ... # type: QgsBearingNumericFormat.FormatDirectionOption
        UseRangeNegative180ToPositive180 = ... # type: QgsBearingNumericFormat.FormatDirectionOption
        UseRange0To360 = ... # type: QgsBearingNumericFormat.FormatDirectionOption

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBearingNumericFormat') -> None: ...

    def setConfiguration(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def setDirectionFormat(self, format: 'QgsBearingNumericFormat.FormatDirectionOption') -> None: ...
    def directionFormat(self) -> 'QgsBearingNumericFormat.FormatDirectionOption': ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> 'QgsBearingNumericFormat|None': ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def suggestSampleValue(self) -> float: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsGeographicCoordinateNumericFormat(QgsBasicNumericFormat):

    class AngleFormat(enum.Enum):
        DegreesMinutesSeconds = ... # type: QgsGeographicCoordinateNumericFormat.AngleFormat
        DegreesMinutes = ... # type: QgsGeographicCoordinateNumericFormat.AngleFormat
        DecimalDegrees = ... # type: QgsGeographicCoordinateNumericFormat.AngleFormat

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGeographicCoordinateNumericFormat') -> None: ...

    def setConfiguration(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def setShowDirectionalSuffix(self, show: bool) -> None: ...
    def showDirectionalSuffix(self) -> bool: ...
    def setShowDegreeLeadingZeros(self, show: bool) -> None: ...
    def showDegreeLeadingZeros(self) -> bool: ...
    def setShowLeadingZeros(self, show: bool) -> None: ...
    def showLeadingZeros(self) -> bool: ...
    def setAngleFormat(self, format: 'QgsGeographicCoordinateNumericFormat.AngleFormat') -> None: ...
    def angleFormat(self) -> 'QgsGeographicCoordinateNumericFormat.AngleFormat': ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> 'QgsGeographicCoordinateNumericFormat|None': ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def suggestSampleValue(self) -> float: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsCurrencyNumericFormat(QgsBasicNumericFormat):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCurrencyNumericFormat') -> None: ...

    def setSuffix(self, suffix: str|None) -> None: ...
    def suffix(self) -> str: ...
    def setPrefix(self, prefix: str|None) -> None: ...
    def prefix(self) -> str: ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def suggestSampleValue(self) -> float: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsExpressionBasedNumericFormat(QgsNumericFormat):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionBasedNumericFormat') -> None: ...

    def expression(self) -> str: ...
    def setExpression(self, expression: str|None) -> None: ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsFallbackNumericFormat(QgsNumericFormat):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFallbackNumericFormat') -> None: ...

    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsFractionNumericFormat(QgsNumericFormat):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFractionNumericFormat') -> None: ...

    def setConfiguration(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    @staticmethod
    def toUnicodeSubscript(input: str|None) -> str: ...
    @staticmethod
    def toUnicodeSuperscript(input: str|None) -> str: ...
    @staticmethod
    def doubleToVulgarFraction(value: float, tolerance: float = ...) -> typing.Tuple[bool, int, int, int]: ...
    def setThousandsSeparator(self, character: str) -> None: ...
    def thousandsSeparator(self) -> str: ...
    def setShowPlusSign(self, show: bool) -> None: ...
    def showPlusSign(self) -> bool: ...
    def setShowThousandsSeparator(self, show: bool) -> None: ...
    def showThousandsSeparator(self) -> bool: ...
    def setUseUnicodeSuperSubscript(self, enabled: bool) -> None: ...
    def useUnicodeSuperSubscript(self) -> bool: ...
    def setUseDedicatedUnicodeCharacters(self, enabled: bool) -> None: ...
    def useDedicatedUnicodeCharacters(self) -> bool: ...
    def suggestSampleValue(self) -> float: ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: 'QgsNumericFormatContext') -> str: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsNumericFormatContext(PyQt6.sip.wrapper):

    class Interpretation(enum.Enum):
        Generic = ... # type: QgsNumericFormatContext.Interpretation
        Latitude = ... # type: QgsNumericFormatContext.Interpretation
        Longitude = ... # type: QgsNumericFormatContext.Interpretation

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNumericFormatContext') -> None: ...

    def setExpressionContext(self, context: QgsExpressionContext) -> None: ...
    def expressionContext(self) -> QgsExpressionContext: ...
    def setInterpretation(self, interpretation: 'QgsNumericFormatContext.Interpretation') -> None: ...
    def interpretation(self) -> 'QgsNumericFormatContext.Interpretation': ...
    def setExponential(self, character: str) -> None: ...
    def exponential(self) -> str: ...
    def setPositiveSign(self, character: str) -> None: ...
    def positiveSign(self) -> str: ...
    def setNegativeSign(self, character: str) -> None: ...
    def negativeSign(self) -> str: ...
    def setZeroDigit(self, character: str) -> None: ...
    def zeroDigit(self) -> str: ...
    def setPercent(self, character: str) -> None: ...
    def percent(self) -> str: ...
    def setDecimalSeparator(self, separator: str) -> None: ...
    def decimalSeparator(self) -> str: ...
    def setThousandsSeparator(self, separator: str) -> None: ...
    def thousandsSeparator(self) -> str: ...


class QgsNumericFormatRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNumericFormatRegistry') -> None: ...

    def sortKey(self, id: str|None) -> int: ...
    def visibleName(self, id: str|None) -> str: ...
    def fallbackFormat(self) -> QgsNumericFormat|None: ...
    def createFromXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def create(self, id: str|None, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def format(self, id: str|None) -> QgsNumericFormat|None: ...
    def removeFormat(self, id: str|None) -> None: ...
    def addFormat(self, format: QgsNumericFormat|None) -> None: ...
    def formats(self) -> list[str]: ...


class QgsPercentageNumericFormat(QgsBasicNumericFormat):

    class InputValues(enum.IntEnum):
        ValuesArePercentage = ... # type: QgsPercentageNumericFormat.InputValues
        ValuesAreFractions = ... # type: QgsPercentageNumericFormat.InputValues

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPercentageNumericFormat') -> None: ...

    def setInputValues(self, format: 'QgsPercentageNumericFormat.InputValues') -> None: ...
    def inputValues(self) -> 'QgsPercentageNumericFormat.InputValues': ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: QgsNumericFormatContext) -> str: ...
    def suggestSampleValue(self) -> float: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsScientificNumericFormat(QgsBasicNumericFormat):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScientificNumericFormat') -> None: ...

    def setNumberDecimalPlaces(self, places: int) -> None: ...
    def configuration(self, context: QgsReadWriteContext) -> dict[str, typing.Any]: ...
    def create(self, configuration: dict[str|None, typing.Any], context: QgsReadWriteContext) -> QgsNumericFormat|None: ...
    def clone(self) -> QgsNumericFormat|None: ...
    def formatDouble(self, value: float, context: QgsNumericFormatContext) -> str: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsProcessingAlgorithm(PyQt6.sip.wrapper):

    class VectorProperties(PyQt6.sip.wrapper):

        availability = ... # type: Qgis.ProcessingPropertyAvailability
        crs = ... # type: QgsCoordinateReferenceSystem
        fields = ... # type: QgsFields
        wkbType = ... # type: Qgis.WkbType

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProcessingAlgorithm.VectorProperties') -> None: ...

    def __init__(self) -> None: ...

    @staticmethod
    def writeFeatureError(sink: QgsFeatureSink|None, parameters: dict[str|None, typing.Any], name: str|None) -> str: ...
    @staticmethod
    def invalidPointCloudError(parameters: dict[str|None, typing.Any], name: str|None) -> str: ...
    @staticmethod
    def invalidSinkError(parameters: dict[str|None, typing.Any], name: str|None) -> str: ...
    @staticmethod
    def invalidRasterError(parameters: dict[str|None, typing.Any], name: str|None) -> str: ...
    @staticmethod
    def invalidSourceError(parameters: dict[str|None, typing.Any], name: str|None) -> str: ...
    def parameterAsAnnotationLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsAnnotationLayer|None: ...
    def parameterAsPointCloudLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', flags: 'QgsProcessing.LayerOptionsFlag' = ...) -> QgsPointCloudLayer|None: ...
    def parameterAsDateTime(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QtCore.QDateTime: ...
    def parameterAsDatabaseTableName(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsSchema(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsConnectionName(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsColor(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QtGui.QColor: ...
    def parameterAsLayoutItem(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', layout: QgsPrintLayout|None) -> QgsLayoutItem|None: ...
    def parameterAsLayout(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsPrintLayout|None: ...
    def parameterAsStrings(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[str]: ...
    @deprecated("""""")
    def parameterAsFields(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[str]: ...
    def parameterAsRange(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[float]: ...
    def parameterAsFileList(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[str]: ...
    def parameterAsLayerList(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', flags: 'QgsProcessing.LayerOptionsFlag' = ...) -> list[QgsMapLayer]: ...
    def parameterAsMatrix(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[typing.Any]: ...
    def parameterAsFile(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsGeometryCrs(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsCoordinateReferenceSystem: ...
    def parameterAsGeometry(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', crs: QgsCoordinateReferenceSystem = ...) -> QgsGeometry: ...
    def parameterAsPointCrs(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsCoordinateReferenceSystem: ...
    def parameterAsPoint(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', crs: QgsCoordinateReferenceSystem = ...) -> QgsPointXY: ...
    def parameterAsExtentCrs(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsCoordinateReferenceSystem: ...
    def parameterAsExtentGeometry(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', crs: QgsCoordinateReferenceSystem = ...) -> QgsGeometry: ...
    def parameterAsExtent(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', crs: QgsCoordinateReferenceSystem = ...) -> QgsRectangle: ...
    def parameterAsCrs(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsCoordinateReferenceSystem: ...
    def parameterAsVectorLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsVectorLayer|None: ...
    def parameterAsFileOutput(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsOutputRasterFormat(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsOutputFormat(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsOutputLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsMeshLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsMeshLayer|None: ...
    def parameterAsRasterLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> 'QgsRasterLayer|None': ...
    def parameterAsLayer(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> QgsMapLayer|None: ...
    def parameterAsCompatibleSourceLayerPathAndLayerName(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', compatibleFormats: collections.abc.Iterable[str|None], preferredFormat: str|None = ..., feedback: 'QgsProcessingFeedback|None' = ...) -> typing.Tuple[str, str]: ...
    def parameterAsCompatibleSourceLayerPath(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', compatibleFormats: collections.abc.Iterable[str|None], preferredFormat: str|None = ..., feedback: 'QgsProcessingFeedback|None' = ...) -> str: ...
    def parameterAsSource(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> 'QgsProcessingFeatureSource|None': ...
    def parameterAsSink(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext', fields: QgsFields, geometryType: Qgis.WkbType = ..., crs: QgsCoordinateReferenceSystem = ..., sinkFlags: QgsFeatureSink.SinkFlag = ..., createOptions: dict[str|None, typing.Any] = ..., datasourceOptions: collections.abc.Iterable[str|None] = ..., layerOptions: collections.abc.Iterable[str|None] = ...) -> typing.Tuple[QgsFeatureSink|None, str]: ...
    def parameterAsBoolean(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> bool: ...
    def parameterAsBool(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> bool: ...
    def parameterAsEnumStrings(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[str]: ...
    def parameterAsEnumString(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsEnums(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[int]: ...
    def parameterAsEnum(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> int: ...
    def parameterAsInts(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> list[int]: ...
    def parameterAsInt(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> int: ...
    def parameterAsDouble(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> float: ...
    def parameterAsExpression(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def parameterAsString(self, parameters: dict[str|None, typing.Any], name: str|None, context: 'QgsProcessingContext') -> str: ...
    def postProcessAlgorithm(self, context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> dict[str, typing.Any]: ...
    def processAlgorithm(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> dict[str, typing.Any]: ...
    def prepareAlgorithm(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> bool: ...
    def addOutput(self, outputDefinition: 'QgsProcessingOutputDefinition|None') -> bool: ...
    def removeParameter(self, name: str|None) -> None: ...
    def addParameter(self, parameterDefinition: 'QgsProcessingParameterDefinition|None', createOutput: bool = ...) -> bool: ...
    def initAlgorithm(self, configuration: dict[str|None, typing.Any] = ...) -> None: ...
    def createInstance(self) -> 'QgsProcessingAlgorithm|None': ...
    def supportInPlaceEdit(self, layer: QgsMapLayer|None) -> bool: ...
    def setProvider(self, provider: 'QgsProcessingProvider|None') -> None: ...
    def asMap(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> dict[str, typing.Any]: ...
    def asQgisProcessCommand(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> typing.Tuple[str, bool]: ...
    def asPythonCommand(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> str: ...
    def validateInputCrs(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> bool: ...
    def createExpressionContext(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', source: 'QgsProcessingFeatureSource|None' = ...) -> QgsExpressionContext: ...
    def createCustomParametersWidget(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def postProcess(self, context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None', runResult: bool = ...) -> dict[str, typing.Any]: ...
    def runPrepared(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> dict[str, typing.Any]: ...
    def prepare(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> bool: ...
    def run(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None', configuration: dict[str|None, typing.Any] = ..., catchExceptions: bool = ...) -> typing.Tuple[dict[str, typing.Any], bool]: ...
    def sinkProperties(self, sink: str|None, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', sourceProperties: dict[str|None, 'QgsProcessingAlgorithm.VectorProperties']) -> 'QgsProcessingAlgorithm.VectorProperties': ...
    def hasHtmlOutputs(self) -> bool: ...
    def outputDefinition(self, name: str|None) -> 'QgsProcessingOutputDefinition|None': ...
    def outputDefinitions(self) -> list['QgsProcessingOutputDefinition']: ...
    def destinationParameterDefinitions(self) -> list['QgsProcessingParameterDefinition']: ...
    def countVisibleParameters(self) -> int: ...
    def parameterDefinition(self, name: str|None) -> 'QgsProcessingParameterDefinition|None': ...
    def parameterDefinitions(self) -> list['QgsProcessingParameterDefinition']: ...
    def provider(self) -> 'QgsProcessingProvider|None': ...
    def autogenerateParameterValues(self, existingParameters: dict[str|None, typing.Any], changedParameter: str|None, mode: Qgis.ProcessingMode) -> dict[str, typing.Any]: ...
    def preprocessParameters(self, parameters: dict[str|None, typing.Any]) -> dict[str, typing.Any]: ...
    def checkParameterValues(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> typing.Tuple[bool, str]: ...
    def canExecute(self) -> typing.Tuple[bool, str]: ...
    def flags(self) -> Qgis.ProcessingAlgorithmFlag: ...
    def groupId(self) -> str: ...
    def group(self) -> str: ...
    def svgIconPath(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def documentationFlags(self) -> Qgis.ProcessingAlgorithmDocumentationFlag: ...
    def helpUrl(self) -> str: ...
    @deprecated("""""")
    def helpString(self) -> str: ...
    def shortHelpString(self) -> str: ...
    def tags(self) -> list[str]: ...
    def shortDescription(self) -> str: ...
    def displayName(self) -> str: ...
    def id(self) -> str: ...
    def name(self) -> str: ...
    def create(self, configuration: dict[str|None, typing.Any] = ...) -> 'QgsProcessingAlgorithm|None': ...


class QgsProcessingModelAlgorithm(QgsProcessingAlgorithm):

    class VariableDefinition(PyQt6.sip.wrapper):

        description = ... # type: str|None
        source = ... # type: 'QgsProcessingModelChildParameterSource'
        value = ... # type: typing.Any

        @typing.overload
        def __init__(self, value: typing.Any = ..., source: 'QgsProcessingModelChildParameterSource' = ..., description: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProcessingModelAlgorithm.VariableDefinition') -> None: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    def __init__(self, name: str|None = ..., group: str|None = ..., groupId: str|None = ...) -> None: ...

    def processAlgorithm(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> dict[str, typing.Any]: ...
    def createInstance(self) -> QgsProcessingAlgorithm|None: ...
    @staticmethod
    def safeName(name: str|None, capitalize: bool = ...) -> str: ...
    def modelParameterFromChildIdAndOutputName(self, childId: str|None, childOutputName: str|None) -> 'QgsProcessingParameterDefinition|None': ...
    def setDesignerParameterValues(self, values: dict[str|None, typing.Any]) -> None: ...
    def designerParameterValues(self) -> dict[str, typing.Any]: ...
    def setVariables(self, variables: dict[str|None, typing.Any]) -> None: ...
    def variables(self) -> dict[str, typing.Any]: ...
    def createExpressionContextScopeForChildAlgorithm(self, childId: str|None, context: 'QgsProcessingContext', modelParameters: dict[str|None, typing.Any] = ..., results: dict[str|None, typing.Any] = ...) -> QgsExpressionContextScope|None: ...
    def variablesForChildAlgorithm(self, childId: str|None, context: 'QgsProcessingContext|None' = ..., modelParameters: dict[str|None, typing.Any] = ..., results: dict[str|None, typing.Any] = ...) -> dict[str, 'QgsProcessingModelAlgorithm.VariableDefinition']: ...
    @typing.overload
    def availableSourcesForChild(self, childId: str|None, param: 'QgsProcessingParameterDefinition|None') -> list['QgsProcessingModelChildParameterSource']: ...
    @typing.overload
    def availableSourcesForChild(self, childId: str|None, parameterTypes: collections.abc.Iterable[str|None] = ..., outputTypes: collections.abc.Iterable[str|None] = ..., dataTypes: collections.abc.Iterable[int] = ...) -> list['QgsProcessingModelChildParameterSource']: ...
    def asPythonCode(self, outputType: 'QgsProcessing.PythonOutputType', indentSize: int) -> list[str]: ...
    def modelNameMatchesFilePath(self) -> bool: ...
    def setSourceFilePath(self, path: str|None) -> None: ...
    def sourceFilePath(self) -> str: ...
    def setHelpContent(self, contents: dict[str|None, typing.Any]) -> None: ...
    def helpContent(self) -> dict[str, typing.Any]: ...
    def loadVariant(self, variant: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def fromFile(self, path: str|None) -> bool: ...
    def toFile(self, path: str|None) -> bool: ...
    def removeGroupBox(self, uuid: str|None) -> None: ...
    def groupBoxes(self) -> list['QgsProcessingModelGroupBox']: ...
    def addGroupBox(self, groupBox: 'QgsProcessingModelGroupBox') -> None: ...
    def updateDestinationParameters(self) -> None: ...
    def setOutputGroup(self, group: str|None) -> None: ...
    def outputGroup(self) -> str: ...
    def setOutputOrder(self, order: collections.abc.Iterable[str|None]) -> None: ...
    def orderedOutputs(self) -> list['QgsProcessingModelOutput']: ...
    def setParameterOrder(self, order: collections.abc.Iterable[str|None]) -> None: ...
    def orderedParameters(self) -> list['QgsProcessingModelParameter']: ...
    def parameterComponent(self, name: str|None) -> 'QgsProcessingModelParameter': ...
    def setParameterComponent(self, component: 'QgsProcessingModelParameter') -> None: ...
    def setParameterComponents(self, parameterComponents: dict[str|None, 'QgsProcessingModelParameter']) -> None: ...
    def parameterComponents(self) -> dict[str, 'QgsProcessingModelParameter']: ...
    def otherParametersDependOnParameter(self, name: str|None) -> bool: ...
    def childAlgorithmsDependOnParameter(self, name: str|None) -> bool: ...
    def changeParameterName(self, oldName: str|None, newName: str|None) -> None: ...
    def removeModelParameter(self, name: str|None) -> None: ...
    def updateModelParameter(self, definition: 'QgsProcessingParameterDefinition|None') -> None: ...
    def addModelParameter(self, definition: 'QgsProcessingParameterDefinition|None', component: 'QgsProcessingModelParameter') -> None: ...
    def validateChildAlgorithm(self, childId: str|None) -> typing.Tuple[bool, list[str]]: ...
    def availableDependenciesForChildAlgorithm(self, childId: str|None) -> list['QgsProcessingModelChildDependency']: ...
    def dependsOnChildAlgorithms(self, childId: str|None) -> set[str]: ...
    def dependentChildAlgorithms(self, childId: str|None, conditionalBranch: str|None = ...) -> set[str]: ...
    def activateChildAlgorithm(self, id: str|None) -> bool: ...
    def deactivateChildAlgorithm(self, id: str|None) -> None: ...
    def removeChildAlgorithm(self, id: str|None) -> bool: ...
    def childAlgorithm(self, id: str|None) -> 'QgsProcessingModelChildAlgorithm': ...
    def addChildAlgorithm(self, algorithm: 'QgsProcessingModelChildAlgorithm') -> str: ...
    def setChildAlgorithm(self, algorithm: 'QgsProcessingModelChildAlgorithm') -> None: ...
    def setChildAlgorithms(self, childAlgorithms: dict[str|None, 'QgsProcessingModelChildAlgorithm']) -> None: ...
    def childAlgorithms(self) -> dict[str, 'QgsProcessingModelChildAlgorithm']: ...
    def validate(self) -> typing.Tuple[bool, list[str]]: ...
    def setGroup(self, group: str|None) -> None: ...
    def setName(self, name: str|None) -> None: ...
    def createExpressionContext(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', source: 'QgsProcessingFeatureSource|None' = ...) -> QgsExpressionContext: ...
    def asPythonCommand(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> str: ...
    def canExecute(self) -> typing.Tuple[bool, str]: ...
    def helpUrl(self) -> str: ...
    def shortDescription(self) -> str: ...
    def shortHelpString(self) -> str: ...
    def svgIconPath(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def groupId(self) -> str: ...
    def group(self) -> str: ...
    def displayName(self) -> str: ...
    def name(self) -> str: ...
    def flags(self) -> Qgis.ProcessingAlgorithmFlag: ...
    def initAlgorithm(self, configuration: dict[str|None, typing.Any] = ...) -> None: ...


class QgsProcessingModelComponent(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsProcessingModelComponent') -> None: ...

    def copyNonDefinitionProperties(self, other: 'QgsProcessingModelComponent') -> None: ...
    def restoreCommonProperties(self, map: dict[str|None, typing.Any]) -> None: ...
    def saveCommonProperties(self, map: dict[str|None, typing.Any]) -> None: ...
    def clone(self) -> 'QgsProcessingModelComponent|None': ...
    def setComment(self, comment: 'QgsProcessingModelComment') -> None: ...
    def comment(self) -> 'QgsProcessingModelComment|None': ...
    def setLinksCollapsed(self, edge: QtCore.Qt.Edge, collapsed: bool) -> None: ...
    def linksCollapsed(self, edge: QtCore.Qt.Edge) -> bool: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setSize(self, size: QtCore.QSizeF) -> None: ...
    def size(self) -> QtCore.QSizeF: ...
    def setPosition(self, position: QtCore.QPointF) -> None: ...
    def position(self) -> QtCore.QPointF: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...


class QgsProcessingModelChildAlgorithm(QgsProcessingModelComponent):

    @typing.overload
    def __init__(self, algorithmId: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsProcessingModelChildAlgorithm') -> None: ...

    def setComment(self, comment: 'QgsProcessingModelComment') -> None: ...
    def comment(self) -> 'QgsProcessingModelComment|None': ...
    def asPythonCode(self, outputType: 'QgsProcessing.PythonOutputType', extraParameters: dict[str|None, str|None], currentIndent: int, indentSize: int, friendlyChildNames: dict[str|None, str|None], friendlyOutputNames: dict[str|None, str|None]) -> list[str]: ...
    def loadVariant(self, child: typing.Any) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def removeModelOutput(self, name: str|None) -> bool: ...
    def setModelOutputs(self, outputs: dict[str|None, 'QgsProcessingModelOutput']) -> None: ...
    def modelOutput(self, name: str|None) -> 'QgsProcessingModelOutput': ...
    def modelOutputs(self) -> dict[str, 'QgsProcessingModelOutput']: ...
    def setDependencies(self, dependencies: collections.abc.Iterable['QgsProcessingModelChildDependency']) -> None: ...
    def dependencies(self) -> list['QgsProcessingModelChildDependency']: ...
    def setActive(self, active: bool) -> None: ...
    def isActive(self) -> bool: ...
    def addParameterSources(self, name: str|None, source: collections.abc.Iterable['QgsProcessingModelChildParameterSource']) -> None: ...
    def setParameterSources(self, sources: typing.Any) -> None: ...
    def parameterSources(self) -> typing.Any: ...
    def algorithm(self) -> QgsProcessingAlgorithm|None: ...
    def setConfiguration(self, configuration: dict[str|None, typing.Any]) -> None: ...
    def configuration(self) -> dict[str, typing.Any]: ...
    def reattach(self) -> bool: ...
    def setAlgorithmId(self, algorithmId: str|None) -> bool: ...
    def algorithmId(self) -> str: ...
    def generateChildId(self, model: QgsProcessingModelAlgorithm) -> None: ...
    def setChildId(self, id: str|None) -> None: ...
    def childId(self) -> str: ...
    def copyNonDefinitionPropertiesFromModel(self, model: QgsProcessingModelAlgorithm|None) -> None: ...
    def clone(self) -> 'QgsProcessingModelChildAlgorithm|None': ...


class QgsProcessingModelChildDependency(PyQt6.sip.wrapper):

    childId = ... # type: str|None
    conditionalBranch = ... # type: str|None

    @typing.overload
    def __init__(self, childId: str|None = ..., conditionalBranch: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelChildDependency') -> None: ...

    def __ge__(self, other: 'QgsProcessingModelChildDependency') -> bool: ...
    def __lt__(self, other: 'QgsProcessingModelChildDependency') -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...


class QgsProcessingModelChildParameterSource(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelChildParameterSource') -> None: ...

    def friendlyIdentifier(self, model: QgsProcessingModelAlgorithm|None) -> str: ...
    def asPythonComment(self, definition: 'QgsProcessingParameterDefinition|None') -> str: ...
    def asPythonCode(self, outputType: 'QgsProcessing.PythonOutputType', definition: 'QgsProcessingParameterDefinition|None', friendlyChildNames: dict[str|None, str|None]) -> str: ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def setExpressionText(self, text: str|None) -> None: ...
    def expressionText(self) -> str: ...
    def setExpression(self, expression: str|None) -> None: ...
    def expression(self) -> str: ...
    def setOutputName(self, name: str|None) -> None: ...
    def outputName(self) -> str: ...
    def setOutputChildId(self, id: str|None) -> None: ...
    def outputChildId(self) -> str: ...
    def setParameterName(self, name: str|None) -> None: ...
    def parameterName(self) -> str: ...
    def setStaticValue(self, value: typing.Any) -> None: ...
    def staticValue(self) -> typing.Any: ...
    def setSource(self, source: Qgis.ProcessingModelChildParameterSource) -> None: ...
    def source(self) -> Qgis.ProcessingModelChildParameterSource: ...
    @staticmethod
    def fromExpressionText(text: str|None) -> 'QgsProcessingModelChildParameterSource': ...
    @staticmethod
    def fromExpression(expression: str|None) -> 'QgsProcessingModelChildParameterSource': ...
    @staticmethod
    def fromChildOutput(childId: str|None, outputName: str|None) -> 'QgsProcessingModelChildParameterSource': ...
    @staticmethod
    def fromModelParameter(parameterName: str|None) -> 'QgsProcessingModelChildParameterSource': ...
    @staticmethod
    def fromStaticValue(value: typing.Any) -> 'QgsProcessingModelChildParameterSource': ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsProcessingModelComment(QgsProcessingModelComponent):

    @typing.overload
    def __init__(self, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelComment') -> None: ...

    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def clone(self) -> 'QgsProcessingModelComment|None': ...


class QgsProcessingModelGroupBox(QgsProcessingModelComponent):

    @typing.overload
    def __init__(self, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelGroupBox') -> None: ...

    def uuid(self) -> str: ...
    def loadVariant(self, map: dict[str|None, typing.Any], ignoreUuid: bool = ...) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def clone(self) -> 'QgsProcessingModelGroupBox|None': ...


class QgsProcessingModelOutput(QgsProcessingModelComponent):

    @typing.overload
    def __init__(self, name: str|None = ..., description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelOutput') -> None: ...

    def setComment(self, comment: QgsProcessingModelComment) -> None: ...
    def comment(self) -> QgsProcessingModelComment|None: ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def setChildOutputName(self, name: str|None) -> None: ...
    def childOutputName(self) -> str: ...
    def setChildId(self, id: str|None) -> None: ...
    def childId(self) -> str: ...
    def setMandatory(self, mandatory: bool) -> None: ...
    def isMandatory(self) -> bool: ...
    def setDefaultValue(self, value: typing.Any) -> None: ...
    def defaultValue(self) -> typing.Any: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def clone(self) -> 'QgsProcessingModelOutput|None': ...


class QgsProcessingModelParameter(QgsProcessingModelComponent):

    @typing.overload
    def __init__(self, parameterName: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelParameter') -> None: ...

    def setComment(self, comment: QgsProcessingModelComment) -> None: ...
    def comment(self) -> QgsProcessingModelComment|None: ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def setParameterName(self, name: str|None) -> None: ...
    def parameterName(self) -> str: ...
    def clone(self) -> 'QgsProcessingModelParameter|None': ...


class QgsProcessingModelChildAlgorithmResult(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelChildAlgorithmResult') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def setHtmlLog(self, log: str|None) -> None: ...
    def htmlLog(self) -> str: ...
    def setOutputs(self, outputs: dict[str|None, typing.Any]) -> None: ...
    def outputs(self) -> dict[str, typing.Any]: ...
    def setInputs(self, inputs: dict[str|None, typing.Any]) -> None: ...
    def inputs(self) -> dict[str, typing.Any]: ...
    def setExecutionStatus(self, status: Qgis.ProcessingModelChildAlgorithmExecutionStatus) -> None: ...
    def executionStatus(self) -> Qgis.ProcessingModelChildAlgorithmExecutionStatus: ...


class QgsProcessingModelResult(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingModelResult') -> None: ...

    def executedChildIds(self) -> set[str]: ...
    def childResults(self) -> dict[str, QgsProcessingModelChildAlgorithmResult]: ...
    def mergeWith(self, other: 'QgsProcessingModelResult') -> None: ...
    def clear(self) -> None: ...


class QgsProcessing(PyQt6.sip.wrapper):

    class LayerOptionsFlag(enum.IntFlag):
        SkipIndexGeneration = ... # type: QgsProcessing.LayerOptionsFlag

    class PythonOutputType(enum.Enum):
        PythonQgsProcessingAlgorithmSubclass = ... # type: QgsProcessing.PythonOutputType

    TEMPORARY_OUTPUT = ... # type: str|None
    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessing') -> None: ...

    @staticmethod
    def documentationFlagToString(flag: Qgis.ProcessingAlgorithmDocumentationFlag) -> str: ...
    @staticmethod
    def sourceTypeToString(type: Qgis.ProcessingSourceType) -> str: ...


class QgsProcessingFeatureBasedAlgorithm(QgsProcessingAlgorithm):

    def __init__(self) -> None: ...

    def sinkProperties(self, sink: str|None, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', sourceProperties: dict[str|None, QgsProcessingAlgorithm.VectorProperties]) -> QgsProcessingAlgorithm.VectorProperties: ...
    def prepareSource(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext') -> None: ...
    def request(self) -> QgsFeatureRequest: ...
    def processAlgorithm(self, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> dict[str, typing.Any]: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    def initParameters(self, configuration: dict[str|None, typing.Any] = ...) -> None: ...
    def outputCrs(self, inputCrs: QgsCoordinateReferenceSystem) -> QgsCoordinateReferenceSystem: ...
    def outputFields(self, inputFields: QgsFields) -> QgsFields: ...
    def outputWkbType(self, inputWkbType: Qgis.WkbType) -> Qgis.WkbType: ...
    def sinkFlags(self) -> QgsFeatureSink.SinkFlag: ...
    def sourceFlags(self) -> Qgis.ProcessingFeatureSourceFlag: ...
    def outputLayerType(self) -> Qgis.ProcessingSourceType: ...
    def inputLayerTypes(self) -> list[int]: ...
    def outputName(self) -> str: ...
    def initAlgorithm(self, configuration: dict[str|None, typing.Any] = ...) -> None: ...
    def inputParameterDescription(self) -> str: ...
    def inputParameterName(self) -> str: ...
    def supportInPlaceEdit(self, layer: QgsMapLayer|None) -> bool: ...
    def processFeature(self, feature: QgsFeature, context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None') -> list[QgsFeature]: ...
    def flags(self) -> Qgis.ProcessingAlgorithmFlag: ...


class QgsProcessingAlgRunnerTask(QgsTask):

    def __init__(self, algorithm: QgsProcessingAlgorithm|None, parameters: dict[str|None, typing.Any], context: 'QgsProcessingContext', feedback: 'QgsProcessingFeedback|None' = ..., flags: QgsTask.Flag = ...) -> None: ...

    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    executed: typing.ClassVar[QtCore.pyqtSignal]
    def algorithmCanceled(self) -> bool: ...
    def cancel(self) -> None: ...


class QgsProcessingFeedback(QgsFeedback):

    def __init__(self, logFeedback: bool = ...) -> None: ...

    def textLog(self) -> str: ...
    def htmlLog(self) -> str: ...
    def pushFormattedResults(self, algorithm: QgsProcessingAlgorithm|None, context: 'QgsProcessingContext', results: dict[str|None, typing.Any]) -> None: ...
    def pushVersionInfo(self, provider: 'QgsProcessingProvider|None' = ...) -> None: ...
    def pushConsoleInfo(self, info: str|None) -> None: ...
    def pushDebugInfo(self, info: str|None) -> None: ...
    def pushCommandInfo(self, info: str|None) -> None: ...
    def pushFormattedMessage(self, html: str|None, text: str|None) -> None: ...
    def pushInfo(self, info: str|None) -> None: ...
    def pushWarning(self, warning: str|None) -> None: ...
    def reportError(self, error: str|None, fatalError: bool = ...) -> None: ...
    def setProgressText(self, text: str|None) -> None: ...


class QgsProcessingMultiStepFeedback(QgsProcessingFeedback):

    def __init__(self, steps: int, feedback: QgsProcessingFeedback|None) -> None: ...

    def textLog(self) -> str: ...
    def htmlLog(self) -> str: ...
    def pushFormattedMessage(self, html: str|None, text: str|None) -> None: ...
    def pushConsoleInfo(self, info: str|None) -> None: ...
    def pushDebugInfo(self, info: str|None) -> None: ...
    def pushCommandInfo(self, info: str|None) -> None: ...
    def pushInfo(self, info: str|None) -> None: ...
    def pushWarning(self, warning: str|None) -> None: ...
    def reportError(self, error: str|None, fatalError: bool = ...) -> None: ...
    def setProgressText(self, text: str|None) -> None: ...
    def setStepWeights(self, weights: collections.abc.Iterable[float]) -> None: ...
    def setCurrentStep(self, step: int) -> None: ...


class QgsProcessingBatchFeedback(QgsProcessingMultiStepFeedback):

    def __init__(self, tasks: int, feedback: QgsProcessingFeedback|None) -> None: ...

    def popErrors(self) -> list[str]: ...
    def reportError(self, error: str|None, fatalError: bool = ...) -> None: ...


class QgsProcessingContext(PyQt6.sip.wrapper):

    class ProcessArgumentFlag(enum.IntFlag):
        IncludeProjectPath = ... # type: QgsProcessingContext.ProcessArgumentFlag

    class Flag(enum.IntEnum):
        Unused = ... # type: QgsProcessingContext.Flag

    class LayerDetails(PyQt6.sip.wrapper):

        forceName = ... # type: bool
        groupName = ... # type: str|None
        layerSortKey = ... # type: int
        layerTypeHint = ... # type: 'QgsProcessingUtils.LayerHint'
        name = ... # type: str|None
        outputName = ... # type: str|None
        project = ... # type: 'QgsProject'

        @typing.overload
        def __init__(self, name: str|None, project: 'QgsProject|None', outputName: str|None = ..., layerTypeHint: 'QgsProcessingUtils.LayerHint' = ...) -> None: ...
        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProcessingContext.LayerDetails') -> None: ...

        def setOutputLayerName(self, layer: QgsMapLayer|None) -> None: ...
        def setPostProcessor(self, processor: 'QgsProcessingLayerPostProcessorInterface|None') -> None: ...
        def postProcessor(self) -> 'QgsProcessingLayerPostProcessorInterface|None': ...

    def __init__(self) -> None: ...

    def clearModelResult(self) -> None: ...
    def modelResult(self) -> QgsProcessingModelResult: ...
    def asQgisProcessArguments(self, flags: 'QgsProcessingContext.ProcessArgumentFlag' = ...) -> list[str]: ...
    def exportToMap(self) -> dict[str, typing.Any]: ...
    def setMaximumThreads(self, threads: int) -> None: ...
    def maximumThreads(self) -> int: ...
    def setTemporaryFolder(self, folder: str|None) -> None: ...
    def temporaryFolder(self) -> str: ...
    def setLogLevel(self, level: Qgis.ProcessingLogLevel) -> None: ...
    def logLevel(self) -> Qgis.ProcessingLogLevel: ...
    def setPreferredRasterFormat(self, format: str|None) -> None: ...
    def preferredRasterFormat(self) -> str: ...
    def setPreferredVectorFormat(self, format: str|None) -> None: ...
    def preferredVectorFormat(self) -> str: ...
    def takeResultLayer(self, id: str|None) -> QgsMapLayer|None: ...
    def getMapLayer(self, identifier: str|None) -> QgsMapLayer|None: ...
    def takeResultsFrom(self, context: 'QgsProcessingContext') -> None: ...
    def pushToThread(self, thread: QtCore.QThread|None) -> None: ...
    def thread(self) -> QtCore.QThread|None: ...
    def setFeedback(self, feedback: QgsProcessingFeedback|None) -> None: ...
    def feedback(self) -> QgsProcessingFeedback|None: ...
    def setDefaultEncoding(self, encoding: str|None) -> None: ...
    def defaultEncoding(self) -> str: ...
    def setTransformErrorCallback(self, a0: typing.Callable[..., None]) -> None: ...
    def setInvalidGeometryCallback(self, a0: typing.Callable[..., None]) -> None: ...
    def setInvalidGeometryCheck(self, check: Qgis.InvalidGeometryCheck) -> None: ...
    def invalidGeometryCheck(self) -> Qgis.InvalidGeometryCheck: ...
    def layerToLoadOnCompletionDetails(self, layer: str|None) -> 'QgsProcessingContext.LayerDetails': ...
    def addLayerToLoadOnCompletion(self, layer: str|None, details: 'QgsProcessingContext.LayerDetails') -> None: ...
    def setLayersToLoadOnCompletion(self, layers: dict[str|None, 'QgsProcessingContext.LayerDetails']) -> None: ...
    def willLoadLayerOnCompletion(self, layer: str|None) -> bool: ...
    def layersToLoadOnCompletion(self) -> dict[str, 'QgsProcessingContext.LayerDetails']: ...
    def temporaryLayerStore(self) -> QgsMapLayerStore|None: ...
    def setCurrentTimeRange(self, currentTimeRange: QgsDateTimeRange) -> None: ...
    def currentTimeRange(self) -> QgsDateTimeRange: ...
    def setAreaUnit(self, areaUnit: Qgis.AreaUnit) -> None: ...
    def areaUnit(self) -> Qgis.AreaUnit: ...
    def setDistanceUnit(self, unit: Qgis.DistanceUnit) -> None: ...
    def distanceUnit(self) -> Qgis.DistanceUnit: ...
    def setEllipsoid(self, ellipsoid: str|None) -> None: ...
    def ellipsoid(self) -> str: ...
    def setTransformContext(self, context: QgsCoordinateTransformContext) -> None: ...
    def transformContext(self) -> QgsCoordinateTransformContext: ...
    def setExpressionContext(self, context: QgsExpressionContext) -> None: ...
    def expressionContext(self) -> QgsExpressionContext: ...
    def setProject(self, project: 'QgsProject|None') -> None: ...
    def project(self) -> 'QgsProject|None': ...
    def setFlags(self, flags: 'QgsProcessingContext.Flag') -> None: ...
    def flags(self) -> 'QgsProcessingContext.Flag': ...
    def copyThreadSafeSettings(self, other: 'QgsProcessingContext') -> None: ...


class QgsProcessingLayerPostProcessorInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingLayerPostProcessorInterface') -> None: ...

    def postProcessLayer(self, layer: QgsMapLayer|None, context: QgsProcessingContext, feedback: QgsProcessingFeedback|None) -> None: ...


class QgsProcessingOutputDefinition(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputDefinition') -> None: ...

    def valueAsFormattedString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def autoCreated(self) -> bool: ...
    def setAutoCreated(self, autoCreated: bool) -> None: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def type(self) -> str: ...
    def modelColor(self) -> QtGui.QColor: ...


class QgsProcessingOutputMapLayer(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputMapLayer') -> None: ...

    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def modelColor(self) -> QtGui.QColor: ...


class QgsProcessingOutputVectorLayer(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., type: Qgis.ProcessingSourceType = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputVectorLayer') -> None: ...

    def setDataType(self, type: Qgis.ProcessingSourceType) -> None: ...
    def dataType(self) -> Qgis.ProcessingSourceType: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def modelColor(self) -> QtGui.QColor: ...


class QgsProcessingOutputRasterLayer(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputRasterLayer') -> None: ...

    def type(self) -> str: ...
    def modelColor(self) -> QtGui.QColor: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputPointCloudLayer(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputPointCloudLayer') -> None: ...

    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputMultipleLayers(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputMultipleLayers') -> None: ...

    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def modelColor(self) -> QtGui.QColor: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputHtml(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputHtml') -> None: ...

    def valueAsFormattedString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def modelColor(self) -> QtGui.QColor: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputVariant(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputVariant') -> None: ...

    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputNumber(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputNumber') -> None: ...

    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def modelColor(self) -> QtGui.QColor: ...


class QgsProcessingOutputString(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputString') -> None: ...

    def type(self) -> str: ...
    def modelColor(self) -> QtGui.QColor: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputBoolean(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputBoolean') -> None: ...

    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def modelColor(self) -> QtGui.QColor: ...


class QgsProcessingOutputFolder(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputFolder') -> None: ...

    def valueAsFormattedString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def modelColor(self) -> QtGui.QColor: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputFile(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputFile') -> None: ...

    def valueAsFormattedString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def modelColor(self) -> QtGui.QColor: ...
    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputConditionalBranch(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputConditionalBranch') -> None: ...

    def type(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingOutputVectorTileLayer(QgsProcessingOutputDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputVectorTileLayer') -> None: ...

    def type(self) -> str: ...
    def modelColor(self) -> QtGui.QColor: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterDefinition(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., help: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDefinition') -> None: ...

    def defaultGuiValueFromSetting(self) -> typing.Any: ...
    def setAdditionalExpressionContextVariables(self, variables: collections.abc.Iterable[str|None]) -> None: ...
    def additionalExpressionContextVariables(self) -> list[str]: ...
    def setDynamicLayerParameterName(self, name: str|None) -> None: ...
    def dynamicLayerParameterName(self) -> str: ...
    def setDynamicPropertyDefinition(self, definition: QgsPropertyDefinition) -> None: ...
    def dynamicPropertyDefinition(self) -> QgsPropertyDefinition: ...
    def setIsDynamic(self, dynamic: bool) -> None: ...
    def isDynamic(self) -> bool: ...
    def toolTip(self) -> str: ...
    def provider(self) -> 'QgsProcessingProvider|None': ...
    def algorithm(self) -> QgsProcessingAlgorithm|None: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def setMetadata(self, metadata: dict[str|None, typing.Any]) -> None: ...
    def metadata(self) -> dict[str, typing.Any]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonComment(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def valueAsStringList(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[list[str], bool]: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def setFlags(self, flags: Qgis.ProcessingParameterFlag) -> None: ...
    def flags(self) -> Qgis.ProcessingParameterFlag: ...
    def defaultValueForGui(self) -> typing.Any: ...
    def setGuiDefaultValueOverride(self, value: typing.Any) -> None: ...
    def guiDefaultValueOverride(self) -> typing.Any: ...
    def setDefaultValue(self, value: typing.Any) -> None: ...
    def defaultValue(self) -> typing.Any: ...
    def setHelp(self, help: str|None) -> None: ...
    def help(self) -> str: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def isDestination(self) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsProcessingParameterDefinition|None': ...
    def userFriendlyString(self, value: typing.Any) -> str: ...
    def modelColor(self) -> QtGui.QColor: ...


class QgsProcessingParameterAggregate(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., parentLayerParameterName: str|None = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterAggregate') -> None: ...

    def setParentLayerParameterName(self, name: str|None) -> None: ...
    def parentLayerParameterName(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterDxfLayers(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDxfLayers') -> None: ...

    @staticmethod
    def layerAsVariantMap(layer: QgsDxfExport.DxfLayer) -> dict[str, typing.Any]: ...
    @staticmethod
    def variantMapAsLayer(layerVariantMap: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsDxfExport.DxfLayer: ...
    @staticmethod
    def parameterAsLayers(layersVariant: typing.Any, context: QgsProcessingContext) -> list[QgsDxfExport.DxfLayer]: ...
    @staticmethod
    def typeName() -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterFieldMapping(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., parentLayerParameterName: str|None = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterFieldMapping') -> None: ...

    def setParentLayerParameterName(self, name: str|None) -> None: ...
    def parentLayerParameterName(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterMeshDatasetGroups(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., meshLayerParameterName: str|None = ..., supportedDataType: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMeshDatasetGroups') -> None: ...

    @staticmethod
    def valueAsDatasetGroup(value: typing.Any) -> list[int]: ...
    def isDataTypeSupported(self, dataType: QgsMeshDatasetGroupMetadata.DataType) -> bool: ...
    def meshLayerParameterName(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterMeshDatasetTime(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., meshLayerParameterName: str|None = ..., datasetGroupParameterName: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMeshDatasetTime') -> None: ...

    @staticmethod
    def timeValueAsDefinedDateTime(value: typing.Any) -> QtCore.QDateTime: ...
    @staticmethod
    def timeValueAsDatasetIndex(value: typing.Any) -> QgsMeshDatasetIndex: ...
    @staticmethod
    def valueAsTimeType(value: typing.Any) -> str: ...
    def datasetGroupParameterName(self) -> str: ...
    def meshLayerParameterName(self) -> str: ...
    @staticmethod
    def typeName() -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingFeatureSourceDefinition(PyQt6.sip.wrapper):

    featureLimit = ... # type: int
    filterExpression = ... # type: str|None
    flags = ... # type: Qgis.ProcessingFeatureSourceDefinitionFlag
    geometryCheck = ... # type: Qgis.InvalidGeometryCheck
    selectedFeaturesOnly = ... # type: bool
    source = ... # type: QgsProperty

    @typing.overload
    def __init__(self, source: str|None = ..., selectedFeaturesOnly: bool = ..., featureLimit: int = ..., flags: Qgis.ProcessingFeatureSourceDefinitionFlag = ..., geometryCheck: Qgis.InvalidGeometryCheck = ..., filterExpression: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QgsProperty, selectedFeaturesOnly: bool = ..., featureLimit: int = ..., flags: Qgis.ProcessingFeatureSourceDefinitionFlag = ..., geometryCheck: Qgis.InvalidGeometryCheck = ..., filterExpression: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingFeatureSourceDefinition') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...


class QgsProcessingRasterLayerDefinition(PyQt6.sip.wrapper):

    dpi = ... # type: int
    referenceScale = ... # type: float
    source = ... # type: QgsProperty

    @typing.overload
    def __init__(self, source: str|None = ..., referenceScale: float = ..., dpi: int = ...) -> None: ...
    @typing.overload
    def __init__(self, source: QgsProperty, referenceScale: float = ..., dpi: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingRasterLayerDefinition') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...


class QgsProcessingOutputLayerDefinition(PyQt6.sip.wrapper):

    createOptions = ... # type: dict[str|None, typing.Any]
    destinationName = ... # type: str|None
    destinationProject = ... # type: 'QgsProject'
    sink = ... # type: QgsProperty

    @typing.overload
    def __init__(self, sink: str|None = ..., destinationProject: 'QgsProject|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, sink: QgsProperty, destinationProject: 'QgsProject|None' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingOutputLayerDefinition') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def loadVariant(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariant(self) -> typing.Any: ...
    def setFormat(self, format: str|None) -> None: ...
    def format(self) -> str: ...
    def setRemappingDefinition(self, definition: QgsRemappingSinkDefinition) -> None: ...
    def remappingDefinition(self) -> QgsRemappingSinkDefinition: ...
    def useRemapping(self) -> bool: ...


class QgsProcessingParameters(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameters') -> None: ...

    @staticmethod
    def parameterFromScriptCode(code: str|None) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def descriptionFromName(name: str|None) -> str: ...
    @staticmethod
    def parameterFromVariantMap(map: dict[str|None, typing.Any]) -> QgsProcessingParameterDefinition|None: ...
    @typing.overload
    @staticmethod
    def parameterAsAnnotationLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsAnnotationLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsAnnotationLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsAnnotationLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsPointCloudLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, flags: QgsProcessing.LayerOptionsFlag = ...) -> QgsPointCloudLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsPointCloudLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, flags: QgsProcessing.LayerOptionsFlag = ...) -> QgsPointCloudLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsDatabaseTableName(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsDatabaseTableName(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsSchema(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsSchema(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsConnectionName(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsConnectionName(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsColor(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QtGui.QColor: ...
    @typing.overload
    @staticmethod
    def parameterAsColor(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QtGui.QColor: ...
    @typing.overload
    @staticmethod
    def parameterAsLayoutItem(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, layout: QgsPrintLayout|None) -> QgsLayoutItem|None: ...
    @typing.overload
    @staticmethod
    def parameterAsLayoutItem(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, layout: QgsPrintLayout|None) -> QgsLayoutItem|None: ...
    @typing.overload
    @staticmethod
    def parameterAsLayout(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsPrintLayout|None: ...
    @typing.overload
    @staticmethod
    def parameterAsLayout(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsPrintLayout|None: ...
    @typing.overload
    @staticmethod
    def parameterAsStrings(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    def parameterAsStrings(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def parameterAsFields(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def parameterAsFields(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    def parameterAsRange(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[float]: ...
    @typing.overload
    @staticmethod
    def parameterAsRange(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[float]: ...
    @typing.overload
    @staticmethod
    def parameterAsFileList(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    def parameterAsFileList(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    def parameterAsLayerList(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, flags: QgsProcessing.LayerOptionsFlag = ...) -> list[QgsMapLayer]: ...
    @typing.overload
    @staticmethod
    def parameterAsLayerList(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, flags: QgsProcessing.LayerOptionsFlag = ...) -> list[QgsMapLayer]: ...
    @typing.overload
    @staticmethod
    def parameterAsMatrix(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[typing.Any]: ...
    @typing.overload
    @staticmethod
    def parameterAsMatrix(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[typing.Any]: ...
    @typing.overload
    @staticmethod
    def parameterAsFile(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsFile(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsGeometryCrs(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsGeometryCrs(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsGeometry(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsGeometry: ...
    @typing.overload
    @staticmethod
    def parameterAsGeometry(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsGeometry: ...
    @typing.overload
    @staticmethod
    def parameterAsPointCrs(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsPointCrs(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsPoint(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsPointXY: ...
    @typing.overload
    @staticmethod
    def parameterAsPoint(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsPointXY: ...
    @typing.overload
    @staticmethod
    def parameterAsExtentCrs(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsExtentCrs(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @staticmethod
    def parameterAsExtentGeometry(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsGeometry: ...
    @typing.overload
    @staticmethod
    def parameterAsExtent(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsRectangle: ...
    @typing.overload
    @staticmethod
    def parameterAsExtent(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, crs: QgsCoordinateReferenceSystem = ...) -> QgsRectangle: ...
    @typing.overload
    @staticmethod
    def parameterAsCrs(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsCrs(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @staticmethod
    def parameterAsMeshLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsMeshLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsMeshLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsMeshLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsVectorLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsVectorLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsVectorLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QgsVectorLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsFileOutput(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsFileOutput(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @staticmethod
    def parameterAsOutputFormat(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsOutputLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsOutputLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, testOnly: bool = ...) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsRasterLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> 'QgsRasterLayer|None': ...
    @typing.overload
    @staticmethod
    def parameterAsRasterLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> 'QgsRasterLayer|None': ...
    @typing.overload
    @staticmethod
    def parameterAsLayer(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, layerHint: 'QgsProcessingUtils.LayerHint' = ..., flags: QgsProcessing.LayerOptionsFlag = ...) -> QgsMapLayer|None: ...
    @typing.overload
    @staticmethod
    def parameterAsLayer(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext, layerHint: 'QgsProcessingUtils.LayerHint' = ..., flags: QgsProcessing.LayerOptionsFlag = ...) -> QgsMapLayer|None: ...
    @staticmethod
    def parameterAsCompatibleSourceLayerPathAndLayerName(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, compatibleFormats: collections.abc.Iterable[str|None], preferredFormat: str|None = ..., feedback: QgsProcessingFeedback|None = ...) -> typing.Tuple[str, str]: ...
    @staticmethod
    def parameterAsCompatibleSourceLayerPath(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext, compatibleFormats: collections.abc.Iterable[str|None], preferredFormat: str|None = ..., feedback: QgsProcessingFeedback|None = ...) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsSource(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> 'QgsProcessingFeatureSource|None': ...
    @typing.overload
    @staticmethod
    def parameterAsSource(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> 'QgsProcessingFeatureSource|None': ...
    @typing.overload
    @staticmethod
    def parameterAsSink(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], fields: QgsFields, geometryType: Qgis.WkbType, crs: QgsCoordinateReferenceSystem, context: QgsProcessingContext, sinkFlags: QgsFeatureSink.SinkFlag = ..., createOptions: dict[str|None, typing.Any] = ..., datasourceOptions: collections.abc.Iterable[str|None] = ..., layerOptions: collections.abc.Iterable[str|None] = ...) -> typing.Tuple[QgsFeatureSink|None, str]: ...
    @typing.overload
    @staticmethod
    def parameterAsSink(definition: QgsProcessingParameterDefinition|None, value: typing.Any, fields: QgsFields, geometryType: Qgis.WkbType, crs: QgsCoordinateReferenceSystem, context: QgsProcessingContext, sinkFlags: QgsFeatureSink.SinkFlag = ..., createOptions: dict[str|None, typing.Any] = ..., datasourceOptions: collections.abc.Iterable[str|None] = ..., layerOptions: collections.abc.Iterable[str|None] = ...) -> typing.Tuple[QgsFeatureSink|None, str]: ...
    @typing.overload
    @staticmethod
    def parameterAsBoolean(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> bool: ...
    @typing.overload
    @staticmethod
    def parameterAsBoolean(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> bool: ...
    @typing.overload
    @staticmethod
    def parameterAsBool(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> bool: ...
    @typing.overload
    @staticmethod
    def parameterAsBool(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> bool: ...
    @typing.overload
    @staticmethod
    def parameterAsEnumStrings(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    def parameterAsEnumStrings(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[str]: ...
    @typing.overload
    @staticmethod
    def parameterAsEnumString(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsEnumString(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsEnums(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[int]: ...
    @typing.overload
    @staticmethod
    def parameterAsEnums(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[int]: ...
    @typing.overload
    @staticmethod
    def parameterAsEnum(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> int: ...
    @typing.overload
    @staticmethod
    def parameterAsEnum(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> int: ...
    @typing.overload
    @staticmethod
    def parameterAsTime(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QtCore.QTime: ...
    @typing.overload
    @staticmethod
    def parameterAsTime(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QtCore.QTime: ...
    @typing.overload
    @staticmethod
    def parameterAsDate(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QtCore.QDate: ...
    @typing.overload
    @staticmethod
    def parameterAsDate(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QtCore.QDate: ...
    @typing.overload
    @staticmethod
    def parameterAsDateTime(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> QtCore.QDateTime: ...
    @typing.overload
    @staticmethod
    def parameterAsDateTime(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> QtCore.QDateTime: ...
    @typing.overload
    @staticmethod
    def parameterAsInts(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> list[int]: ...
    @typing.overload
    @staticmethod
    def parameterAsInts(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> list[int]: ...
    @typing.overload
    @staticmethod
    def parameterAsInt(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> int: ...
    @typing.overload
    @staticmethod
    def parameterAsInt(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> int: ...
    @typing.overload
    @staticmethod
    def parameterAsDouble(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> float: ...
    @typing.overload
    @staticmethod
    def parameterAsDouble(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> float: ...
    @typing.overload
    @staticmethod
    def parameterAsExpression(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsExpression(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsString(definition: QgsProcessingParameterDefinition|None, parameters: dict[str|None, typing.Any], context: QgsProcessingContext) -> str: ...
    @typing.overload
    @staticmethod
    def parameterAsString(definition: QgsProcessingParameterDefinition|None, value: typing.Any, context: QgsProcessingContext) -> str: ...
    @staticmethod
    def isDynamic(parameters: dict[str|None, typing.Any], name: str|None) -> bool: ...


class QgsProcessingParameterBoolean(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterBoolean') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterBoolean|None': ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterCrs(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterCrs') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterCrs|None': ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...
    def userFriendlyString(self, value: typing.Any) -> str: ...


class QgsProcessingParameterExtent(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterExtent') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterExtent|None': ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterPoint(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterPoint') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterPoint|None': ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterGeometry(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., geometryTypes: collections.abc.Iterable[int] = ..., allowMultipart: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterGeometry') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterGeometry|None': ...
    def userFriendlyString(self, value: typing.Any) -> str: ...
    def setAllowMultipart(self, allowMultipart: bool) -> None: ...
    def allowMultipart(self) -> bool: ...
    def setGeometryTypes(self, geometryTypes: collections.abc.Iterable[int]) -> None: ...
    def geometryTypes(self) -> list[int]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterFile(QgsProcessingParameterDefinition, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., behavior: Qgis.ProcessingFileParameterBehavior = ..., extension: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., fileFilter: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterFile') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None, behavior: Qgis.ProcessingFileParameterBehavior = ...) -> 'QgsProcessingParameterFile|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setFileFilter(self, filter: str|None) -> None: ...
    def fileFilter(self) -> str: ...
    def setExtension(self, extension: str|None) -> None: ...
    def extension(self) -> str: ...
    def setBehavior(self, behavior: Qgis.ProcessingFileParameterBehavior) -> None: ...
    def behavior(self) -> Qgis.ProcessingFileParameterBehavior: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterMatrix(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., numberRows: int = ..., hasFixedNumberRows: bool = ..., headers: collections.abc.Iterable[str|None] = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMatrix') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterMatrix|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setHasFixedNumberRows(self, hasFixedNumberRows: bool) -> None: ...
    def hasFixedNumberRows(self) -> bool: ...
    def setNumberRows(self, rows: int) -> None: ...
    def numberRows(self) -> int: ...
    def setHeaders(self, headers: collections.abc.Iterable[str|None]) -> None: ...
    def headers(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterMultipleLayers(QgsProcessingParameterDefinition, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., layerType: Qgis.ProcessingSourceType = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMultipleLayers') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterMultipleLayers|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setMinimumNumberInputs(self, minimum: int) -> None: ...
    def minimumNumberInputs(self) -> int: ...
    def setLayerType(self, type: Qgis.ProcessingSourceType) -> None: ...
    def layerType(self) -> Qgis.ProcessingSourceType: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterNumber(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., type: Qgis.ProcessingNumberParameterType = ..., defaultValue: typing.Any = ..., optional: bool = ..., minValue: float = ..., maxValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterNumber') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterNumber|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDataType(self, type: Qgis.ProcessingNumberParameterType) -> None: ...
    def dataType(self) -> Qgis.ProcessingNumberParameterType: ...
    def setMaximum(self, maximum: float) -> None: ...
    def maximum(self) -> float: ...
    def setMinimum(self, minimum: float) -> None: ...
    def minimum(self) -> float: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def toolTip(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterDistance(QgsProcessingParameterNumber):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentParameterName: str|None = ..., optional: bool = ..., minValue: float = ..., maxValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDistance') -> None: ...

    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDefaultUnit(self, unit: Qgis.DistanceUnit) -> None: ...
    def defaultUnit(self) -> Qgis.DistanceUnit: ...
    def setParentParameterName(self, parentParameterName: str|None) -> None: ...
    def parentParameterName(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsProcessingParameterDistance|None': ...
    def userFriendlyString(self, value: typing.Any) -> str: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterArea(QgsProcessingParameterNumber):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentParameterName: str|None = ..., optional: bool = ..., minValue: float = ..., maxValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterArea') -> None: ...

    def userFriendlyString(self, value: typing.Any) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDefaultUnit(self, unit: Qgis.AreaUnit) -> None: ...
    def defaultUnit(self) -> Qgis.AreaUnit: ...
    def setParentParameterName(self, parentParameterName: str|None) -> None: ...
    def parentParameterName(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsProcessingParameterArea|None': ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterVolume(QgsProcessingParameterNumber):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentParameterName: str|None = ..., optional: bool = ..., minValue: float = ..., maxValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterVolume') -> None: ...

    def userFriendlyString(self, value: typing.Any) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDefaultUnit(self, unit: Qgis.VolumeUnit) -> None: ...
    def defaultUnit(self) -> Qgis.VolumeUnit: ...
    def setParentParameterName(self, parentParameterName: str|None) -> None: ...
    def parentParameterName(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsProcessingParameterVolume|None': ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterDuration(QgsProcessingParameterNumber):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., minValue: float = ..., maxValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDuration') -> None: ...

    def userFriendlyString(self, value: typing.Any) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDefaultUnit(self, unit: Qgis.TemporalUnit) -> None: ...
    def defaultUnit(self) -> Qgis.TemporalUnit: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsProcessingParameterDuration|None': ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterScale(QgsProcessingParameterNumber):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterScale') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterScale|None': ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> 'QgsProcessingParameterScale|None': ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterRange(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., type: Qgis.ProcessingNumberParameterType = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterRange') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterRange|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDataType(self, dataType: Qgis.ProcessingNumberParameterType) -> None: ...
    def dataType(self) -> Qgis.ProcessingNumberParameterType: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterRasterLayer(QgsProcessingParameterDefinition, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterRasterLayer') -> None: ...

    def parameterCapabilities(self) -> Qgis.RasterProcessingParameterCapability: ...
    def setParameterCapabilities(self, capabilities: Qgis.RasterProcessingParameterCapability) -> None: ...
    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterRasterLayer|None': ...
    def createFileFilter(self) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterEnum(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., options: collections.abc.Iterable[str|None] = ..., allowMultiple: bool = ..., defaultValue: typing.Any = ..., optional: bool = ..., usesStaticStrings: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterEnum') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterEnum|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setUsesStaticStrings(self, usesStaticStrings: bool) -> None: ...
    def usesStaticStrings(self) -> bool: ...
    def setAllowMultiple(self, allowMultiple: bool) -> None: ...
    def allowMultiple(self) -> bool: ...
    def setOptions(self, options: collections.abc.Iterable[str|None]) -> None: ...
    def options(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonComment(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...
    def userFriendlyString(self, value: typing.Any) -> str: ...


class QgsProcessingParameterString(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., multiLine: bool = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterString') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterString|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setMultiLine(self, multiLine: bool) -> None: ...
    def multiLine(self) -> bool: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterAuthConfig(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterAuthConfig') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterAuthConfig|None': ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterExpression(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentLayerParameterName: str|None = ..., optional: bool = ..., type: Qgis.ExpressionType = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterExpression') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterExpression|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setExpressionType(self, type: Qgis.ExpressionType) -> None: ...
    def expressionType(self) -> Qgis.ExpressionType: ...
    def setParentLayerParameterName(self, parentLayerParameterName: str|None) -> None: ...
    def parentLayerParameterName(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterLimitedDataTypes(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, types: collections.abc.Iterable[int] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterLimitedDataTypes') -> None: ...

    def setDataTypes(self, types: collections.abc.Iterable[int]) -> None: ...
    def dataTypes(self) -> list[int]: ...


class QgsProcessingParameterVectorLayer(QgsProcessingParameterDefinition, QgsProcessingParameterLimitedDataTypes, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., types: collections.abc.Iterable[int] = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterVectorLayer') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterVectorLayer|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterMeshLayer(QgsProcessingParameterDefinition, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMeshLayer') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterMeshLayer|None': ...
    def createFileFilter(self) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterMapLayer(QgsProcessingParameterDefinition, QgsProcessingParameterLimitedDataTypes, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., types: collections.abc.Iterable[int] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMapLayer') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterMapLayer|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterField(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentLayerParameterName: str|None = ..., type: Qgis.ProcessingFieldParameterDataType = ..., allowMultiple: bool = ..., optional: bool = ..., defaultToAllFields: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterField') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterField|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDefaultToAllFields(self, enabled: bool) -> None: ...
    def defaultToAllFields(self) -> bool: ...
    def setAllowMultiple(self, allowMultiple: bool) -> None: ...
    def allowMultiple(self) -> bool: ...
    def setDataType(self, type: Qgis.ProcessingFieldParameterDataType) -> None: ...
    def dataType(self) -> Qgis.ProcessingFieldParameterDataType: ...
    def setParentLayerParameterName(self, parentLayerParameterName: str|None) -> None: ...
    def parentLayerParameterName(self) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterFeatureSource(QgsProcessingParameterDefinition, QgsProcessingParameterLimitedDataTypes, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., types: collections.abc.Iterable[int] = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterFeatureSource') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterFeatureSource|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingDestinationParameter(QgsProcessingParameterDefinition, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingDestinationParameter') -> None: ...

    def originalProvider(self) -> 'QgsProcessingProvider|None': ...
    def setCreateByDefault(self, createByDefault: bool) -> None: ...
    def createByDefault(self) -> bool: ...
    def isSupportedOutputValue(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[bool, str]: ...
    def generateTemporaryDestination(self, context: QgsProcessingContext|None = ...) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def setSupportsNonFileBasedOutput(self, supportsNonFileBasedOutput: bool) -> None: ...
    def supportsNonFileBasedOutput(self) -> bool: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def isDestination(self) -> bool: ...


class QgsProcessingParameterFeatureSink(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., type: Qgis.ProcessingSourceType = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ..., supportsAppend: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterFeatureSink') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterFeatureSink|None': ...
    def generateTemporaryDestination(self, context: QgsProcessingContext|None = ...) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setSupportsAppend(self, supportsAppend: bool) -> None: ...
    def supportsAppend(self) -> bool: ...
    def setDataType(self, type: Qgis.ProcessingSourceType) -> None: ...
    def hasGeometry(self) -> bool: ...
    def dataType(self) -> Qgis.ProcessingSourceType: ...
    def supportedOutputVectorLayerExtensions(self) -> list[str]: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterVectorDestination(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., type: Qgis.ProcessingSourceType = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterVectorDestination') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterVectorDestination|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDataType(self, type: Qgis.ProcessingSourceType) -> None: ...
    def hasGeometry(self) -> bool: ...
    def dataType(self) -> Qgis.ProcessingSourceType: ...
    def supportedOutputVectorLayerExtensions(self) -> list[str]: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterRasterDestination(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterRasterDestination') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterRasterDestination|None': ...
    def supportedOutputRasterLayerFormatAndExtensions(self) -> list[tuple[str, str]]: ...
    @deprecated("""""")
    def supportedOutputRasterLayerExtensions(self) -> list[str]: ...
    def createFileFilter(self) -> str: ...
    def defaultFileFormat(self) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterFileDestination(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., fileFilter: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterFileDestination') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterFileDestination|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setFileFilter(self, filter: str|None) -> None: ...
    def fileFilter(self) -> str: ...
    def createFileFilter(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterFolderDestination(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterFolderDestination') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterFolderDestination|None': ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterBand(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentLayerParameterName: str|None = ..., optional: bool = ..., allowMultiple: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterBand') -> None: ...

    def setAllowMultiple(self, allowMultiple: bool) -> None: ...
    def allowMultiple(self) -> bool: ...
    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterBand|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setParentLayerParameterName(self, parentLayerParameterName: str|None) -> None: ...
    def parentLayerParameterName(self) -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterLayout(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterLayout') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterLayout|None': ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterLayoutItem(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentLayoutParameterName: str|None = ..., itemType: int = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterLayoutItem') -> None: ...

    def setItemType(self, type: int) -> None: ...
    def itemType(self) -> int: ...
    def setParentLayoutParameterName(self, name: str|None) -> None: ...
    def parentLayoutParameterName(self) -> str: ...
    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterLayoutItem|None': ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterColor(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., opacityEnabled: bool = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterColor') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterColor|None': ...
    def setOpacityEnabled(self, enabled: bool) -> None: ...
    def opacityEnabled(self) -> bool: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterCoordinateOperation(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., sourceCrsParameterName: str|None = ..., destinationCrsParameterName: str|None = ..., staticSourceCrs: typing.Any = ..., staticDestinationCrs: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterCoordinateOperation') -> None: ...

    def setDestinationCrs(self, crs: typing.Any) -> None: ...
    def destinationCrs(self) -> typing.Any: ...
    def setSourceCrs(self, crs: typing.Any) -> None: ...
    def sourceCrs(self) -> typing.Any: ...
    def setDestinationCrsParameterName(self, name: str|None) -> None: ...
    def destinationCrsParameterName(self) -> str: ...
    def setSourceCrsParameterName(self, name: str|None) -> None: ...
    def sourceCrsParameterName(self) -> str: ...
    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterCoordinateOperation|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterMapTheme(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterMapTheme') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterMapTheme|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterDateTime(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., type: Qgis.ProcessingDateTimeParameterDataType = ..., defaultValue: typing.Any = ..., optional: bool = ..., minValue: QtCore.QDateTime|datetime.datetime = ..., maxValue: QtCore.QDateTime|datetime.datetime = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDateTime') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterDateTime|None': ...
    def userFriendlyString(self, value: typing.Any) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDataType(self, type: Qgis.ProcessingDateTimeParameterDataType) -> None: ...
    def dataType(self) -> Qgis.ProcessingDateTimeParameterDataType: ...
    def setMaximum(self, maximum: QtCore.QDateTime|datetime.datetime) -> None: ...
    def maximum(self) -> QtCore.QDateTime: ...
    def setMinimum(self, minimum: QtCore.QDateTime|datetime.datetime) -> None: ...
    def minimum(self) -> QtCore.QDateTime: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def toolTip(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterProviderConnection(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, provider: str|None, defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterProviderConnection') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterProviderConnection|None': ...
    def setProviderId(self, provider: str|None) -> None: ...
    def providerId(self) -> str: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterDatabaseSchema(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, connectionParameterName: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDatabaseSchema') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterDatabaseSchema|None': ...
    def setParentConnectionParameterName(self, name: str|None) -> None: ...
    def parentConnectionParameterName(self) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterDatabaseTable(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, connectionParameterName: str|None = ..., schemaParameterName: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., allowNewTableNames: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterDatabaseTable') -> None: ...

    def setAllowNewTableNames(self, allowed: bool) -> None: ...
    def allowNewTableNames(self) -> bool: ...
    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterDatabaseTable|None': ...
    def setParentSchemaParameterName(self, name: str|None) -> None: ...
    def parentSchemaParameterName(self) -> str: ...
    def setParentConnectionParameterName(self, name: str|None) -> None: ...
    def parentConnectionParameterName(self) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterPointCloudLayer(QgsProcessingParameterDefinition, QgsFileFilterGenerator):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterPointCloudLayer') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterPointCloudLayer|None': ...
    def createFileFilter(self) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterAnnotationLayer(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterAnnotationLayer') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterAnnotationLayer|None': ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterPointCloudDestination(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterPointCloudDestination') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterPointCloudDestination|None': ...
    def supportedOutputPointCloudLayerExtensions(self) -> list[str]: ...
    def createFileFilter(self) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterPointCloudAttribute(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., parentLayerParameterName: str|None = ..., allowMultiple: bool = ..., optional: bool = ..., defaultToAllAttributes: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterPointCloudAttribute') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterPointCloudAttribute|None': ...
    def fromVariantMap(self, map: dict[str|None, typing.Any]) -> bool: ...
    def toVariantMap(self) -> dict[str, typing.Any]: ...
    def setDefaultToAllAttributes(self, enabled: bool) -> None: ...
    def defaultToAllAttributes(self) -> bool: ...
    def setAllowMultiple(self, allowMultiple: bool) -> None: ...
    def allowMultiple(self) -> bool: ...
    def setParentLayerParameterName(self, parentLayerParameterName: str|None) -> None: ...
    def parentLayerParameterName(self) -> str: ...
    def dependsOnOtherParameters(self) -> list[str]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def asScriptCode(self) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterVectorTileDestination(QgsProcessingDestinationParameter):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ..., defaultValue: typing.Any = ..., optional: bool = ..., createByDefault: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterVectorTileDestination') -> None: ...

    @staticmethod
    def fromScriptCode(name: str|None, description: str|None, isOptional: bool, definition: str|None) -> 'QgsProcessingParameterVectorTileDestination|None': ...
    def supportedOutputVectorTileLayerExtensions(self) -> list[str]: ...
    def createFileFilter(self) -> str: ...
    def defaultFileExtension(self) -> str: ...
    def toOutputDefinition(self) -> QgsProcessingOutputDefinition|None: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def typeName() -> str: ...


class QgsProcessingParameterTinInputLayers(QgsProcessingParameterDefinition):

    class InputLayer(PyQt6.sip.wrapper):

        attributeIndex = ... # type: int
        source = ... # type: str|None
        type = ... # type: Qgis.ProcessingTinInputLayerType

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProcessingParameterTinInputLayers.InputLayer') -> None: ...

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterTinInputLayers') -> None: ...

    @staticmethod
    def typeName() -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterType(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterType') -> None: ...

    def modelColor(self) -> QtGui.QColor: ...
    def acceptedDataTypes(self, parameter: QgsProcessingParameterDefinition|None) -> list[int]: ...
    def acceptedOutputTypes(self) -> list[str]: ...
    def acceptedParameterTypes(self) -> list[str]: ...
    def acceptedStringValues(self) -> list[str]: ...
    def acceptedPythonTypes(self) -> list[str]: ...
    def metadata(self) -> dict[str, typing.Any]: ...
    def flags(self) -> Qgis.ProcessingParameterTypeFlag: ...
    def id(self) -> str: ...
    def className(self) -> str: ...
    def pythonImportString(self) -> str: ...
    def name(self) -> str: ...
    def description(self) -> str: ...
    def create(self, name: str|None) -> QgsProcessingParameterDefinition|None: ...
    @staticmethod
    def defaultModelColor() -> QtGui.QColor: ...


class QgsProcessingParameterVectorTileWriterLayers(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterVectorTileWriterLayers') -> None: ...

    @staticmethod
    def layerAsVariantMap(layer: 'QgsVectorTileWriter.Layer') -> dict[str, typing.Any]: ...
    @staticmethod
    def variantMapAsLayer(layerVariantMap: dict[str|None, typing.Any], context: QgsProcessingContext) -> 'QgsVectorTileWriter.Layer': ...
    @staticmethod
    def parameterAsLayers(layersVariant: typing.Any, context: QgsProcessingContext) -> list['QgsVectorTileWriter.Layer']: ...
    @staticmethod
    def typeName() -> str: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterAlignRasterLayers(QgsProcessingParameterDefinition):

    @typing.overload
    def __init__(self, name: str|None, description: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterAlignRasterLayers') -> None: ...

    @staticmethod
    def itemAsVariantMap(item: QgsAlignRasterData.RasterItem) -> dict[str, typing.Any]: ...
    @staticmethod
    def variantMapAsItem(layerVariantMap: dict[str|None, typing.Any], context: QgsProcessingContext) -> QgsAlignRasterData.RasterItem: ...
    @staticmethod
    def parameterAsItems(layersVariant: typing.Any, context: QgsProcessingContext) -> list[QgsAlignRasterData.RasterItem]: ...
    @staticmethod
    def typeName() -> str: ...
    def valueAsJsonObject(self, value: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    def valueAsString(self, value: typing.Any, context: QgsProcessingContext) -> typing.Tuple[str, bool]: ...
    def asPythonString(self, outputType: QgsProcessing.PythonOutputType = ...) -> str: ...
    def valueAsPythonString(self, value: typing.Any, context: QgsProcessingContext) -> str: ...
    def checkValueIsAcceptable(self, input: typing.Any, context: QgsProcessingContext|None = ...) -> bool: ...
    def type(self) -> str: ...
    def clone(self) -> QgsProcessingParameterDefinition|None: ...


class QgsProcessingProvider(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def addAlgorithm(self, algorithm: QgsProcessingAlgorithm|None) -> bool: ...
    def loadAlgorithms(self) -> None: ...
    algorithmsLoaded: typing.ClassVar[QtCore.pyqtSignal]
    def algorithm(self, name: str|None) -> QgsProcessingAlgorithm|None: ...
    def algorithms(self) -> list[QgsProcessingAlgorithm]: ...
    def refreshAlgorithms(self) -> None: ...
    def unload(self) -> None: ...
    def load(self) -> bool: ...
    def supportsNonFileBasedOutput(self) -> bool: ...
    def defaultVectorTileFileExtension(self) -> str: ...
    def defaultPointCloudFileExtension(self) -> str: ...
    def defaultRasterFileExtension(self) -> str: ...
    def defaultRasterFileFormat(self) -> str: ...
    def defaultVectorFileExtension(self, hasGeometry: bool = ...) -> str: ...
    def isSupportedOutputValue(self, outputValue: typing.Any, parameter: QgsProcessingDestinationParameter|None, context: QgsProcessingContext) -> typing.Tuple[bool, str]: ...
    def supportedOutputTableExtensions(self) -> list[str]: ...
    def supportedOutputVectorTileLayerExtensions(self) -> list[str]: ...
    def supportedOutputPointCloudLayerExtensions(self) -> list[str]: ...
    def supportedOutputVectorLayerExtensions(self) -> list[str]: ...
    def supportedOutputRasterLayerFormatAndExtensions(self) -> list[tuple[str, str]]: ...
    def supportedOutputRasterLayerExtensions(self) -> list[str]: ...
    def isActive(self) -> bool: ...
    def warningMessage(self) -> str: ...
    def canBeActivated(self) -> bool: ...
    def versionInfo(self) -> str: ...
    def longName(self) -> str: ...
    def name(self) -> str: ...
    def helpId(self) -> str: ...
    def id(self) -> str: ...
    def flags(self) -> Qgis.ProcessingProviderFlag: ...
    def svgIconPath(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...


class QgsProcessingAlgorithmInformation(PyQt6.sip.wrapper):

    displayName = ... # type: str|None
    icon = ... # type: QtGui.QIcon

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingAlgorithmInformation') -> None: ...


class QgsProcessingRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    parameterTypeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    parameterTypeAdded: typing.ClassVar[QtCore.pyqtSignal]
    providerRemoved: typing.ClassVar[QtCore.pyqtSignal]
    providerAdded: typing.ClassVar[QtCore.pyqtSignal]
    def parameterTypes(self) -> list[QgsProcessingParameterType]: ...
    def parameterType(self, id: str|None) -> QgsProcessingParameterType|None: ...
    def removeParameterType(self, type: QgsProcessingParameterType|None) -> None: ...
    def addParameterType(self, type: QgsProcessingParameterType|None) -> bool: ...
    def addAlgorithmAlias(self, aliasId: str|None, actualId: str|None) -> None: ...
    def createAlgorithmById(self, id: str|None, configuration: dict[str|None, typing.Any] = ...) -> QgsProcessingAlgorithm|None: ...
    def algorithmById(self, id: str|None) -> QgsProcessingAlgorithm|None: ...
    def algorithmInformation(self, id: str|None) -> QgsProcessingAlgorithmInformation: ...
    def algorithms(self) -> list[QgsProcessingAlgorithm]: ...
    def providerById(self, id: str|None) -> QgsProcessingProvider|None: ...
    @typing.overload
    def removeProvider(self, provider: QgsProcessingProvider|None) -> bool: ...
    @typing.overload
    def removeProvider(self, providerId: str|None) -> bool: ...
    def addProvider(self, provider: QgsProcessingProvider|None) -> bool: ...
    def providers(self) -> list[QgsProcessingProvider]: ...


class QgsProcessingUtils(PyQt6.sip.wrapper):

    class LayerHint(enum.IntEnum):
        UnknownType = ... # type: QgsProcessingUtils.LayerHint
        Vector = ... # type: QgsProcessingUtils.LayerHint
        Raster = ... # type: QgsProcessingUtils.LayerHint
        Mesh = ... # type: QgsProcessingUtils.LayerHint
        PointCloud = ... # type: QgsProcessingUtils.LayerHint
        Annotation = ... # type: QgsProcessingUtils.LayerHint
        VectorTile = ... # type: QgsProcessingUtils.LayerHint
        TiledScene = ... # type: QgsProcessingUtils.LayerHint

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingUtils') -> None: ...

    @staticmethod
    def resolveDefaultEncoding(defaultEncoding: str|None = ...) -> str: ...
    @staticmethod
    def preprocessQgisProcessParameters(parameters: dict[str|None, typing.Any], error: str|None) -> typing.Tuple[dict[str, typing.Any], bool]: ...
    @staticmethod
    def removePointerValuesFromMap(map: dict[str|None, typing.Any]) -> dict[str, typing.Any]: ...
    @staticmethod
    def defaultVectorTileExtension() -> str: ...
    @staticmethod
    def defaultPointCloudExtension() -> str: ...
    @staticmethod
    def defaultRasterExtension() -> str: ...
    @staticmethod
    def defaultRasterFormat() -> str: ...
    @staticmethod
    def defaultVectorExtension() -> str: ...
    @staticmethod
    def indicesToFields(indices: collections.abc.Iterable[int], fields: QgsFields) -> QgsFields: ...
    @staticmethod
    def fieldNamesToIndices(fieldNames: collections.abc.Iterable[str|None], fields: QgsFields) -> list[int]: ...
    @staticmethod
    def combineFields(fieldsA: QgsFields, fieldsB: QgsFields, fieldsBPrefix: str|None = ...) -> QgsFields: ...
    @staticmethod
    def convertToCompatibleFormatAndLayerName(layer: QgsVectorLayer|None, selectedFeaturesOnly: bool, baseName: str|None, compatibleFormats: collections.abc.Iterable[str|None], preferredFormat: str|None, context: QgsProcessingContext, feedback: QgsProcessingFeedback|None, featureLimit: int = ..., filterExpression: str|None = ...) -> typing.Tuple[str, str]: ...
    @staticmethod
    def convertToCompatibleFormat(layer: QgsVectorLayer|None, selectedFeaturesOnly: bool, baseName: str|None, compatibleFormats: collections.abc.Iterable[str|None], preferredFormat: str|None, context: QgsProcessingContext, feedback: QgsProcessingFeedback|None, featureLimit: int = ..., filterExpression: str|None = ...) -> str: ...
    @staticmethod
    def outputDefinitionIndex(algorithm: QgsProcessingAlgorithm|None, name: str|None) -> int: ...
    @staticmethod
    def formatHelpMapAsHtml(map: dict[str|None, typing.Any], algorithm: QgsProcessingAlgorithm|None) -> str: ...
    @staticmethod
    def generateTempFilename(basename: str|None, context: QgsProcessingContext|None = ...) -> str: ...
    @staticmethod
    def tempFolder(context: QgsProcessingContext|None = ...) -> str: ...
    @staticmethod
    def generateIteratingDestination(input: typing.Any, id: typing.Any, context: QgsProcessingContext) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def combineLayerExtents(layers: collections.abc.Iterable[QgsMapLayer], crs: QgsCoordinateReferenceSystem, context: QgsProcessingContext) -> QgsRectangle: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def combineLayerExtents(layers: collections.abc.Iterable[QgsMapLayer], crs: QgsCoordinateReferenceSystem = ...) -> QgsRectangle: ...
    @staticmethod
    def createFeatureSink(destination: str|None, context: QgsProcessingContext, fields: QgsFields, geometryType: Qgis.WkbType, crs: QgsCoordinateReferenceSystem, createOptions: dict[str|None, typing.Any] = ...) -> typing.Tuple[QgsFeatureSink|None, str]: ...
    @staticmethod
    def stringToPythonLiteral(string: str|None) -> str: ...
    @staticmethod
    def variantToPythonLiteral(value: typing.Any) -> str: ...
    @staticmethod
    def layerToStringIdentifier(layer: QgsMapLayer|None, layerName: str|None = ...) -> str: ...
    @staticmethod
    def normalizeLayerSource(source: str|None) -> str: ...
    @staticmethod
    def variantToCrs(value: typing.Any, context: QgsProcessingContext, fallbackValue: typing.Any = ...) -> QgsCoordinateReferenceSystem: ...
    @staticmethod
    def variantToSource(value: typing.Any, context: QgsProcessingContext, fallbackValue: typing.Any = ...) -> 'QgsProcessingFeatureSource|None': ...
    @staticmethod
    def mapLayerFromString(string: str|None, context: QgsProcessingContext, allowLoadingNewLayers: bool = ..., typeHint: 'QgsProcessingUtils.LayerHint' = ..., flags: QgsProcessing.LayerOptionsFlag = ...) -> QgsMapLayer|None: ...
    @staticmethod
    def decodeProviderKeyAndUri(string: str|None) -> typing.Tuple[bool, str, str]: ...
    @staticmethod
    def encodeProviderKeyAndUri(providerKey: str|None, uri: str|None) -> str: ...
    @staticmethod
    def compatibleLayers(project: 'QgsProject|None', sort: bool = ...) -> list[QgsMapLayer]: ...
    @staticmethod
    def compatibleTiledSceneLayers(project: 'QgsProject|None', sort: bool = ...) -> list['QgsTiledSceneLayer']: ...
    @staticmethod
    def compatibleVectorTileLayers(project: 'QgsProject|None', sort: bool = ...) -> list['QgsVectorTileLayer']: ...
    @staticmethod
    def compatibleAnnotationLayers(project: 'QgsProject|None', sort: bool = ...) -> list[QgsAnnotationLayer]: ...
    @staticmethod
    def compatiblePointCloudLayers(project: 'QgsProject|None', sort: bool = ...) -> list[QgsPointCloudLayer]: ...
    @staticmethod
    def compatiblePluginLayers(project: 'QgsProject|None', sort: bool = ...) -> list[QgsPluginLayer]: ...
    @staticmethod
    def compatibleMeshLayers(project: 'QgsProject|None', sort: bool = ...) -> list[QgsMeshLayer]: ...
    @staticmethod
    def compatibleVectorLayers(project: 'QgsProject|None', sourceTypes: collections.abc.Iterable[int] = ..., sort: bool = ...) -> list[QgsVectorLayer]: ...
    @staticmethod
    def compatibleRasterLayers(project: 'QgsProject|None', sort: bool = ...) -> list['QgsRasterLayer']: ...


class QgsProcessingFeatureSource(QgsFeatureSource):

    @typing.overload
    def __init__(self, originalSource: QgsFeatureSource|None, context: QgsProcessingContext, ownsOriginalSource: bool = ..., featureLimit: int = ..., filterExpression: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingFeatureSource') -> None: ...

    def invalidGeometryCheck(self) -> Qgis.InvalidGeometryCheck: ...
    def setInvalidGeometryCheck(self, method: Qgis.InvalidGeometryCheck) -> None: ...
    def createExpressionContextScope(self) -> QgsExpressionContextScope|None: ...
    def hasSpatialIndex(self) -> Qgis.SpatialIndexPresence: ...
    def allFeatureIds(self) -> typing.Any: ...
    def sourceExtent(self) -> QgsRectangle: ...
    def maximumValue(self, fieldIndex: int) -> typing.Any: ...
    def minimumValue(self, fieldIndex: int) -> typing.Any: ...
    def uniqueValues(self, fieldIndex: int, limit: int = ...) -> set[typing.Any]: ...
    def sourceName(self) -> str: ...
    def featureCount(self) -> int: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def fields(self) -> QgsFields: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    def hasFeatures(self) -> Qgis.FeatureAvailability: ...
    @typing.overload
    def getFeatures(self, request: QgsFeatureRequest, flags: Qgis.ProcessingFeatureSourceFlag) -> QgsFeatureIterator: ...
    @typing.overload
    def getFeatures(self, request: QgsFeatureRequest = ...) -> QgsFeatureIterator: ...


class QgsProjectTranslator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectTranslator') -> None: ...

    def translate(self, context: str|None, sourceText: str|None, disambiguation: str = ..., n: int = ...) -> str: ...


class QgsProject(QtCore.QObject, QgsExpressionContextGenerator, QgsExpressionContextScopeGenerator, QgsProjectTranslator):

    class DataDefinedServerProperty(enum.IntEnum):
        NoProperty = ... # type: QgsProject.DataDefinedServerProperty
        AllProperties = ... # type: QgsProject.DataDefinedServerProperty
        WMSOnlineResource = ... # type: QgsProject.DataDefinedServerProperty

    def __init__(self, parent: QtCore.QObject|None = ..., capabilities: Qgis.ProjectCapability = ...) -> None: ...

    def rollBack(self, stopEditing: bool = ..., vectorLayer: QgsVectorLayer|None = ...) -> typing.Tuple[bool, list[str]]: ...
    def commitChanges(self, stopEditing: bool = ..., vectorLayer: QgsVectorLayer|None = ...) -> typing.Tuple[bool, list[str]]: ...
    def startEditing(self, vectorLayer: QgsVectorLayer|None = ...) -> bool: ...
    def dataDefinedServerProperties(self) -> QgsPropertyCollection: ...
    def setDataDefinedServerProperties(self, properties: QgsPropertyCollection) -> None: ...
    def registerTranslatableObjects(self, translationContext: QgsTranslationContext|None) -> None: ...
    def registerTranslatableContainers(self, translationContext: QgsTranslationContext|None, parent: QgsAttributeEditorContainer|None, layerId: str|None) -> None: ...
    def setPresetHomePath(self, path: str|None) -> None: ...
    def setDirty(self, b: bool = ...) -> None: ...
    def setSnappingConfig(self, snappingConfig: QgsSnappingConfig) -> None: ...
    elevationShadingRendererChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapScalesChanged: typing.ClassVar[QtCore.pyqtSignal]
    dirtySet: typing.ClassVar[QtCore.pyqtSignal]
    isDirtyChanged: typing.ClassVar[QtCore.pyqtSignal]
    layersAddedWithoutLegend: typing.ClassVar[QtCore.pyqtSignal]
    legendLayersAdded: typing.ClassVar[QtCore.pyqtSignal]
    layerWasAdded: typing.ClassVar[QtCore.pyqtSignal]
    layersAdded: typing.ClassVar[QtCore.pyqtSignal]
    removeAll: typing.ClassVar[QtCore.pyqtSignal]
    layerRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layersRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layerWillBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    layersWillBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    selectionColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    backgroundColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    projectColorsChanged: typing.ClassVar[QtCore.pyqtSignal]
    metadataChanged: typing.ClassVar[QtCore.pyqtSignal]
    labelingEngineSettingsChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapThemeCollectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    avoidIntersectionsLayersChanged: typing.ClassVar[QtCore.pyqtSignal]
    topologicalEditingChanged: typing.ClassVar[QtCore.pyqtSignal]
    transactionGroupsChanged: typing.ClassVar[QtCore.pyqtSignal]
    transactionModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    missingDatumTransforms: typing.ClassVar[QtCore.pyqtSignal]
    transformContextChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleMethodChanged: typing.ClassVar[QtCore.pyqtSignal]
    areaUnitsChanged: typing.ClassVar[QtCore.pyqtSignal]
    distanceUnitsChanged: typing.ClassVar[QtCore.pyqtSignal]
    ellipsoidChanged: typing.ClassVar[QtCore.pyqtSignal]
    verticalCrsChanged: typing.ClassVar[QtCore.pyqtSignal]
    crs3DChanged: typing.ClassVar[QtCore.pyqtSignal]
    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    customVariablesChanged: typing.ClassVar[QtCore.pyqtSignal]
    avoidIntersectionsModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    snappingConfigChanged: typing.ClassVar[QtCore.pyqtSignal]
    homePathChanged: typing.ClassVar[QtCore.pyqtSignal]
    fileNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    titleChanged: typing.ClassVar[QtCore.pyqtSignal]
    nonIdentifiableLayersChanged: typing.ClassVar[QtCore.pyqtSignal]
    loadingLayerMessageReceived: typing.ClassVar[QtCore.pyqtSignal]
    loadingLayer: typing.ClassVar[QtCore.pyqtSignal]
    layerLoaded: typing.ClassVar[QtCore.pyqtSignal]
    readVersionMismatchOccurred: typing.ClassVar[QtCore.pyqtSignal]
    oldProjectVersionWarning: typing.ClassVar[QtCore.pyqtSignal]
    projectSaved: typing.ClassVar[QtCore.pyqtSignal]
    writeMapLayer: typing.ClassVar[QtCore.pyqtSignal]
    readMapLayer: typing.ClassVar[QtCore.pyqtSignal]
    writeProject: typing.ClassVar[QtCore.pyqtSignal]
    readProjectWithContext: typing.ClassVar[QtCore.pyqtSignal]
    readProject: typing.ClassVar[QtCore.pyqtSignal]
    aboutToBeCleared: typing.ClassVar[QtCore.pyqtSignal]
    cleared: typing.ClassVar[QtCore.pyqtSignal]
    def __repr__(self) -> typing.Any: ...
    def setElevationShadingRenderer(self, elevationShadingRenderer: QgsElevationShadingRenderer) -> None: ...
    def elevationShadingRenderer(self) -> QgsElevationShadingRenderer: ...
    @typing.overload
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    def accept(self, visitor: QgsObjectEntityVisitorInterface|None, context: QgsObjectVisitorContext) -> bool: ...
    def translate(self, context: str|None, sourceText: str|None, disambiguation: str = ..., n: int = ...) -> str: ...
    def generateTsFile(self, locale: str|None) -> None: ...
    @deprecated("""""")
    def useProjectScales(self) -> bool: ...
    @deprecated("""""")
    def setUseProjectScales(self, enabled: bool) -> None: ...
    @deprecated("""""")
    def mapScales(self) -> list[float]: ...
    @deprecated("""""")
    def setMapScales(self, scales: collections.abc.Iterable[float]) -> None: ...
    def selectionColor(self) -> QtGui.QColor: ...
    def setSelectionColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def backgroundColor(self) -> QtGui.QColor: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setProjectColors(self, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]]) -> None: ...
    def setRequiredLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    def requiredLayers(self) -> set[QgsMapLayer]: ...
    def setMetadata(self, metadata: QgsProjectMetadata) -> None: ...
    def metadata(self) -> QgsProjectMetadata: ...
    def resolveAttachmentIdentifier(self, identifier: str|None) -> str: ...
    def attachmentIdentifier(self, attachedFile: str|None) -> str: ...
    def removeAttachedFile(self, path: str|None) -> bool: ...
    def attachedFiles(self) -> list[str]: ...
    def createAttachedFile(self, nameTemplate: str|None) -> str: ...
    def auxiliaryStorage(self) -> QgsAuxiliaryStorage|None: ...
    @deprecated("""""")
    def trustLayerMetadata(self) -> bool: ...
    @deprecated("""""")
    def setTrustLayerMetadata(self, trust: bool) -> None: ...
    def defaultCrsForNewLayers(self) -> QgsCoordinateReferenceSystem: ...
    def reloadAllLayers(self) -> None: ...
    def removeAllMapLayers(self) -> None: ...
    def mainAnnotationLayer(self) -> QgsAnnotationLayer|None: ...
    def takeMapLayer(self, layer: QgsMapLayer|None) -> QgsMapLayer|None: ...
    @typing.overload
    def removeMapLayer(self, layerId: str|None) -> None: ...
    @typing.overload
    def removeMapLayer(self, layer: QgsMapLayer|None) -> None: ...
    def removeMapLayers(self, layers: list[QgsVectorLayer]|list[str]) -> None: ...
    def addMapLayer(self, mapLayer: QgsMapLayer|None, addToLegend: bool = ...) -> QgsMapLayer|None: ...
    def addMapLayers(self, mapLayers: collections.abc.Iterable[QgsMapLayer], addToLegend: bool = ...) -> list[QgsMapLayer]: ...
    def isZipped(self) -> bool: ...
    def mapLayers(self, validOnly: bool = ...) -> typing.Any: ...
    def mapLayersByShortName(self, shortName: str|None) -> list[QgsMapLayer]: ...
    def mapLayersByName(self, layerName: str|None) -> list[QgsMapLayer]: ...
    def mapLayer(self, layerId: str|None) -> QgsMapLayer|None: ...
    def validCount(self) -> int: ...
    def count(self) -> int: ...
    def layerStore(self) -> QgsMapLayerStore|None: ...
    def labelingEngineSettings(self) -> QgsLabelingEngineSettings: ...
    def setLabelingEngineSettings(self, settings: QgsLabelingEngineSettings) -> None: ...
    def setCustomVariables(self, customVariables: dict[str|None, typing.Any]) -> None: ...
    def customVariables(self) -> dict[str, typing.Any]: ...
    def avoidIntersectionsMode(self) -> Qgis.AvoidIntersectionsMode: ...
    def setAvoidIntersectionsMode(self, mode: Qgis.AvoidIntersectionsMode) -> None: ...
    def setAvoidIntersectionsLayers(self, layers: collections.abc.Iterable[QgsVectorLayer]) -> None: ...
    def avoidIntersectionsLayers(self) -> list[QgsVectorLayer]: ...
    def snappingConfig(self) -> QgsSnappingConfig: ...
    def createExpressionContextScope(self) -> QgsExpressionContextScope|None: ...
    def createExpressionContext(self) -> QgsExpressionContext: ...
    @deprecated("""""")
    def setEvaluateDefaultValues(self, evaluateDefaultValues: bool) -> None: ...
    @deprecated("""""")
    def evaluateDefaultValues(self) -> bool: ...
    def editBufferGroup(self) -> 'QgsVectorLayerEditBufferGroup|None': ...
    def transactionGroup(self, providerKey: str|None, connString: str|None) -> QgsTransactionGroup|None: ...
    def setTransactionMode(self, transactionMode: Qgis.TransactionMode) -> bool: ...
    def transactionMode(self) -> Qgis.TransactionMode: ...
    @deprecated("""""")
    def setAutoTransaction(self, autoTransaction: bool) -> None: ...
    @deprecated("""""")
    def autoTransaction(self) -> bool: ...
    def nonIdentifiableLayers(self) -> list[str]: ...
    @typing.overload
    def setNonIdentifiableLayers(self, layers: collections.abc.Iterable[QgsMapLayer]) -> None: ...
    @typing.overload
    def setNonIdentifiableLayers(self, layerIds: collections.abc.Iterable[str|None]) -> None: ...
    def annotationManager(self) -> QgsAnnotationManager|None: ...
    def mapThemeCollection(self) -> QgsMapThemeCollection|None: ...
    def layerTreeRegistryBridge(self) -> QgsLayerTreeRegistryBridge|None: ...
    def layerTreeRoot(self) -> QgsLayerTree|None: ...
    def gpsSettings(self) -> 'QgsProjectGpsSettings|None': ...
    def displaySettings(self) -> 'QgsProjectDisplaySettings|None': ...
    def elevationProperties(self) -> 'QgsProjectElevationProperties|None': ...
    def timeSettings(self) -> 'QgsProjectTimeSettings|None': ...
    def styleSettings(self) -> 'QgsProjectStyleSettings|None': ...
    def viewSettings(self) -> 'QgsProjectViewSettings|None': ...
    def sensorManager(self) -> 'QgsSensorManager|None': ...
    def bookmarkManager(self) -> QgsBookmarkManager|None: ...
    def viewsManager(self) -> 'QgsMapViewsManager|None': ...
    def selectiveMaskingSourceSetManager(self) -> 'QgsSelectiveMaskingSourceSetManager|None': ...
    def elevationProfileManager(self) -> QgsElevationProfileManager|None: ...
    def layoutManager(self) -> QgsLayoutManager|None: ...
    def relationManager(self) -> QgsRelationManager|None: ...
    def presetHomePath(self) -> str: ...
    def homePath(self) -> str: ...
    def setScaleMethod(self, method: Qgis.ScaleCalculationMethod) -> None: ...
    def scaleMethod(self) -> Qgis.ScaleCalculationMethod: ...
    def setAreaUnits(self, unit: Qgis.AreaUnit) -> None: ...
    def areaUnits(self) -> Qgis.AreaUnit: ...
    def setDistanceUnits(self, unit: Qgis.DistanceUnit) -> None: ...
    def distanceUnits(self) -> Qgis.DistanceUnit: ...
    def topologicalEditing(self) -> bool: ...
    def setTopologicalEditing(self, enabled: bool) -> None: ...
    def createEmbeddedGroup(self, groupName: str|None, projectFilePath: str|None, invisibleLayers: collections.abc.Iterable[str|None], flags: Qgis.ProjectReadFlag = ...) -> QgsLayerTreeGroup|None: ...
    def layerIsEmbedded(self, id: str|None) -> str: ...
    def setBadLayerHandler(self, handler: 'QgsProjectBadLayerHandler|None') -> None: ...
    def error(self) -> str: ...
    def readPath(self, filename: str|None) -> str: ...
    def writePath(self, filename: str|None) -> str: ...
    def pathResolver(self) -> QgsPathResolver: ...
    def dumpProperties(self) -> None: ...
    def subkeyList(self, scope: str|None, key: str|None) -> list[str]: ...
    def entryList(self, scope: str|None, key: str|None) -> list[str]: ...
    def removeEntry(self, scope: str|None, key: str|None) -> bool: ...
    def readBoolEntry(self, scope: str|None, key: str|None, def_: bool = ...) -> typing.Tuple[bool, bool]: ...
    def readDoubleEntry(self, scope: str|None, key: str|None, def_: float = ...) -> typing.Tuple[float, bool]: ...
    def readNumEntry(self, scope: str|None, key: str|None, def_: int = ...) -> typing.Tuple[int, bool]: ...
    def readEntry(self, scope: str|None, key: str|None, def_: str|None = ...) -> typing.Tuple[str, bool]: ...
    def readListEntry(self, scope: str|None, key: str|None, def_: collections.abc.Iterable[str|None] = ...) -> typing.Tuple[list[str], bool]: ...
    @typing.overload
    def writeEntry(self, scope: str|None, key: str|None, value: int) -> bool: ...
    @typing.overload
    def writeEntry(self, scope: str|None, key: str|None, value: str|None) -> bool: ...
    @typing.overload
    def writeEntry(self, scope: str|None, key: str|None, value: collections.abc.Iterable[str|None]) -> bool: ...
    def writeEntryDouble(self, scope: str|None, key: str|None, value: float) -> bool: ...
    def writeEntryBool(self, scope: str|None, key: str|None, value: bool) -> bool: ...
    @typing.overload
    def write(self, filename: str|None) -> bool: ...
    @typing.overload
    def write(self) -> bool: ...
    def readLayer(self, layerNode: QtXml.QDomNode) -> bool: ...
    @typing.overload
    def read(self, filename: str|None, flags: Qgis.ProjectReadFlag = ...) -> bool: ...
    @typing.overload
    def read(self, flags: Qgis.ProjectReadFlag = ...) -> bool: ...
    def clear(self) -> None: ...
    def setTransformContext(self, context: QgsCoordinateTransformContext) -> None: ...
    def transformContext(self) -> QgsCoordinateTransformContext: ...
    def setVerticalCrs(self, crs: QgsCoordinateReferenceSystem) -> typing.Tuple[bool, str]: ...
    def verticalCrs(self) -> QgsCoordinateReferenceSystem: ...
    def setEllipsoid(self, ellipsoid: str|None) -> None: ...
    def ellipsoid(self) -> str: ...
    def setCrs(self, crs: QgsCoordinateReferenceSystem, adjustEllipsoid: bool = ...) -> None: ...
    def crs3D(self) -> QgsCoordinateReferenceSystem: ...
    def crs(self) -> QgsCoordinateReferenceSystem: ...
    def setFilePathStorage(self, type: Qgis.FilePathType) -> None: ...
    def filePathStorage(self) -> Qgis.FilePathType: ...
    def baseName(self) -> str: ...
    def absolutePath(self) -> str: ...
    def absoluteFilePath(self) -> str: ...
    def lastModified(self) -> QtCore.QDateTime: ...
    def projectStorage(self) -> 'QgsProjectStorage|None': ...
    @deprecated("""""")
    def fileInfo(self) -> QtCore.QFileInfo: ...
    def originalPath(self) -> str: ...
    def setOriginalPath(self, path: str|None) -> None: ...
    def fileName(self) -> str: ...
    def setFileName(self, name: str|None) -> None: ...
    def isDirty(self) -> bool: ...
    def lastSaveVersion(self) -> 'QgsProjectVersion': ...
    def lastSaveDateTime(self) -> QtCore.QDateTime: ...
    def saveUserFullName(self) -> str: ...
    def saveUser(self) -> str: ...
    def setFlag(self, flag: Qgis.ProjectFlag, enabled: bool = ...) -> None: ...
    def setFlags(self, flags: Qgis.ProjectFlag) -> None: ...
    def flags(self) -> Qgis.ProjectFlag: ...
    def capabilities(self) -> Qgis.ProjectCapability: ...
    def title(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    @staticmethod
    def setInstance(project: 'QgsProject|None') -> None: ...
    @staticmethod
    def instance() -> 'QgsProject|None': ...


class QgsProjectDirtyBlocker(PyQt6.sip.wrapper):

    def __init__(self, project: QgsProject|None) -> None: ...


class QgsProjectBadLayerHandler(PyQt6.sip.wrapper):

    class ProviderType(enum.IntEnum):
        IS_FILE = ... # type: QgsProjectBadLayerHandler.ProviderType
        IS_DATABASE = ... # type: QgsProjectBadLayerHandler.ProviderType
        IS_URL = ... # type: QgsProjectBadLayerHandler.ProviderType
        IS_Unknown = ... # type: QgsProjectBadLayerHandler.ProviderType

    class DataType(enum.IntEnum):
        IS_VECTOR = ... # type: QgsProjectBadLayerHandler.DataType
        IS_RASTER = ... # type: QgsProjectBadLayerHandler.DataType
        IS_BOGUS = ... # type: QgsProjectBadLayerHandler.DataType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectBadLayerHandler') -> None: ...

    def setDataSource(self, layerNode: QtXml.QDomNode, dataSource: str|None) -> None: ...
    def providerType(self, layerNode: QtXml.QDomNode) -> 'QgsProjectBadLayerHandler.ProviderType': ...
    def dataSource(self, layerNode: QtXml.QDomNode) -> str: ...
    def dataType(self, layerNode: QtXml.QDomNode) -> 'QgsProjectBadLayerHandler.DataType': ...
    def handleBadLayers(self, layers: collections.abc.Iterable[QtXml.QDomNode]) -> None: ...


class QgsProjectDisplaySettings(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    coordinateCrsChanged: typing.ClassVar[QtCore.pyqtSignal]
    coordinateCustomCrsChanged: typing.ClassVar[QtCore.pyqtSignal]
    coordinateAxisOrderChanged: typing.ClassVar[QtCore.pyqtSignal]
    coordinateTypeChanged: typing.ClassVar[QtCore.pyqtSignal]
    geographicCoordinateFormatChanged: typing.ClassVar[QtCore.pyqtSignal]
    bearingFormatChanged: typing.ClassVar[QtCore.pyqtSignal]
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def coordinateCrs(self) -> QgsCoordinateReferenceSystem: ...
    def setCoordinateCustomCrs(self, crs: QgsCoordinateReferenceSystem) -> None: ...
    def coordinateCustomCrs(self) -> QgsCoordinateReferenceSystem: ...
    def setCoordinateAxisOrder(self, order: Qgis.CoordinateOrder) -> None: ...
    def coordinateAxisOrder(self) -> Qgis.CoordinateOrder: ...
    def setCoordinateType(self, type: Qgis.CoordinateDisplayType) -> None: ...
    def coordinateType(self) -> Qgis.CoordinateDisplayType: ...
    def geographicCoordinateFormat(self) -> QgsGeographicCoordinateNumericFormat|None: ...
    def setGeographicCoordinateFormat(self, format: QgsGeographicCoordinateNumericFormat|None) -> None: ...
    def bearingFormat(self) -> QgsBearingNumericFormat|None: ...
    def setBearingFormat(self, format: QgsBearingNumericFormat|None) -> None: ...
    def reset(self) -> None: ...


class QgsProjectElevationProperties(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    elevationRangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setInvertElevationFilter(self, invert: bool) -> None: ...
    def setElevationFilterRangeSize(self, size: float) -> None: ...
    def setElevationRange(self, range: QgsDoubleRange) -> None: ...
    def invertElevationFilter(self) -> bool: ...
    def elevationFilterRangeSize(self) -> float: ...
    def elevationRange(self) -> QgsDoubleRange: ...
    def setTerrainProvider(self, provider: QgsAbstractTerrainProvider|None) -> None: ...
    def terrainProvider(self) -> QgsAbstractTerrainProvider|None: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def resolveReferences(self, project: QgsProject|None) -> None: ...
    def reset(self) -> None: ...


class QgsProjectFileTransform(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, domDocument: QtXml.QDomDocument, version: 'QgsProjectVersion') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectFileTransform') -> None: ...

    @staticmethod
    def fixOldSymbolLayerReferences(mapLayers: typing.Any) -> None: ...
    def currentVersion(self) -> 'QgsProjectVersion': ...
    def dom(self) -> QtXml.QDomDocument: ...
    @staticmethod
    def convertRasterProperties(doc: QtXml.QDomDocument, parentNode: QtXml.QDomNode, rasterPropertiesElem: QtXml.QDomElement, rlayer: 'QgsRasterLayer|None') -> None: ...
    def dump(self) -> None: ...
    def updateRevision(self, version: 'QgsProjectVersion') -> bool: ...


class QgsProjectGpsSettings(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    destinationTimeStampFieldChanged: typing.ClassVar[QtCore.pyqtSignal]
    destinationLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    destinationFollowsActiveLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    automaticallyCommitFeaturesChanged: typing.ClassVar[QtCore.pyqtSignal]
    automaticallyAddTrackVerticesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDestinationTimeStampField(self, layer: QgsVectorLayer|None, field: str|None) -> None: ...
    def setDestinationLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setDestinationFollowsActiveLayer(self, follow: bool) -> None: ...
    def setAutomaticallyCommitFeatures(self, enabled: bool) -> None: ...
    def setAutomaticallyAddTrackVertices(self, enabled: bool) -> None: ...
    def destinationTimeStampField(self) -> str: ...
    def destinationTimeStampFields(self) -> dict[str, str]: ...
    def destinationLayer(self) -> QgsVectorLayer|None: ...
    def destinationFollowsActiveLayer(self) -> bool: ...
    def automaticallyCommitFeatures(self) -> bool: ...
    def automaticallyAddTrackVertices(self) -> bool: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def reset(self) -> None: ...
    def resolveReferences(self, project: QgsProject|None) -> None: ...


class QgsProjectProperty(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectProperty') -> None: ...

    def value(self) -> typing.Any: ...
    def writeXml(self, nodeName: str|None, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def readXml(self, keyNode: QtXml.QDomNode) -> bool: ...
    def isLeaf(self) -> bool: ...
    def isValue(self) -> bool: ...
    def isKey(self) -> bool: ...
    def dump(self, tabs: int = ...) -> None: ...


class QgsProjectPropertyValue(QgsProjectProperty):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, value: typing.Any) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectPropertyValue') -> None: ...

    def writeXml(self, nodeName: str|None, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def readXml(self, keyNode: QtXml.QDomNode) -> bool: ...
    def dump(self, tabs: int = ...) -> None: ...
    def isLeaf(self) -> bool: ...
    def value(self) -> typing.Any: ...
    def isValue(self) -> bool: ...
    def isKey(self) -> bool: ...


class QgsProjectPropertyKey(QgsProjectProperty):

    @typing.overload
    def __init__(self, name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectPropertyKey') -> None: ...

    def find(self, propertyName: str|None) -> QgsProjectProperty|None: ...
    def clearKeys(self) -> None: ...
    def clear(self) -> None: ...
    def subkeyList(self, entries: collections.abc.Iterable[str|None]) -> None: ...
    def entryList(self, entries: collections.abc.Iterable[str|None]) -> None: ...
    def isLeaf(self) -> bool: ...
    def isValue(self) -> bool: ...
    def isKey(self) -> bool: ...
    def isEmpty(self) -> bool: ...
    def count(self) -> int: ...
    def writeXml(self, nodeName: str|None, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def readXml(self, keyNode: QtXml.QDomNode) -> bool: ...
    def dump(self, tabs: int = ...) -> None: ...
    @typing.overload
    def setValue(self, name: str|None, value: typing.Any) -> QgsProjectPropertyValue|None: ...
    @typing.overload
    def setValue(self, value: typing.Any) -> QgsProjectPropertyValue|None: ...
    def removeKey(self, keyName: str|None) -> None: ...
    def addKey(self, keyName: str|None) -> 'QgsProjectPropertyKey|None': ...
    def value(self) -> typing.Any: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...


class QgsSelectiveMaskingSourceSetManager(QgsProjectStoredObjectManagerBase):

    def __init__(self, project: QgsProject|None = ...) -> None: ...

    setRenamed: typing.ClassVar[QtCore.pyqtSignal]
    setAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    setRemoved: typing.ClassVar[QtCore.pyqtSignal]
    setAdded: typing.ClassVar[QtCore.pyqtSignal]
    setAboutToBeAdded: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def generateUniqueTitle(self) -> str: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def setByName(self, name: str|None) -> 'QgsSelectiveMaskingSourceSet': ...
    def setById(self, id: str|None) -> 'QgsSelectiveMaskingSourceSet': ...
    def sets(self) -> list['QgsSelectiveMaskingSourceSet']: ...
    def renameSet(self, oldName: str|None, newName: str|None) -> bool: ...
    def clear(self) -> None: ...
    def removeSet(self, name: str|None) -> bool: ...
    def updateSet(self, set: 'QgsSelectiveMaskingSourceSet') -> bool: ...
    def addSet(self, set: 'QgsSelectiveMaskingSourceSet') -> bool: ...


class QgsSelectiveMaskingSourceSetManagerModel(QgsProjectStoredObjectManagerModelBase):

    class CustomRole(enum.IntEnum):
        Object = ... # type: QgsSelectiveMaskingSourceSetManagerModel.CustomRole
        IsEmptyObject = ... # type: QgsSelectiveMaskingSourceSetManagerModel.CustomRole
        SetId = ... # type: QgsSelectiveMaskingSourceSetManagerModel.CustomRole

    def __init__(self, manager: QgsSelectiveMaskingSourceSetManager|None, parent: QtCore.QObject|None = ...) -> None: ...

    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def indexFromSet(self, set: 'QgsSelectiveMaskingSourceSet|None') -> QtCore.QModelIndex: ...
    def setFromIndex(self, index: QtCore.QModelIndex) -> 'QgsSelectiveMaskingSourceSet|None': ...


class QgsSelectiveMaskingSourceSetManagerProxyModel(QgsProjectStoredObjectManagerProxyModelBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...


class QgsProjectServerValidator(PyQt6.sip.wrapper):

    class ValidationError(enum.IntEnum):
        DuplicatedNames = ... # type: QgsProjectServerValidator.ValidationError
        LayerShortName = ... # type: QgsProjectServerValidator.ValidationError
        LayerEncoding = ... # type: QgsProjectServerValidator.ValidationError
        ProjectShortName = ... # type: QgsProjectServerValidator.ValidationError
        ProjectRootNameConflict = ... # type: QgsProjectServerValidator.ValidationError
        OnlyMaptipTrueButEmptyMaptip = ... # type: QgsProjectServerValidator.ValidationError

    class ValidationResult(PyQt6.sip.wrapper):

        error = ... # type: 'QgsProjectServerValidator.ValidationError'
        identifier = ... # type: typing.Any

        @typing.overload
        def __init__(self, error: 'QgsProjectServerValidator.ValidationError', identifier: typing.Any) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProjectServerValidator.ValidationResult') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectServerValidator') -> None: ...

    @staticmethod
    def validate(project: QgsProject|None) -> typing.Tuple[bool, list['QgsProjectServerValidator.ValidationResult']]: ...
    @staticmethod
    def displayValidationError(error: 'QgsProjectServerValidator.ValidationError') -> str: ...


class QgsProjectStorage(PyQt6.sip.wrapper):

    class Metadata(PyQt6.sip.wrapper):

        lastModified = ... # type: QtCore.QDateTime|datetime.datetime
        name = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProjectStorage.Metadata') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectStorage') -> None: ...

    @deprecated("""""")
    def showSaveGui(self) -> str: ...
    @deprecated("""""")
    def showLoadGui(self) -> str: ...
    @deprecated("""""")
    def visibleName(self) -> str: ...
    def filePath(self, uri: str|None) -> str: ...
    def readProjectStorageMetadata(self, uri: str|None) -> typing.Tuple[bool, 'QgsProjectStorage.Metadata']: ...
    def renameProject(self, uri: str|None, uriNew: str|None) -> bool: ...
    def removeProject(self, uri: str|None) -> bool: ...
    def writeProject(self, uri: str|None, device: QtCore.QIODevice|None, context: QgsReadWriteContext) -> bool: ...
    def readProject(self, uri: str|None, device: QtCore.QIODevice|None, context: QgsReadWriteContext) -> bool: ...
    def listProjects(self, uri: str|None) -> list[str]: ...
    def isSupportedUri(self, uri: str|None) -> bool: ...
    def type(self) -> str: ...


class QgsProjectStorageRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectStorageRegistry') -> None: ...

    def unregisterProjectStorage(self, storage: QgsProjectStorage|None) -> None: ...
    def registerProjectStorage(self, storage: QgsProjectStorage|None) -> None: ...
    def projectStorages(self) -> list[QgsProjectStorage]: ...
    def projectStorageFromUri(self, uri: str|None) -> QgsProjectStorage|None: ...
    def projectStorageFromType(self, type: str|None) -> QgsProjectStorage|None: ...


class QgsProjectStyleSettings(QtCore.QObject):

    def __init__(self, project: QgsProject|None = ...) -> None: ...

    styleDatabasesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def combinedStyleModel(self) -> 'QgsCombinedStyleModel|None': ...
    def setStyleDatabasePaths(self, paths: collections.abc.Iterable[str|None]) -> None: ...
    def addStyleDatabasePath(self, path: str|None) -> None: ...
    def styleAtPath(self, path: str|None) -> 'QgsStyle|None': ...
    def styles(self) -> list['QgsStyle']: ...
    def styleDatabasePaths(self) -> list[str]: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext, flags: Qgis.ProjectReadFlag = ...) -> bool: ...
    def colorSpace(self) -> QtGui.QColorSpace: ...
    def setColorSpace(self, colorSpace: QtGui.QColorSpace) -> None: ...
    def colorModel(self) -> Qgis.ColorModel: ...
    def setColorModel(self, colorModel: Qgis.ColorModel) -> None: ...
    def projectStyle(self) -> 'QgsStyle|None': ...
    def setProjectStyle(self, style: 'QgsStyle|None') -> None: ...
    def removeProjectStyle(self) -> None: ...
    def reset(self) -> None: ...
    def setDefaultSymbolOpacity(self, opacity: float) -> None: ...
    def defaultSymbolOpacity(self) -> float: ...
    def setRandomizeDefaultSymbolColor(self, randomized: bool) -> None: ...
    def randomizeDefaultSymbolColor(self) -> bool: ...
    def setDefaultTextFormat(self, textFormat: 'QgsTextFormat') -> None: ...
    def defaultTextFormat(self) -> 'QgsTextFormat': ...
    def setDefaultColorRamp(self, colorRamp: QgsColorRamp|None) -> None: ...
    def defaultColorRamp(self) -> QgsColorRamp|None: ...
    def setDefaultSymbol(self, symbolType: Qgis.SymbolType, symbol: 'QgsSymbol|None') -> None: ...
    def defaultSymbol(self, symbolType: Qgis.SymbolType) -> 'QgsSymbol|None': ...


class QgsProjectStyleDatabaseModel(QtCore.QAbstractListModel):

    class CustomRole(enum.IntEnum):
        Style = ... # type: QgsProjectStyleDatabaseModel.CustomRole
        Path = ... # type: QgsProjectStyleDatabaseModel.CustomRole

    def __init__(self, settings: QgsProjectStyleSettings|None, parent: QtCore.QObject|None = ...) -> None: ...

    def showDefaultStyle(self) -> bool: ...
    def setShowDefaultStyle(self, show: bool) -> None: ...
    def indexFromStyle(self, style: 'QgsStyle|None') -> QtCore.QModelIndex: ...
    def styleFromIndex(self, index: QtCore.QModelIndex) -> 'QgsStyle|None': ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...


class QgsProjectStyleDatabaseProxyModel(QtCore.QSortFilterProxyModel):

    class Filter(enum.IntFlag):
        FilterHideReadOnly = ... # type: QgsProjectStyleDatabaseProxyModel.Filter

    def __init__(self, model: QgsProjectStyleDatabaseModel|None, parent: QtCore.QObject|None = ...) -> None: ...

    def setFilters(self, filters: 'QgsProjectStyleDatabaseProxyModel.Filter') -> None: ...
    def filters(self) -> 'QgsProjectStyleDatabaseProxyModel.Filter': ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...


class QgsProjectTimeSettings(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    temporalRangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTotalMovieFrames(self, frames: int) -> None: ...
    def totalMovieFrames(self) -> int: ...
    def isTemporalRangeCumulative(self) -> bool: ...
    def setIsTemporalRangeCumulative(self, state: bool) -> None: ...
    def framesPerSecond(self) -> float: ...
    def setFramesPerSecond(self, rate: float) -> None: ...
    def setTimeStep(self, step: float) -> None: ...
    def timeStep(self) -> float: ...
    def setTimeStepUnit(self, unit: Qgis.TemporalUnit) -> None: ...
    def timeStepUnit(self) -> Qgis.TemporalUnit: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def setTemporalRange(self, range: QgsDateTimeRange) -> None: ...
    def temporalRange(self) -> QgsDateTimeRange: ...
    def reset(self) -> None: ...


class QgsProjectUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectUtils') -> None: ...

    @staticmethod
    def checkUserTrust(project: QgsProject|None) -> Qgis.ProjectTrustStatus: ...
    @staticmethod
    def layerIsContainedInGroupLayer(project: QgsProject|None, layer: QgsMapLayer|None) -> bool: ...
    @staticmethod
    def updateLayerPath(project: QgsProject|None, oldPath: str|None, newPath: str|None) -> bool: ...
    @staticmethod
    def layersMatchingUri(project: QgsProject|None, provider: str|None, uri: str|None, level: Qgis.SourceHierarchyLevel = ...) -> list[QgsMapLayer]: ...
    @staticmethod
    def layersMatchingPath(project: QgsProject|None, path: str|None) -> list[QgsMapLayer]: ...


class QgsProjectVersion(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, major: int, minor: int, sub: int, name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, string: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectVersion') -> None: ...

    def __le__(self, other: 'QgsProjectVersion') -> bool: ...
    def __lt__(self, other: 'QgsProjectVersion') -> bool: ...
    def __gt__(self, other: 'QgsProjectVersion') -> bool: ...
    def __ge__(self, other: 'QgsProjectVersion') -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def isNull(self) -> bool: ...
    def text(self) -> str: ...
    def subVersion(self) -> int: ...
    def minorVersion(self) -> int: ...
    def majorVersion(self) -> int: ...


class QgsProjectViewSettings(QtCore.QObject):

    def __init__(self, project: QgsProject|None = ...) -> None: ...

    presetFullExtentChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapScalesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def setDefaultRotation(self, rotation: float) -> None: ...
    def defaultRotation(self) -> float: ...
    def useProjectScales(self) -> bool: ...
    def setUseProjectScales(self, enabled: bool) -> None: ...
    def mapScales(self) -> list[float]: ...
    def setMapScales(self, scales: collections.abc.Iterable[float]) -> None: ...
    def fullExtent(self) -> QgsReferencedRectangle: ...
    def restoreProjectExtentOnProjectLoad(self) -> bool: ...
    def setRestoreProjectExtentOnProjectLoad(self, state: bool) -> None: ...
    def setPresetFullExtent(self, extent: QgsReferencedRectangle) -> None: ...
    def presetFullExtent(self) -> QgsReferencedRectangle: ...
    def setDefaultViewExtent(self, extent: QgsReferencedRectangle) -> None: ...
    def defaultViewExtent(self) -> QgsReferencedRectangle: ...
    def reset(self) -> None: ...


class QgsMapViewsManager(QtCore.QObject):

    def __init__(self, project: QgsProject|None) -> None: ...

    views3DListChanged: typing.ClassVar[QtCore.pyqtSignal]
    def rename3DView(self, oldTitle: str|None, newTitle: str|None) -> None: ...
    def remove3DView(self, name: str|None) -> None: ...
    def clear(self) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument) -> bool: ...


class QgsAbstractDbTableModel(QtGui.QStandardItemModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def setSql(self, index: QtCore.QModelIndex, sql: str|None) -> None: ...
    def searchableColumn(self, column: int) -> bool: ...
    def defaultSearchColumn(self) -> int: ...
    def columns(self) -> list[str]: ...


class QgsAbstractProviderConnection(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None, configuration: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractProviderConnection') -> None: ...

    def setConfiguration(self, configuration: dict[str|None, typing.Any]) -> None: ...
    def configuration(self) -> dict[str, typing.Any]: ...
    def setUri(self, uri: str|None) -> None: ...
    def uri(self) -> str: ...
    def icon(self) -> QtGui.QIcon: ...
    def remove(self, name: str|None) -> None: ...
    def store(self, name: str|None) -> None: ...


class QgsAbstractDatabaseProviderConnection(QgsAbstractProviderConnection):

    class GeometryColumnCapability(enum.IntEnum):
        Z = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        M = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        SinglePart = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        Curves = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        SinglePoint = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        SingleLineString = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        SinglePolygon = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability
        PolyhedralSurfaces = ... # type: QgsAbstractDatabaseProviderConnection.GeometryColumnCapability

    class Capability(enum.IntEnum):
        CreateVectorTable = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DropRasterTable = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DropVectorTable = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        RenameVectorTable = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        RenameRasterTable = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        CreateSchema = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DropSchema = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        RenameSchema = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        ExecuteSql = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        Vacuum = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        Tables = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        Schemas = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        SqlLayers = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        TableExists = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        Spatial = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        CreateSpatialIndex = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        SpatialIndexExists = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DeleteSpatialIndex = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DeleteField = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DeleteFieldCascade = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        AddField = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        ListFieldDomains = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        RetrieveFieldDomain = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        SetFieldDomain = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        AddFieldDomain = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        RenameField = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        RetrieveRelationships = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        AddRelationship = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        UpdateRelationship = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        DeleteRelationship = ... # type: QgsAbstractDatabaseProviderConnection.Capability
        MoveTableToSchema = ... # type: QgsAbstractDatabaseProviderConnection.Capability

    class TableFlag(enum.IntFlag):
        Aspatial = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag
        Vector = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag
        Raster = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag
        View = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag
        MaterializedView = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag
        Foreign = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag
        IncludeSystemTables = ... # type: QgsAbstractDatabaseProviderConnection.TableFlag

    class QueryResult(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection.QueryResult') -> None: ...

        def setQueryExecutionTime(self, queryExecutionTime: float) -> None: ...
        def queryExecutionTime(self) -> float: ...
        def __next__(self) -> typing.Any: ...
        def __iter__(self) -> 'QgsAbstractDatabaseProviderConnection.QueryResult|None': ...
        def rowCount(self) -> int: ...
        def fetchedRowCount(self) -> int: ...
        def nextRow(self) -> list[typing.Any]: ...
        def hasNextRow(self) -> bool: ...
        def rows(self, feedback: QgsFeedback|None = ...) -> typing.Any: ...
        def columns(self) -> list[str]: ...

    class SqlVectorLayerOptions(PyQt6.sip.wrapper):

        disableSelectAtId = ... # type: bool
        filter = ... # type: str|None
        geometryColumn = ... # type: str|None
        layerName = ... # type: str|None
        primaryKeyColumns = ... # type: collections.abc.Iterable[str|None]
        sql = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection.SqlVectorLayerOptions') -> None: ...

    class TableProperty(PyQt6.sip.wrapper):

        class GeometryColumnType(PyQt6.sip.wrapper):

            crs = ... # type: QgsCoordinateReferenceSystem
            wkbType = ... # type: Qgis.WkbType

            @typing.overload
            def __init__(self) -> None: ...
            @typing.overload
            def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection.TableProperty.GeometryColumnType') -> None: ...

            def __ne__(self, other: object): ...
            def __eq__(self, other: object): ...
            def __repr__(self) -> typing.Any: ...

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection.TableProperty') -> None: ...

        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def maxCoordinateDimensions(self) -> int: ...
        def setFlag(self, flag: 'QgsAbstractDatabaseProviderConnection.TableFlag') -> None: ...
        def setGeometryColumnCount(self, geometryColumnCount: int) -> None: ...
        def geometryColumnCount(self) -> int: ...
        def setInfo(self, info: dict[str|None, typing.Any]) -> None: ...
        def info(self) -> dict[str, typing.Any]: ...
        def setComment(self, comment: str|None) -> None: ...
        def comment(self) -> str: ...
        def setFlags(self, flags: 'QgsAbstractDatabaseProviderConnection.TableFlag') -> None: ...
        def flags(self) -> 'QgsAbstractDatabaseProviderConnection.TableFlag': ...
        def crsList(self) -> list[QgsCoordinateReferenceSystem]: ...
        def setPrimaryKeyColumns(self, primaryKeyColumns: collections.abc.Iterable[str|None]) -> None: ...
        def primaryKeyColumns(self) -> list[str]: ...
        def setGeometryColumn(self, geometryColumn: str|None) -> None: ...
        def geometryColumn(self) -> str: ...
        def setSchema(self, schema: str|None) -> None: ...
        def schema(self) -> str: ...
        def at(self, index: int) -> 'QgsAbstractDatabaseProviderConnection.TableProperty': ...
        def defaultName(self) -> str: ...
        def setGeometryColumnTypes(self, geometryColumnTypes: collections.abc.Iterable['QgsAbstractDatabaseProviderConnection.TableProperty.GeometryColumnType']) -> None: ...
        def geometryColumnTypes(self) -> list['QgsAbstractDatabaseProviderConnection.TableProperty.GeometryColumnType']: ...
        def addGeometryColumnType(self, type: Qgis.WkbType, crs: QgsCoordinateReferenceSystem) -> None: ...
        def setTableName(self, name: str|None) -> None: ...
        def tableName(self) -> str: ...
        def __repr__(self) -> typing.Any: ...

    class SpatialIndexOptions(PyQt6.sip.wrapper):

        geometryColumnName = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection.SpatialIndexOptions') -> None: ...

    class VectorLayerExporterOptions(PyQt6.sip.wrapper):

        geometryColumn = ... # type: str|None
        layerName = ... # type: str|None
        primaryKeyColumns = ... # type: collections.abc.Iterable[str|None]
        schema = ... # type: str|None
        wkbType = ... # type: Qgis.WkbType

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection.VectorLayerExporterOptions') -> None: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None, configuration: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractDatabaseProviderConnection') -> None: ...

    @typing.overload
    def checkCapability(self, capability: 'QgsAbstractDatabaseProviderConnection.Capability') -> None: ...
    @typing.overload
    def checkCapability(self, capability: Qgis.DatabaseProviderConnectionCapability2) -> None: ...
    def searchLayerMetadata(self, searchContext: QgsMetadataSearchContext, searchString: str|None = ..., geographicExtent: QgsRectangle = ..., feedback: QgsFeedback|None = ...) -> list[QgsLayerMetadataProviderResult]: ...
    def queryBuilder(self) -> 'QgsProviderSqlQueryBuilder|None': ...
    def deleteRelationship(self, relationship: QgsWeakRelation) -> None: ...
    def updateRelationship(self, relationship: QgsWeakRelation) -> None: ...
    def addRelationship(self, relationship: QgsWeakRelation) -> None: ...
    def relationships(self, schema: str|None = ..., tableName: str|None = ...) -> list[QgsWeakRelation]: ...
    def relatedTableTypes(self) -> list[str]: ...
    def supportedRelationshipCapabilities(self) -> Qgis.RelationshipCapability: ...
    def supportedRelationshipStrengths(self) -> list[Qgis.RelationshipStrength]: ...
    def supportedRelationshipCardinalities(self) -> list[Qgis.RelationshipCardinality]: ...
    def moveTableToSchema(self, sourceSchema: str|None, tableName: str|None, targetSchema: str|None) -> None: ...
    def setFieldComment(self, fieldName: str|None, schema: str|None, tableName: str|None, comment: str|None) -> None: ...
    def setTableComment(self, schema: str|None, tableName: str|None, comment: str|None) -> None: ...
    def setFieldAlias(self, fieldName: str|None, schema: str|None, tableName: str|None, alias: str|None) -> None: ...
    def deleteFieldDomain(self, name: str|None, schema: str|None) -> None: ...
    def updateFieldDomain(self, domain: 'QgsFieldDomain|None', schema: str|None) -> None: ...
    def addFieldDomain(self, domain: 'QgsFieldDomain', schema: str|None) -> None: ...
    def setFieldDomainName(self, fieldName: str|None, schema: str|None, tableName: str|None, domainName: str|None) -> None: ...
    def fieldDomain(self, name: str|None) -> 'QgsFieldDomain|None': ...
    def supportedFieldDomainTypes(self) -> list[Qgis.FieldDomainType]: ...
    def fieldDomainNames(self) -> list[str]: ...
    def defaultGeometryColumnName(self) -> str: ...
    def defaultPrimaryKeyColumnName(self) -> str: ...
    def illegalFieldNames(self) -> set[str]: ...
    def sqlDictionary(self) -> dict[Qgis.SqlKeywordCategory, list[list[str]]]: ...
    def providerKey(self) -> str: ...
    def nativeTypes(self) -> list['QgsVectorDataProvider.NativeType']: ...
    def fields(self, schema: str|None, table: str|None, feedback: QgsFeedback|None = ...) -> QgsFields: ...
    def schemas(self) -> list[str]: ...
    def tables(self, schema: str|None = ..., flags: int = ...) -> list['QgsAbstractDatabaseProviderConnection.TableProperty']: ...
    def table(self, schema: str|None, table: str|None, feedback: QgsFeedback|None = ...) -> 'QgsAbstractDatabaseProviderConnection.TableProperty': ...
    def deleteSpatialIndex(self, schema: str|None, name: str|None, geometryColumn: str|None) -> None: ...
    def spatialIndexExists(self, schema: str|None, name: str|None, geometryColumn: str|None) -> bool: ...
    def createSpatialIndex(self, schema: str|None, name: str|None, options: 'QgsAbstractDatabaseProviderConnection.SpatialIndexOptions' = ...) -> None: ...
    def vacuum(self, schema: str|None, name: str|None) -> None: ...
    def execSql(self, sql: str|None, feedback: QgsFeedback|None = ...) -> 'QgsAbstractDatabaseProviderConnection.QueryResult': ...
    def sqlOptions(self, layerSource: str|None) -> 'QgsAbstractDatabaseProviderConnection.SqlVectorLayerOptions': ...
    def validateSqlVectorLayer(self, options: 'QgsAbstractDatabaseProviderConnection.SqlVectorLayerOptions') -> typing.Tuple[bool, str]: ...
    def createSqlVectorLayer(self, options: 'QgsAbstractDatabaseProviderConnection.SqlVectorLayerOptions') -> QgsVectorLayer|None: ...
    def executeSql(self, sql: str|None, feedback: QgsFeedback|None = ...) -> typing.Any: ...
    def renameSchema(self, name: str|None, newName: str|None) -> None: ...
    def renameField(self, schema: str|None, tableName: str|None, name: str|None, newName: str|None) -> None: ...
    def addField(self, field: QgsField, schema: str|None, tableName: str|None) -> None: ...
    def deleteField(self, fieldName: str|None, schema: str|None, tableName: str|None, force: bool = ...) -> None: ...
    def dropSchema(self, name: str|None, force: bool = ...) -> None: ...
    def createSchema(self, name: str|None) -> None: ...
    def renameRasterTable(self, schema: str|None, name: str|None, newName: str|None) -> None: ...
    def renameVectorTable(self, schema: str|None, name: str|None, newName: str|None) -> None: ...
    def dropRasterTable(self, schema: str|None, name: str|None) -> None: ...
    def dropVectorTable(self, schema: str|None, name: str|None) -> None: ...
    def tableExists(self, schema: str|None, name: str|None) -> bool: ...
    def createVectorLayerExporterDestinationUri(self, options: 'QgsAbstractDatabaseProviderConnection.VectorLayerExporterOptions') -> typing.Tuple[str, dict[str, typing.Any]]: ...
    def createVectorTable(self, schema: str|None, name: str|None, fields: QgsFields, wkbType: Qgis.WkbType, srs: QgsCoordinateReferenceSystem, overwrite: bool, options: dict[str|None, typing.Any]) -> None: ...
    def tableUri(self, schema: str|None, name: str|None) -> str: ...
    def sqlLayerDefinitionCapabilities(self) -> Qgis.SqlLayerDefinitionCapability: ...
    def tableImportCapabilities(self) -> Qgis.DatabaseProviderTableImportCapability: ...
    def geometryColumnCapabilities(self) -> 'QgsAbstractDatabaseProviderConnection.GeometryColumnCapability': ...
    def capabilities2(self) -> Qgis.DatabaseProviderConnectionCapability2: ...
    def capabilities(self) -> 'QgsAbstractDatabaseProviderConnection.Capability': ...


class QgsMeshDriverMetadata(PyQt6.sip.wrapper):

    class MeshDriverCapability(enum.IntEnum):
        CanWriteFaceDatasets = ... # type: QgsMeshDriverMetadata.MeshDriverCapability
        CanWriteVertexDatasets = ... # type: QgsMeshDriverMetadata.MeshDriverCapability
        CanWriteEdgeDatasets = ... # type: QgsMeshDriverMetadata.MeshDriverCapability
        CanWriteMeshData = ... # type: QgsMeshDriverMetadata.MeshDriverCapability

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, name: str|None, description: str|None, capabilities: 'QgsMeshDriverMetadata.MeshDriverCapability', writeDatasetOnFileSuffix: str|None) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, description: str|None, capabilities: 'QgsMeshDriverMetadata.MeshDriverCapability', writeDatasetOnFileSuffix: str|None, writeMeshFrameOnFileSuffix: str|None, maxVerticesPerface: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMeshDriverMetadata') -> None: ...

    def maximumVerticesCountPerFace(self) -> int: ...
    def writeMeshFrameOnFileSuffix(self) -> str: ...
    def writeDatasetOnFileSuffix(self) -> str: ...
    def description(self) -> str: ...
    def name(self) -> str: ...
    def capabilities(self) -> 'QgsMeshDriverMetadata.MeshDriverCapability': ...


class QgsProviderMetadata(QtCore.QObject):

    class ProviderCapability(enum.IntEnum):
        FileBasedUris = ... # type: QgsProviderMetadata.ProviderCapability
        SaveLayerMetadata = ... # type: QgsProviderMetadata.ProviderCapability
        ParallelCreateProvider = ... # type: QgsProviderMetadata.ProviderCapability

    class ProviderMetadataCapability(enum.IntEnum):
        PriorityForUri = ... # type: QgsProviderMetadata.ProviderMetadataCapability
        LayerTypesForUri = ... # type: QgsProviderMetadata.ProviderMetadataCapability
        QuerySublayers = ... # type: QgsProviderMetadata.ProviderMetadataCapability
        CreateDatabase = ... # type: QgsProviderMetadata.ProviderMetadataCapability
        UrisReferToSame = ... # type: QgsProviderMetadata.ProviderMetadataCapability

    def __init__(self, key: str|None, description: str|None, library: str|None = ...) -> None: ...

    connectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    connectionDeleted: typing.ClassVar[QtCore.pyqtSignal]
    connectionCreated: typing.ClassVar[QtCore.pyqtSignal]
    def __repr__(self) -> typing.Any: ...
    def saveConnection(self, connection: QgsAbstractProviderConnection|None, name: str|None) -> None: ...
    def deleteConnection(self, name: str|None) -> None: ...
    @typing.overload
    def createConnection(self, uri: str|None, configuration: dict[str|None, typing.Any]) -> QgsAbstractProviderConnection|None: ...
    @typing.overload
    def createConnection(self, name: str|None) -> QgsAbstractProviderConnection|None: ...
    def findConnection(self, name: str|None, cached: bool = ...) -> QgsAbstractProviderConnection|None: ...
    def dbConnections(self, cached: bool = ...) -> typing.Any: ...
    def connections(self, cached: bool = ...) -> typing.Any: ...
    def createTransaction(self, connString: str|None) -> QgsTransaction|None: ...
    def createDb(self, dbPath: str|None, errCause: str|None) -> bool: ...
    def saveLayerMetadata(self, uri: str|None, metadata: QgsLayerMetadata) -> typing.Tuple[bool, str]: ...
    def loadStoredStyle(self, uri: str|None, styleName: str|None, errCause: str|None) -> str: ...
    def loadStyle(self, uri: str|None, errCause: str|None) -> str: ...
    def saveStyle(self, uri: str|None, qmlStyle: str|None, sldStyle: str|None, styleName: str|None, styleDescription: str|None, uiFileContent: str|None, useAsDefault: bool, errCause: str|None) -> bool: ...
    def deleteStyleById(self, uri: str|None, styleId: str|None, errCause: str|None) -> bool: ...
    def getStyleById(self, uri: str|None, styleId: str|None, errCause: str|None) -> str: ...
    def styleExists(self, uri: str|None, styleId: str|None) -> typing.Tuple[bool, str]: ...
    def listStyles(self, uri: str|None, ids: collections.abc.Iterable[str|None], names: collections.abc.Iterable[str|None], descriptions: collections.abc.Iterable[str|None], errCause: str|None) -> int: ...
    def dataItemProviders(self) -> list[QgsDataItemProvider]: ...
    def urisReferToSame(self, uri1: str|None, uri2: str|None, level: Qgis.SourceHierarchyLevel = ...) -> bool: ...
    def cleanUri(self, uri: str|None, flags: Qgis.UriCleaningFlag = ...) -> str: ...
    def relativeToAbsoluteUri(self, uri: str|None, context: QgsReadWriteContext) -> str: ...
    def absoluteToRelativeUri(self, uri: str|None, context: QgsReadWriteContext) -> str: ...
    def encodeUri(self, parts: dict[str|None, typing.Any]) -> str: ...
    def decodeUri(self, uri: str|None) -> dict[str, typing.Any]: ...
    def pyramidResamplingMethods(self) -> list[tuple[str, str]]: ...
    @typing.overload
    def createMeshData(self, mesh: QgsMesh, fileName: str|None, driverName: str|None, crs: QgsCoordinateReferenceSystem, metadata: dict[str|None, str|None] = ...) -> bool: ...
    @typing.overload
    def createMeshData(self, mesh: QgsMesh, uri: str|None, crs: QgsCoordinateReferenceSystem, metadata: dict[str|None, str|None] = ...) -> bool: ...
    def createRasterDataProvider(self, uri: str|None, format: str|None, nBands: int, type: Qgis.DataType, width: int, height: int, crs: QgsCoordinateReferenceSystem, createOptions: collections.abc.Iterable[str|None] = ...) -> typing.Tuple['QgsRasterDataProvider|None', float]: ...
    def createDatabase(self, uri: str|None) -> typing.Tuple[bool, str]: ...
    @staticmethod
    def boolParameter(uri: dict[str|None, typing.Any], parameter: str|None, defaultValue: bool = ...) -> bool: ...
    @staticmethod
    def setBoolParameter(uri: dict[str|None, typing.Any], parameter: str|None, value: typing.Any) -> None: ...
    def createProvider(self, uri: str|None, options: QgsDataProvider.ProviderOptions, flags: Qgis.DataProviderReadFlag = ...) -> QgsDataProvider|None: ...
    def suggestGroupNameForUri(self, uri: str|None) -> str: ...
    def querySublayers(self, uri: str|None, flags: Qgis.SublayerQueryFlag = ..., feedback: QgsFeedback|None = ...) -> list['QgsProviderSublayerDetails']: ...
    def sidecarFilesForUri(self, uri: str|None) -> list[str]: ...
    def uriIsBlocklisted(self, uri: str|None) -> bool: ...
    def validLayerTypesForUri(self, uri: str|None) -> list[Qgis.LayerType]: ...
    def priorityForUri(self, uri: str|None) -> int: ...
    def meshDriversMetadata(self) -> list[QgsMeshDriverMetadata]: ...
    def filters(self, type: Qgis.FileFilterType) -> str: ...
    def cleanupProvider(self) -> None: ...
    def initProvider(self) -> None: ...
    @deprecated("""""")
    def library(self) -> str: ...
    def supportedLayerTypes(self) -> list[Qgis.LayerType]: ...
    def providerCapabilities(self) -> 'QgsProviderMetadata.ProviderCapability': ...
    def capabilities(self) -> 'QgsProviderMetadata.ProviderMetadataCapability': ...
    def icon(self) -> QtGui.QIcon: ...
    def description(self) -> str: ...
    def key(self) -> str: ...


class QgsProviderRegistry(PyQt6.sip.wrapper):

    class WidgetMode(enum.IntEnum):
        Standalone = ... # type: QgsProviderRegistry.WidgetMode
        Embedded = ... # type: QgsProviderRegistry.WidgetMode
        Manager = ... # type: QgsProviderRegistry.WidgetMode

    class ProviderCandidateDetails(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, metadata: QgsProviderMetadata|None, layerTypes: collections.abc.Iterable[Qgis.LayerType]) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProviderRegistry.ProviderCandidateDetails') -> None: ...

        def __repr__(self) -> typing.Any: ...
        def layerTypes(self) -> list[Qgis.LayerType]: ...
        def metadata(self) -> QgsProviderMetadata|None: ...

    class UnusableUriDetails(PyQt6.sip.wrapper):

        detailedWarning = ... # type: str|None
        layerTypes = ... # type: collections.abc.Iterable[Qgis.LayerType]
        uri = ... # type: str|None
        warning = ... # type: str|None

        @typing.overload
        def __init__(self, uri: str|None = ..., warning: str|None = ..., layerTypes: collections.abc.Iterable[Qgis.LayerType] = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProviderRegistry.UnusableUriDetails') -> None: ...

        def __repr__(self) -> typing.Any: ...

    class UnusableUriHandlerInterface(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProviderRegistry.UnusableUriHandlerInterface') -> None: ...

        def details(self, uri: str|None) -> 'QgsProviderRegistry.UnusableUriDetails': ...
        def matchesUri(self, uri: str|None) -> bool: ...

    def __init__(self, a0: 'QgsProviderRegistry') -> None: ...

    def registerProvider(self, providerMetadata: QgsProviderMetadata|None) -> bool: ...
    @deprecated("""""")
    def registerGuis(self, widget: QtWidgets.QWidget|None) -> None: ...
    def protocolDrivers(self) -> str: ...
    def directoryDrivers(self) -> str: ...
    def databaseDrivers(self) -> str: ...
    def fileTiledSceneFilters(self) -> str: ...
    def fileVectorTileFilters(self) -> str: ...
    def filePointCloudFilters(self) -> str: ...
    def fileMeshDatasetFilters(self) -> str: ...
    def fileMeshFilters(self) -> str: ...
    def fileRasterFilters(self) -> str: ...
    def fileVectorFilters(self) -> str: ...
    def querySublayers(self, uri: str|None, flags: Qgis.SublayerQueryFlag = ..., feedback: QgsFeedback|None = ...) -> list['QgsProviderSublayerDetails']: ...
    def uriIsBlocklisted(self, uri: str|None) -> bool: ...
    def shouldDeferUriForOtherProviders(self, uri: str|None, providerKey: str|None) -> bool: ...
    def handleUnusableUri(self, uri: str|None) -> typing.Tuple[bool, 'QgsProviderRegistry.UnusableUriDetails']: ...
    def registerUnusableUriHandler(self, handler: 'QgsProviderRegistry.UnusableUriHandlerInterface|None') -> bool: ...
    def preferredProvidersForUri(self, uri: str|None) -> list['QgsProviderRegistry.ProviderCandidateDetails']: ...
    def providersForLayerType(self, type: Qgis.LayerType) -> set[str]: ...
    def providerMetadata(self, providerKey: str|None) -> QgsProviderMetadata|None: ...
    def providerList(self) -> list[str]: ...
    @deprecated("""""")
    def createProviderLibrary(self, providerKey: str|None) -> QtCore.QLibrary|None: ...
    @deprecated("""""")
    def function(self, providerKey: str|None, functionName: str|None) -> PyQt6.sip.voidptr: ...
    def createTransaction(self, providerKey: str|None, connString: str|None) -> QgsTransaction|None: ...
    def createDb(self, providerKey: str|None, dbPath: str|None, errCause: str|None) -> bool: ...
    def saveLayerMetadata(self, providerKey: str|None, uri: str|None, metadata: QgsLayerMetadata) -> typing.Tuple[bool, str]: ...
    def loadStoredStyle(self, providerKey: str|None, uri: str|None, styleName: str|None, errCause: str|None) -> str: ...
    def loadStyle(self, providerKey: str|None, uri: str|None, errCause: str|None) -> str: ...
    def saveStyle(self, providerKey: str|None, uri: str|None, qmlStyle: str|None, sldStyle: str|None, styleName: str|None, styleDescription: str|None, uiFileContent: str|None, useAsDefault: bool, errCause: str|None) -> bool: ...
    def deleteStyleById(self, providerKey: str|None, uri: str|None, styleId: str|None, errCause: str|None) -> bool: ...
    def getStyleById(self, providerKey: str|None, uri: str|None, styleId: str|None, errCause: str|None) -> str: ...
    def styleExists(self, providerKey: str|None, uri: str|None, styleId: str|None) -> typing.Tuple[bool, str]: ...
    def listStyles(self, providerKey: str|None, uri: str|None, ids: collections.abc.Iterable[str|None], names: collections.abc.Iterable[str|None], descriptions: collections.abc.Iterable[str|None], errCause: str|None) -> int: ...
    def dataItemProviders(self, providerKey: str|None) -> list[QgsDataItemProvider]: ...
    @deprecated("""""")
    def createSelectionWidget(self, providerKey: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., widgetMode: 'QgsProviderRegistry.WidgetMode' = ...) -> QtWidgets.QWidget|None: ...
    def relativeToAbsoluteUri(self, providerKey: str|None, uri: str|None, context: QgsReadWriteContext) -> str: ...
    def absoluteToRelativeUri(self, providerKey: str|None, uri: str|None, context: QgsReadWriteContext) -> str: ...
    def encodeUri(self, providerKey: str|None, parts: dict[str|None, typing.Any]) -> str: ...
    def decodeUri(self, providerKey: str|None, uri: str|None) -> dict[str, typing.Any]: ...
    def pyramidResamplingMethods(self, providerKey: str|None) -> list[tuple[str, str]]: ...
    def createRasterDataProvider(self, providerKey: str|None, uri: str|None, format: str|None, nBands: int, type: Qgis.DataType, width: int, height: int, crs: QgsCoordinateReferenceSystem, createOptions: collections.abc.Iterable[str|None] = ...) -> typing.Tuple['QgsRasterDataProvider|None', float]: ...
    @deprecated("""""")
    def providerCapabilities(self, providerKey: str|None) -> Qgis.DataItemProviderCapability: ...
    def createProvider(self, providerKey: str|None, dataSource: str|None, options: QgsDataProvider.ProviderOptions = ..., flags: Qgis.DataProviderReadFlag = ...) -> QgsDataProvider|None: ...
    def setLibraryDirectory(self, path: QtCore.QDir) -> None: ...
    def libraryDirectory(self) -> QtCore.QDir: ...
    def pluginList(self, asHtml: bool = ...) -> str: ...
    @deprecated("""""")
    def library(self, providerKey: str|None) -> str: ...
    @staticmethod
    def instance(pluginPath: str|None = ...) -> 'QgsProviderRegistry|None': ...


class QgsProviderSqlQueryBuilder(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProviderSqlQueryBuilder') -> None: ...

    def quoteIdentifier(self, identifier: str|None) -> str: ...
    def createLimitQueryForTable(self, schema: str|None, name: str|None, limit: int = ...) -> str: ...


class QgsProviderSublayerDetails(PyQt6.sip.wrapper):

    class LayerOptions(PyQt6.sip.wrapper):

        loadAllStoredStyle = ... # type: bool
        loadDefaultStyle = ... # type: bool
        transformContext = ... # type: QgsCoordinateTransformContext

        @typing.overload
        def __init__(self, transformContext: QgsCoordinateTransformContext) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProviderSublayerDetails.LayerOptions') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProviderSublayerDetails') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def toMimeUri(self) -> QgsMimeDataUtils.Uri: ...
    def skippedContainerScan(self) -> bool: ...
    def setSkippedContainerScan(self, skipped: bool) -> None: ...
    def setLayerNumber(self, number: int) -> None: ...
    def layerNumber(self) -> int: ...
    def __repr__(self) -> typing.Any: ...
    def setGeometryColumnName(self, name: str|None) -> None: ...
    def geometryColumnName(self) -> str: ...
    def setWkbType(self, type: Qgis.WkbType) -> None: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def setFeatureCount(self, count: int) -> None: ...
    def featureCount(self) -> int: ...
    def setPath(self, path: collections.abc.Iterable[str|None]) -> None: ...
    def path(self) -> list[str]: ...
    def setDriverName(self, driver: str|None) -> None: ...
    def driverName(self) -> str: ...
    def setFlags(self, newFlags: Qgis.SublayerFlag) -> None: ...
    def flags(self) -> Qgis.SublayerFlag: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def toLayer(self, options: 'QgsProviderSublayerDetails.LayerOptions') -> QgsMapLayer|None: ...
    def setUri(self, uri: str|None) -> None: ...
    def uri(self) -> str: ...
    def setType(self, type: Qgis.LayerType) -> None: ...
    def type(self) -> Qgis.LayerType: ...
    def setProviderKey(self, key: str|None) -> None: ...
    def providerKey(self) -> str: ...


class QgsProviderSublayerModel(QtCore.QAbstractItemModel):

    class Column(enum.IntEnum):
        Name = ... # type: QgsProviderSublayerModel.Column
        Description = ... # type: QgsProviderSublayerModel.Column

    class Role(enum.IntEnum):
        ProviderKey = ... # type: QgsProviderSublayerModel.Role
        LayerType = ... # type: QgsProviderSublayerModel.Role
        Uri = ... # type: QgsProviderSublayerModel.Role
        Name = ... # type: QgsProviderSublayerModel.Role
        Description = ... # type: QgsProviderSublayerModel.Role
        Path = ... # type: QgsProviderSublayerModel.Role
        FeatureCount = ... # type: QgsProviderSublayerModel.Role
        WkbType = ... # type: QgsProviderSublayerModel.Role
        GeometryColumnName = ... # type: QgsProviderSublayerModel.Role
        LayerNumber = ... # type: QgsProviderSublayerModel.Role
        IsNonLayerItem = ... # type: QgsProviderSublayerModel.Role
        NonLayerItemType = ... # type: QgsProviderSublayerModel.Role
        Flags = ... # type: QgsProviderSublayerModel.Role

    class NonLayerItem(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProviderSublayerModel.NonLayerItem') -> None: ...

        def __repr__(self) -> typing.Any: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...
        def setIcon(self, icon: QtGui.QIcon) -> None: ...
        def icon(self) -> QtGui.QIcon: ...
        def setUri(self, uri: str|None) -> None: ...
        def uri(self) -> str: ...
        def setDescription(self, description: str|None) -> None: ...
        def description(self) -> str: ...
        def setName(self, name: str|None) -> None: ...
        def name(self) -> str: ...
        def setType(self, type: str|None) -> None: ...
        def type(self) -> str: ...

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def addNonLayerItem(self, item: 'QgsProviderSublayerModel.NonLayerItem') -> None: ...
    def indexToNonLayerItem(self, index: QtCore.QModelIndex) -> 'QgsProviderSublayerModel.NonLayerItem': ...
    def indexToSublayer(self, index: QtCore.QModelIndex) -> QgsProviderSublayerDetails: ...
    def sublayerDetails(self) -> list[QgsProviderSublayerDetails]: ...
    def setSublayerDetails(self, details: collections.abc.Iterable[QgsProviderSublayerDetails]) -> None: ...


class QgsProviderSublayerProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, source_left: QtCore.QModelIndex, source_right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def setIncludeEmptyLayers(self, include: bool) -> None: ...
    def includeEmptyLayers(self) -> bool: ...
    def setIncludeSystemTables(self, include: bool) -> None: ...
    def includeSystemTables(self) -> bool: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def filterString(self) -> str: ...


class QgsProviderSublayerTask(QgsTask):

    @typing.overload
    def __init__(self, uri: str|None, includeSystemTables: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None, providerKey: str|None, includeSystemTables: bool = ...) -> None: ...

    def run(self) -> bool: ...
    def cancel(self) -> None: ...
    def results(self) -> list[QgsProviderSublayerDetails]: ...


class QgsProviderUtils(PyQt6.sip.wrapper):

    class SublayerCompletenessFlag(enum.IntFlag):
        IgnoreUnknownFeatureCount = ... # type: QgsProviderUtils.SublayerCompletenessFlag
        IgnoreUnknownGeometryType = ... # type: QgsProviderUtils.SublayerCompletenessFlag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProviderUtils') -> None: ...

    @staticmethod
    def suggestLayerNameFromFilePath(path: str|None) -> str: ...
    @staticmethod
    def sublayerDetailsAreIncomplete(details: collections.abc.Iterable[QgsProviderSublayerDetails], flags: 'QgsProviderUtils.SublayerCompletenessFlag' = ...) -> bool: ...


class QgsArcGisPortalUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsArcGisPortalUtils') -> None: ...

    @typing.overload
    @staticmethod
    def retrieveGroupItemsOfType(contentUrl: str|None, groupId: str|None, authcfg: str|None, itemTypes: collections.abc.Iterable[int], requestHeaders: QgsHttpHeaders = ..., feedback: QgsFeedback|None = ..., pageSize: int = ..., urlPrefix: str|None = ..., forceRefresh: bool = ...) -> typing.Tuple[list[typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def retrieveGroupItemsOfType(contentUrl: str|None, groupId: str|None, authcfg: str|None, itemTypes: collections.abc.Iterable[int], requestHeaders: dict[str|None, typing.Any], feedback: QgsFeedback|None = ..., pageSize: int = ..., urlPrefix: str|None = ...) -> typing.Tuple[list[typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    def retrieveGroupContent(contentUrl: str|None, groupId: str|None, authcfg: str|None, requestHeaders: QgsHttpHeaders = ..., feedback: QgsFeedback|None = ..., pageSize: int = ..., urlPrefix: str|None = ..., forceRefresh: bool = ...) -> typing.Tuple[list[typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def retrieveGroupContent(contentUrl: str|None, groupId: str|None, authcfg: str|None, requestHeaders: dict[str|None, typing.Any], feedback: QgsFeedback|None = ..., pageSize: int = ..., urlPrefix: str|None = ...) -> typing.Tuple[list[typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    def retrieveUserGroups(communityUrl: str|None, user: str|None, authcfg: str|None, requestHeaders: QgsHttpHeaders = ..., feedback: QgsFeedback|None = ..., urlPrefix: str|None = ..., forceRefresh: bool = ...) -> typing.Tuple[list[typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def retrieveUserGroups(communityUrl: str|None, user: str|None, authcfg: str|None, requestHeaders: dict[str|None, typing.Any], feedback: QgsFeedback|None = ..., urlPrefix: str|None = ...) -> typing.Tuple[list[typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    def retrieveUserInfo(communityUrl: str|None, user: str|None, authcfg: str|None, requestHeaders: QgsHttpHeaders = ..., feedback: QgsFeedback|None = ..., urlPrefix: str|None = ..., forceRefresh: bool = ...) -> typing.Tuple[dict[str, typing.Any], str, str]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def retrieveUserInfo(communityUrl: str|None, user: str|None, authcfg: str|None, requestHeaders: dict[str|None, typing.Any], feedback: QgsFeedback|None = ..., urlPrefix: str|None = ...) -> typing.Tuple[dict[str, typing.Any], str, str]: ...


class QgsArcGisRestContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsArcGisRestContext') -> None: ...

    def objectIdFieldName(self) -> str: ...
    def setObjectIdFieldName(self, name: str|None) -> None: ...
    def timeZone(self) -> QtCore.QTimeZone: ...
    def setTimeZone(self, zone: QtCore.QTimeZone) -> None: ...


class QgsArcGisRestUtils(PyQt6.sip.wrapper):

    class FeatureToJsonFlag(enum.IntFlag):
        IncludeGeometry = ... # type: QgsArcGisRestUtils.FeatureToJsonFlag
        IncludeNonObjectIdAttributes = ... # type: QgsArcGisRestUtils.FeatureToJsonFlag
        SkipUnsetAttributes = ... # type: QgsArcGisRestUtils.FeatureToJsonFlag

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsArcGisRestUtils') -> None: ...

    @staticmethod
    def serviceTypeFromString(type: str|None) -> Qgis.ArcGisRestServiceType: ...
    @staticmethod
    def fieldDefinitionToJson(field: QgsField) -> dict[str, typing.Any]: ...
    @staticmethod
    def variantToAttributeValue(variant: typing.Any, expectedType: QtCore.QMetaType.Type, context: QgsArcGisRestContext) -> typing.Any: ...
    @staticmethod
    def featureToJson(feature: QgsFeature, context: QgsArcGisRestContext, crs: QgsCoordinateReferenceSystem = ..., flags: 'QgsArcGisRestUtils.FeatureToJsonFlag' = ...) -> dict[str, typing.Any]: ...
    @staticmethod
    def convertRectangle(value: typing.Any) -> QgsRectangle: ...
    @staticmethod
    def crsToJson(crs: QgsCoordinateReferenceSystem) -> dict[str, typing.Any]: ...
    @staticmethod
    def geometryToJson(geometry: QgsGeometry, context: QgsArcGisRestContext, crs: QgsCoordinateReferenceSystem = ...) -> dict[str, typing.Any]: ...
    @staticmethod
    def convertDateTime(value: typing.Any) -> QtCore.QDateTime: ...
    @staticmethod
    def convertFillStyle(style: str|None) -> QtCore.Qt.BrushStyle: ...
    @staticmethod
    def convertLineStyle(style: str|None) -> QtCore.Qt.PenStyle: ...
    @staticmethod
    def convertColor(data: typing.Any) -> QtGui.QColor: ...
    @staticmethod
    def convertLabelingExpression(string: str|None) -> str: ...
    @staticmethod
    def convertLabeling(data: collections.abc.Iterable[typing.Any]) -> QgsAbstractVectorLayerLabeling|None: ...
    @staticmethod
    def convertRenderer(rendererData: dict[str|None, typing.Any]) -> 'QgsFeatureRenderer'|None: ...
    @staticmethod
    def convertSymbol(definition: dict[str|None, typing.Any]) -> 'QgsSymbol'|None: ...
    @staticmethod
    def convertSpatialReference(spatialReferenceMap: dict[str|None, typing.Any]) -> QgsCoordinateReferenceSystem: ...
    @staticmethod
    def convertGeometry(geometry: dict[str|None, typing.Any], esriGeometryType: str|None, hasM: bool, hasZ: bool, allowCurves: bool = ...) -> typing.Tuple[QgsAbstractGeometry|None, QgsCoordinateReferenceSystem|None]: ...
    @staticmethod
    def convertGeometryType(type: str|None) -> Qgis.WkbType: ...
    @staticmethod
    def convertFieldType(type: str|None) -> QtCore.QMetaType.Type: ...


class QgsMemoryProviderUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMemoryProviderUtils') -> None: ...

    @staticmethod
    def createMemoryLayer(name: str|None, fields: QgsFields, geometryType: Qgis.WkbType = ..., crs: QgsCoordinateReferenceSystem = ..., loadDefaultStyle: bool = ...) -> QgsVectorLayer|None: ...


class QgsSensorThingsUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSensorThingsUtils') -> None: ...

    @staticmethod
    def asQueryString(baseType: Qgis.SensorThingsEntity, expansions: collections.abc.Iterable['QgsSensorThingsExpansionDefinition']) -> str: ...
    @staticmethod
    def relationshipCardinality(baseType: Qgis.SensorThingsEntity, relatedType: Qgis.SensorThingsEntity) -> typing.Tuple[Qgis.RelationshipCardinality, bool]: ...
    @staticmethod
    def expandableTargets(type: Qgis.SensorThingsEntity) -> list[Qgis.SensorThingsEntity]: ...
    @staticmethod
    def availableGeometryTypes(uri: str|None, type: Qgis.SensorThingsEntity, feedback: QgsFeedback|None = ..., authCfg: str|None = ...) -> list[Qgis.GeometryType]: ...
    @staticmethod
    def combineFilters(filters: collections.abc.Iterable[str|None]) -> str: ...
    @staticmethod
    def filterForExtent(geometryField: str|None, extent: QgsRectangle) -> str: ...
    @staticmethod
    def filterForWkbType(entityType: Qgis.SensorThingsEntity, wkbType: Qgis.WkbType) -> str: ...
    @staticmethod
    def geometryTypeForEntity(type: Qgis.SensorThingsEntity) -> Qgis.GeometryType: ...
    @staticmethod
    def entityTypeHasGeometry(type: Qgis.SensorThingsEntity) -> bool: ...
    @staticmethod
    def geometryFieldForEntityType(type: Qgis.SensorThingsEntity) -> str: ...
    @staticmethod
    def fieldsForExpandedEntityType(baseType: Qgis.SensorThingsEntity, expandedTypes: collections.abc.Iterable[Qgis.SensorThingsEntity]) -> QgsFields: ...
    @staticmethod
    def fieldsForEntityType(type: Qgis.SensorThingsEntity, includeRangeFieldProxies: bool = ...) -> QgsFields: ...
    @staticmethod
    def propertiesForEntityType(type: Qgis.SensorThingsEntity) -> list[str]: ...
    @staticmethod
    def entityToSetString(type: Qgis.SensorThingsEntity) -> str: ...
    @staticmethod
    def entitySetStringToEntity(type: str|None) -> Qgis.SensorThingsEntity: ...
    @staticmethod
    def displayString(type: Qgis.SensorThingsEntity, plural: bool = ...) -> str: ...
    @staticmethod
    def stringToEntity(type: str|None) -> Qgis.SensorThingsEntity: ...


class QgsSensorThingsExpansionDefinition(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, childEntity: Qgis.SensorThingsEntity = ..., orderBy: str|None = ..., sortOrder: QtCore.Qt.SortOrder = ..., limit: int = ..., filter: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSensorThingsExpansionDefinition') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def asQueryString(self, parentEntityType: Qgis.SensorThingsEntity, additionalOptions: collections.abc.Iterable[str|None] = ...) -> str: ...
    @staticmethod
    def fromString(string: str|None) -> 'QgsSensorThingsExpansionDefinition': ...
    def toString(self) -> str: ...
    def setFilter(self, filter: str|None) -> None: ...
    def filter(self) -> str: ...
    def setLimit(self, limit: int) -> None: ...
    def limit(self) -> int: ...
    def setSortOrder(self, order: QtCore.Qt.SortOrder) -> None: ...
    def sortOrder(self) -> QtCore.Qt.SortOrder: ...
    def setOrderBy(self, field: str|None) -> None: ...
    def orderBy(self) -> str: ...
    def setChildEntity(self, entity: Qgis.SensorThingsEntity) -> None: ...
    def childEntity(self) -> Qgis.SensorThingsEntity: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def defaultDefinitionForEntity(entity: Qgis.SensorThingsEntity) -> 'QgsSensorThingsExpansionDefinition': ...


class QgsRasterAttributeTable(PyQt6.sip.wrapper):

    class UsageInformation(PyQt6.sip.wrapper):

        allowedTypes = ... # type: collections.abc.Iterable[QtCore.QMetaType.Type]
        description = ... # type: str|None
        isColor = ... # type: bool
        isRamp = ... # type: bool
        maybeClass = ... # type: bool
        required = ... # type: bool
        supported = ... # type: bool
        unique = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterAttributeTable.UsageInformation') -> None: ...

    class Field(PyQt6.sip.wrapper):

        name = ... # type: str|None
        type = ... # type: QtCore.QMetaType.Type
        usage = ... # type: Qgis.RasterAttributeTableFieldUsage

        @typing.overload
        def __init__(self, name: str|None, usage: Qgis.RasterAttributeTableFieldUsage, type: QtCore.QMetaType.Type) -> None: ...
        @typing.overload
        @deprecated("""""")
        def __init__(self, name: str|None, usage: Qgis.RasterAttributeTableFieldUsage, type: typing.Any) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterAttributeTable.Field') -> None: ...

        def isRamp(self) -> bool: ...
        def isColor(self) -> bool: ...

    class MinMaxClass(PyQt6.sip.wrapper):

        color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
        minMaxValues = ... # type: collections.abc.Iterable[float]
        name = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterAttributeTable.MinMaxClass') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterAttributeTable') -> None: ...

    @staticmethod
    def usageInformation() -> dict[int, 'QgsRasterAttributeTable.UsageInformation']: ...
    @staticmethod
    def createFromRaster(rasterLayer: 'QgsRasterLayer|None') -> typing.Tuple['QgsRasterAttributeTable|None', int]: ...
    @staticmethod
    def valueAndColorFieldUsages() -> list[Qgis.RasterAttributeTableFieldUsage]: ...
    @staticmethod
    def usageName(fieldusage: Qgis.RasterAttributeTableFieldUsage) -> str: ...
    def filePath(self) -> str: ...
    @typing.overload
    @staticmethod
    def guessFieldUsage(name: str|None, type: QtCore.QMetaType.Type) -> Qgis.RasterAttributeTableFieldUsage: ...
    @typing.overload
    @staticmethod
    def guessFieldUsage(name: str|None, type: typing.Any) -> Qgis.RasterAttributeTableFieldUsage: ...
    def orderedRows(self) -> typing.Any: ...
    def createRenderer(self, provider: 'QgsRasterDataProvider|None', bandNumber: int, classificationColumn: int = ...) -> 'QgsRasterRenderer|None': ...
    def colorRamp(self, labelColumn: int = ...) -> typing.Tuple[QgsGradientColorRamp, list[str]]: ...
    def minMaxClasses(self, classificationColumn: int = ...) -> list['QgsRasterAttributeTable.MinMaxClass']: ...
    def row(self, matchValue: float) -> list[typing.Any]: ...
    def maximumValue(self) -> float: ...
    def minimumValue(self) -> float: ...
    def value(self, row: int, column: int) -> typing.Any: ...
    def setValue(self, row: int, column: int, value: typing.Any) -> bool: ...
    def fieldsByUsage(self, fieldUsage: Qgis.RasterAttributeTableFieldUsage) -> list['QgsRasterAttributeTable.Field']: ...
    def fieldByName(self, name: str|None) -> typing.Tuple['QgsRasterAttributeTable.Field', bool]: ...
    def data(self) -> typing.Any: ...
    def readFromFile(self, path: str|None) -> typing.Tuple[bool, str]: ...
    def writeToFile(self, path: str|None) -> typing.Tuple[bool, str]: ...
    def appendRow(self, data: collections.abc.Iterable[typing.Any]) -> typing.Tuple[bool, str]: ...
    def removeRow(self, position: int = ...) -> typing.Tuple[bool, str]: ...
    def insertRow(self, position: int, rowData: collections.abc.Iterable[typing.Any]) -> typing.Tuple[bool, str]: ...
    def removeField(self, name: str|None) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def appendField(self, name: str|None, usage: Qgis.RasterAttributeTableFieldUsage, type: QtCore.QMetaType.Type) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def appendField(self, name: str|None, usage: Qgis.RasterAttributeTableFieldUsage, type: typing.Any) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def appendField(self, field: 'QgsRasterAttributeTable.Field') -> typing.Tuple[bool, str]: ...
    def insertRamp(self, position: int) -> typing.Tuple[bool, str]: ...
    def setFieldUsage(self, fieldIndex: int, usage: Qgis.RasterAttributeTableFieldUsage) -> bool: ...
    def insertColor(self, position: int) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def insertField(self, position: int, field: 'QgsRasterAttributeTable.Field') -> typing.Tuple[bool, str]: ...
    @typing.overload
    def insertField(self, position: int, name: str|None, usage: Qgis.RasterAttributeTableFieldUsage, type: QtCore.QMetaType.Type) -> typing.Tuple[bool, str]: ...
    @typing.overload
    @deprecated("""""")
    def insertField(self, position: int, name: str|None, usage: Qgis.RasterAttributeTableFieldUsage, type: typing.Any) -> typing.Tuple[bool, str]: ...
    def isValid(self) -> typing.Tuple[bool, str]: ...
    def setDirty(self, isDirty: bool) -> None: ...
    def isDirty(self) -> bool: ...
    def qgisFeatures(self) -> list[QgsFeature]: ...
    def qgisFields(self) -> QgsFields: ...
    def fields(self) -> list['QgsRasterAttributeTable.Field']: ...
    def ramp(self, row: int) -> QgsGradientColorRamp: ...
    def color(self, row: int) -> QtGui.QColor: ...
    def usages(self) -> list[int]: ...
    def setRamp(self, row: int, colorMin: QtGui.QColor|QtCore.Qt.GlobalColor|int, colorMax: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> bool: ...
    def hasRamp(self) -> bool: ...
    def setColor(self, row: int, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> bool: ...
    def hasColor(self) -> bool: ...
    def type(self) -> Qgis.RasterAttributeTableType: ...


class QgsRasterResampler(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterResampler') -> None: ...

    def tileBufferPixels(self) -> int: ...
    def clone(self) -> 'QgsRasterResampler|None': ...
    def type(self) -> str: ...
    @deprecated("""""")
    def resample(self, srcImage: QtGui.QImage, dstImage: QtGui.QImage) -> None: ...


class QgsRasterResamplerV2(QgsRasterResampler):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterResamplerV2') -> None: ...

    def resampleV2(self, source: QtGui.QImage, size: QtCore.QSize) -> QtGui.QImage: ...


class QgsBilinearRasterResampler(QgsRasterResamplerV2):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsBilinearRasterResampler') -> None: ...

    def tileBufferPixels(self) -> int: ...
    def clone(self) -> 'QgsBilinearRasterResampler|None': ...
    def type(self) -> str: ...
    def resampleV2(self, source: QtGui.QImage, size: QtCore.QSize) -> QtGui.QImage: ...
    @deprecated("""""")
    def resample(self, srcImage: QtGui.QImage, dstImage: QtGui.QImage) -> None: ...


class QgsRasterInterface(PyQt6.sip.wrapper):

    def __init__(self, input: 'QgsRasterInterface|None' = ...) -> None: ...

    @typing.overload
    @deprecated("""""")
    def initStatistics(self, statistics: 'QgsRasterBandStats', bandNo: int, stats: int, boundingBox: QgsRectangle = ..., binCount: int = ...) -> None: ...
    @typing.overload
    def initStatistics(self, statistics: 'QgsRasterBandStats', bandNo: int, stats: Qgis.RasterBandStatistic = ..., boundingBox: QgsRectangle = ..., binCount: int = ...) -> None: ...
    def initHistogram(self, histogram: 'QgsRasterHistogram', bandNo: int, binCount: int, minimum: typing.Any = ..., maximum: typing.Any = ..., boundingBox: QgsRectangle = ..., sampleSize: int = ..., includeOutOfRange: bool = ...) -> None: ...
    def readXml(self, filterElem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def cumulativeCut(self, bandNo: int, lowerCount: float, upperCount: float, extent: QgsRectangle = ..., sampleSize: int = ...) -> typing.Tuple[float, float]: ...
    def hasHistogram(self, bandNo: int, binCount: int, minimum: typing.Any = ..., maximum: typing.Any = ..., extent: QgsRectangle = ..., sampleSize: int = ..., includeOutOfRange: bool = ...) -> bool: ...
    def histogram(self, bandNo: int, binCount: int = ..., minimum: typing.Any = ..., maximum: typing.Any = ..., extent: QgsRectangle = ..., sampleSize: int = ..., includeOutOfRange: bool = ..., feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterHistogram': ...
    @typing.overload
    @deprecated("""""")
    def hasStatistics(self, bandNo: int, stats: int, extent: QgsRectangle = ..., sampleSize: int = ...) -> bool: ...
    @typing.overload
    def hasStatistics(self, bandNo: int, stats: Qgis.RasterBandStatistic = ..., extent: QgsRectangle = ..., sampleSize: int = ...) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def bandStatistics(self, bandNo: int, stats: int, extent: QgsRectangle = ..., sampleSize: int = ..., feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBandStats': ...
    @typing.overload
    def bandStatistics(self, bandNo: int, stats: Qgis.RasterBandStatistic = ..., extent: QgsRectangle = ..., sampleSize: int = ..., feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBandStats': ...
    def sourceInput(self) -> 'QgsRasterInterface|None': ...
    def setOn(self, on: bool) -> None: ...
    def on(self) -> bool: ...
    def input(self) -> 'QgsRasterInterface|None': ...
    def setInput(self, input: 'QgsRasterInterface|None') -> bool: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    def displayBandName(self, bandNumber: int) -> str: ...
    def colorInterpretationName(self, bandNumber: int) -> str: ...
    def generateBandName(self, bandNumber: int) -> str: ...
    def ySize(self) -> int: ...
    def xSize(self) -> int: ...
    def yBlockSize(self) -> int: ...
    def xBlockSize(self) -> int: ...
    def bandCount(self) -> int: ...
    def dataTypeSize(self, bandNo: int) -> int: ...
    def extent(self) -> QgsRectangle: ...
    def sourceDataType(self, bandNo: int) -> Qgis.DataType: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    @deprecated("""""")
    def capabilitiesString(self) -> str: ...
    def capabilities(self) -> Qgis.RasterInterfaceCapability: ...
    def clone(self) -> 'QgsRasterInterface|None': ...


class QgsBrightnessContrastFilter(QgsRasterInterface):

    def __init__(self, input: QgsRasterInterface|None = ...) -> None: ...

    def readXml(self, filterElem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def gamma(self) -> float: ...
    def setGamma(self, gamma: float) -> None: ...
    def contrast(self) -> int: ...
    def setContrast(self, contrast: int) -> None: ...
    def brightness(self) -> int: ...
    def setBrightness(self, brightness: int) -> None: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    def setInput(self, input: QgsRasterInterface|None) -> bool: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def bandCount(self) -> int: ...
    def clone(self) -> 'QgsBrightnessContrastFilter|None': ...


class QgsContrastEnhancementFunction(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, a0: Qgis.DataType, a1: float, a2: float) -> None: ...
    @typing.overload
    def __init__(self, f: 'QgsContrastEnhancementFunction') -> None: ...

    def minimumValue(self) -> float: ...
    def maximumValue(self) -> float: ...
    def setMinimumValue(self, value: float) -> None: ...
    def setMaximumValue(self, value: float) -> None: ...
    def isValueInDisplayableRange(self, value: float) -> bool: ...
    def enhance(self, value: float) -> int: ...


class QgsClipToMinMaxEnhancement(QgsContrastEnhancementFunction):

    @typing.overload
    def __init__(self, a0: Qgis.DataType, a1: float, a2: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsClipToMinMaxEnhancement') -> None: ...

    def isValueInDisplayableRange(self, a0: float) -> bool: ...
    def enhance(self, a0: float) -> int: ...


class QgsRasterShaderFunction(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, minimumValue: float = ..., maximumValue: float = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterShaderFunction') -> None: ...

    def setLabelPrecision(self, labelPrecision: int) -> None: ...
    def labelPrecision(self) -> int: ...
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    def maximumValue(self) -> float: ...
    def minimumValue(self) -> float: ...
    def minimumMaximumRange(self) -> float: ...
    @typing.overload
    def shade(self, value: float) -> typing.Tuple[bool, int, int, int, int]: ...
    @typing.overload
    def shade(self, redValue: float, greenValue: float, blueValue: float, alphaValue: float) -> typing.Tuple[bool, int, int, int, int]: ...
    def setMinimumValue(self, value: float) -> None: ...
    def setMaximumValue(self, value: float) -> None: ...


class QgsColorRampShader(QgsRasterShaderFunction):

    class ColorRampItem(PyQt6.sip.wrapper):

        color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
        label = ... # type: str|None
        value = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, val: float, col: QtGui.QColor|QtCore.Qt.GlobalColor|int, lbl: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsColorRampShader.ColorRampItem') -> None: ...

        def __ge__(self, other: 'QgsColorRampShader.ColorRampItem') -> bool: ...
        def __eq__(self, other: object): ...
        def __ne__(self, other: object): ...
        def __lt__(self, other: 'QgsColorRampShader.ColorRampItem') -> bool: ...

    @typing.overload
    def __init__(self, minimumValue: float = ..., maximumValue: float = ..., colorRamp: QgsColorRamp|None = ..., type: Qgis.ShaderInterpolationMethod = ..., classificationMode: Qgis.ShaderClassificationMethod = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsColorRampShader') -> None: ...

    def setLegendSettings(self, settings: QgsColorRampLegendNodeSettings|None) -> None: ...
    def legendSettings(self) -> QgsColorRampLegendNodeSettings|None: ...
    def clip(self) -> bool: ...
    def setClip(self, clip: bool) -> None: ...
    def classificationMode(self) -> Qgis.ShaderClassificationMethod: ...
    def setClassificationMode(self, classificationMode: Qgis.ShaderClassificationMethod) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext = ...) -> QtXml.QDomElement: ...
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    @typing.overload
    def shade(self, value: float) -> typing.Tuple[bool, int, int, int, int]: ...
    @typing.overload
    def shade(self, redValue: float, greenValue: float, blueValue: float, alphaValue: float) -> typing.Tuple[bool, int, int, int, int]: ...
    def classifyColorRampV2(self, band: int = ..., extent: QgsRectangle = ..., input: QgsRasterInterface|None = ...) -> None: ...
    def classifyColorRamp(self, classes: int = ..., band: int = ..., extent: QgsRectangle = ..., input: QgsRasterInterface|None = ...) -> None: ...
    def setSourceColorRamp(self, colorramp: QgsColorRamp|None) -> None: ...
    def createColorRamp(self) -> QgsColorRamp|None: ...
    def sourceColorRamp(self) -> QgsColorRamp|None: ...
    def isEmpty(self) -> bool: ...
    @typing.overload
    def setColorRampType(self, colorRampType: Qgis.ShaderInterpolationMethod) -> None: ...
    @typing.overload
    def setColorRampType(self, type: str|None) -> None: ...
    def setColorRampItemList(self, list: collections.abc.Iterable['QgsColorRampShader.ColorRampItem']) -> None: ...
    def colorRampTypeAsQString(self) -> str: ...
    def colorRampType(self) -> Qgis.ShaderInterpolationMethod: ...
    def colorRampItemList(self) -> list['QgsColorRampShader.ColorRampItem']: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsContrastEnhancement(PyQt6.sip.wrapper):

    class ContrastEnhancementAlgorithm(enum.IntEnum):
        NoEnhancement = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
        StretchToMinimumMaximum = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
        StretchAndClipToMinimumMaximum = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
        ClipToMinimumMaximum = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
        UserDefinedEnhancement = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm

    @typing.overload
    def __init__(self, datatype: Qgis.DataType = ...) -> None: ...
    @typing.overload
    def __init__(self, ce: 'QgsContrastEnhancement') -> None: ...

    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement) -> None: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def setMinimumValue(self, value: float, generateTable: bool = ...) -> None: ...
    def setMaximumValue(self, value: float, generateTable: bool = ...) -> None: ...
    def setContrastEnhancementFunction(self, function: QgsContrastEnhancementFunction|None) -> None: ...
    def setContrastEnhancementAlgorithm(self, algorithm: 'QgsContrastEnhancement.ContrastEnhancementAlgorithm', generateTable: bool = ...) -> None: ...
    def isValueInDisplayableRange(self, value: float) -> bool: ...
    def enhanceContrast(self, value: float) -> int: ...
    def contrastEnhancementAlgorithm(self) -> 'QgsContrastEnhancement.ContrastEnhancementAlgorithm': ...
    def minimumValue(self) -> float: ...
    def maximumValue(self) -> float: ...
    @staticmethod
    def contrastEnhancementAlgorithmFromString(contrastEnhancementString: str|None) -> 'QgsContrastEnhancement.ContrastEnhancementAlgorithm': ...
    @staticmethod
    def contrastEnhancementAlgorithmString(algorithm: 'QgsContrastEnhancement.ContrastEnhancementAlgorithm') -> str: ...
    @staticmethod
    def minimumValuePossible(dataType: Qgis.DataType) -> float: ...
    @staticmethod
    def maximumValuePossible(dataType: Qgis.DataType) -> float: ...


class QgsCubicRasterResampler(QgsRasterResamplerV2):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCubicRasterResampler') -> None: ...

    def tileBufferPixels(self) -> int: ...
    def type(self) -> str: ...
    @deprecated("""""")
    def resample(self, srcImage: QtGui.QImage, dstImage: QtGui.QImage) -> None: ...
    def resampleV2(self, source: QtGui.QImage, size: QtCore.QSize) -> QtGui.QImage: ...
    def clone(self) -> 'QgsCubicRasterResampler|None': ...


class QgsExifTools(PyQt6.sip.wrapper):

    class GeoTagDetails(PyQt6.sip.wrapper):

        elevation = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExifTools.GeoTagDetails') -> None: ...

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExifTools') -> None: ...

    @staticmethod
    def tagImage(imagePath: str|None, tag: str|None, value: typing.Any) -> bool: ...
    @staticmethod
    def geoTagImage(imagePath: str|None, location: QgsPointXY, details: 'QgsExifTools.GeoTagDetails' = ...) -> bool: ...
    @staticmethod
    def hasGeoTag(imagePath: str|None) -> bool: ...
    @staticmethod
    def getGeoTag(imagePath: str|None) -> typing.Tuple[QgsPoint, bool]: ...
    @staticmethod
    def readTag(imagePath: str|None, key: str|None) -> typing.Any: ...
    @staticmethod
    def readTags(imagePath: str|None) -> dict[str, typing.Any]: ...


class QgsRasterRenderer(QgsRasterInterface):

    NODATA_COLOR = ... # type: int

    def __init__(self, input: QgsRasterInterface|None = ..., type: str|None = ...) -> None: ...

    def renderColorForNodataPixel(self) -> int: ...
    def _writeXml(self, doc: QtXml.QDomDocument, rasterRendererElem: QtXml.QDomElement) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def setMinMaxOrigin(self, origin: 'QgsRasterMinMaxOrigin') -> None: ...
    def minMaxOrigin(self) -> 'QgsRasterMinMaxOrigin': ...
    def usesBands(self) -> list[int]: ...
    def copyCommonProperties(self, other: 'QgsRasterRenderer|None', copyMinMaxOrigin: bool = ...) -> None: ...
    def readXml(self, rendererElem: QtXml.QDomElement) -> None: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    def alphaBand(self) -> int: ...
    def setAlphaBand(self, band: int) -> None: ...
    def rasterTransparency(self) -> 'QgsRasterTransparency|None': ...
    def setRasterTransparency(self, t: 'QgsRasterTransparency|None') -> None: ...
    def setNodataColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def nodataColor(self) -> QtGui.QColor: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def usesTransparency(self) -> bool: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    def setInput(self, input: QgsRasterInterface|None) -> bool: ...
    def canCreateRasterAttributeTable(self) -> bool: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def type(self) -> str: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def bandCount(self) -> int: ...
    def clone(self) -> 'QgsRasterRenderer|None': ...


class QgsHillshadeRenderer(QgsRasterRenderer):

    def __init__(self, input: QgsRasterInterface|None, band: int, lightAzimuth: float, lightAltitude: float) -> None: ...

    def setMultiDirectional(self, isMultiDirectional: bool) -> None: ...
    def setZFactor(self, zfactor: float) -> None: ...
    def setAltitude(self, altitude: float) -> None: ...
    def setAzimuth(self, azimuth: float) -> None: ...
    def multiDirectional(self) -> bool: ...
    def zFactor(self) -> float: ...
    def altitude(self) -> float: ...
    def azimuth(self) -> float: ...
    def setInputBand(self, band: int) -> bool: ...
    @deprecated("""""")
    def setBand(self, bandNo: int) -> None: ...
    @deprecated("""""")
    def band(self) -> int: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def inputBand(self) -> int: ...
    def usesBands(self) -> list[int]: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsHillshadeRenderer|None': ...


class QgsHueSaturationFilter(QgsRasterInterface):

    class GrayscaleMode(enum.IntEnum):
        GrayscaleOff = ... # type: QgsHueSaturationFilter.GrayscaleMode
        GrayscaleLightness = ... # type: QgsHueSaturationFilter.GrayscaleMode
        GrayscaleLuminosity = ... # type: QgsHueSaturationFilter.GrayscaleMode
        GrayscaleAverage = ... # type: QgsHueSaturationFilter.GrayscaleMode

    def __init__(self, input: QgsRasterInterface|None = ...) -> None: ...

    def readXml(self, filterElem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def colorizeStrength(self) -> int: ...
    def setColorizeStrength(self, colorizeStrength: int) -> None: ...
    def colorizeColor(self) -> QtGui.QColor: ...
    def setColorizeColor(self, colorizeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def colorizeOn(self) -> bool: ...
    def setColorizeOn(self, colorizeOn: bool) -> None: ...
    def grayscaleMode(self) -> 'QgsHueSaturationFilter.GrayscaleMode': ...
    def setGrayscaleMode(self, grayscaleMode: 'QgsHueSaturationFilter.GrayscaleMode') -> None: ...
    def invertColors(self) -> bool: ...
    def setInvertColors(self, invertColors: bool) -> None: ...
    def saturation(self) -> int: ...
    def setSaturation(self, saturation: int) -> None: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    def setInput(self, input: QgsRasterInterface|None) -> bool: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def bandCount(self) -> int: ...
    def clone(self) -> 'QgsHueSaturationFilter|None': ...


class QgsLinearMinMaxEnhancement(QgsContrastEnhancementFunction):

    @typing.overload
    def __init__(self, a0: Qgis.DataType, a1: float, a2: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLinearMinMaxEnhancement') -> None: ...

    def enhance(self, a0: float) -> int: ...


class QgsLinearMinMaxEnhancementWithClip(QgsContrastEnhancementFunction):

    @typing.overload
    def __init__(self, a0: Qgis.DataType, a1: float, a2: float) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLinearMinMaxEnhancementWithClip') -> None: ...

    def isValueInDisplayableRange(self, a0: float) -> bool: ...
    def enhance(self, a0: float) -> int: ...


class QgsMultiBandColorRenderer(QgsRasterRenderer):

    def __init__(self, input: QgsRasterInterface|None, redBand: int, greenBand: int, blueBand: int, redEnhancement: QgsContrastEnhancement|None = ..., greenEnhancement: QgsContrastEnhancement|None = ..., blueEnhancement: QgsContrastEnhancement|None = ...) -> None: ...

    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def usesBands(self) -> list[int]: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def setBlueContrastEnhancement(self, ce: QgsContrastEnhancement|None) -> None: ...
    def blueContrastEnhancement(self) -> QgsContrastEnhancement|None: ...
    def setGreenContrastEnhancement(self, ce: QgsContrastEnhancement|None) -> None: ...
    def greenContrastEnhancement(self) -> QgsContrastEnhancement|None: ...
    def setRedContrastEnhancement(self, ce: QgsContrastEnhancement|None) -> None: ...
    def redContrastEnhancement(self) -> QgsContrastEnhancement|None: ...
    def setBlueBand(self, band: int) -> None: ...
    def blueBand(self) -> int: ...
    def setGreenBand(self, band: int) -> None: ...
    def greenBand(self) -> int: ...
    def setRedBand(self, band: int) -> None: ...
    def redBand(self) -> int: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsMultiBandColorRenderer|None': ...


class QgsPalettedRasterRenderer(QgsRasterRenderer):

    class Class(PyQt6.sip.wrapper):

        color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
        label = ... # type: str|None
        value = ... # type: float

        @typing.overload
        def __init__(self, value: float, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., label: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsPalettedRasterRenderer.Class') -> None: ...

    class MultiValueClass(PyQt6.sip.wrapper):

        color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
        label = ... # type: str|None
        values = ... # type: collections.abc.Iterable[typing.Any]

        @typing.overload
        def __init__(self, values: collections.abc.Iterable[typing.Any], color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., label: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsPalettedRasterRenderer.MultiValueClass') -> None: ...

    def __init__(self, input: QgsRasterInterface|None, bandNumber: int, classes: collections.abc.Iterable['QgsPalettedRasterRenderer.Class']) -> None: ...

    @staticmethod
    def classDataFromRaster(raster: QgsRasterInterface|None, bandNumber: int, ramp: QgsColorRamp|None = ..., feedback: 'QgsRasterBlockFeedback|None' = ...) -> list['QgsPalettedRasterRenderer.Class']: ...
    @staticmethod
    def classDataToString(classes: collections.abc.Iterable['QgsPalettedRasterRenderer.Class']) -> str: ...
    @staticmethod
    def classDataFromFile(path: str|None) -> list['QgsPalettedRasterRenderer.Class']: ...
    @staticmethod
    def classDataFromString(string: str|None) -> list['QgsPalettedRasterRenderer.Class']: ...
    @staticmethod
    def rasterAttributeTableToClassData(attributeTable: QgsRasterAttributeTable|None, classificationColumn: int = ..., ramp: QgsColorRamp|None = ...) -> list['QgsPalettedRasterRenderer.MultiValueClass']: ...
    @staticmethod
    def colorTableToClassData(table: collections.abc.Iterable[QgsColorRampShader.ColorRampItem]) -> list['QgsPalettedRasterRenderer.Class']: ...
    def sourceColorRamp(self) -> QgsColorRamp|None: ...
    def setSourceColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def usesBands(self) -> list[int]: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    @deprecated("""""")
    def band(self) -> int: ...
    def setLabel(self, idx: float, label: str|None) -> None: ...
    def label(self, idx: float) -> str: ...
    def setMultiValueClasses(self, classes: collections.abc.Iterable['QgsPalettedRasterRenderer.MultiValueClass']) -> None: ...
    def canCreateRasterAttributeTable(self) -> bool: ...
    def multiValueClasses(self) -> list['QgsPalettedRasterRenderer.MultiValueClass']: ...
    def classes(self) -> list['QgsPalettedRasterRenderer.Class']: ...
    def nColors(self) -> int: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> 'QgsRasterBlock|None': ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsPalettedRasterRenderer|None': ...


class QgsRaster(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRaster') -> None: ...

    @staticmethod
    def representableValue(value: float, dataType: Qgis.DataType) -> float: ...


class QgsRasterBandStats(PyQt6.sip.wrapper):

    bandNumber = ... # type: int
    elementCount = ... # type: int
    extent = ... # type: QgsRectangle
    height = ... # type: int
    maximumValue = ... # type: float
    mean = ... # type: float
    minimumValue = ... # type: float
    range = ... # type: float
    statsGathered = ... # type: Qgis.RasterBandStatistic
    stdDev = ... # type: float
    sum = ... # type: float
    sumOfSquares = ... # type: float
    width = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterBandStats') -> None: ...

    def contains(self, s: 'QgsRasterBandStats') -> bool: ...


class QgsRasterBlock(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, dataType: Qgis.DataType, width: int, height: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterBlock') -> None: ...

    def minimumMaximum(self) -> typing.Tuple[bool, float, int, int, float, int, int]: ...
    def maximum(self) -> typing.Tuple[bool, float, int, int]: ...
    def minimum(self) -> typing.Tuple[bool, float, int, int]: ...
    def height(self) -> int: ...
    def width(self) -> int: ...
    @staticmethod
    def subRect(extent: QgsRectangle, width: int, height: int, subExtent: QgsRectangle) -> QtCore.QRect: ...
    def toString(self) -> str: ...
    def setError(self, error: QgsError) -> None: ...
    def error(self) -> QgsError: ...
    def applyScaleOffset(self, scale: float, offset: float) -> None: ...
    def applyNoDataValues(self, rangeList: collections.abc.Iterable['QgsRasterRange']) -> None: ...
    def setImage(self, image: QtGui.QImage|None) -> bool: ...
    def image(self) -> QtGui.QImage: ...
    def convert(self, destDataType: Qgis.DataType) -> bool: ...
    @staticmethod
    def printValue(value: float, localized: bool = ...) -> str: ...
    def setData(self, data: QtCore.QByteArray|bytes|bytearray|memoryview, offset: int = ...) -> None: ...
    def data(self) -> QtCore.QByteArray: ...
    def fill(self, value: float) -> None: ...
    @typing.overload
    def setIsData(self, row: int, column: int) -> None: ...
    @typing.overload
    def setIsData(self, index: int) -> None: ...
    def setIsNoDataExcept(self, exceptRect: QtCore.QRect) -> bool: ...
    @typing.overload
    def setIsNoData(self, row: int, column: int) -> bool: ...
    @typing.overload
    def setIsNoData(self, index: int) -> bool: ...
    @typing.overload
    def setIsNoData(self) -> bool: ...
    @typing.overload
    def setColor(self, row: int, column: int, color: int) -> bool: ...
    @typing.overload
    def setColor(self, index: int, color: int) -> bool: ...
    @typing.overload
    def setValue(self, row: int, column: int, value: float) -> bool: ...
    @typing.overload
    def setValue(self, index: int, value: float) -> bool: ...
    @typing.overload
    def isNoData(self, row: int, column: int) -> bool: ...
    @typing.overload
    def isNoData(self, row: int, column: int) -> bool: ...
    @typing.overload
    def isNoData(self, index: int) -> bool: ...
    @typing.overload
    def color(self, row: int, column: int) -> int: ...
    @typing.overload
    def color(self, index: int) -> int: ...
    @typing.overload
    def value(self, row: int, column: int) -> float: ...
    @typing.overload
    def value(self, index: int) -> float: ...
    @staticmethod
    def valueBytes(dataType: Qgis.DataType, value: float) -> QtCore.QByteArray: ...
    def noDataValue(self) -> float: ...
    def resetNoDataValue(self) -> None: ...
    def setNoDataValue(self, noDataValue: float) -> None: ...
    def hasNoData(self) -> bool: ...
    def hasNoDataValue(self) -> bool: ...
    @staticmethod
    def typeWithNoDataValue(dataType: Qgis.DataType) -> typing.Tuple[Qgis.DataType, float]: ...
    def dataType(self) -> Qgis.DataType: ...
    @staticmethod
    def typeIsColor(type: Qgis.DataType) -> bool: ...
    @staticmethod
    def typeIsComplex(type: Qgis.DataType) -> bool: ...
    @staticmethod
    def typeIsNumeric(type: Qgis.DataType) -> bool: ...
    def dataTypeSize(self) -> int: ...
    @staticmethod
    def typeSize(dataType: Qgis.DataType) -> int: ...
    def isEmpty(self) -> bool: ...
    def setValid(self, valid: bool) -> None: ...
    def isValid(self) -> bool: ...
    def reset(self, dataType: Qgis.DataType, width: int, height: int) -> bool: ...


class QgsRasterChecker(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterChecker') -> None: ...

    def runTest(self, verifiedKey: str|None, verifiedUri: str|None, expectedKey: str|None, expectedUri: str|None) -> bool: ...
    def report(self) -> str: ...


class QgsRasterContourRenderer(QgsRasterRenderer):

    def __init__(self, input: QgsRasterInterface|None) -> None: ...

    def setDownscale(self, scale: float) -> None: ...
    def downscale(self) -> float: ...
    def setContourIndexSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def contourIndexSymbol(self) -> 'QgsLineSymbol|None': ...
    def setContourIndexInterval(self, interval: float) -> None: ...
    def contourIndexInterval(self) -> float: ...
    def setContourSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def contourSymbol(self) -> 'QgsLineSymbol|None': ...
    def setContourInterval(self, interval: float) -> None: ...
    def contourInterval(self) -> float: ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def usesBands(self) -> list[int]: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> QgsRasterBlock|None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsRasterContourRenderer|None': ...


class QgsImageFetcher(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    error: typing.ClassVar[QtCore.pyqtSignal]
    progress: typing.ClassVar[QtCore.pyqtSignal]
    finish: typing.ClassVar[QtCore.pyqtSignal]
    def start(self) -> None: ...


class QgsRasterDataProvider(QgsDataProvider, QgsRasterInterface):

    class TransformType(enum.IntEnum):
        TransformImageToLayer = ... # type: QgsRasterDataProvider.TransformType
        TransformLayerToImage = ... # type: QgsRasterDataProvider.TransformType

    class VirtualRasterInputLayers(PyQt6.sip.wrapper):

        name = ... # type: str|None
        provider = ... # type: str|None
        uri = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterDataProvider.VirtualRasterInputLayers') -> None: ...

    class VirtualRasterParameters(PyQt6.sip.wrapper):

        crs = ... # type: QgsCoordinateReferenceSystem
        extent = ... # type: QgsRectangle
        formula = ... # type: str|None
        height = ... # type: int
        rInputLayers = ... # type: collections.abc.Iterable['QgsRasterDataProvider.VirtualRasterInputLayers']
        width = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterDataProvider.VirtualRasterParameters') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None, providerOptions: QgsDataProvider.ProviderOptions = ..., flags: Qgis.DataProviderReadFlag = ...) -> None: ...

    def copyBaseSettings(self, other: 'QgsRasterDataProvider') -> None: ...
    def userNoDataValuesContains(self, bandNo: int, value: float) -> bool: ...
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def bandDescription(self, bandNumber: int) -> str: ...
    def readNativeAttributeTable(self) -> typing.Tuple[bool, str]: ...
    def writeNativeAttributeTable(self) -> typing.Tuple[bool, str]: ...
    def readFileBasedAttributeTable(self, bandNumber: int, path: str|None) -> typing.Tuple[bool, str]: ...
    def writeFileBasedAttributeTable(self, bandNumber: int, path: str|None) -> typing.Tuple[bool, str]: ...
    def removeAttributeTable(self, bandNumber: int) -> None: ...
    def setAttributeTable(self, bandNumber: int, attributeTable: QgsRasterAttributeTable|None) -> None: ...
    def attributeTable(self, bandNumber: int) -> QgsRasterAttributeTable|None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def readXml(self, filterElem: QtXml.QDomElement) -> None: ...
    def maxOversampling(self) -> float: ...
    def setMaxOversampling(self, factor: float) -> bool: ...
    def zoomedOutResamplingMethod(self) -> Qgis.RasterResamplingMethod: ...
    def setZoomedOutResamplingMethod(self, method: Qgis.RasterResamplingMethod) -> bool: ...
    def zoomedInResamplingMethod(self) -> Qgis.RasterResamplingMethod: ...
    def setZoomedInResamplingMethod(self, method: Qgis.RasterResamplingMethod) -> bool: ...
    def isProviderResamplingEnabled(self) -> bool: ...
    def enableProviderResampling(self, enable: bool) -> bool: ...
    def transformCoordinates(self, point: QgsPoint, type: 'QgsRasterDataProvider.TransformType') -> QgsPoint: ...
    def ignoreExtents(self) -> bool: ...
    def nativeResolutions(self) -> list[float]: ...
    def stepHeight(self) -> int: ...
    def stepWidth(self) -> int: ...
    @staticmethod
    def identifyFormatToCapability(format: Qgis.RasterIdentifyFormat) -> Qgis.RasterInterfaceCapability: ...
    @staticmethod
    def identifyFormatLabel(format: Qgis.RasterIdentifyFormat) -> str: ...
    @staticmethod
    def identifyFormatFromName(formatName: str|None) -> Qgis.RasterIdentifyFormat: ...
    @staticmethod
    def identifyFormatName(format: Qgis.RasterIdentifyFormat) -> str: ...
    def validatePyramidsConfigOptions(self, pyramidsFormat: Qgis.RasterPyramidFormat, configOptions: collections.abc.Iterable[str|None], fileFormat: str|None) -> str: ...
    def validateCreationOptions(self, createOptions: collections.abc.Iterable[str|None], format: str|None) -> str: ...
    @staticmethod
    def encodeVirtualRasterProviderUri(parts: 'QgsRasterDataProvider.VirtualRasterParameters') -> str: ...
    @staticmethod
    def decodeVirtualRasterProviderUri(uri: str|None) -> typing.Tuple['QgsRasterDataProvider.VirtualRasterParameters', bool]: ...
    @staticmethod
    def pyramidResamplingMethods(providerKey: str|None) -> list[tuple[str, str]]: ...
    def remove(self) -> bool: ...
    def setNoDataValue(self, bandNo: int, noDataValue: float) -> bool: ...
    @staticmethod
    def create(providerKey: str|None, uri: str|None, format: str|None, nBands: int, type: Qgis.DataType, width: int, height: int, crs: QgsCoordinateReferenceSystem, createOptions: collections.abc.Iterable[str|None] = ...) -> typing.Tuple['QgsRasterDataProvider|None', float]: ...
    def writeBlock(self, block: QgsRasterBlock|None, band: int, xOffset: int = ..., yOffset: int = ...) -> bool: ...
    def write(self, data: PyQt6.sip.voidptr, band: int, width: int, height: int, xOffset: int, yOffset: int) -> bool: ...
    def setEditable(self, enabled: bool) -> bool: ...
    def isEditable(self) -> bool: ...
    def dataTimestamp(self) -> QtCore.QDateTime: ...
    def timestamp(self) -> QtCore.QDateTime: ...
    def setDpi(self, dpi: int) -> None: ...
    def dpi(self) -> int: ...
    def lastErrorFormat(self) -> str: ...
    def lastError(self) -> str: ...
    def lastErrorTitle(self) -> str: ...
    def sample(self, point: QgsPointXY, band: int, boundingBox: QgsRectangle = ..., width: int = ..., height: int = ..., dpi: int = ...) -> typing.Tuple[float, bool]: ...
    def identify(self, point: QgsPointXY, format: Qgis.RasterIdentifyFormat, boundingBox: QgsRectangle = ..., width: int = ..., height: int = ..., dpi: int = ...) -> 'QgsRasterIdentifyResult': ...
    def hasPyramids(self) -> bool: ...
    def buildPyramidList(self, overviewList: collections.abc.Iterable[int] = ...) -> list['QgsRasterPyramid']: ...
    def buildPyramids(self, pyramidList: collections.abc.Iterable['QgsRasterPyramid'], resamplingMethod: str|None = ..., format: Qgis.RasterPyramidFormat = ..., configOptions: collections.abc.Iterable[str|None] = ..., feedback: 'QgsRasterBlockFeedback|None' = ...) -> str: ...
    def getLegendGraphicFetcher(self, mapSettings: QgsMapSettings|None) -> QgsImageFetcher|None: ...
    def supportsLegendGraphic(self) -> bool: ...
    def elevationProperties(self) -> 'QgsRasterDataProviderElevationProperties|None': ...
    def temporalCapabilities(self) -> 'QgsRasterDataProviderTemporalCapabilities|None': ...
    def subLayers(self) -> list[str]: ...
    def colorTable(self, bandNo: int) -> list[QgsColorRampShader.ColorRampItem]: ...
    def userNoDataValues(self, bandNo: int) -> list['QgsRasterRange']: ...
    def setUserNoDataValue(self, bandNo: int, noData: collections.abc.Iterable['QgsRasterRange']) -> None: ...
    def sourceNoDataValue(self, bandNo: int) -> float: ...
    def setUseSourceNoDataValue(self, bandNo: int, use: bool) -> None: ...
    def useSourceNoDataValue(self, bandNo: int) -> bool: ...
    def sourceHasNoDataValue(self, bandNo: int) -> bool: ...
    def block(self, bandNo: int, boundingBox: QgsRectangle, width: int, height: int, feedback: 'QgsRasterBlockFeedback|None' = ...) -> QgsRasterBlock|None: ...
    def maximumTileSize(self) -> QtCore.QSize: ...
    def bandOffset(self, bandNo: int) -> float: ...
    def bandScale(self, bandNo: int) -> float: ...
    def colorInterpretationName(self, bandNo: int) -> str: ...
    def reload(self) -> bool: ...
    def colorName(self, colorInterpretation: Qgis.RasterColorInterpretation) -> str: ...
    def colorInterpretation(self, bandNo: int) -> Qgis.RasterColorInterpretation: ...
    def sourceDataType(self, bandNo: int) -> Qgis.DataType: ...
    def fields(self) -> QgsFields: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def extent(self) -> QgsRectangle: ...
    def setInput(self, input: QgsRasterInterface|None) -> bool: ...
    def providerCapabilities(self) -> Qgis.RasterProviderCapability: ...
    def clone(self) -> 'QgsRasterDataProvider|None': ...


class QgsRasterDataProviderElevationProperties(QgsDataProviderElevationProperties):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterDataProviderElevationProperties') -> None: ...


class QgsRasterDataProviderTemporalCapabilities(QgsDataProviderTemporalCapabilities):

    @typing.overload
    def __init__(self, enabled: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterDataProviderTemporalCapabilities') -> None: ...

    def setDefaultInterval(self, interval: QgsInterval) -> None: ...
    def defaultInterval(self) -> QgsInterval: ...
    def requestedTemporalRange(self) -> QgsDateTimeRange: ...
    def availableReferenceTemporalRange(self) -> QgsDateTimeRange: ...
    def setAvailableReferenceTemporalRange(self, range: QgsDateTimeRange) -> None: ...
    def allAvailableTemporalRanges(self) -> list[QgsDateTimeRange]: ...
    def setAllAvailableTemporalRanges(self, ranges: collections.abc.Iterable[QgsDateTimeRange]) -> None: ...
    def availableTemporalRange(self) -> QgsDateTimeRange: ...
    def setAvailableTemporalRange(self, range: QgsDateTimeRange) -> None: ...
    def setIntervalHandlingMethod(self, method: Qgis.TemporalIntervalMatchMethod) -> None: ...
    def intervalHandlingMethod(self) -> Qgis.TemporalIntervalMatchMethod: ...
    def setFlags(self, flags: Qgis.RasterTemporalCapabilityFlag) -> None: ...
    def flags(self) -> Qgis.RasterTemporalCapabilityFlag: ...


class QgsRasterDrawer(PyQt6.sip.wrapper):

    @typing.overload
    @deprecated("""""")
    def __init__(self, iterator: 'QgsRasterIterator|None', dpiTarget: float) -> None: ...
    @typing.overload
    def __init__(self, iterator: 'QgsRasterIterator|None') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterDrawer') -> None: ...

    @typing.overload
    def draw(self, p: QtGui.QPainter|None, viewPort: 'QgsRasterViewPort|None', qgsMapToPixel: QgsMapToPixel|None, feedback: 'QgsRasterBlockFeedback|None' = ...) -> None: ...
    @typing.overload
    def draw(self, context: QgsRenderContext, viewPort: 'QgsRasterViewPort|None', feedback: 'QgsRasterBlockFeedback|None' = ...) -> None: ...


class QgsRasterFileWriter(PyQt6.sip.wrapper):

    class RasterFormatOption(enum.IntEnum):
        SortRecommended = ... # type: QgsRasterFileWriter.RasterFormatOption

    class FilterFormatDetails(PyQt6.sip.wrapper):

        driverName = ... # type: str|None
        filterString = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterFileWriter.FilterFormatDetails') -> None: ...

    @typing.overload
    def __init__(self, outputUrl: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterFileWriter') -> None: ...

    @staticmethod
    def extensionsForFormat(format: str|None) -> list[str]: ...
    @staticmethod
    def driverForExtension(extension: str|None) -> str: ...
    @staticmethod
    def supportedFormatExtensions(options: 'QgsRasterFileWriter.RasterFormatOption' = ...) -> list[str]: ...
    @staticmethod
    def supportedFiltersAndFormats(options: 'QgsRasterFileWriter.RasterFormatOption' = ...) -> list['QgsRasterFileWriter.FilterFormatDetails']: ...
    @staticmethod
    def filterForDriver(driverName: str|None) -> str: ...
    def pyramidsConfigOptions(self) -> list[str]: ...
    def setPyramidsConfigOptions(self, list: collections.abc.Iterable[str|None]) -> None: ...
    def setCreationOptions(self, options: collections.abc.Iterable[str|None]) -> None: ...
    def creationOptions(self) -> list[str]: ...
    @deprecated("""""")
    def createOptions(self) -> list[str]: ...
    @deprecated("""""")
    def setCreateOptions(self, list: collections.abc.Iterable[str|None]) -> None: ...
    def maxTileHeight(self) -> int: ...
    def setMaxTileHeight(self, h: int) -> None: ...
    def setPyramidsFormat(self, f: Qgis.RasterPyramidFormat) -> None: ...
    def pyramidsFormat(self) -> Qgis.RasterPyramidFormat: ...
    def setPyramidsResampling(self, str: str|None) -> None: ...
    def pyramidsResampling(self) -> str: ...
    def setPyramidsList(self, list: collections.abc.Iterable[int]) -> None: ...
    def pyramidsList(self) -> list[int]: ...
    def setBuildPyramidsFlag(self, flag: Qgis.RasterBuildPyramidOption) -> None: ...
    def buildPyramidsFlag(self) -> Qgis.RasterBuildPyramidOption: ...
    def maxTileWidth(self) -> int: ...
    def setMaxTileWidth(self, w: int) -> None: ...
    def tiledMode(self) -> bool: ...
    def setTiledMode(self, t: bool) -> None: ...
    def outputProviderKey(self) -> str: ...
    def setOutputProviderKey(self, key: str|None) -> None: ...
    def outputFormat(self) -> str: ...
    def setOutputFormat(self, format: str|None) -> None: ...
    def outputUrl(self) -> str: ...
    @typing.overload
    @deprecated("""""")
    def writeRaster(self, pipe: 'QgsRasterPipe|None', nCols: int, nRows: int, outputExtent: QgsRectangle, crs: QgsCoordinateReferenceSystem, feedback: 'QgsRasterBlockFeedback|None' = ...) -> Qgis.RasterFileWriterResult: ...
    @typing.overload
    def writeRaster(self, pipe: 'QgsRasterPipe|None', nCols: int, nRows: int, outputExtent: QgsRectangle, crs: QgsCoordinateReferenceSystem, transformContext: QgsCoordinateTransformContext, feedback: 'QgsRasterBlockFeedback|None' = ...) -> Qgis.RasterFileWriterResult: ...
    def createMultiBandRaster(self, dataType: Qgis.DataType, width: int, height: int, extent: QgsRectangle, crs: QgsCoordinateReferenceSystem, nBands: int) -> QgsRasterDataProvider|None: ...
    def createOneBandRaster(self, dataType: Qgis.DataType, width: int, height: int, extent: QgsRectangle, crs: QgsCoordinateReferenceSystem) -> QgsRasterDataProvider|None: ...


class QgsRasterFileWriterTask(QgsTask):

    @typing.overload
    @deprecated("""""")
    def __init__(self, writer: QgsRasterFileWriter, pipe: 'QgsRasterPipe|None', columns: int, rows: int, outputExtent: QgsRectangle, crs: QgsCoordinateReferenceSystem) -> None: ...
    @typing.overload
    def __init__(self, writer: QgsRasterFileWriter, pipe: 'QgsRasterPipe|None', columns: int, rows: int, outputExtent: QgsRectangle, crs: QgsCoordinateReferenceSystem, transformContext: QgsCoordinateTransformContext) -> None: ...

    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    writeComplete: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...


class QgsRasterHistogram(PyQt6.sip.wrapper):

    bandNumber = ... # type: int
    binCount = ... # type: int
    extent = ... # type: QgsRectangle
    height = ... # type: int
    histogramVector = ... # type: collections.abc.Iterable[int]
    includeOutOfRange = ... # type: bool
    maximum = ... # type: float
    minimum = ... # type: float
    nonNullCount = ... # type: int
    valid = ... # type: bool
    width = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterHistogram') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsRasterIdentifyResult(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, format: Qgis.RasterIdentifyFormat, results: dict[int, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, error: QgsError) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterIdentifyResult') -> None: ...

    def setError(self, error: QgsError) -> None: ...
    def error(self) -> QgsError: ...
    def params(self) -> dict[str, typing.Any]: ...
    def setParams(self, params: dict[str|None, typing.Any]) -> None: ...
    def results(self) -> dict[int, typing.Any]: ...
    def format(self) -> Qgis.RasterIdentifyFormat: ...
    def isValid(self) -> bool: ...


class QgsRasterBlockFeedback(QgsFeedback):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def setRenderContext(self, renderContext: QgsRenderContext) -> None: ...
    def renderContext(self) -> QgsRenderContext: ...
    def errors(self) -> list[str]: ...
    def appendError(self, error: str|None) -> None: ...
    def setRenderPartialOutput(self, enable: bool) -> None: ...
    def renderPartialOutput(self) -> bool: ...
    def setPreviewOnly(self, preview: bool) -> None: ...
    def isPreviewOnly(self) -> bool: ...
    def onNewData(self) -> None: ...


class QgsRasterIterator(PyQt6.sip.wrapper):

    DEFAULT_MAXIMUM_TILE_HEIGHT = ... # type: int
    DEFAULT_MAXIMUM_TILE_WIDTH = ... # type: int

    @typing.overload
    def __init__(self, input: QgsRasterInterface|None, tileOverlapPixels: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterIterator') -> None: ...

    def progress(self, bandNumber: int, currentBlockProgress: float = ...) -> float: ...
    def blockCount(self) -> int: ...
    def blockCountHeight(self) -> int: ...
    def blockCountWidth(self) -> int: ...
    def maximumTileHeight(self) -> int: ...
    def setMaximumTileHeight(self, h: int) -> None: ...
    def maximumTileWidth(self) -> int: ...
    def setMaximumTileWidth(self, w: int) -> None: ...
    def input(self) -> QgsRasterInterface|None: ...
    def stopRasterRead(self, bandNumber: int) -> None: ...
    def readNextRasterPart(self, bandNumber: int) -> typing.Tuple[bool, int, int, QgsRasterBlock|None, int, int]: ...
    def next(self, bandNumber: int) -> typing.Tuple[bool, int, int, int, int, QgsRectangle]: ...
    def startRasterRead(self, bandNumber: int, nCols: int, nRows: int, extent: QgsRectangle, feedback: QgsRasterBlockFeedback|None = ...) -> None: ...
    @staticmethod
    def subRegion(rasterExtent: QgsRectangle, rasterWidth: int, rasterHeight: int, subRegion: QgsRectangle, resamplingFactor: int = ...) -> typing.Tuple[QgsRectangle, int, int, int, int]: ...
    def snapToPixelFactor(self) -> int: ...
    def setSnapToPixelFactor(self, factor: int) -> None: ...


class QgsAbstractRasterLayerLabeling(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def toSld(self, parent: QtXml.QDomNode, props: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def createFromElement(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsAbstractRasterLayerLabeling|None': ...
    def isInScaleRange(self, scale: float) -> bool: ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> 'QgsAbstractRasterLayerLabeling|None': ...
    def type(self) -> str: ...
    @staticmethod
    def defaultLabelingForLayer(layer: 'QgsRasterLayer|None') -> 'QgsAbstractRasterLayerLabeling|None': ...


class QgsRasterLayerSimpleLabeling(QgsAbstractRasterLayerLabeling):

    def __init__(self) -> None: ...

    def setResampleOver(self, pixels: int) -> None: ...
    def resampleOver(self) -> int: ...
    def setResampleMethod(self, method: Qgis.RasterResamplingMethod) -> None: ...
    def resampleMethod(self) -> Qgis.RasterResamplingMethod: ...
    def isInScaleRange(self, scale: float) -> bool: ...
    def hasScaleBasedVisibility(self) -> bool: ...
    def setScaleBasedVisibility(self, enabled: bool) -> None: ...
    def setMinimumScale(self, scale: float) -> None: ...
    def minimumScale(self) -> float: ...
    def setMaximumScale(self, scale: float) -> None: ...
    def maximumScale(self) -> float: ...
    def setZIndex(self, index: float) -> None: ...
    def zIndex(self) -> float: ...
    def setThinningSettings(self, settings: QgsLabelThinningSettings) -> None: ...
    def thinningSettings(self) -> QgsLabelThinningSettings: ...
    def setPlacementSettings(self, settings: QgsLabelPlacementSettings) -> None: ...
    def placementSettings(self) -> QgsLabelPlacementSettings: ...
    def setPriority(self, priority: float) -> None: ...
    def priority(self) -> float: ...
    def setBand(self, band: int) -> None: ...
    def band(self) -> int: ...
    def setNumericFormat(self, format: QgsNumericFormat|None) -> None: ...
    def numericFormat(self) -> QgsNumericFormat|None: ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsRasterLayerSimpleLabeling|None': ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def requiresAdvancedEffects(self) -> bool: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> 'QgsRasterLayerSimpleLabeling|None': ...
    def type(self) -> str: ...


class QgsRasterLayer(QgsMapLayer, QgsAbstractProfileSource):

    class LayerOptions(PyQt6.sip.wrapper):

        loadDefaultStyle = ... # type: bool
        skipCrsValidation = ... # type: bool
        transformContext = ... # type: QgsCoordinateTransformContext

        @typing.overload
        def __init__(self, loadDefaultStyle: bool = ..., transformContext: QgsCoordinateTransformContext = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterLayer.LayerOptions') -> None: ...

    MULTIPLE_BAND_MULTI_BYTE_ENHANCEMENT_ALGORITHM = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
    MULTIPLE_BAND_MULTI_BYTE_MIN_MAX_LIMITS = ... # type: Qgis.RasterRangeLimit
    MULTIPLE_BAND_SINGLE_BYTE_ENHANCEMENT_ALGORITHM = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
    MULTIPLE_BAND_SINGLE_BYTE_MIN_MAX_LIMITS = ... # type: Qgis.RasterRangeLimit
    SAMPLE_SIZE = ... # type: float
    SINGLE_BAND_ENHANCEMENT_ALGORITHM = ... # type: QgsContrastEnhancement.ContrastEnhancementAlgorithm
    SINGLE_BAND_MIN_MAX_LIMITS = ... # type: Qgis.RasterRangeLimit

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None, baseName: str|None = ..., providerType: str|None = ..., options: 'QgsRasterLayer.LayerOptions' = ...) -> None: ...

    def decodedSource(self, source: str|None, provider: str|None, context: QgsReadWriteContext) -> str: ...
    def encodedSource(self, source: str|None, context: QgsReadWriteContext) -> str: ...
    def writeXml(self, layer_node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, a0: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readXml(self, layer_node: QtXml.QDomNode, context: QgsReadWriteContext) -> bool: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    subsetStringChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTransformContext(self, transformContext: QgsCoordinateTransformContext) -> None: ...
    def showStatusMessage(self, message: str|None) -> None: ...
    def elevationProperties(self) -> QgsMapLayerElevationProperties|None: ...
    def temporalProperties(self) -> QgsMapLayerTemporalProperties|None: ...
    def ignoreExtents(self) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def writeSld(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, props: dict[str|None, typing.Any] = ...) -> bool: ...
    @typing.overload
    def writeSld(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsSldExportContext) -> bool: ...
    def setLabeling(self, labeling: QgsAbstractRasterLayerLabeling|None) -> None: ...
    def labeling(self) -> QgsAbstractRasterLayerLabeling|None: ...
    def setLabelsEnabled(self, enabled: bool) -> None: ...
    def labelsEnabled(self) -> bool: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def timestamp(self) -> QtCore.QDateTime: ...
    def setSubLayerVisibility(self, name: str|None, vis: bool) -> None: ...
    def setLayerOrder(self, layers: collections.abc.Iterable[str|None]) -> None: ...
    def previewAsImage(self, size: QtCore.QSize, bgColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., format: QtGui.QImage.Format = ...) -> QtGui.QImage: ...
    def subLayers(self) -> list[str]: ...
    def setDefaultContrastEnhancement(self) -> None: ...
    def setSubsetString(self, subset: str|None) -> bool: ...
    def subsetString(self) -> str: ...
    def setContrastEnhancement(self, algorithm: QgsContrastEnhancement.ContrastEnhancementAlgorithm, limits: Qgis.RasterRangeLimit = ..., extent: QgsRectangle = ..., sampleSize: int = ..., generateLookupTableFlag: bool = ...) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def rasterUnitsPerPixelY(self) -> float: ...
    def rasterUnitsPerPixelX(self) -> float: ...
    def paletteAsPixmap(self, bandNumber: int = ...) -> QtGui.QPixmap: ...
    def properties(self) -> Qgis.MapLayerProperty: ...
    def htmlMetadata(self) -> str: ...
    def isSpatial(self) -> bool: ...
    @deprecated("""""")
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    def draw(self, theQPainter: QtGui.QPainter|None, myRasterViewPort: 'QgsRasterViewPort|None', qgsMapToPixel: QgsMapToPixel|None = ...) -> None: ...
    def createMapRenderer(self, rendererContext: QgsRenderContext) -> QgsMapLayerRenderer|None: ...
    def reload(self) -> None: ...
    def constDataProvider(self) -> QgsRasterDataProvider|None: ...
    def dataProvider(self) -> QgsRasterDataProvider|None: ...
    def canCreateRasterAttributeTable(self) -> bool: ...
    def attributeTableCount(self) -> int: ...
    def attributeTable(self, bandNumber: int) -> QgsRasterAttributeTable|None: ...
    def bandName(self, bandNoInt: int) -> str: ...
    def bandCount(self) -> int: ...
    def height(self) -> int: ...
    def width(self) -> int: ...
    def pipe(self) -> 'QgsRasterPipe|None': ...
    def resamplingStage(self) -> Qgis.RasterResamplingStage: ...
    def setResamplingStage(self, stage: Qgis.RasterResamplingStage) -> None: ...
    def hueSaturationFilter(self) -> QgsHueSaturationFilter|None: ...
    def brightnessFilter(self) -> QgsBrightnessContrastFilter|None: ...
    def resampleFilter(self) -> 'QgsRasterResampleFilter|None': ...
    def renderer(self) -> QgsRasterRenderer|None: ...
    def setRenderer(self, renderer: QgsRasterRenderer|None) -> None: ...
    def rasterType(self) -> Qgis.RasterLayerType: ...
    @typing.overload
    @deprecated("""""")
    def setDataProvider(self, provider: str|None) -> None: ...
    @typing.overload
    def setDataProvider(self, provider: str|None, options: QgsDataProvider.ProviderOptions, flags: Qgis.DataProviderReadFlag = ...) -> None: ...
    @staticmethod
    def lastModified(name: str|None) -> QtCore.QDateTime: ...
    @typing.overload
    @staticmethod
    def isValidRasterFileName(fileNameQString: str|None, retError: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    def isValidRasterFileName(fileNameQString: str|None) -> bool: ...
    def createProfileGenerator(self, request: QgsProfileRequest) -> QgsAbstractProfileGenerator|None: ...
    def profileSourceName(self) -> str: ...
    def profileSourceId(self) -> str: ...
    def profileSource(self) -> QgsAbstractProfileSource|None: ...
    def clone(self) -> 'QgsRasterLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsRasterLayerElevationProperties(QgsMapLayerElevationProperties):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    @staticmethod
    def layerLooksLikeDem(layer: QgsRasterLayer|None) -> bool: ...
    def setElevationLimit(self, limit: float) -> None: ...
    def elevationLimit(self) -> float: ...
    def setProfileSymbology(self, symbology: Qgis.ProfileSurfaceSymbology) -> None: ...
    def profileSymbology(self) -> Qgis.ProfileSurfaceSymbology: ...
    def setProfileFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def profileFillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setProfileLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def profileLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def bandForElevationRange(self, layer: QgsRasterLayer|None, range: QgsDoubleRange) -> int: ...
    def elevationRangeForPixelValue(self, layer: QgsRasterLayer|None, band: int, pixelValue: float) -> QgsDoubleRange: ...
    def setFixedRangePerBand(self, ranges: dict[int, QgsDoubleRange]) -> None: ...
    def fixedRangePerBand(self) -> dict[int, QgsDoubleRange]: ...
    def setFixedRange(self, range: QgsDoubleRange) -> None: ...
    def fixedRange(self) -> QgsDoubleRange: ...
    def setBandNumber(self, band: int) -> None: ...
    def bandNumber(self) -> int: ...
    def setMode(self, mode: Qgis.RasterElevationMode) -> None: ...
    def mode(self) -> Qgis.RasterElevationMode: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def isEnabled(self) -> bool: ...
    def flags(self) -> QgsMapLayerElevationProperties.Flag: ...
    def showByDefaultInElevationProfilePlots(self) -> bool: ...
    def significantZValues(self, layer: QgsMapLayer|None) -> list[float]: ...
    def calculateZRange(self, layer: QgsMapLayer|None) -> QgsDoubleRange: ...
    def isVisibleInZRange(self, range: QgsDoubleRange, layer: QgsMapLayer|None = ...) -> bool: ...
    def htmlSummary(self) -> str: ...
    def clone(self) -> 'QgsRasterLayerElevationProperties|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def hasElevation(self) -> bool: ...


class QgsRasterLayerTemporalProperties(QgsMapLayerTemporalProperties):

    def __init__(self, parent: QtCore.QObject|None = ..., enabled: bool = ...) -> None: ...

    def setDefaultsFromDataProviderTemporalCapabilities(self, capabilities: QgsDataProviderTemporalCapabilities|None) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def setTemporalRepresentationScale(self, scale: QgsInterval) -> None: ...
    def temporalRepresentationScale(self) -> QgsInterval: ...
    def setAccumulatePixels(self, accumulate: bool) -> None: ...
    def accumulatePixels(self) -> bool: ...
    def setTemporalRepresentationOffset(self, offset: QtCore.QDateTime|datetime.datetime) -> None: ...
    def temporalRepresentationOffset(self) -> QtCore.QDateTime: ...
    def setBandNumber(self, number: int) -> None: ...
    def bandNumber(self) -> int: ...
    def filteredBandsForTemporalRange(self, layer: QgsRasterLayer|None, range: QgsDateTimeRange) -> list[int]: ...
    def bandForTemporalRange(self, layer: QgsRasterLayer|None, range: QgsDateTimeRange) -> int: ...
    def setFixedRangePerBand(self, ranges: dict[int, QgsDateTimeRange]) -> None: ...
    def fixedRangePerBand(self) -> dict[int, QgsDateTimeRange]: ...
    def fixedTemporalRange(self) -> QgsDateTimeRange: ...
    def setFixedTemporalRange(self, range: QgsDateTimeRange) -> None: ...
    def setIntervalHandlingMethod(self, method: Qgis.TemporalIntervalMatchMethod) -> None: ...
    def intervalHandlingMethod(self) -> Qgis.TemporalIntervalMatchMethod: ...
    def flags(self) -> QgsTemporalProperty.Flag: ...
    def setMode(self, mode: Qgis.RasterTemporalMode) -> None: ...
    def mode(self) -> Qgis.RasterTemporalMode: ...
    def allTemporalRanges(self, layer: QgsMapLayer|None) -> list[QgsDateTimeRange]: ...
    def isVisibleInTemporalRange(self, range: QgsDateTimeRange) -> bool: ...


class QgsRasterLayerUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterLayerUtils') -> None: ...

    @staticmethod
    def alignRasterExtent(extent: QgsRectangle, origin: QgsPointXY, pixelSizeX: float, pixelSizeY: float) -> QgsRectangle: ...
    @staticmethod
    def computeMinMax(provider: QgsRasterDataProvider|None, band: int, mmo: 'QgsRasterMinMaxOrigin', limits: Qgis.RasterRangeLimit, extent: QgsRectangle, sampleSize: int) -> typing.Tuple[float, float]: ...
    @staticmethod
    def renderedBandForElevationAndTemporalRange(layer: QgsRasterLayer|None, temporalRange: QgsDateTimeRange, elevationRange: QgsDoubleRange) -> typing.Tuple[int, bool]: ...


class QgsRasterMinMaxOrigin(PyQt6.sip.wrapper):

    CUMULATIVE_CUT_LOWER = ... # type: float
    CUMULATIVE_CUT_UPPER = ... # type: float
    DEFAULT_STDDEV_FACTOR = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterMinMaxOrigin') -> None: ...

    def __ne__(self, other: object): ...
    @staticmethod
    def statAccuracyFromString(accuracy: str|None) -> Qgis.RasterRangeAccuracy: ...
    @staticmethod
    def statAccuracyString(accuracy: Qgis.RasterRangeAccuracy) -> str: ...
    @staticmethod
    def extentFromString(extent: str|None) -> Qgis.RasterRangeExtent: ...
    @staticmethod
    def extentString(extent: Qgis.RasterRangeExtent) -> str: ...
    @staticmethod
    def limitsFromString(limits: str|None) -> Qgis.RasterRangeLimit: ...
    @staticmethod
    def limitsString(limits: Qgis.RasterRangeLimit) -> str: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def setStdDevFactor(self, val: float) -> None: ...
    def setCumulativeCutUpper(self, val: float) -> None: ...
    def setCumulativeCutLower(self, val: float) -> None: ...
    def setStatAccuracy(self, accuracy: Qgis.RasterRangeAccuracy) -> None: ...
    def setExtent(self, extent: Qgis.RasterRangeExtent) -> None: ...
    def setLimits(self, limits: Qgis.RasterRangeLimit) -> None: ...
    def stdDevFactor(self) -> float: ...
    def cumulativeCutUpper(self) -> float: ...
    def cumulativeCutLower(self) -> float: ...
    def statAccuracy(self) -> Qgis.RasterRangeAccuracy: ...
    def extent(self) -> Qgis.RasterRangeExtent: ...
    def limits(self) -> Qgis.RasterRangeLimit: ...
    def __eq__(self, other: object): ...


class QgsRasterNuller(QgsRasterInterface):

    class NoData(PyQt6.sip.wrapper):

        max = ... # type: float
        min = ... # type: float

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterNuller.NoData') -> None: ...

    def __init__(self, input: QgsRasterInterface|None = ...) -> None: ...

    def setOutputNoDataValue(self, bandNo: int, noData: float) -> None: ...
    def noData(self, bandNo: int) -> list['QgsRasterRange']: ...
    def setNoData(self, bandNo: int, noData: collections.abc.Iterable['QgsRasterRange']) -> None: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def bandCount(self) -> int: ...
    def clone(self) -> 'QgsRasterNuller|None': ...


class QgsRasterPipe(PyQt6.sip.wrapper):

    class Property(enum.IntEnum):
        RendererOpacity = ... # type: QgsRasterPipe.Property

    def __init__(self) -> None: ...

    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    def evaluateDataDefinedProperties(self, context: QgsExpressionContext) -> None: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def resamplingStage(self) -> Qgis.RasterResamplingStage: ...
    def setResamplingStage(self, stage: Qgis.RasterResamplingStage) -> None: ...
    def nuller(self) -> QgsRasterNuller|None: ...
    def projector(self) -> 'QgsRasterProjector|None': ...
    def hueSaturationFilter(self) -> QgsHueSaturationFilter|None: ...
    def brightnessFilter(self) -> QgsBrightnessContrastFilter|None: ...
    def resampleFilter(self) -> 'QgsRasterResampleFilter|None': ...
    def renderer(self) -> QgsRasterRenderer|None: ...
    def provider(self) -> QgsRasterDataProvider|None: ...
    def canSetOn(self, idx: int, on: bool) -> bool: ...
    def setOn(self, idx: int, on: bool) -> bool: ...
    def last(self) -> QgsRasterInterface|None: ...
    def at(self, idx: int) -> QgsRasterInterface|None: ...
    def size(self) -> int: ...
    @typing.overload
    def remove(self, idx: int) -> bool: ...
    @typing.overload
    def remove(self, interface: QgsRasterInterface|None) -> bool: ...
    def set(self, interface: QgsRasterInterface|None) -> bool: ...
    def replace(self, idx: int, interface: QgsRasterInterface|None) -> bool: ...
    def insert(self, idx: int, interface: QgsRasterInterface|None) -> bool: ...
    def moveToThread(self, thread: QtCore.QThread|None) -> None: ...


class QgsRasterProjector(QgsRasterInterface):

    class Precision(enum.IntEnum):
        Approximate = ... # type: QgsRasterProjector.Precision
        Exact = ... # type: QgsRasterProjector.Precision

    staticMetaObject = ... # type: QtCore.QMetaObject

    def __init__(self) -> None: ...

    @staticmethod
    def extentSize(ct: QgsCoordinateTransform, srcExtent: QgsRectangle, srcXSize: int, srcYSize: int) -> typing.Tuple[bool, QgsRectangle, int, int]: ...
    def destExtentSize(self, srcExtent: QgsRectangle, srcXSize: int, srcYSize: int) -> typing.Tuple[bool, QgsRectangle, int, int]: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    @staticmethod
    def precisionLabel(precision: 'QgsRasterProjector.Precision') -> str: ...
    def setPrecision(self, precision: 'QgsRasterProjector.Precision') -> None: ...
    def precision(self) -> 'QgsRasterProjector.Precision': ...
    def destinationCrs(self) -> QgsCoordinateReferenceSystem: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    @typing.overload
    @deprecated("""""")
    def setCrs(self, srcCRS: QgsCoordinateReferenceSystem, destCRS: QgsCoordinateReferenceSystem, srcDatumTransform: int = ..., destDatumTransform: int = ...) -> None: ...
    @typing.overload
    def setCrs(self, srcCRS: QgsCoordinateReferenceSystem, destCRS: QgsCoordinateReferenceSystem, transformContext: QgsCoordinateTransformContext) -> None: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def bandCount(self) -> int: ...
    def clone(self) -> 'QgsRasterProjector|None': ...


class QgsRasterPyramid(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterPyramid') -> None: ...

    def setBuild(self, build: bool) -> None: ...
    def getBuild(self) -> bool: ...
    def setExists(self, exists: bool) -> None: ...
    def getExists(self) -> bool: ...
    def getYDim(self) -> int: ...
    def setYDim(self, dimension: int) -> None: ...
    def getXDim(self) -> int: ...
    def setXDim(self, dimension: int) -> None: ...
    def setLevel(self, level: int) -> None: ...
    def getLevel(self) -> int: ...
    @property
    def build(self) -> bool: ...
    @build.setter
    def build(self, build: bool) -> None: ...
    @property
    def exists(self) -> bool: ...
    @exists.setter
    def exists(self, exists: bool) -> None: ...
    @property
    def yDim(self) -> int: ...
    @yDim.setter
    def yDim(self, dimension: int) -> None: ...
    @property
    def xDim(self) -> int: ...
    @xDim.setter
    def xDim(self, dimension: int) -> None: ...
    @property
    def level(self) -> int: ...
    @level.setter
    def level(self, level: int) -> None: ...


class QgsRasterRange(PyQt6.sip.wrapper):

    class BoundsType(enum.IntEnum):
        IncludeMinAndMax = ... # type: QgsRasterRange.BoundsType
        IncludeMax = ... # type: QgsRasterRange.BoundsType
        IncludeMin = ... # type: QgsRasterRange.BoundsType
        Exclusive = ... # type: QgsRasterRange.BoundsType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, min: float, max: float, bounds: 'QgsRasterRange.BoundsType' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterRange') -> None: ...

    def __ne__(self, other: object): ...
    def asText(self) -> str: ...
    def overlaps(self, other: 'QgsRasterRange') -> bool: ...
    @typing.overload
    def contains(self, value: float) -> bool: ...
    @typing.overload
    @staticmethod
    def contains(value: float, rangeList: collections.abc.Iterable['QgsRasterRange']) -> bool: ...
    def __eq__(self, other: object): ...
    def setBounds(self, type: 'QgsRasterRange.BoundsType') -> None: ...
    def setMax(self, max: float) -> float: ...
    def setMin(self, min: float) -> float: ...
    def bounds(self) -> 'QgsRasterRange.BoundsType': ...
    def max(self) -> float: ...
    def min(self) -> float: ...


class QgsRasterRendererRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterRendererRegistry') -> None: ...

    def defaultRendererForDrawingStyle(self, drawingStyle: Qgis.RasterDrawingStyle, provider: QgsRasterDataProvider|None) -> QgsRasterRenderer|None: ...
    def rendererCapabilities(self, rendererName: str|None) -> Qgis.RasterRendererCapability: ...
    def renderersList(self) -> list[str]: ...


class QgsRasterRendererUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterRendererUtils') -> None: ...

    @staticmethod
    def saveColorMapFile(path: str|None, items: collections.abc.Iterable[QgsColorRampShader.ColorRampItem], type: Qgis.ShaderInterpolationMethod) -> bool: ...
    @staticmethod
    def parseColorMapFile(path: str|None) -> typing.Tuple[bool, list[QgsColorRampShader.ColorRampItem], Qgis.ShaderInterpolationMethod, list[str]]: ...


class QgsRasterResampleFilter(QgsRasterInterface):

    def __init__(self, input: QgsRasterInterface|None = ...) -> None: ...

    def readXml(self, filterElem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def maxOversampling(self) -> float: ...
    def setMaxOversampling(self, os: float) -> None: ...
    def zoomedOutResampler(self) -> QgsRasterResampler|None: ...
    def setZoomedOutResampler(self, r: QgsRasterResampler|None) -> None: ...
    def zoomedInResampler(self) -> QgsRasterResampler|None: ...
    def setZoomedInResampler(self, r: QgsRasterResampler|None) -> None: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    def setInput(self, input: QgsRasterInterface|None) -> bool: ...
    def dataType(self, bandNo: int) -> Qgis.DataType: ...
    def bandCount(self) -> int: ...
    def clone(self) -> 'QgsRasterResampleFilter|None': ...


class QgsRasterShader(PyQt6.sip.wrapper):

    def __init__(self, minimumValue: float = ..., maximumValue: float = ...) -> None: ...

    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parent: QtXml.QDomElement, context: QgsReadWriteContext = ...) -> None: ...
    def setMinimumValue(self, value: float) -> None: ...
    def setMaximumValue(self, value: float) -> None: ...
    def setRasterShaderFunction(self, function: QgsRasterShaderFunction|None) -> None: ...
    @typing.overload
    def shade(self, value: float) -> typing.Tuple[bool, int, int, int, int]: ...
    @typing.overload
    def shade(self, redValue: float, greenValue: float, blueValue: float, alphaValue: float) -> typing.Tuple[bool, int, int, int, int]: ...
    def rasterShaderFunction(self) -> QgsRasterShaderFunction|None: ...
    def minimumValue(self) -> float: ...
    def maximumValue(self) -> float: ...


class QgsRasterTransparency(PyQt6.sip.wrapper):

    class TransparentThreeValuePixel(PyQt6.sip.wrapper):

        blue = ... # type: float
        fuzzyToleranceBlue = ... # type: float
        fuzzyToleranceGreen = ... # type: float
        fuzzyToleranceRed = ... # type: float
        green = ... # type: float
        opacity = ... # type: float
        red = ... # type: float

        @typing.overload
        def __init__(self, red: float = ..., green: float = ..., blue: float = ..., opacity: float = ..., fuzzyToleranceRed: float = ..., fuzzyToleranceGreen: float = ..., fuzzyToleranceBlue: float = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterTransparency.TransparentThreeValuePixel') -> None: ...

        def __repr__(self) -> typing.Any: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    class TransparentSingleValuePixel(PyQt6.sip.wrapper):

        includeMaximum = ... # type: bool
        includeMinimum = ... # type: bool
        max = ... # type: float
        min = ... # type: float
        opacity = ... # type: float

        @typing.overload
        def __init__(self, minimum: float = ..., maximum: float = ..., opacity: float = ..., includeMinimum: bool = ..., includeMaximum: bool = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRasterTransparency.TransparentSingleValuePixel') -> None: ...

        def __repr__(self) -> typing.Any: ...
        def __ne__(self, other: object): ...
        def __eq__(self, other: object): ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterTransparency') -> None: ...

    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def isEmpty(self) -> bool: ...
    def opacityForRgbValues(self, redValue: float, greenValue: float, blueValue: float) -> float: ...
    def opacityForValue(self, value: float) -> float: ...
    @typing.overload
    @deprecated("""""")
    def alphaValue(self, value: float, globalTransparency: int = ...) -> int: ...
    @typing.overload
    @deprecated("""""")
    def alphaValue(self, redValue: float, greenValue: float, blueValue: float, globalTransparency: int = ...) -> int: ...
    def setTransparentThreeValuePixelList(self, newList: collections.abc.Iterable['QgsRasterTransparency.TransparentThreeValuePixel']) -> None: ...
    def setTransparentSingleValuePixelList(self, newList: collections.abc.Iterable['QgsRasterTransparency.TransparentSingleValuePixel']) -> None: ...
    @typing.overload
    def initializeTransparentPixelList(self, value: float) -> None: ...
    @typing.overload
    def initializeTransparentPixelList(self, redValue: float, greenValue: float, blueValue: float) -> None: ...
    def transparentThreeValuePixelList(self) -> list['QgsRasterTransparency.TransparentThreeValuePixel']: ...
    def transparentSingleValuePixelList(self) -> list['QgsRasterTransparency.TransparentSingleValuePixel']: ...


class QgsRasterViewPort(PyQt6.sip.wrapper):

    mBottomRightPoint = ... # type: QgsPointXY
    mDestCRS = ... # type: QgsCoordinateReferenceSystem
    mDrawnExtent = ... # type: QgsRectangle
    mHeight = ... # type: int
    mSrcCRS = ... # type: QgsCoordinateReferenceSystem
    mTopLeftPoint = ... # type: QgsPointXY
    mTransformContext = ... # type: QgsCoordinateTransformContext
    mWidth = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRasterViewPort') -> None: ...


class QgsSingleBandColorDataRenderer(QgsRasterRenderer):

    def __init__(self, input: QgsRasterInterface|None, band: int) -> None: ...

    def usesBands(self) -> list[int]: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    def setInput(self, input: QgsRasterInterface|None) -> bool: ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsSingleBandColorDataRenderer|None': ...


class QgsSingleBandGrayRenderer(QgsRasterRenderer):

    class Gradient(enum.IntEnum):
        BlackToWhite = ... # type: QgsSingleBandGrayRenderer.Gradient
        WhiteToBlack = ... # type: QgsSingleBandGrayRenderer.Gradient

    def __init__(self, input: QgsRasterInterface|None, grayBand: int) -> None: ...

    def setLegendSettings(self, settings: QgsColorRampLegendNodeSettings|None) -> None: ...
    def legendSettings(self) -> QgsColorRampLegendNodeSettings|None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def usesBands(self) -> list[int]: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def gradient(self) -> 'QgsSingleBandGrayRenderer.Gradient': ...
    def setGradient(self, gradient: 'QgsSingleBandGrayRenderer.Gradient') -> None: ...
    def setContrastEnhancement(self, ce: QgsContrastEnhancement|None) -> None: ...
    def contrastEnhancement(self) -> QgsContrastEnhancement|None: ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    @deprecated("""""")
    def setGrayBand(self, band: int) -> None: ...
    @deprecated("""""")
    def grayBand(self) -> int: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsSingleBandGrayRenderer|None': ...


class QgsSingleBandPseudoColorRenderer(QgsRasterRenderer):

    def __init__(self, input: QgsRasterInterface|None, band: int = ..., shader: QgsRasterShader|None = ...) -> None: ...

    def setClassificationMax(self, max: float) -> None: ...
    def setClassificationMin(self, min: float) -> None: ...
    def classificationMax(self) -> float: ...
    def classificationMin(self) -> float: ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    @deprecated("""""")
    def setBand(self, bandNo: int) -> None: ...
    @deprecated("""""")
    def band(self) -> int: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def usesBands(self) -> list[int]: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def legendSymbologyItems(self) -> list[tuple[str, QtGui.QColor]]: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def createShader(self, colorRamp: QgsColorRamp|None = ..., colorRampType: Qgis.ShaderInterpolationMethod = ..., classificationMode: Qgis.ShaderClassificationMethod = ..., classes: int = ..., clip: bool = ..., extent: QgsRectangle = ...) -> None: ...
    def canCreateRasterAttributeTable(self) -> bool: ...
    def constShader(self) -> QgsRasterShader|None: ...
    def shader(self) -> QgsRasterShader|None: ...
    def setShader(self, shader: QgsRasterShader|None) -> None: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsSingleBandPseudoColorRenderer|None': ...


class QgsRasterSingleColorRenderer(QgsRasterRenderer):

    def __init__(self, input: QgsRasterInterface|None, band: int, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...

    def usesBands(self) -> list[int]: ...
    def setInputBand(self, band: int) -> bool: ...
    def inputBand(self) -> int: ...
    def writeXml(self, doc: QtXml.QDomDocument, parentElem: QtXml.QDomElement) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def block(self, bandNo: int, extent: QgsRectangle, width: int, height: int, feedback: QgsRasterBlockFeedback|None = ...) -> QgsRasterBlock|None: ...
    @staticmethod
    def create(elem: QtXml.QDomElement, input: QgsRasterInterface|None) -> QgsRasterRenderer|None: ...
    def flags(self) -> Qgis.RasterRendererFlag: ...
    def clone(self) -> 'QgsRasterSingleColorRenderer|None': ...


class QgsScaleBarRenderer(PyQt6.sip.wrapper):

    class Flag(enum.IntFlag):
        FlagUsesLineSymbol = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesFillSymbol = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesAlternateFillSymbol = ... # type: QgsScaleBarRenderer.Flag
        FlagRespectsUnits = ... # type: QgsScaleBarRenderer.Flag
        FlagRespectsMapUnitsPerScaleBarUnit = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesUnitLabel = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesSegments = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesLabelBarSpace = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesLabelVerticalPlacement = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesLabelHorizontalPlacement = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesAlignment = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesSubdivisions = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesDivisionSymbol = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesSubdivisionSymbol = ... # type: QgsScaleBarRenderer.Flag
        FlagUsesSubdivisionsHeight = ... # type: QgsScaleBarRenderer.Flag

    class ScaleBarContext(PyQt6.sip.wrapper):

        flags = ... # type: 'QgsScaleBarRenderer.Flag'
        scale = ... # type: float
        segmentWidth = ... # type: float
        size = ... # type: QtCore.QSizeF

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsScaleBarRenderer.ScaleBarContext') -> None: ...

        def isValid(self) -> bool: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScaleBarRenderer') -> None: ...

    def segmentWidths(self, scaleContext: 'QgsScaleBarRenderer.ScaleBarContext', settings: 'QgsScaleBarSettings') -> list[float]: ...
    @typing.overload
    @deprecated("""""")
    def segmentPositions(self, scaleContext: 'QgsScaleBarRenderer.ScaleBarContext', settings: 'QgsScaleBarSettings') -> list[float]: ...
    @typing.overload
    def segmentPositions(self, context: QgsRenderContext, scaleContext: 'QgsScaleBarRenderer.ScaleBarContext', settings: 'QgsScaleBarSettings') -> list[float]: ...
    @typing.overload
    @deprecated("""""")
    def firstLabelXOffset(self, settings: 'QgsScaleBarSettings') -> float: ...
    @typing.overload
    def firstLabelXOffset(self, settings: 'QgsScaleBarSettings', context: QgsRenderContext, scaleContext: 'QgsScaleBarRenderer.ScaleBarContext') -> float: ...
    def firstLabelString(self, settings: 'QgsScaleBarSettings') -> str: ...
    def drawDefaultLabels(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: 'QgsScaleBarRenderer.ScaleBarContext') -> None: ...
    def applyDefaultSettings(self, settings: 'QgsScaleBarSettings') -> bool: ...
    @typing.overload
    @deprecated("""""")
    def calculateBoxSize(self, settings: 'QgsScaleBarSettings', scaleContext: 'QgsScaleBarRenderer.ScaleBarContext') -> QtCore.QSizeF: ...
    @typing.overload
    def calculateBoxSize(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: 'QgsScaleBarRenderer.ScaleBarContext') -> QtCore.QSizeF: ...
    def draw(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: 'QgsScaleBarRenderer.ScaleBarContext') -> None: ...
    def clone(self) -> 'QgsScaleBarRenderer|None': ...
    def sortKey(self) -> int: ...
    def flags(self) -> 'QgsScaleBarRenderer.Flag': ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...
    @deprecated("""""")
    def name(self) -> str: ...


class QgsDoubleBoxScaleBarRenderer(QgsScaleBarRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDoubleBoxScaleBarRenderer') -> None: ...

    def applyDefaultSettings(self, settings: 'QgsScaleBarSettings') -> bool: ...
    def draw(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> None: ...
    def clone(self) -> 'QgsDoubleBoxScaleBarRenderer|None': ...
    def sortKey(self) -> int: ...
    def flags(self) -> QgsScaleBarRenderer.Flag: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsHollowScaleBarRenderer(QgsScaleBarRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHollowScaleBarRenderer') -> None: ...

    def applyDefaultSettings(self, settings: 'QgsScaleBarSettings') -> bool: ...
    def draw(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> None: ...
    def clone(self) -> 'QgsHollowScaleBarRenderer|None': ...
    def sortKey(self) -> int: ...
    def flags(self) -> QgsScaleBarRenderer.Flag: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsNumericScaleBarRenderer(QgsScaleBarRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNumericScaleBarRenderer') -> None: ...

    @typing.overload
    def calculateBoxSize(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> QtCore.QSizeF: ...
    @typing.overload
    @deprecated("""""")
    def calculateBoxSize(self, settings: 'QgsScaleBarSettings', scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> QtCore.QSizeF: ...
    def draw(self, context: QgsRenderContext, settings: 'QgsScaleBarSettings', scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> None: ...
    def clone(self) -> 'QgsNumericScaleBarRenderer|None': ...
    def flags(self) -> QgsScaleBarRenderer.Flag: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsScaleBarRendererRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScaleBarRendererRegistry') -> None: ...

    def sortKey(self, id: str|None) -> int: ...
    def visibleName(self, id: str|None) -> str: ...
    def renderer(self, id: str|None) -> QgsScaleBarRenderer|None: ...
    def removeRenderer(self, id: str|None) -> None: ...
    def addRenderer(self, renderer: QgsScaleBarRenderer|None) -> None: ...
    def sortedRendererList(self) -> list[str]: ...
    def renderers(self) -> list[str]: ...


class QgsScaleBarSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsScaleBarSettings') -> None: ...

    def setNumericFormat(self, format: QgsNumericFormat|None) -> None: ...
    def numericFormat(self) -> QgsNumericFormat|None: ...
    @deprecated("""""")
    def setLineCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    @deprecated("""""")
    def lineCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    @deprecated("""""")
    def setLineJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    @deprecated("""""")
    def lineJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setAlignment(self, alignment: Qgis.ScaleBarAlignment) -> None: ...
    def alignment(self) -> Qgis.ScaleBarAlignment: ...
    def setBoxContentSpace(self, space: float) -> None: ...
    def boxContentSpace(self) -> float: ...
    def setLabelHorizontalPlacement(self, placement: Qgis.ScaleBarDistanceLabelHorizontalPlacement) -> None: ...
    def labelHorizontalPlacement(self) -> Qgis.ScaleBarDistanceLabelHorizontalPlacement: ...
    def setLabelVerticalPlacement(self, placement: Qgis.ScaleBarDistanceLabelVerticalPlacement) -> None: ...
    def labelVerticalPlacement(self) -> Qgis.ScaleBarDistanceLabelVerticalPlacement: ...
    def setLabelBarSpace(self, space: float) -> None: ...
    def labelBarSpace(self) -> float: ...
    def setHeight(self, height: float) -> None: ...
    def height(self) -> float: ...
    @deprecated("""""")
    def setBrush2(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    @deprecated("""""")
    def brush2(self) -> QtGui.QBrush: ...
    @deprecated("""""")
    def setBrush(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    @deprecated("""""")
    def brush(self) -> QtGui.QBrush: ...
    def setAlternateFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def alternateFillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setFillSymbol(self, symbol: 'QgsFillSymbol|None') -> None: ...
    def fillSymbol(self) -> 'QgsFillSymbol|None': ...
    def setSubdivisionLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def subdivisionLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setDivisionLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def divisionLineSymbol(self) -> 'QgsLineSymbol|None': ...
    def setLineSymbol(self, symbol: 'QgsLineSymbol|None') -> None: ...
    def lineSymbol(self) -> 'QgsLineSymbol|None': ...
    @deprecated("""""")
    def setPen(self, pen: QtGui.QPen|QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def pen(self) -> QtGui.QPen: ...
    @deprecated("""""")
    def setLineWidth(self, width: float) -> None: ...
    @deprecated("""""")
    def lineWidth(self) -> float: ...
    @deprecated("""""")
    def setLineColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def lineColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFillColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fillColor2(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fillColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFontColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def fontColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def setFont(self, font: QtGui.QFont) -> None: ...
    @deprecated("""""")
    def font(self) -> QtGui.QFont: ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def setUnitLabel(self, label: str|None) -> None: ...
    def unitLabel(self) -> str: ...
    def setMapUnitsPerScaleBarUnit(self, units: float) -> None: ...
    def mapUnitsPerScaleBarUnit(self) -> float: ...
    def setUnits(self, units: Qgis.DistanceUnit) -> None: ...
    def units(self) -> Qgis.DistanceUnit: ...
    def setMaximumBarWidth(self, width: float) -> None: ...
    def maximumBarWidth(self) -> float: ...
    def setMinimumBarWidth(self, width: float) -> None: ...
    def minimumBarWidth(self) -> float: ...
    def setSegmentSizeMode(self, mode: Qgis.ScaleBarSegmentSizeMode) -> None: ...
    def segmentSizeMode(self) -> Qgis.ScaleBarSegmentSizeMode: ...
    def setUnitsPerSegment(self, units: float) -> None: ...
    def unitsPerSegment(self) -> float: ...
    def setSubdivisionsHeight(self, height: float) -> None: ...
    def subdivisionsHeight(self) -> float: ...
    def setNumberOfSubdivisions(self, subdivisions: int) -> None: ...
    def numberOfSubdivisions(self) -> int: ...
    def setNumberOfSegmentsLeft(self, segments: int) -> None: ...
    def numberOfSegmentsLeft(self) -> int: ...
    def setNumberOfSegments(self, segments: int) -> None: ...
    def numberOfSegments(self) -> int: ...


class QgsSingleBoxScaleBarRenderer(QgsScaleBarRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSingleBoxScaleBarRenderer') -> None: ...

    def applyDefaultSettings(self, settings: QgsScaleBarSettings) -> bool: ...
    def draw(self, context: QgsRenderContext, settings: QgsScaleBarSettings, scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> None: ...
    def clone(self) -> 'QgsSingleBoxScaleBarRenderer|None': ...
    def flags(self) -> QgsScaleBarRenderer.Flag: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsSteppedLineScaleBarRenderer(QgsScaleBarRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSteppedLineScaleBarRenderer') -> None: ...

    def draw(self, context: QgsRenderContext, settings: QgsScaleBarSettings, scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> None: ...
    def clone(self) -> 'QgsSteppedLineScaleBarRenderer|None': ...
    def flags(self) -> QgsScaleBarRenderer.Flag: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsTicksScaleBarRenderer(QgsScaleBarRenderer):

    class TickPosition(enum.IntEnum):
        TicksUp = ... # type: QgsTicksScaleBarRenderer.TickPosition
        TicksDown = ... # type: QgsTicksScaleBarRenderer.TickPosition
        TicksMiddle = ... # type: QgsTicksScaleBarRenderer.TickPosition

    @typing.overload
    def __init__(self, position: 'QgsTicksScaleBarRenderer.TickPosition' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTicksScaleBarRenderer') -> None: ...

    def tickPosition(self) -> 'QgsTicksScaleBarRenderer.TickPosition': ...
    def setTickPosition(self, position: 'QgsTicksScaleBarRenderer.TickPosition') -> None: ...
    def draw(self, context: QgsRenderContext, settings: QgsScaleBarSettings, scaleContext: QgsScaleBarRenderer.ScaleBarContext) -> None: ...
    def clone(self) -> 'QgsTicksScaleBarRenderer|None': ...
    def flags(self) -> QgsScaleBarRenderer.Flag: ...
    def sortKey(self) -> int: ...
    def visibleName(self) -> str: ...
    def id(self) -> str: ...


class QgsStacAsset(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, href: str|None, title: str|None, description: str|None, mediaType: str|None, roles: collections.abc.Iterable[str|None]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacAsset') -> None: ...

    def isDownloadable(self) -> bool: ...
    def toHtml(self, assetId: str|None) -> str: ...
    def uri(self, authcfg: str|None = ...) -> QgsMimeDataUtils.Uri: ...
    def formatName(self) -> str: ...
    def isCloudOptimized(self) -> bool: ...
    def roles(self) -> list[str]: ...
    def mediaType(self) -> str: ...
    def description(self) -> str: ...
    def title(self) -> str: ...
    def href(self) -> str: ...


class QgsStacObject(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, id: str|None, version: str|None, links: collections.abc.Iterable['QgsStacLink']) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacObject') -> None: ...

    def parentUrl(self) -> str: ...
    def rootUrl(self) -> str: ...
    def url(self) -> str: ...
    def setLinks(self, links: collections.abc.Iterable['QgsStacLink']) -> None: ...
    def links(self) -> list['QgsStacLink']: ...
    def setId(self, id: str|None) -> None: ...
    def id(self) -> str: ...
    def setStacExtensions(self, stacExtensions: collections.abc.Iterable[str|None]) -> None: ...
    def stacExtensions(self) -> list[str]: ...
    def setStacVersion(self, stacVersion: str|None) -> None: ...
    def stacVersion(self) -> str: ...
    def toHtml(self) -> str: ...
    def type(self) -> Qgis.StacObjectType: ...


class QgsStacCatalog(QgsStacObject):

    @typing.overload
    def __init__(self, id: str|None, version: str|None, description: str|None, links: collections.abc.Iterable['QgsStacLink']) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacCatalog') -> None: ...

    def conformsTo(self, conformanceClass: str|None) -> bool: ...
    def addConformanceClass(self, conformanceClass: str|None) -> None: ...
    def setConformanceClasses(self, conformanceClasses: collections.abc.Iterable[str|None]) -> None: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def toHtml(self) -> str: ...
    def type(self) -> Qgis.StacObjectType: ...


class QgsStacCollection(QgsStacCatalog):

    @typing.overload
    def __init__(self, id: str|None, version: str|None, description: str|None, links: collections.abc.Iterable['QgsStacLink'], license: str|None, extent: 'QgsStacExtent') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacCollection') -> None: ...

    def setAssets(self, assets: dict[str|None, QgsStacAsset]) -> None: ...
    def assets(self) -> dict[str, QgsStacAsset]: ...
    def setSummaries(self, summaries: dict[str|None, typing.Any]) -> None: ...
    def summaries(self) -> dict[str, typing.Any]: ...
    def setExtent(self, extent: 'QgsStacExtent') -> None: ...
    def extent(self) -> 'QgsStacExtent': ...
    def setProviders(self, providers: collections.abc.Iterable['QgsStacProvider']) -> None: ...
    def providers(self) -> list['QgsStacProvider']: ...
    def setLicense(self, license: str|None) -> None: ...
    def license(self) -> str: ...
    def setKeywords(self, keywords: collections.abc.Iterable[str|None]) -> None: ...
    def keywords(self) -> list[str]: ...
    def toHtml(self) -> str: ...
    def type(self) -> Qgis.StacObjectType: ...


class QgsStacCollectionList(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, collections: collections.abc.Iterable[QgsStacCollection], links: collections.abc.Iterable['QgsStacLink'], numberMatched: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacCollectionList') -> None: ...

    def prevUrl(self) -> QtCore.QUrl: ...
    def nextUrl(self) -> QtCore.QUrl: ...
    def rootUrl(self) -> QtCore.QUrl: ...
    def url(self) -> QtCore.QUrl: ...
    def numberMatched(self) -> int: ...
    def numberReturned(self) -> int: ...
    def takeCollections(self) -> list[QgsStacCollection]: ...
    def collections(self) -> list[QgsStacCollection]: ...


class QgsStacConnection(QgsAbstractProviderConnection):

    class Data(PyQt6.sip.wrapper):

        authCfg = ... # type: str|None
        httpHeaders = ... # type: QgsHttpHeaders
        password = ... # type: str|None
        url = ... # type: str|None
        username = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsStacConnection.Data') -> None: ...

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None, configuration: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacConnection') -> None: ...

    @staticmethod
    def setSelectedConnection(connName: str|None) -> None: ...
    @staticmethod
    def selectedConnection() -> str: ...
    @staticmethod
    def addConnection(name: str|None, conn: 'QgsStacConnection.Data') -> None: ...
    @staticmethod
    def deleteConnection(name: str|None) -> None: ...
    @staticmethod
    def connection(name: str|None) -> 'QgsStacConnection.Data': ...
    @staticmethod
    def connectionList() -> list[str]: ...
    @staticmethod
    def decodedUri(uri: str|None) -> 'QgsStacConnection.Data': ...
    @staticmethod
    def encodedUri(conn: 'QgsStacConnection.Data') -> str: ...
    def remove(self, name: str|None) -> None: ...
    def store(self, name: str|None) -> None: ...


class QgsStacController(QtCore.QObject):

    def __init__(self) -> None: ...

    finishedCollectionsRequest: typing.ClassVar[QtCore.pyqtSignal]
    finishedItemCollectionRequest: typing.ClassVar[QtCore.pyqtSignal]
    finishedStacObjectRequest: typing.ClassVar[QtCore.pyqtSignal]
    def setAuthCfg(self, authCfg: str|None) -> None: ...
    def authCfg(self) -> str: ...
    def takeCollections(self, requestId: int) -> QgsStacCollectionList|None: ...
    def takeItemCollection(self, requestId: int) -> 'QgsStacItemCollection'|None: ...
    def cancelPendingAsyncRequests(self) -> None: ...
    def fetchCollectionsAsync(self, url: QtCore.QUrl) -> int: ...
    def fetchItemCollectionAsync(self, url: QtCore.QUrl) -> int: ...
    def fetchStacObjectAsync(self, url: QtCore.QUrl) -> int: ...
    def fetchCollections(self, url: QtCore.QUrl, error: str|None = ...) -> QgsStacCollectionList|None: ...
    def fetchItemCollection(self, url: QtCore.QUrl, error: str|None = ...) -> 'QgsStacItemCollection'|None: ...
    def openLocalItem(self, fileName: str|None) -> 'QgsStacItem'|None: ...
    def openLocalCollection(self, fileName: str|None) -> QgsStacCollection|None: ...
    def openLocalCatalog(self, fileName: str|None) -> QgsStacCatalog|None: ...


class QgsStacExtent(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacExtent') -> None: ...

    def hasDetailedTemporalExtents(self) -> bool: ...
    def hasDetailedSpatialExtents(self) -> bool: ...
    def detailedTemporalExtents(self) -> list[QgsDateTimeRange]: ...
    def detailedSpatialExtents(self) -> list[QgsBox3D]: ...
    def temporalExtent(self) -> QgsDateTimeRange: ...
    def addDetailedTemporalExtent(self, extent: QgsDateTimeRange) -> None: ...
    def setTemporalExtent(self, extent: QgsDateTimeRange) -> None: ...
    def spatialExtent(self) -> QgsBox3D: ...
    @typing.overload
    def addDetailedSpatialExtent(self, extent: QgsBox3D) -> None: ...
    @typing.overload
    def addDetailedSpatialExtent(self, extent: QgsRectangle) -> None: ...
    @typing.overload
    def setSpatialExtent(self, extent: QgsBox3D) -> None: ...
    @typing.overload
    def setSpatialExtent(self, extent: QgsRectangle) -> None: ...


class QgsStacItemCollection(PyQt6.sip.wrapper):

    def __init__(self, items: collections.abc.Iterable['QgsStacItem'], links: collections.abc.Iterable['QgsStacLink'], numberMatched: int = ...) -> None: ...

    def numberMatched(self) -> int: ...
    def numberReturned(self) -> int: ...
    def nextUrl(self) -> QtCore.QUrl: ...
    def collectionUrl(self) -> QtCore.QUrl: ...
    def parentUrl(self) -> QtCore.QUrl: ...
    def rootUrl(self) -> QtCore.QUrl: ...
    def url(self) -> QtCore.QUrl: ...
    def takeItems(self) -> list['QgsStacItem']: ...
    def items(self) -> list['QgsStacItem']: ...


class QgsStacItem(QgsStacObject):

    @typing.overload
    def __init__(self, id: str|None, version: str|None, geometry: QgsGeometry, properties: dict[str|None, typing.Any], links: collections.abc.Iterable['QgsStacLink'], assets: dict[str|None, QgsStacAsset], bbox: QgsBox3D) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacItem') -> None: ...

    def uris(self) -> list[QgsMimeDataUtils.Uri]: ...
    def description(self) -> str: ...
    def title(self) -> str: ...
    def dateTimeRange(self) -> QgsDateTimeRange: ...
    def hasDateTimeRange(self) -> bool: ...
    def dateTime(self) -> QtCore.QDateTime: ...
    def setCollection(self, collection: str|None) -> None: ...
    def collection(self) -> str: ...
    def setAssets(self, assets: dict[str|None, QgsStacAsset]) -> None: ...
    def assets(self) -> dict[str, QgsStacAsset]: ...
    def setProperties(self, properties: dict[str|None, typing.Any]) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def setBoundingBox(self, bbox: QgsBox3D) -> None: ...
    def boundingBox(self) -> QgsBox3D: ...
    def setGeometry(self, geometry: QgsGeometry) -> None: ...
    def geometry(self) -> QgsGeometry: ...
    def toHtml(self) -> str: ...
    def type(self) -> Qgis.StacObjectType: ...


class QgsStacLink(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, href: str|None, relation: str|None, mediaType: str|None, title: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacLink') -> None: ...

    def title(self) -> str: ...
    def mediaType(self) -> str: ...
    def relation(self) -> str: ...
    def href(self) -> str: ...


class QgsStacParser(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def error(self) -> str: ...
    def type(self) -> Qgis.StacObjectType: ...
    def collections(self) -> QgsStacCollectionList|None: ...
    def catalog(self) -> QgsStacCatalog|None: ...
    def setBaseUrl(self, url: QtCore.QUrl) -> None: ...
    def setData(self, data: QtCore.QByteArray|bytes|bytearray|memoryview) -> None: ...


class QgsStacProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, roles: collections.abc.Iterable[str|None], url: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStacProvider') -> None: ...

    def url(self) -> str: ...
    def roles(self) -> list[str]: ...
    def description(self) -> str: ...
    def name(self) -> str: ...


class QgsFeatureRenderer(PyQt6.sip.wrapper):

    class Capability(enum.IntEnum):
        SymbolLevels = ... # type: QgsFeatureRenderer.Capability
        MoreSymbolsPerFeature = ... # type: QgsFeatureRenderer.Capability
        Filter = ... # type: QgsFeatureRenderer.Capability
        ScaleDependent = ... # type: QgsFeatureRenderer.Capability

    class Property(enum.IntEnum):
        HeatmapRadius = ... # type: QgsFeatureRenderer.Property
        HeatmapMaximum = ... # type: QgsFeatureRenderer.Property

    def __init__(self, type: str|None) -> None: ...

    @staticmethod
    def convertSymbolRotation(symbol: 'QgsSymbol|None', field: str|None) -> None: ...
    @staticmethod
    def convertSymbolSizeScale(symbol: 'QgsSymbol|None', method: Qgis.ScaleMethod, field: str|None) -> None: ...
    def saveRendererData(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    @staticmethod
    def _getPoint(context: QgsRenderContext, point: QgsPoint) -> QtCore.QPointF: ...
    def renderVertexMarkerPolygon(self, pts: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: QgsRenderContext) -> None: ...
    def renderVertexMarkerPolyline(self, pts: QtGui.QPolygonF, context: QgsRenderContext) -> None: ...
    def renderVertexMarker(self, pt: QtCore.QPointF, context: QgsRenderContext) -> None: ...
    def renderFeatureWithSymbol(self, feature: QgsFeature, symbol: 'QgsSymbol|None', context: QgsRenderContext, layer: int, selected: bool, drawVertexMarker: bool) -> None: ...
    def maximumExtentBuffer(self, context: QgsRenderContext) -> float: ...
    def copyRendererData(self, destRenderer: 'QgsFeatureRenderer|None') -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def embeddedRenderer(self) -> 'QgsFeatureRenderer|None': ...
    def setEmbeddedRenderer(self, subRenderer: 'QgsFeatureRenderer|None') -> None: ...
    def setOrderByEnabled(self, enabled: bool) -> None: ...
    def orderByEnabled(self) -> bool: ...
    def setOrderBy(self, orderBy: QgsFeatureRequest.OrderBy) -> None: ...
    def orderBy(self) -> QgsFeatureRequest.OrderBy: ...
    def setReferenceScale(self, scale: float) -> None: ...
    def referenceScale(self) -> float: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def setDataDefinedProperty(self, key: 'QgsFeatureRenderer.Property', property: QgsProperty) -> None: ...
    def setForceRasterRender(self, forceRaster: bool) -> None: ...
    def forceRasterRender(self) -> bool: ...
    def setPaintEffect(self, effect: QgsPaintEffect|None) -> None: ...
    def paintEffect(self) -> QgsPaintEffect|None: ...
    def modifyRequestExtent(self, extent: QgsRectangle, context: QgsRenderContext) -> None: ...
    def originalSymbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list['QgsSymbol']: ...
    def symbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list['QgsSymbol']: ...
    def willRenderFeature(self, feature: QgsFeature, context: QgsRenderContext) -> bool: ...
    def setVertexMarkerAppearance(self, type: Qgis.VertexMarkerType, size: float) -> None: ...
    def legendClassificationAttribute(self) -> str: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def legendSymbolItems(self) -> list['QgsLegendSymbolItem']: ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def setLegendSymbolItem(self, key: str|None, symbol: 'QgsSymbol|None') -> None: ...
    def checkLegendSymbolItem(self, key: str|None, state: bool = ...) -> None: ...
    def legendSymbolItemChecked(self, key: str|None) -> bool: ...
    def legendSymbolItemsCheckable(self) -> bool: ...
    def legendKeys(self) -> set[str]: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    @staticmethod
    def loadSld(node: QtXml.QDomNode, geomType: Qgis.GeometryType, errorMessage: str|None) -> 'QgsFeatureRenderer|None': ...
    def writeSld(self, doc: QtXml.QDomDocument, styleName: str|None, props: dict[str|None, typing.Any] = ...) -> QtXml.QDomElement: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def load(symbologyElem: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsFeatureRenderer|None': ...
    def setUsingSymbolLevels(self, usingSymbolLevels: bool) -> None: ...
    def usingSymbolLevels(self) -> bool: ...
    def symbols(self, context: QgsRenderContext) -> list['QgsSymbol']: ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...
    def capabilities(self) -> 'QgsFeatureRenderer.Capability': ...
    def dump(self) -> str: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    def clone(self) -> 'QgsFeatureRenderer|None': ...
    def filterNeedsGeometry(self) -> bool: ...
    def usesEmbeddedSymbols(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def filter(self, fields: QgsFields = ...) -> str: ...
    def canSkipRender(self) -> bool: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...
    def type(self) -> str: ...
    @staticmethod
    def defaultRenderer(geomType: Qgis.GeometryType) -> 'QgsFeatureRenderer|None': ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...


class Qgs25DRenderer(QgsFeatureRenderer):

    def __init__(self) -> None: ...

    def setShadowEnabled(self, value: bool) -> None: ...
    def shadowEnabled(self) -> bool: ...
    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'Qgs25DRenderer|None': ...
    def setShadowSpread(self, shadowSpread: float) -> None: ...
    def shadowSpread(self) -> float: ...
    def setShadowColor(self, shadowColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def shadowColor(self) -> QtGui.QColor: ...
    def wallShadingEnabled(self) -> bool: ...
    def setWallShadingEnabled(self, enabled: bool) -> None: ...
    def setWallColor(self, wallColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def wallColor(self) -> QtGui.QColor: ...
    def setRoofColor(self, roofColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def roofColor(self) -> QtGui.QColor: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def symbols(self, context: QgsRenderContext) -> list['QgsSymbol']: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...
    def clone(self) -> QgsFeatureRenderer|None: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...


class QgsSymbolLayer(PyQt6.sip.wrapper):

    class Property(enum.IntEnum):
        Size = ... # type: QgsSymbolLayer.Property
        Angle = ... # type: QgsSymbolLayer.Property
        Name = ... # type: QgsSymbolLayer.Property
        FillColor = ... # type: QgsSymbolLayer.Property
        StrokeColor = ... # type: QgsSymbolLayer.Property
        StrokeWidth = ... # type: QgsSymbolLayer.Property
        StrokeStyle = ... # type: QgsSymbolLayer.Property
        Offset = ... # type: QgsSymbolLayer.Property
        Character = ... # type: QgsSymbolLayer.Property
        Width = ... # type: QgsSymbolLayer.Property
        Height = ... # type: QgsSymbolLayer.Property
        PreserveAspectRatio = ... # type: QgsSymbolLayer.Property
        FillStyle = ... # type: QgsSymbolLayer.Property
        JoinStyle = ... # type: QgsSymbolLayer.Property
        SecondaryColor = ... # type: QgsSymbolLayer.Property
        LineAngle = ... # type: QgsSymbolLayer.Property
        LineDistance = ... # type: QgsSymbolLayer.Property
        GradientType = ... # type: QgsSymbolLayer.Property
        CoordinateMode = ... # type: QgsSymbolLayer.Property
        GradientSpread = ... # type: QgsSymbolLayer.Property
        GradientReference1X = ... # type: QgsSymbolLayer.Property
        GradientReference1Y = ... # type: QgsSymbolLayer.Property
        GradientReference2X = ... # type: QgsSymbolLayer.Property
        GradientReference2Y = ... # type: QgsSymbolLayer.Property
        GradientReference1IsCentroid = ... # type: QgsSymbolLayer.Property
        GradientReference2IsCentroid = ... # type: QgsSymbolLayer.Property
        BlurRadius = ... # type: QgsSymbolLayer.Property
        ShapeburstUseWholeShape = ... # type: QgsSymbolLayer.Property
        ShapeburstMaxDistance = ... # type: QgsSymbolLayer.Property
        ShapeburstIgnoreRings = ... # type: QgsSymbolLayer.Property
        File = ... # type: QgsSymbolLayer.Property
        DistanceX = ... # type: QgsSymbolLayer.Property
        DistanceY = ... # type: QgsSymbolLayer.Property
        DisplacementX = ... # type: QgsSymbolLayer.Property
        DisplacementY = ... # type: QgsSymbolLayer.Property
        Opacity = ... # type: QgsSymbolLayer.Property
        CustomDash = ... # type: QgsSymbolLayer.Property
        CapStyle = ... # type: QgsSymbolLayer.Property
        Placement = ... # type: QgsSymbolLayer.Property
        Interval = ... # type: QgsSymbolLayer.Property
        OffsetAlongLine = ... # type: QgsSymbolLayer.Property
        AverageAngleLength = ... # type: QgsSymbolLayer.Property
        HorizontalAnchor = ... # type: QgsSymbolLayer.Property
        VerticalAnchor = ... # type: QgsSymbolLayer.Property
        LayerEnabled = ... # type: QgsSymbolLayer.Property
        ArrowWidth = ... # type: QgsSymbolLayer.Property
        ArrowStartWidth = ... # type: QgsSymbolLayer.Property
        ArrowHeadLength = ... # type: QgsSymbolLayer.Property
        ArrowHeadThickness = ... # type: QgsSymbolLayer.Property
        ArrowHeadType = ... # type: QgsSymbolLayer.Property
        ArrowType = ... # type: QgsSymbolLayer.Property
        OffsetX = ... # type: QgsSymbolLayer.Property
        OffsetY = ... # type: QgsSymbolLayer.Property
        PointCount = ... # type: QgsSymbolLayer.Property
        RandomSeed = ... # type: QgsSymbolLayer.Property
        ClipPoints = ... # type: QgsSymbolLayer.Property
        DensityArea = ... # type: QgsSymbolLayer.Property
        FontFamily = ... # type: QgsSymbolLayer.Property
        FontStyle = ... # type: QgsSymbolLayer.Property
        DashPatternOffset = ... # type: QgsSymbolLayer.Property
        TrimStart = ... # type: QgsSymbolLayer.Property
        TrimEnd = ... # type: QgsSymbolLayer.Property
        LineStartWidthValue = ... # type: QgsSymbolLayer.Property
        LineEndWidthValue = ... # type: QgsSymbolLayer.Property
        LineStartColorValue = ... # type: QgsSymbolLayer.Property
        LineEndColorValue = ... # type: QgsSymbolLayer.Property
        MarkerClipping = ... # type: QgsSymbolLayer.Property
        RandomOffsetX = ... # type: QgsSymbolLayer.Property
        RandomOffsetY = ... # type: QgsSymbolLayer.Property
        LineClipping = ... # type: QgsSymbolLayer.Property
        SkipMultiples = ... # type: QgsSymbolLayer.Property
        ShowMarker = ... # type: QgsSymbolLayer.Property
        BlankSegments = ... # type: QgsSymbolLayer.Property

    def __init__(self, type: Qgis.SymbolType, locked: bool = ...) -> None: ...

    def shouldRenderUsingSelectionColor(self, context: 'QgsSymbolRenderContext') -> bool: ...
    def removeMasks(self, context: QgsRenderContext, recursive: bool) -> None: ...
    def copyPaintEffect(self, destLayer: 'QgsSymbolLayer|None') -> None: ...
    def copyDataDefinedProperties(self, destLayer: 'QgsSymbolLayer|None') -> None: ...
    def copyCommonProperties(self, destLayer: 'QgsSymbolLayer|None') -> None: ...
    def restoreOldDataDefinedProperties(self, stringMap: dict[str|None, typing.Any]) -> None: ...
    def installMasks(self, context: QgsRenderContext, recursive: bool, rect: QtCore.QRectF = ...) -> bool: ...
    def id(self) -> str: ...
    def setId(self, id: str|None) -> None: ...
    def prepareMasks(self, context: 'QgsSymbolRenderContext') -> None: ...
    def setSelectiveMaskingSourceSetId(self, id: str|None) -> None: ...
    def selectiveMaskingSourceSetId(self) -> str: ...
    def masks(self) -> list['QgsSymbolLayerReference']: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def prepareExpressions(self, context: 'QgsSymbolRenderContext') -> None: ...
    def setPaintEffect(self, effect: QgsPaintEffect|None) -> None: ...
    def paintEffect(self) -> QgsPaintEffect|None: ...
    def dxfBrushStyle(self) -> QtCore.Qt.BrushStyle: ...
    def dxfBrushColor(self, context: 'QgsSymbolRenderContext') -> QtGui.QColor: ...
    def dxfPenStyle(self) -> QtCore.Qt.PenStyle: ...
    def dxfCustomDashPattern(self) -> typing.Tuple[list[float], Qgis.RenderUnit]: ...
    def dxfAngle(self, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfColor(self, context: 'QgsSymbolRenderContext') -> QtGui.QColor: ...
    def dxfOffset(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfSize(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfWidth(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def writeDxf(self, e: QgsDxfExport, mmMapUnitScaleFactor: float, layerName: str|None, context: 'QgsSymbolRenderContext', shift: QtCore.QPointF = ...) -> bool: ...
    def setDataDefinedProperty(self, key: 'QgsSymbolLayer.Property', property: QgsProperty) -> None: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def renderingPass(self) -> int: ...
    def setRenderingPass(self, renderingPass: int) -> None: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def isLocked(self) -> bool: ...
    def setLocked(self, locked: bool) -> None: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def rendersIdenticallyTo(self, other: 'QgsSymbolLayer|None') -> bool: ...
    def isCompatibleWithSymbol(self, symbol: 'QgsSymbol|None') -> bool: ...
    def type(self) -> Qgis.SymbolType: ...
    def setSubSymbol(self, symbol: 'QgsSymbol|None') -> bool: ...
    def subSymbol(self) -> 'QgsSymbol|None': ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def ogrFeatureStyle(self, mmScaleFactor: float, mapUnitScaleFactor: float) -> str: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSymbolLayer|None': ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setUserFlags(self, flags: Qgis.SymbolLayerUserFlag) -> None: ...
    def userFlags(self) -> Qgis.SymbolLayerUserFlag: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...


class QgsLineSymbolLayer(QgsSymbolLayer):

    class RenderRingFilter(enum.IntEnum):
        AllRings = ... # type: QgsLineSymbolLayer.RenderRingFilter
        ExteriorRingOnly = ... # type: QgsLineSymbolLayer.RenderRingFilter
        InteriorRingsOnly = ... # type: QgsLineSymbolLayer.RenderRingFilter

    def __init__(self, locked: bool = ...) -> None: ...

    def setRingFilter(self, filter: 'QgsLineSymbolLayer.RenderRingFilter') -> None: ...
    def ringFilter(self) -> 'QgsLineSymbolLayer.RenderRingFilter': ...
    def widthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def widthUnit(self) -> Qgis.RenderUnit: ...
    def setWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setOffset(self, offset: float) -> None: ...
    def offset(self) -> float: ...
    @typing.overload
    def width(self) -> float: ...
    @typing.overload
    def width(self, context: QgsRenderContext) -> float: ...
    def setWidth(self, width: float) -> None: ...
    def renderPolygonStroke(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def dxfWidth(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...


class QgsArrowSymbolLayer(QgsLineSymbolLayer):

    class ArrowType(enum.IntEnum):
        ArrowPlain = ... # type: QgsArrowSymbolLayer.ArrowType
        ArrowLeftHalf = ... # type: QgsArrowSymbolLayer.ArrowType
        ArrowRightHalf = ... # type: QgsArrowSymbolLayer.ArrowType

    class HeadType(enum.IntEnum):
        HeadSingle = ... # type: QgsArrowSymbolLayer.HeadType
        HeadReversed = ... # type: QgsArrowSymbolLayer.HeadType
        HeadDouble = ... # type: QgsArrowSymbolLayer.HeadType

    def __init__(self) -> None: ...

    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def setArrowType(self, type: 'QgsArrowSymbolLayer.ArrowType') -> None: ...
    def arrowType(self) -> 'QgsArrowSymbolLayer.ArrowType': ...
    def setHeadType(self, type: 'QgsArrowSymbolLayer.HeadType') -> None: ...
    def headType(self) -> 'QgsArrowSymbolLayer.HeadType': ...
    def setIsRepeated(self, isRepeated: bool) -> None: ...
    def isRepeated(self) -> bool: ...
    def setIsCurved(self, isCurved: bool) -> None: ...
    def isCurved(self) -> bool: ...
    def setHeadThicknessUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def headThicknessUnitScale(self) -> QgsMapUnitScale: ...
    def setHeadThicknessUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def headThicknessUnit(self) -> Qgis.RenderUnit: ...
    def setHeadThickness(self, thickness: float) -> None: ...
    def headThickness(self) -> float: ...
    def setHeadLengthUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def headLengthUnitScale(self) -> QgsMapUnitScale: ...
    def setHeadLengthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def headLengthUnit(self) -> Qgis.RenderUnit: ...
    def setHeadLength(self, length: float) -> None: ...
    def headLength(self) -> float: ...
    def setArrowStartWidthUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def arrowStartWidthUnitScale(self) -> QgsMapUnitScale: ...
    def setArrowStartWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def arrowStartWidthUnit(self) -> Qgis.RenderUnit: ...
    def setArrowStartWidth(self, width: float) -> None: ...
    def arrowStartWidth(self) -> float: ...
    def setArrowWidthUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def arrowWidthUnitScale(self) -> QgsMapUnitScale: ...
    def setArrowWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def arrowWidthUnit(self) -> Qgis.RenderUnit: ...
    def setArrowWidth(self, width: float) -> None: ...
    def arrowWidth(self) -> float: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def setSubSymbol(self, symbol: 'QgsSymbol|None') -> bool: ...
    def subSymbol(self) -> 'QgsSymbol|None': ...
    def clone(self) -> 'QgsArrowSymbolLayer|None': ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsRendererCategory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, value: typing.Any, symbol: 'QgsSymbol|None', label: str|None, render: bool = ..., uuid: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, cat: 'QgsRendererCategory') -> None: ...

    def __repr__(self) -> typing.Any: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, classAttribute: str|None, context: QgsSldExportContext) -> bool: ...
    def dump(self) -> str: ...
    def setRenderState(self, render: bool) -> None: ...
    def renderState(self) -> bool: ...
    def setLabel(self, label: str|None) -> None: ...
    def setSymbol(self, s: 'QgsSymbol|None') -> None: ...
    def setValue(self, value: typing.Any) -> None: ...
    def label(self) -> str: ...
    def symbol(self) -> 'QgsSymbol|None': ...
    def value(self) -> typing.Any: ...
    def uuid(self) -> str: ...


class QgsCategorizedSymbolRenderer(QgsFeatureRenderer):

    def __init__(self, attrName: str|None = ..., categories: collections.abc.Iterable[QgsRendererCategory] = ...) -> None: ...

    def symbolForValue2(self, value: typing.Any) -> typing.Tuple['QgsSymbol|None', bool]: ...
    @deprecated("""""")
    def symbolForValue(self, value: typing.Any) -> 'QgsSymbol|None': ...
    @deprecated("""""")
    def skipRender(self) -> 'QgsSymbol|None': ...
    def rebuildHash(self) -> None: ...
    @staticmethod
    @deprecated("""""")
    def displayString(value: typing.Any, precision: int = ...) -> str: ...
    @staticmethod
    def createCategories(values: collections.abc.Iterable[typing.Any], symbol: 'QgsSymbol|None', layer: QgsVectorLayer|None = ..., fieldName: str|None = ...) -> list[QgsRendererCategory]: ...
    def matchToSymbols(self, style: 'QgsStyle|None', type: Qgis.SymbolType, caseSensitive: bool = ..., useTolerantMatch: bool = ...) -> typing.Tuple[int, list[typing.Any], list[str]]: ...
    def dataDefinedSizeLegend(self) -> QgsDataDefinedSizeLegend|None: ...
    def setDataDefinedSizeLegend(self, settings: QgsDataDefinedSizeLegend|None) -> None: ...
    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None, layer: QgsVectorLayer|None = ...) -> 'QgsCategorizedSymbolRenderer|None': ...
    def legendClassificationAttribute(self) -> str: ...
    def checkLegendSymbolItem(self, key: str|None, state: bool = ...) -> None: ...
    def setLegendSymbolItem(self, key: str|None, symbol: 'QgsSymbol|None') -> None: ...
    def legendSymbolItemChecked(self, key: str|None) -> bool: ...
    def legendSymbolItemsCheckable(self) -> bool: ...
    def updateColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def setSourceColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def sourceColorRamp(self) -> QgsColorRamp|None: ...
    def setSourceSymbol(self, sym: 'QgsSymbol|None') -> None: ...
    def sourceSymbol(self) -> 'QgsSymbol|None': ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def legendSymbolItems(self) -> list['QgsLegendSymbolItem']: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def setClassAttribute(self, attr: str|None) -> None: ...
    def classAttribute(self) -> str: ...
    def sortByLabel(self, order: QtCore.Qt.SortOrder = ...) -> None: ...
    def sortByValue(self, order: QtCore.Qt.SortOrder = ...) -> None: ...
    def moveCategory(self, from_: int, to: int) -> None: ...
    def deleteAllCategories(self) -> None: ...
    def deleteCategory(self, catIndex: int) -> bool: ...
    def addCategory(self, category: QgsRendererCategory) -> None: ...
    def updateCategoryRenderState(self, catIndex: int, render: bool) -> bool: ...
    def updateCategoryLabel(self, catIndex: int, label: str|None) -> bool: ...
    def updateCategorySymbol(self, catIndex: int, symbol: 'QgsSymbol|None') -> bool: ...
    def updateCategoryValue(self, catIndex: int, value: typing.Any) -> bool: ...
    def categoryIndexForLabel(self, val: str|None) -> int: ...
    def categoryIndexForValue(self, val: typing.Any) -> int: ...
    def categories(self) -> list[QgsRendererCategory]: ...
    def updateSymbols(self, sym: 'QgsSymbol|None') -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def symbols(self, context: QgsRenderContext) -> list['QgsSymbol']: ...
    def filter(self, fields: QgsFields = ...) -> str: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsCategorizedSymbolRenderer|None': ...
    def dump(self) -> str: ...
    def filterNeedsGeometry(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...


class QgsColorBrewerPalette(PyQt6.sip.wrapper):

    BREWER_STRING = ... # type: str

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsColorBrewerPalette') -> None: ...

    @staticmethod
    def listSchemeVariants(schemeName: str|None) -> list[int]: ...
    @staticmethod
    def listSchemes() -> list[str]: ...
    @staticmethod
    def listSchemeColors(schemeName: str|None, colors: int) -> list[QtGui.QColor]: ...


class QgsCombinedStyleModel(QtCore.QConcatenateTablesProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def addTargetScreenProperties(self, properties: QgsScreenProperties) -> None: ...
    def addDesiredIconSize(self, size: QtCore.QSize) -> None: ...
    def styles(self) -> list['QgsStyle']: ...
    def removeStyle(self, style: 'QgsStyle|None') -> None: ...
    def addDefaultStyle(self) -> None: ...
    def addStyle(self, style: 'QgsStyle|None') -> None: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...


class QgsCptCityArchive(PyQt6.sip.wrapper):

    def __init__(self, archiveName: str|None = ..., baseDir: str|None = ...) -> None: ...

    def selectionItems(self) -> list['QgsCptCityDataItem']: ...
    def rootItems(self) -> list['QgsCptCityDataItem']: ...
    @staticmethod
    def archiveRegistry() -> typing.Any: ...
    @staticmethod
    def defaultArchive() -> 'QgsCptCityArchive|None': ...
    @staticmethod
    def clearArchives() -> None: ...
    @staticmethod
    def initDefaultArchive() -> None: ...
    @staticmethod
    def initArchive(archiveName: str|None, archiveBaseDir: str|None) -> None: ...
    @staticmethod
    def initArchives(loadAll: bool = ...) -> None: ...
    def archiveName(self) -> str: ...
    def isEmpty(self) -> bool: ...
    @staticmethod
    def description(fileName: str|None) -> dict[str, str]: ...
    @staticmethod
    def copyingInfo(fileName: str|None) -> dict[str, str]: ...
    @staticmethod
    def findFileName(target: str|None, startDir: str|None, baseDir: str|None) -> str: ...
    def descFileName(self, dirName: str|None) -> str: ...
    def copyingFileName(self, dirName: str|None) -> str: ...
    def setBaseDir(self, dirName: str|None) -> None: ...
    @staticmethod
    def defaultBaseDir() -> str: ...
    @typing.overload
    def baseDir(self) -> str: ...
    @typing.overload
    @staticmethod
    def baseDir(archiveName: str|None) -> str: ...


class QgsCptCityDataItem(QtCore.QObject):

    class Type(enum.IntEnum):
        ColorRamp = ... # type: QgsCptCityDataItem.Type
        Collection = ... # type: QgsCptCityDataItem.Type
        Directory = ... # type: QgsCptCityDataItem.Type
        Selection = ... # type: QgsCptCityDataItem.Type
        AllRamps = ... # type: QgsCptCityDataItem.Type

    def __init__(self, type: 'QgsCptCityDataItem.Type', parent: 'QgsCptCityDataItem|None', name: str|None, path: str|None) -> None: ...

    endRemoveItems: typing.ClassVar[QtCore.pyqtSignal]
    beginRemoveItems: typing.ClassVar[QtCore.pyqtSignal]
    endInsertItems: typing.ClassVar[QtCore.pyqtSignal]
    beginInsertItems: typing.ClassVar[QtCore.pyqtSignal]
    def isValid(self) -> bool: ...
    def toolTip(self) -> str: ...
    def setToolTip(self, msg: str|None) -> None: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def shortInfo(self) -> str: ...
    def info(self) -> str: ...
    def path(self) -> str: ...
    def name(self) -> str: ...
    @typing.overload
    def icon(self) -> QtGui.QIcon: ...
    @typing.overload
    def icon(self, size: QtCore.QSize) -> QtGui.QIcon: ...
    def children(self) -> list['QgsCptCityDataItem']: ...
    def setParent(self, parent: 'QgsCptCityDataItem|None') -> None: ...
    def parent(self) -> 'QgsCptCityDataItem|None': ...
    def type(self) -> 'QgsCptCityDataItem.Type': ...
    @staticmethod
    def findItem(items: collections.abc.Iterable['QgsCptCityDataItem'], item: 'QgsCptCityDataItem|None') -> int: ...
    @deprecated("""""")
    def handleDrop(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction) -> bool: ...
    @deprecated("""""")
    def acceptDrop(self) -> bool: ...
    @deprecated("""""")
    def paramWidget(self) -> QtWidgets.QWidget|None: ...
    def equal(self, other: 'QgsCptCityDataItem|None') -> bool: ...
    def removeChildItem(self, child: 'QgsCptCityDataItem|None') -> 'QgsCptCityDataItem|None': ...
    def deleteChildItem(self, child: 'QgsCptCityDataItem|None') -> None: ...
    def addChildItem(self, child: 'QgsCptCityDataItem|None', refresh: bool = ...) -> None: ...
    def isPopulated(self) -> bool: ...
    def populate(self) -> None: ...
    def createChildren(self) -> list['QgsCptCityDataItem']: ...
    def refresh(self) -> None: ...
    def leafCount(self) -> int: ...
    def rowCount(self) -> int: ...
    def hasChildren(self) -> bool: ...


class QgsCptCityColorRampItem(QgsCptCityDataItem):

    @typing.overload
    def __init__(self, parent: QgsCptCityDataItem|None, name: str|None, path: str|None, variantName: str|None = ..., initialize: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QgsCptCityDataItem|None, name: str|None, path: str|None, variantList: collections.abc.Iterable[str|None], initialize: bool = ...) -> None: ...

    def init(self) -> None: ...
    @typing.overload
    def icon(self) -> QtGui.QIcon: ...
    @typing.overload
    def icon(self, size: QtCore.QSize) -> QtGui.QIcon: ...
    def ramp(self) -> QgsCptCityColorRamp: ...
    def leafCount(self) -> int: ...
    def equal(self, other: QgsCptCityDataItem|None) -> bool: ...


class QgsCptCityCollectionItem(QgsCptCityDataItem):

    def __init__(self, parent: QgsCptCityDataItem|None, name: str|None, path: str|None) -> None: ...

    def childrenRamps(self, recursive: bool) -> list[QgsCptCityDataItem]: ...
    def addChild(self, item: QgsCptCityDataItem|None) -> None: ...
    def setPopulated(self) -> None: ...


class QgsCptCityDirectoryItem(QgsCptCityCollectionItem):

    def __init__(self, parent: QgsCptCityDataItem|None, name: str|None, path: str|None) -> None: ...

    def dirEntries(self) -> list[str]: ...
    def rampsMap(self) -> dict[str, list[str]]: ...
    @staticmethod
    def dataItem(parent: QgsCptCityDataItem|None, name: str|None, path: str|None) -> QgsCptCityDataItem|None: ...
    def equal(self, other: QgsCptCityDataItem|None) -> bool: ...
    def createChildren(self) -> list[QgsCptCityDataItem]: ...


class QgsCptCitySelectionItem(QgsCptCityCollectionItem):

    def __init__(self, parent: QgsCptCityDataItem|None, name: str|None, path: str|None) -> None: ...

    def parseXml(self) -> None: ...
    def selectionsList(self) -> list[str]: ...
    def equal(self, other: QgsCptCityDataItem|None) -> bool: ...
    def createChildren(self) -> list[QgsCptCityDataItem]: ...


class QgsCptCityAllRampsItem(QgsCptCityCollectionItem):

    def __init__(self, parent: QgsCptCityDataItem|None, name: str|None, items: collections.abc.Iterable[QgsCptCityDataItem]) -> None: ...

    def createChildren(self) -> list[QgsCptCityDataItem]: ...


class QgsCptCityBrowserModel(QtCore.QAbstractItemModel):

    class ViewType(enum.IntEnum):
        Authors = ... # type: QgsCptCityBrowserModel.ViewType
        Selections = ... # type: QgsCptCityBrowserModel.ViewType
        List = ... # type: QgsCptCityBrowserModel.ViewType

    def __init__(self, parent: QtCore.QObject|None = ..., archive: QgsCptCityArchive|None = ..., Type: 'QgsCptCityBrowserModel.ViewType' = ...) -> None: ...

    def removeRootItems(self) -> None: ...
    def addRootItems(self) -> None: ...
    def endRemoveItems(self) -> None: ...
    def beginRemoveItems(self, parent: QgsCptCityDataItem|None, first: int, last: int) -> None: ...
    def endInsertItems(self) -> None: ...
    def beginInsertItems(self, parent: QgsCptCityDataItem|None, first: int, last: int) -> None: ...
    def fetchMore(self, parent: QtCore.QModelIndex) -> None: ...
    def canFetchMore(self, parent: QtCore.QModelIndex) -> bool: ...
    def connectItem(self, item: QgsCptCityDataItem|None) -> None: ...
    def findPath(self, path: str|None) -> QtCore.QModelIndex: ...
    @typing.overload
    def refresh(self, path: str|None) -> None: ...
    @typing.overload
    def refresh(self, index: QtCore.QModelIndex = ...) -> None: ...
    def reload(self) -> None: ...
    def hasChildren(self, parent: QtCore.QModelIndex = ...) -> bool: ...
    def dataItem(self, idx: QtCore.QModelIndex) -> QgsCptCityDataItem|None: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def findItem(self, item: QgsCptCityDataItem|None, parent: QgsCptCityDataItem|None = ...) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsMarkerSymbolLayer(QgsSymbolLayer):

    def __init__(self, locked: bool = ...) -> None: ...

    @staticmethod
    def _rotatedOffset(offset: QtCore.QPointF, angle: float) -> QtCore.QPointF: ...
    def markerOffset2(self, context: 'QgsSymbolRenderContext', width: float, height: float, widthUnit: Qgis.RenderUnit, heightUnit: Qgis.RenderUnit, widthMapUnitScale: QgsMapUnitScale, heightMapUnitScale: QgsMapUnitScale) -> typing.Tuple[float, float]: ...
    def markerOffsetWithWidthAndHeight(self, context: 'QgsSymbolRenderContext', width: float, height: float) -> typing.Tuple[float, float]: ...
    def markerOffset(self, context: 'QgsSymbolRenderContext') -> typing.Tuple[float, float]: ...
    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def dxfAngle(self, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfSize(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    @typing.overload
    @deprecated("""""")
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def verticalAnchorPoint(self) -> Qgis.VerticalAnchorPoint: ...
    def setVerticalAnchorPoint(self, v: Qgis.VerticalAnchorPoint) -> None: ...
    def horizontalAnchorPoint(self) -> Qgis.HorizontalAnchorPoint: ...
    def setHorizontalAnchorPoint(self, h: Qgis.HorizontalAnchorPoint) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offset(self) -> QtCore.QPointF: ...
    def setOffset(self, offset: QtCore.QPointF) -> None: ...
    def scaleMethod(self) -> Qgis.ScaleMethod: ...
    def setScaleMethod(self, scaleMethod: Qgis.ScaleMethod) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def size(self) -> float: ...
    def setSize(self, size: float) -> None: ...
    def setLineAngle(self, lineAngle: float) -> None: ...
    def angle(self) -> float: ...
    def setAngle(self, angle: float) -> None: ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...


class QgsEllipseSymbolLayer(QgsMarkerSymbolLayer):

    class Shape(enum.IntEnum):
        Circle = ... # type: QgsEllipseSymbolLayer.Shape
        Rectangle = ... # type: QgsEllipseSymbolLayer.Shape
        Diamond = ... # type: QgsEllipseSymbolLayer.Shape
        Cross = ... # type: QgsEllipseSymbolLayer.Shape
        Arrow = ... # type: QgsEllipseSymbolLayer.Shape
        HalfArc = ... # type: QgsEllipseSymbolLayer.Shape
        Triangle = ... # type: QgsEllipseSymbolLayer.Shape
        RightHalfTriangle = ... # type: QgsEllipseSymbolLayer.Shape
        LeftHalfTriangle = ... # type: QgsEllipseSymbolLayer.Shape
        SemiCircle = ... # type: QgsEllipseSymbolLayer.Shape
        ThirdCircle = ... # type: QgsEllipseSymbolLayer.Shape
        QuarterCircle = ... # type: QgsEllipseSymbolLayer.Shape
        Pentagon = ... # type: QgsEllipseSymbolLayer.Shape
        Hexagon = ... # type: QgsEllipseSymbolLayer.Shape
        Octagon = ... # type: QgsEllipseSymbolLayer.Shape
        Star = ... # type: QgsEllipseSymbolLayer.Shape

    def __init__(self) -> None: ...

    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def symbolHeightMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSymbolHeightMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def symbolHeightUnit(self) -> Qgis.RenderUnit: ...
    def setSymbolHeightUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def symbolWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSymbolWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def symbolWidthUnit(self) -> Qgis.RenderUnit: ...
    def setSymbolWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setStrokeColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setFillColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeWidth(self) -> float: ...
    def setStrokeWidth(self, w: float) -> None: ...
    def setPenCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    def penCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setStrokeStyle(self, strokeStyle: QtCore.Qt.PenStyle) -> None: ...
    def strokeStyle(self) -> QtCore.Qt.PenStyle: ...
    def symbolHeight(self) -> float: ...
    def setSymbolHeight(self, h: float) -> None: ...
    def symbolWidth(self) -> float: ...
    def setSymbolWidth(self, w: float) -> None: ...
    def setSize(self, size: float) -> None: ...
    @staticmethod
    def encodeShape(shape: 'QgsEllipseSymbolLayer.Shape') -> str: ...
    @staticmethod
    def decodeShape(name: str|None) -> typing.Tuple['QgsEllipseSymbolLayer.Shape', bool]: ...
    def setShape(self, shape: 'QgsEllipseSymbolLayer.Shape') -> None: ...
    def shape(self) -> 'QgsEllipseSymbolLayer.Shape': ...
    @deprecated("""""")
    def symbolName(self) -> str: ...
    @deprecated("""""")
    def setSymbolName(self, name: str|None) -> None: ...
    def writeDxf(self, e: QgsDxfExport, mmMapUnitScaleFactor: float, layerName: str|None, context: 'QgsSymbolRenderContext', shift: QtCore.QPointF = ...) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsEllipseSymbolLayer|None': ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...
    @staticmethod
    def shapeIsFilled(shape: 'QgsEllipseSymbolLayer.Shape') -> bool: ...
    @staticmethod
    def availableShapes() -> list['QgsEllipseSymbolLayer.Shape']: ...


class QgsEmbeddedSymbolRenderer(QgsFeatureRenderer):

    def __init__(self, defaultSymbol: 'QgsSymbol|None') -> None: ...

    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsEmbeddedSymbolRenderer|None': ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def setDefaultSymbol(self, symbol: 'QgsSymbol|None') -> None: ...
    def defaultSymbol(self) -> 'QgsSymbol|None': ...
    def symbols(self, context: QgsRenderContext) -> list['QgsSymbol']: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    def clone(self) -> 'QgsEmbeddedSymbolRenderer|None': ...
    def usesEmbeddedSymbols(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> 'QgsSymbol|None': ...


class QgsFeatureRendererGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureRendererGenerator') -> None: ...

    def createRenderer(self) -> QgsFeatureRenderer|None: ...
    def level(self) -> float: ...
    def id(self) -> str: ...


class QgsSymbol(PyQt6.sip.wrapper):

    class Property(enum.IntEnum):
        Opacity = ... # type: QgsSymbol.Property
        ExtentBuffer = ... # type: QgsSymbol.Property

    def __init__(self, type: Qgis.SymbolType, layers: collections.abc.Iterable[QgsSymbolLayer]) -> None: ...

    def renderVertexMarker(self, pt: QtCore.QPointF, context: QgsRenderContext, currentVertexMarkerType: Qgis.VertexMarkerType, currentVertexMarkerSize: float) -> None: ...
    def renderUsingLayer(self, layer: QgsSymbolLayer|None, context: 'QgsSymbolRenderContext', geometryType: Qgis.GeometryType = ..., points: QtGui.QPolygonF|None = ..., rings: collections.abc.Iterable[QtGui.QPolygonF] = ...) -> None: ...
    def copyCommonProperties(self, other: 'QgsSymbol|None') -> None: ...
    def cloneLayers(self) -> list[QgsSymbolLayer]: ...
    @staticmethod
    def _getPolygon(pts: QtGui.QPolygonF, holes: collections.abc.Iterable[QtGui.QPolygonF], context: QgsRenderContext, polygon: QgsPolygon, clipToExtent: bool = ..., correctRingOrientation: bool = ...) -> None: ...
    @staticmethod
    def _getPolygonRing(context: QgsRenderContext, curve: QgsCurve, clipToExtent: bool, isExteriorRing: bool = ..., correctRingOrientation: bool = ...) -> QtGui.QPolygonF: ...
    @staticmethod
    def _getLineString(context: QgsRenderContext, curve: QgsCurve, clipToExtent: bool = ...) -> QtGui.QPolygonF: ...
    @staticmethod
    def _getPoint(context: QgsRenderContext, point: QgsPoint) -> QtCore.QPointF: ...
    def setExtentBufferSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def extentBufferSizeUnit(self) -> Qgis.RenderUnit: ...
    def setExtentBuffer(self, extentBuffer: float) -> None: ...
    def extentBuffer(self) -> float: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ...) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ...) -> None: ...
    def symbolRenderContext(self) -> 'QgsSymbolRenderContext|None': ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ..., currentVertexMarkerType: Qgis.VertexMarkerType = ..., currentVertexMarkerSize: float = ...) -> None: ...
    @deprecated("""""")
    def layer(self) -> QgsVectorLayer|None: ...
    @deprecated("""""")
    def setLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def setDataDefinedProperty(self, key: 'QgsSymbol.Property', property: QgsProperty) -> None: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def setAnimationSettings(self, settings: 'QgsSymbolAnimationSettings') -> None: ...
    def animationSettings(self) -> 'QgsSymbolAnimationSettings': ...
    def setBufferSettings(self, settings: 'QgsSymbolBufferSettings|None') -> None: ...
    def bufferSettings(self) -> 'QgsSymbolBufferSettings|None': ...
    def forceRHR(self) -> bool: ...
    def setForceRHR(self, force: bool) -> None: ...
    def clipFeaturesToExtent(self) -> bool: ...
    def setClipFeaturesToExtent(self, clipFeaturesToExtent: bool) -> None: ...
    def flags(self) -> Qgis.SymbolFlag: ...
    def setFlags(self, flags: Qgis.SymbolFlag) -> None: ...
    def renderHints(self) -> Qgis.SymbolRenderHint: ...
    def setRenderHints(self, hints: Qgis.SymbolRenderHint) -> None: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSymbol|None': ...
    def rendersIdenticallyTo(self, other: 'QgsSymbol|None') -> bool: ...
    def dump(self) -> str: ...
    @deprecated("""""")
    def bigSymbolPreviewImage(self, expressionContext: QgsExpressionContext|None = ..., flags: int = ...) -> QtGui.QImage: ...
    def bigSymbolPreviewImageV2(self, expressionContext: QgsExpressionContext|None = ..., flags: Qgis.SymbolPreviewFlag = ..., screen: QgsScreenProperties = ...) -> QtGui.QImage: ...
    def asImage(self, size: QtCore.QSize, customContext: QgsRenderContext|None = ...) -> QtGui.QImage: ...
    def exportImage(self, path: str|None, format: str|None, size: QtCore.QSize) -> None: ...
    def drawPreviewIcon(self, painter: QtGui.QPainter|None, size: QtCore.QSize, customContext: QgsRenderContext|None = ..., selected: bool = ..., expressionContext: QgsExpressionContext|None = ..., patchShape: QgsLegendPatchShape|None = ..., screen: QgsScreenProperties = ...) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields = ...) -> None: ...
    def changeSymbolLayer(self, index: int, layer: QgsSymbolLayer|None) -> bool: ...
    def takeSymbolLayer(self, index: int) -> QgsSymbolLayer|None: ...
    def deleteSymbolLayer(self, index: int) -> bool: ...
    def appendSymbolLayer(self, layer: QgsSymbolLayer|None) -> bool: ...
    def insertSymbolLayer(self, index: int, layer: QgsSymbolLayer|None) -> bool: ...
    def __delitem__(self, index: int) -> None: ...
    def __getitem__(self, index: int) -> QgsSymbolLayer: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def symbolLayerCount(self) -> int: ...
    def symbolLayer(self, layer: int) -> QgsSymbolLayer: ...
    def symbolLayers(self) -> list[QgsSymbolLayer]: ...
    def type(self) -> Qgis.SymbolType: ...
    @staticmethod
    def defaultSymbol(geomType: Qgis.GeometryType) -> 'QgsSymbol|None': ...
    @staticmethod
    def propertyDefinitions() -> dict[int, QgsPropertyDefinition]: ...
    @staticmethod
    def symbolTypeForGeometryType(type: Qgis.GeometryType) -> Qgis.SymbolType: ...
    @staticmethod
    def symbolTypeToString(type: Qgis.SymbolType) -> str: ...


class QgsFillSymbol(QgsSymbol):

    def __init__(self, layers: collections.abc.Iterable[QgsSymbolLayer] = ...) -> None: ...

    def clone(self) -> 'QgsFillSymbol|None': ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], f: QgsFeature|None, context: QgsRenderContext, layer: int = ..., selected: bool = ...) -> None: ...
    def setAngle(self, angle: float) -> None: ...
    @staticmethod
    def createSimple(properties: dict[str|None, typing.Any]) -> 'QgsFillSymbol'|None: ...


class QgsFillSymbolLayer(QgsSymbolLayer):

    def __init__(self, locked: bool = ...) -> None: ...

    def _renderPolygon(self, p: QtGui.QPainter|None, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def toTiledPatternImage(self) -> QtGui.QImage: ...
    def angle(self) -> float: ...
    def setAngle(self, angle: float) -> None: ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...


class QgsSimpleFillSymbolLayer(QgsFillSymbolLayer):

    def __init__(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., style: QtCore.Qt.BrushStyle = ..., strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., strokeStyle: QtCore.Qt.PenStyle = ..., strokeWidth: float = ..., penJoinStyle: QtCore.Qt.PenJoinStyle = ...) -> None: ...

    def toTiledPatternImage(self) -> QtGui.QImage: ...
    def dxfBrushStyle(self) -> QtCore.Qt.BrushStyle: ...
    def dxfBrushColor(self, context: 'QgsSymbolRenderContext') -> QtGui.QColor: ...
    def dxfPenStyle(self) -> QtCore.Qt.PenStyle: ...
    def dxfAngle(self, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfColor(self, context: 'QgsSymbolRenderContext') -> QtGui.QColor: ...
    def dxfWidth(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offset(self) -> QtCore.QPointF: ...
    def setOffset(self, offset: QtCore.QPointF) -> None: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setStrokeWidth(self, strokeWidth: float) -> None: ...
    def strokeWidth(self) -> float: ...
    def setStrokeStyle(self, strokeStyle: QtCore.Qt.PenStyle) -> None: ...
    def strokeStyle(self) -> QtCore.Qt.PenStyle: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setStrokeColor(self, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setBrushStyle(self, style: QtCore.Qt.BrushStyle) -> None: ...
    def brushStyle(self) -> QtCore.Qt.BrushStyle: ...
    def ogrFeatureStyle(self, mmScaleFactor: float, mapUnitScaleFactor: float) -> str: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSimpleFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsGradientFillSymbolLayer(QgsFillSymbolLayer):

    def __init__(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., color2: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., gradientColorType: Qgis.GradientColorSource = ..., gradientType: Qgis.GradientType = ..., coordinateMode: Qgis.SymbolCoordinateReference = ..., gradientSpread: Qgis.GradientSpread = ...) -> None: ...

    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offset(self) -> QtCore.QPointF: ...
    def setOffset(self, offset: QtCore.QPointF) -> None: ...
    def referencePoint2IsCentroid(self) -> bool: ...
    def setReferencePoint2IsCentroid(self, isCentroid: bool) -> None: ...
    def referencePoint2(self) -> QtCore.QPointF: ...
    def setReferencePoint2(self, referencePoint: QtCore.QPointF) -> None: ...
    def referencePoint1IsCentroid(self) -> bool: ...
    def setReferencePoint1IsCentroid(self, isCentroid: bool) -> None: ...
    def referencePoint1(self) -> QtCore.QPointF: ...
    def setReferencePoint1(self, referencePoint: QtCore.QPointF) -> None: ...
    def setGradientSpread(self, gradientSpread: Qgis.GradientSpread) -> None: ...
    def gradientSpread(self) -> Qgis.GradientSpread: ...
    def setCoordinateMode(self, coordinateMode: Qgis.SymbolCoordinateReference) -> None: ...
    def coordinateMode(self) -> Qgis.SymbolCoordinateReference: ...
    def setColor2(self, color2: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color2(self) -> QtGui.QColor: ...
    def setColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def colorRamp(self) -> QgsColorRamp|None: ...
    def setGradientColorType(self, gradientColorType: Qgis.GradientColorSource) -> None: ...
    def gradientColorType(self) -> Qgis.GradientColorSource: ...
    def setGradientType(self, gradientType: Qgis.GradientType) -> None: ...
    def gradientType(self) -> Qgis.GradientType: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def clone(self) -> 'QgsGradientFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsShapeburstFillSymbolLayer(QgsFillSymbolLayer):

    def __init__(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., color2: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., colorType: Qgis.GradientColorSource = ..., blurRadius: int = ..., useWholeShape: bool = ..., maxDistance: float = ...) -> None: ...

    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offset(self) -> QtCore.QPointF: ...
    def setOffset(self, offset: QtCore.QPointF) -> None: ...
    def ignoreRings(self) -> bool: ...
    def setIgnoreRings(self, ignoreRings: bool) -> None: ...
    def color2(self) -> QtGui.QColor: ...
    def setColor2(self, color2: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def colorRamp(self) -> QgsColorRamp|None: ...
    def setColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def colorType(self) -> Qgis.GradientColorSource: ...
    def setColorType(self, colorType: Qgis.GradientColorSource) -> None: ...
    def distanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceUnit(self) -> Qgis.RenderUnit: ...
    def setDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def maxDistance(self) -> float: ...
    def setMaxDistance(self, maxDistance: float) -> None: ...
    def useWholeShape(self) -> bool: ...
    def setUseWholeShape(self, useWholeShape: bool) -> None: ...
    def blurRadius(self) -> int: ...
    def setBlurRadius(self, blurRadius: int) -> None: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def clone(self) -> 'QgsShapeburstFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsImageFillSymbolLayer(QgsFillSymbolLayer):

    def __init__(self) -> None: ...

    def applyBrushTransformFromContext(self, context: 'QgsSymbolRenderContext|None' = ...) -> bool: ...
    def applyDataDefinedSettings(self, context: 'QgsSymbolRenderContext') -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def dxfPenStyle(self) -> QtCore.Qt.PenStyle: ...
    def dxfWidth(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def coordinateReference(self) -> Qgis.SymbolCoordinateReference: ...
    def setCoordinateReference(self, coordinateReference: Qgis.SymbolCoordinateReference) -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...


class QgsRasterFillSymbolLayer(QgsImageFillSymbolLayer):

    def __init__(self, imageFilePath: str|None = ...) -> None: ...

    def applyBrushTransformFromContext(self, context: 'QgsSymbolRenderContext|None' = ...) -> bool: ...
    def applyDataDefinedSettings(self, context: 'QgsSymbolRenderContext') -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    @deprecated("""""")
    def widthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    @deprecated("""""")
    def setWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    @deprecated("""""")
    def widthUnit(self) -> Qgis.RenderUnit: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    @deprecated("""""")
    def setWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def height(self) -> float: ...
    def setHeight(self, height: float) -> None: ...
    def width(self) -> float: ...
    def setWidth(self, width: float) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offset(self) -> QtCore.QPointF: ...
    def setOffset(self, offset: QtCore.QPointF) -> None: ...
    def opacity(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def coordinateMode(self) -> Qgis.SymbolCoordinateReference: ...
    def setCoordinateMode(self, mode: Qgis.SymbolCoordinateReference) -> None: ...
    def imageFilePath(self) -> str: ...
    def setImageFilePath(self, imagePath: str|None) -> None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def usesMapUnits(self) -> bool: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def clone(self) -> 'QgsRasterFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def resolvePaths(properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsSVGFillSymbolLayer(QgsImageFillSymbolLayer):

    @typing.overload
    def __init__(self, svgFilePath: str|None, width: float = ..., rotation: float = ...) -> None: ...
    @typing.overload
    def __init__(self, svgData: QtCore.QByteArray|bytes|bytearray|memoryview, width: float = ..., rotation: float = ...) -> None: ...

    def applyDataDefinedSettings(self, context: 'QgsSymbolRenderContext') -> None: ...
    def setParameters(self, parameters: dict[str|None, QgsProperty]) -> None: ...
    def parameters(self) -> dict[str, QgsProperty]: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def svgStrokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSvgStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def svgStrokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setSvgStrokeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def patternWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setPatternWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def patternWidthUnit(self) -> Qgis.RenderUnit: ...
    def setPatternWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def svgStrokeWidth(self) -> float: ...
    def setSvgStrokeWidth(self, w: float) -> None: ...
    def svgStrokeColor(self) -> QtGui.QColor: ...
    def setSvgStrokeColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def svgFillColor(self) -> QtGui.QColor: ...
    def setSvgFillColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def patternWidth(self) -> float: ...
    def setPatternWidth(self, width: float) -> None: ...
    def svgFilePath(self) -> str: ...
    def setSvgFilePath(self, svgPath: str|None) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def dxfColor(self, context: 'QgsSymbolRenderContext') -> QtGui.QColor: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def usesMapUnits(self) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSVGFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def resolvePaths(properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsLinePatternFillSymbolLayer(QgsImageFillSymbolLayer):

    def __init__(self) -> None: ...

    def applyDataDefinedSettings(self, context: 'QgsSymbolRenderContext') -> None: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setClipMode(self, mode: Qgis.LineClipMode) -> None: ...
    def clipMode(self) -> Qgis.LineClipMode: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def lineWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setLineWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def lineWidthUnit(self) -> Qgis.RenderUnit: ...
    def setLineWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def distanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceUnit(self) -> Qgis.RenderUnit: ...
    def setDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offset(self) -> float: ...
    def setOffset(self, offset: float) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def lineWidth(self) -> float: ...
    def setLineWidth(self, w: float) -> None: ...
    def distance(self) -> float: ...
    def setDistance(self, d: float) -> None: ...
    def lineAngle(self) -> float: ...
    def setLineAngle(self, a: float) -> None: ...
    def ogrFeatureStyleWidth(self, widthScaleFactor: float) -> str: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def toTiledPatternImage(self) -> QtGui.QImage: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsLinePatternFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsPointPatternFillSymbolLayer(QgsImageFillSymbolLayer):

    def __init__(self) -> None: ...

    def applyDataDefinedSettings(self, context: 'QgsSymbolRenderContext') -> None: ...
    def setSeed(self, seed: int) -> None: ...
    def seed(self) -> int: ...
    def setRandomDeviationYMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def setRandomDeviationXMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def randomDeviationYMapUnitScale(self) -> QgsMapUnitScale: ...
    def randomDeviationXMapUnitScale(self) -> QgsMapUnitScale: ...
    def randomDeviationYUnit(self) -> Qgis.RenderUnit: ...
    def setRandomDeviationYUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def randomDeviationXUnit(self) -> Qgis.RenderUnit: ...
    def setRandomDeviationXUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def maximumRandomDeviationY(self) -> float: ...
    def setMaximumRandomDeviationY(self, deviation: float) -> None: ...
    def maximumRandomDeviationX(self) -> float: ...
    def setMaximumRandomDeviationX(self, deviation: float) -> None: ...
    def setClipMode(self, mode: Qgis.MarkerClipMode) -> None: ...
    def clipMode(self) -> Qgis.MarkerClipMode: ...
    def offsetYMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetYMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetYUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetYUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetXMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetXMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetXUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetXUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetY(self) -> float: ...
    def setOffsetY(self, offset: float) -> None: ...
    def offsetX(self) -> float: ...
    def setOffsetX(self, offset: float) -> None: ...
    def displacementYMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDisplacementYMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def displacementYUnit(self) -> Qgis.RenderUnit: ...
    def setDisplacementYUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setDisplacementY(self, d: float) -> None: ...
    def displacementY(self) -> float: ...
    def displacementXMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDisplacementXMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def displacementXUnit(self) -> Qgis.RenderUnit: ...
    def setDisplacementXUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setDisplacementX(self, d: float) -> None: ...
    def displacementX(self) -> float: ...
    def distanceYMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceYMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceYUnit(self) -> Qgis.RenderUnit: ...
    def setDistanceYUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setDistanceY(self, d: float) -> None: ...
    def distanceY(self) -> float: ...
    def distanceXMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceXMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceXUnit(self) -> Qgis.RenderUnit: ...
    def setDistanceXUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setDistanceX(self, d: float) -> None: ...
    def distanceX(self) -> float: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def toTiledPatternImage(self) -> QtGui.QImage: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsPointPatternFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsRandomMarkerFillSymbolLayer(QgsFillSymbolLayer):

    def __init__(self, pointCount: int = ..., method: Qgis.PointCountMethod = ..., densityArea: float = ..., seed: int = ...) -> None: ...

    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def densityAreaUnitScale(self) -> QgsMapUnitScale: ...
    def setDensityAreaUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def densityAreaUnit(self) -> Qgis.RenderUnit: ...
    def setDensityAreaUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setDensityArea(self, area: float) -> None: ...
    def densityArea(self) -> float: ...
    def setCountMethod(self, method: Qgis.PointCountMethod) -> None: ...
    def countMethod(self) -> Qgis.PointCountMethod: ...
    def setClipPoints(self, clipped: bool) -> None: ...
    def clipPoints(self) -> bool: ...
    def setSeed(self, seed: int) -> None: ...
    def seed(self) -> int: ...
    def setPointCount(self, count: int) -> None: ...
    def pointCount(self) -> int: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def rendersIdenticallyTo(self, other: QgsSymbolLayer|None) -> bool: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def clone(self) -> 'QgsRandomMarkerFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsCentroidFillSymbolLayer(QgsFillSymbolLayer):

    def __init__(self) -> None: ...

    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def setClipOnCurrentPartOnly(self, clipOnCurrentPartOnly: bool) -> None: ...
    def clipOnCurrentPartOnly(self) -> bool: ...
    def setClipPoints(self, clipPoints: bool) -> None: ...
    def clipPoints(self) -> bool: ...
    def pointOnAllParts(self) -> bool: ...
    def setPointOnAllParts(self, pointOnAllParts: bool) -> None: ...
    def pointOnSurface(self) -> bool: ...
    def setPointOnSurface(self, pointOnSurface: bool) -> None: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsCentroidFillSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygon(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsGeometryGeneratorSymbolLayer(QgsSymbolLayer):

    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def render(self, context: 'QgsSymbolRenderContext', geometryType: Qgis.GeometryType = ..., points: QtGui.QPolygonF|None = ..., rings: collections.abc.Iterable[QtGui.QPolygonF] = ...) -> None: ...
    def isCompatibleWithSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def setUnits(self, units: Qgis.RenderUnit) -> None: ...
    def units(self) -> Qgis.RenderUnit: ...
    def geometryExpression(self) -> str: ...
    def setGeometryExpression(self, exp: str|None) -> None: ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> QgsSymbolLayer|None: ...
    def rendersIdenticallyTo(self, other: QgsSymbolLayer|None) -> bool: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def color(self) -> QtGui.QColor: ...
    def usesMapUnits(self) -> bool: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def symbolType(self) -> Qgis.SymbolType: ...
    def setSymbolType(self, symbolType: Qgis.SymbolType) -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any]) -> QgsSymbolLayer|None: ...


class QgsGraduatedSymbolRenderer(QgsFeatureRenderer):

    class Mode(enum.IntEnum):
        EqualInterval = ... # type: QgsGraduatedSymbolRenderer.Mode
        Quantile = ... # type: QgsGraduatedSymbolRenderer.Mode
        Jenks = ... # type: QgsGraduatedSymbolRenderer.Mode
        StdDev = ... # type: QgsGraduatedSymbolRenderer.Mode
        Pretty = ... # type: QgsGraduatedSymbolRenderer.Mode
        Custom = ... # type: QgsGraduatedSymbolRenderer.Mode

    def __init__(self, attrName: str|None = ..., ranges: collections.abc.Iterable['QgsRendererRange'] = ...) -> None: ...

    def legendKeyForValue(self, value: float) -> str: ...
    def symbolForValue(self, value: float) -> QgsSymbol|None: ...
    def rangeForValue(self, value: float) -> 'QgsRendererRange|None': ...
    def updateRangeLabels(self) -> None: ...
    def dataDefinedSizeLegend(self) -> QgsDataDefinedSizeLegend|None: ...
    def setDataDefinedSizeLegend(self, settings: QgsDataDefinedSizeLegend|None) -> None: ...
    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsGraduatedSymbolRenderer|None': ...
    def legendClassificationAttribute(self) -> str: ...
    def setLegendSymbolItem(self, key: str|None, symbol: QgsSymbol|None) -> None: ...
    def checkLegendSymbolItem(self, key: str|None, state: bool = ...) -> None: ...
    def legendSymbolItemChecked(self, key: str|None) -> bool: ...
    def legendSymbolItemsCheckable(self) -> bool: ...
    def setGraduatedMethod(self, method: Qgis.GraduatedMethod) -> None: ...
    def graduatedMethod(self) -> Qgis.GraduatedMethod: ...
    def maxSymbolSize(self) -> float: ...
    def minSymbolSize(self) -> float: ...
    def setSymbolSizes(self, minSize: float, maxSize: float) -> None: ...
    def updateSymbols(self, sym: QgsSymbol|None) -> None: ...
    def updateColorRamp(self, ramp: QgsColorRamp|None = ...) -> None: ...
    def setSourceColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def sourceColorRamp(self) -> QgsColorRamp|None: ...
    def setSourceSymbol(self, sym: QgsSymbol|None) -> None: ...
    def sourceSymbol(self) -> QgsSymbol|None: ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def legendSymbolItems(self) -> list['QgsLegendSymbolItem']: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    @staticmethod
    @deprecated("""""")
    def createRenderer(vlayer: QgsVectorLayer|None, attrName: str|None, classes: int, mode: 'QgsGraduatedSymbolRenderer.Mode', symbol: QgsSymbol|None, ramp: QgsColorRamp|None, legendFormat: 'QgsRendererRangeLabelFormat' = ..., useSymmetricMode: bool = ..., symmetryPoint: float = ..., listForCboPrettyBreaks: collections.abc.Iterable[str|None] = ..., astride: bool = ...) -> 'QgsGraduatedSymbolRenderer|None': ...
    def calculateLabelPrecision(self, updateRanges: bool = ...) -> None: ...
    @deprecated("""""")
    def setLabelFormat(self, labelFormat: 'QgsRendererRangeLabelFormat', updateRanges: bool = ...) -> None: ...
    @deprecated("""""")
    def labelFormat(self) -> 'QgsRendererRangeLabelFormat': ...
    @typing.overload
    @deprecated("""""")
    def updateClasses(self, vlayer: QgsVectorLayer|None, mode: 'QgsGraduatedSymbolRenderer.Mode', nclasses: int, useSymmetricMode: bool = ..., symmetryPoint: float = ..., astride: bool = ...) -> None: ...
    @typing.overload
    def updateClasses(self, vl: QgsVectorLayer|None, nclasses: int) -> str: ...
    @staticmethod
    @deprecated("""""")
    def calcEqualIntervalBreaks(minimum: float, maximum: float, classes: int, useSymmetricMode: bool, symmetryPoint: float, astride: bool) -> list[float]: ...
    @staticmethod
    @deprecated("""""")
    def makeBreaksSymmetric(breaks: collections.abc.Iterable[float], symmetryPoint: float, astride: bool) -> list[float]: ...
    @deprecated("""""")
    def setAstride(self, astride: bool) -> None: ...
    @deprecated("""""")
    def astride(self) -> bool: ...
    @deprecated("""""")
    def setSymmetryPoint(self, symmetryPoint: float) -> None: ...
    @deprecated("""""")
    def symmetryPoint(self) -> float: ...
    @deprecated("""""")
    def setUseSymmetricMode(self, useSymmetricMode: bool) -> None: ...
    @deprecated("""""")
    def useSymmetricMode(self) -> bool: ...
    @deprecated("""""")
    def setMode(self, mode: 'QgsGraduatedSymbolRenderer.Mode') -> None: ...
    @deprecated("""""")
    def mode(self) -> 'QgsGraduatedSymbolRenderer.Mode': ...
    def setClassificationMethod(self, method: QgsClassificationMethod|None) -> None: ...
    def classificationMethod(self) -> QgsClassificationMethod|None: ...
    def sortByLabel(self, order: QtCore.Qt.SortOrder = ...) -> None: ...
    def sortByValue(self, order: QtCore.Qt.SortOrder = ...) -> None: ...
    def rangesHaveGaps(self) -> bool: ...
    def rangesOverlap(self) -> bool: ...
    def moveClass(self, from_: int, to: int) -> None: ...
    def deleteAllClasses(self) -> None: ...
    def deleteClass(self, idx: int) -> None: ...
    def addBreak(self, breakValue: float, updateSymbols: bool = ...) -> None: ...
    def addClassLowerUpper(self, lower: float, upper: float) -> None: ...
    def addClassRange(self, range: 'QgsRendererRange') -> None: ...
    def addClass(self, symbol: QgsSymbol|None) -> None: ...
    def updateRangeRenderState(self, rangeIndex: int, render: bool) -> bool: ...
    def updateRangeLowerValue(self, rangeIndex: int, value: float) -> bool: ...
    def updateRangeUpperValue(self, rangeIndex: int, value: float) -> bool: ...
    def updateRangeLabel(self, rangeIndex: int, label: str|None) -> bool: ...
    def updateRangeSymbol(self, rangeIndex: int, symbol: QgsSymbol|None) -> bool: ...
    def ranges(self) -> list['QgsRendererRange']: ...
    def setClassAttribute(self, attr: str|None) -> None: ...
    def classAttribute(self) -> str: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsGraduatedSymbolRenderer|None': ...
    def dump(self) -> str: ...
    def filterNeedsGeometry(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...


class QgsHeatmapRenderer(QgsFeatureRenderer):

    def __init__(self) -> None: ...

    def setWeightExpression(self, expression: str|None) -> None: ...
    def weightExpression(self) -> str: ...
    def setRenderQuality(self, quality: int) -> None: ...
    def renderQuality(self) -> float: ...
    def setMaximumValue(self, value: float) -> None: ...
    def maximumValue(self) -> float: ...
    def setRadiusMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def radiusMapUnitScale(self) -> QgsMapUnitScale: ...
    def setRadiusUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def radiusUnit(self) -> Qgis.RenderUnit: ...
    def setRadius(self, radius: float) -> None: ...
    def radius(self) -> float: ...
    def setLegendSettings(self, settings: QgsColorRampLegendNodeSettings) -> None: ...
    def legendSettings(self) -> QgsColorRampLegendNodeSettings: ...
    def setColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def colorRamp(self) -> QgsColorRamp|None: ...
    def modifyRequestExtent(self, extent: QgsRectangle, context: QgsRenderContext) -> None: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsHeatmapRenderer|None': ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def dump(self) -> str: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def clone(self) -> 'QgsHeatmapRenderer|None': ...


class QgsInterpolatedLineColor(PyQt6.sip.wrapper):

    class ColoringMethod(enum.IntEnum):
        SingleColor = ... # type: QgsInterpolatedLineColor.ColoringMethod
        ColorRamp = ... # type: QgsInterpolatedLineColor.ColoringMethod

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, colorRampShader: QgsColorRampShader) -> None: ...
    @typing.overload
    def __init__(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsInterpolatedLineColor') -> None: ...

    def graduatedColors(self, value1: float, value2: float, breakValues: collections.abc.Iterable[float], breakColors: collections.abc.Iterable[QtGui.QColor|QtCore.Qt.GlobalColor|int], gradients: collections.abc.Iterable[QtGui.QLinearGradient]) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def singleColor(self) -> QtGui.QColor: ...
    def colorRampShader(self) -> QgsColorRampShader: ...
    def coloringMethod(self) -> 'QgsInterpolatedLineColor.ColoringMethod': ...
    def setColoringMethod(self, coloringMethod: 'QgsInterpolatedLineColor.ColoringMethod') -> None: ...
    def color(self, magnitude: float) -> QtGui.QColor: ...
    @typing.overload
    def setColor(self, colorRampShader: QgsColorRampShader) -> None: ...
    @typing.overload
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...


class QgsInterpolatedLineWidth(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsInterpolatedLineWidth') -> None: ...

    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def strokeWidth(self, value: float) -> float: ...
    def setFixedStrokeWidth(self, fixedWidth: float) -> None: ...
    def fixedStrokeWidth(self) -> float: ...
    def setIsVariableWidth(self, isVariableWidth: bool) -> None: ...
    def isVariableWidth(self) -> bool: ...
    def setUseAbsoluteValue(self, useAbsoluteValue: bool) -> None: ...
    def useAbsoluteValue(self) -> bool: ...
    def setIgnoreOutOfRange(self, ignoreOutOfRange: bool) -> None: ...
    def ignoreOutOfRange(self) -> bool: ...
    def setMaximumWidth(self, maximumWidth: float) -> None: ...
    def maximumWidth(self) -> float: ...
    def setMinimumWidth(self, minimumWidth: float) -> None: ...
    def minimumWidth(self) -> float: ...
    def setMaximumValue(self, maximumValue: float) -> None: ...
    def maximumValue(self) -> float: ...
    def setMinimumValue(self, minimumValue: float) -> None: ...
    def minimumValue(self) -> float: ...


class QgsInterpolatedLineRenderer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsInterpolatedLineRenderer') -> None: ...

    def setSelected(self, selected: bool) -> None: ...
    def renderInDeviceCoordinates(self, valueColor1: float, valueColor2: float, valueWidth1: float, valueWidth2: float, point1: QtCore.QPointF, point2: QtCore.QPointF, context: QgsRenderContext) -> None: ...
    @typing.overload
    def render(self, value1: float, value2: float, point1: QgsPointXY, point2: QgsPointXY, context: QgsRenderContext) -> None: ...
    @typing.overload
    def render(self, valueColor1: float, valueColor2: float, valueWidth1: float, valueWidth2: float, point1: QgsPointXY, point2: QgsPointXY, context: QgsRenderContext) -> None: ...
    def interpolatedColor(self) -> QgsInterpolatedLineColor: ...
    def setInterpolatedColor(self, strokeColoring: QgsInterpolatedLineColor) -> None: ...
    def widthUnit(self) -> Qgis.RenderUnit: ...
    def setWidthUnit(self, strokeWidthUnit: Qgis.RenderUnit) -> None: ...
    def interpolatedLineWidth(self) -> QgsInterpolatedLineWidth: ...
    def setInterpolatedWidth(self, strokeWidth: QgsInterpolatedLineWidth) -> None: ...


class QgsInterpolatedLineSymbolLayer(QgsLineSymbolLayer):

    def __init__(self) -> None: ...

    def interpolatedColor(self) -> QgsInterpolatedLineColor: ...
    def setInterpolatedColor(self, interpolatedLineColor: QgsInterpolatedLineColor) -> None: ...
    @deprecated("""""")
    def endValueExpressionForColor(self) -> str: ...
    @deprecated("""""")
    def startValueExpressionForColor(self) -> str: ...
    @deprecated("""""")
    def setExpressionsStringForColor(self, start: str|None, end: str|None) -> None: ...
    def interpolatedWidth(self) -> QgsInterpolatedLineWidth: ...
    def setInterpolatedWidth(self, interpolatedLineWidth: QgsInterpolatedLineWidth) -> None: ...
    def widthUnit(self) -> Qgis.RenderUnit: ...
    def setWidthUnit(self, strokeWidthUnit: Qgis.RenderUnit) -> None: ...
    @deprecated("""""")
    def endValueExpressionForWidth(self) -> str: ...
    @deprecated("""""")
    def startValueExpressionForWidth(self) -> str: ...
    @deprecated("""""")
    def setExpressionsStringForWidth(self, start: str|None, end: str|None) -> None: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsInterpolatedLineSymbolLayer|None': ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any]) -> QgsSymbolLayer|None: ...


class QgsMergedFeatureRenderer(QgsFeatureRenderer):

    class GeometryOperation(enum.IntEnum):
        Merge = ... # type: QgsMergedFeatureRenderer.GeometryOperation
        InvertOnly = ... # type: QgsMergedFeatureRenderer.GeometryOperation
        MergeAndInvert = ... # type: QgsMergedFeatureRenderer.GeometryOperation

    @typing.overload
    def __init__(self, embeddedRenderer: QgsFeatureRenderer|None) -> None: ...
    @typing.overload
    def __init__(self, type: str|None, embeddedRenderer: QgsFeatureRenderer|None) -> None: ...

    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsMergedFeatureRenderer|None': ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def checkLegendSymbolItem(self, key: str|None, state: bool = ...) -> None: ...
    def legendSymbolItemChecked(self, key: str|None) -> bool: ...
    def legendSymbolItemsCheckable(self) -> bool: ...
    def setLegendSymbolItem(self, key: str|None, symbol: QgsSymbol|None) -> None: ...
    def embeddedRenderer(self) -> QgsFeatureRenderer|None: ...
    def setEmbeddedRenderer(self, subRenderer: QgsFeatureRenderer|None) -> None: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def willRenderFeature(self, feature: QgsFeature, context: QgsRenderContext) -> bool: ...
    def legendSymbolItems(self) -> list['QgsLegendSymbolItem']: ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def originalSymbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def symbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    def filterNeedsGeometry(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def dump(self) -> str: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def clone(self) -> 'QgsMergedFeatureRenderer|None': ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...


class QgsInvertedPolygonRenderer(QgsMergedFeatureRenderer):

    def __init__(self, embeddedRenderer: QgsFeatureRenderer|None = ...) -> None: ...

    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsInvertedPolygonRenderer|None': ...
    def setPreprocessingEnabled(self, enabled: bool) -> None: ...
    def preprocessingEnabled(self) -> bool: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def dump(self) -> str: ...
    def clone(self) -> 'QgsInvertedPolygonRenderer|None': ...


class QgsLegendSymbolItem(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, symbol: QgsSymbol|None, label: str|None, ruleKey: str|None, checkable: bool = ..., scaleMinDenom: int = ..., scaleMaxDenom: int = ..., level: int = ..., parentRuleKey: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsLegendSymbolItem') -> None: ...

    def userData(self, key: int) -> typing.Any: ...
    def setUserData(self, key: int, value: typing.Any) -> None: ...
    def dataDefinedSizeLegendSettings(self) -> QgsDataDefinedSizeLegend|None: ...
    def setDataDefinedSizeLegendSettings(self, settings: QgsDataDefinedSizeLegend|None) -> None: ...
    def setSymbol(self, s: QgsSymbol|None) -> None: ...
    def parentRuleKey(self) -> str: ...
    def level(self) -> int: ...
    def scaleMaxDenom(self) -> int: ...
    def scaleMinDenom(self) -> int: ...
    def isScaleOK(self, scale: float) -> bool: ...
    def legacyRuleKey(self) -> QgsSymbol|None: ...
    def isCheckable(self) -> bool: ...
    def ruleKey(self) -> str: ...
    def label(self) -> str: ...
    def symbol(self) -> QgsSymbol|None: ...


class QgsLinearReferencingSymbolLayer(QgsLineSymbolLayer):

    def __init__(self) -> None: ...

    def averageAngleMapUnitScale(self) -> QgsMapUnitScale: ...
    def setAverageAngleMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def averageAngleUnit(self) -> Qgis.RenderUnit: ...
    def setAverageAngleUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setAverageAngleLength(self, length: float) -> None: ...
    def averageAngleLength(self) -> float: ...
    def setLabelSource(self, source: Qgis.LinearReferencingLabelSource) -> None: ...
    def labelSource(self) -> Qgis.LinearReferencingLabelSource: ...
    def setPlacement(self, placement: Qgis.LinearReferencingPlacement) -> None: ...
    def placement(self) -> Qgis.LinearReferencingPlacement: ...
    def setShowMarker(self, show: bool) -> None: ...
    def showMarker(self) -> bool: ...
    def setLabelOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def labelOffsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setLabelOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def labelOffsetUnit(self) -> Qgis.RenderUnit: ...
    def setLabelOffset(self, offset: QtCore.QPointF) -> None: ...
    def labelOffset(self) -> QtCore.QPointF: ...
    def setRotateLabels(self, rotate: bool) -> None: ...
    def rotateLabels(self) -> bool: ...
    def setSkipMultiplesOf(self, multiple: float) -> None: ...
    def skipMultiplesOf(self) -> float: ...
    def setInterval(self, interval: float) -> None: ...
    def interval(self) -> float: ...
    def setNumericFormat(self, format: QgsNumericFormat|None) -> None: ...
    def numericFormat(self) -> QgsNumericFormat|None: ...
    def setTextFormat(self, format: 'QgsTextFormat') -> None: ...
    def textFormat(self) -> 'QgsTextFormat': ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsLinearReferencingSymbolLayer|None': ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsLineSymbol(QgsSymbol):

    def __init__(self, layers: collections.abc.Iterable[QgsSymbolLayer] = ...) -> None: ...

    def clone(self) -> 'QgsLineSymbol|None': ...
    def renderPolyline(self, points: QtGui.QPolygonF, f: QgsFeature|None, context: QgsRenderContext, layer: int = ..., selected: bool = ...) -> None: ...
    def dataDefinedWidth(self) -> QgsProperty: ...
    def setDataDefinedWidth(self, property: QgsProperty) -> None: ...
    @typing.overload
    def width(self) -> float: ...
    @typing.overload
    def width(self, context: QgsRenderContext) -> float: ...
    def setWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setWidth(self, width: float) -> None: ...
    @staticmethod
    def createSimple(properties: dict[str|None, typing.Any]) -> 'QgsLineSymbol'|None: ...


class QgsSimpleLineSymbolLayer(QgsLineSymbolLayer):

    def __init__(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., width: float = ..., penStyle: QtCore.Qt.PenStyle = ...) -> None: ...

    def setTweakDashPatternOnCorners(self, enabled: bool) -> None: ...
    def tweakDashPatternOnCorners(self) -> bool: ...
    def setAlignDashPattern(self, enabled: bool) -> None: ...
    def alignDashPattern(self) -> bool: ...
    def setDrawInsidePolygon(self, drawInsidePolygon: bool) -> None: ...
    def drawInsidePolygon(self) -> bool: ...
    def setTrimDistanceEndMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def trimDistanceEndMapUnitScale(self) -> QgsMapUnitScale: ...
    def trimDistanceEndUnit(self) -> Qgis.RenderUnit: ...
    def setTrimDistanceEndUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setTrimDistanceEnd(self, distance: float) -> None: ...
    def trimDistanceEnd(self) -> float: ...
    def setTrimDistanceStartMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def trimDistanceStartMapUnitScale(self) -> QgsMapUnitScale: ...
    def trimDistanceStartUnit(self) -> Qgis.RenderUnit: ...
    def setTrimDistanceStartUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setTrimDistanceStart(self, distance: float) -> None: ...
    def trimDistanceStart(self) -> float: ...
    def setDashPatternOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def dashPatternOffsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def dashPatternOffsetUnit(self) -> Qgis.RenderUnit: ...
    def setDashPatternOffsetUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setDashPatternOffset(self, offset: float) -> None: ...
    def dashPatternOffset(self) -> float: ...
    def setCustomDashVector(self, vector: collections.abc.Iterable[float]) -> None: ...
    def customDashVector(self) -> list[float]: ...
    def setCustomDashPatternMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def customDashPatternMapUnitScale(self) -> QgsMapUnitScale: ...
    def customDashPatternUnit(self) -> Qgis.RenderUnit: ...
    def setCustomDashPatternUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setUseCustomDashPattern(self, b: bool) -> None: ...
    def useCustomDashPattern(self) -> bool: ...
    def setPenCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    def penCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setPenStyle(self, style: QtCore.Qt.PenStyle) -> None: ...
    def penStyle(self) -> QtCore.Qt.PenStyle: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def dxfColor(self, context: 'QgsSymbolRenderContext') -> QtGui.QColor: ...
    def dxfOffset(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfWidth(self, e: QgsDxfExport, context: 'QgsSymbolRenderContext') -> float: ...
    def dxfPenStyle(self) -> QtCore.Qt.PenStyle: ...
    def dxfCustomDashPattern(self) -> typing.Tuple[list[float], Qgis.RenderUnit]: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def ogrFeatureStyle(self, mmScaleFactor: float, mapUnitScaleFactor: float) -> str: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSimpleLineSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolygonStroke(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsTemplatedLineSymbolLayerBase(QgsLineSymbolLayer):

    def __init__(self, rotateSymbol: bool = ..., interval: float = ...) -> None: ...

    @staticmethod
    def setCommonProperties(destLayer: 'QgsTemplatedLineSymbolLayerBase|None', properties: dict[str|None, typing.Any]) -> None: ...
    def renderSymbol(self, point: QtCore.QPointF, feature: QgsFeature|None, context: QgsRenderContext, layer: int = ..., selected: bool = ...) -> None: ...
    def setSymbolAngle(self, angle: float) -> None: ...
    def symbolAngle(self) -> float: ...
    def setSymbolLineAngle(self, angle: float) -> None: ...
    def copyTemplateSymbolProperties(self, destLayer: 'QgsTemplatedLineSymbolLayerBase|None') -> None: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def canCauseArtifactsBetweenAdjacentTiles(self) -> bool: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def renderPolygonStroke(self, points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF], context: 'QgsSymbolRenderContext') -> None: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def blankSegmentsUnit(self) -> Qgis.RenderUnit: ...
    def setBlankSegmentsUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def averageAngleMapUnitScale(self) -> QgsMapUnitScale: ...
    def setAverageAngleMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def averageAngleUnit(self) -> Qgis.RenderUnit: ...
    def setAverageAngleUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setAverageAngleLength(self, length: float) -> None: ...
    def averageAngleLength(self) -> float: ...
    def setOffsetAlongLineMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetAlongLineMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetAlongLineUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def offsetAlongLineUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetAlongLine(self, offsetAlongLine: float) -> None: ...
    def offsetAlongLine(self) -> float: ...
    def setPlaceOnEveryPart(self, respect: bool) -> None: ...
    def placeOnEveryPart(self) -> bool: ...
    def setPlacements(self, placements: Qgis.MarkerLinePlacement) -> None: ...
    def placements(self) -> Qgis.MarkerLinePlacement: ...
    @deprecated("""""")
    def setPlacement(self, placement: Qgis.MarkerLinePlacement) -> None: ...
    @deprecated("""""")
    def placement(self) -> Qgis.MarkerLinePlacement: ...
    def intervalMapUnitScale(self) -> QgsMapUnitScale: ...
    def setIntervalMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def intervalUnit(self) -> Qgis.RenderUnit: ...
    def setIntervalUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setInterval(self, interval: float) -> None: ...
    def interval(self) -> float: ...
    def setRotateSymbols(self, rotate: bool) -> None: ...
    def rotateSymbols(self) -> bool: ...


class QgsMarkerLineSymbolLayer(QgsTemplatedLineSymbolLayerBase):

    def __init__(self, rotateMarker: bool = ..., interval: float = ...) -> None: ...

    def renderSymbol(self, point: QtCore.QPointF, feature: QgsFeature|None, context: QgsRenderContext, layer: int = ..., selected: bool = ...) -> None: ...
    def setSymbolAngle(self, angle: float) -> None: ...
    def symbolAngle(self) -> float: ...
    def setSymbolLineAngle(self, angle: float) -> None: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    @deprecated("""""")
    def setRotateMarker(self, rotate: bool) -> None: ...
    @deprecated("""""")
    def rotateMarker(self) -> bool: ...
    def setDataDefinedProperty(self, key: QgsSymbolLayer.Property, property: QgsProperty) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def usesMapUnits(self) -> bool: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    @typing.overload
    def width(self) -> float: ...
    @typing.overload
    def width(self, context: QgsRenderContext) -> float: ...
    def setWidth(self, width: float) -> None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsMarkerLineSymbolLayer|None': ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsHashedLineSymbolLayer(QgsTemplatedLineSymbolLayerBase):

    def __init__(self, rotateSymbol: bool = ..., interval: float = ...) -> None: ...

    def renderSymbol(self, point: QtCore.QPointF, feature: QgsFeature|None, context: QgsRenderContext, layer: int = ..., selected: bool = ...) -> None: ...
    def setSymbolAngle(self, angle: float) -> None: ...
    def symbolAngle(self) -> float: ...
    def setSymbolLineAngle(self, angle: float) -> None: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def hashLengthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setHashLengthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def hashLengthUnit(self) -> Qgis.RenderUnit: ...
    def setHashLengthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setHashLength(self, length: float) -> None: ...
    def hashLength(self) -> float: ...
    def setHashAngle(self, angle: float) -> None: ...
    def hashAngle(self) -> float: ...
    def usesMapUnits(self) -> bool: ...
    def setDataDefinedProperty(self, key: QgsSymbolLayer.Property, property: QgsProperty) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    @typing.overload
    def width(self) -> float: ...
    @typing.overload
    def width(self, context: QgsRenderContext) -> float: ...
    def setWidth(self, width: float) -> None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def clone(self) -> 'QgsHashedLineSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsAbstractBrushedLineSymbolLayer(QgsLineSymbolLayer):

    def __init__(self) -> None: ...

    def renderPolylineUsingBrush(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext', brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient, patternThickness: float, patternLength: float) -> None: ...
    def setPenCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    def penCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...


class QgsRasterLineSymbolLayer(QgsAbstractBrushedLineSymbolLayer):

    def __init__(self, path: str|None = ...) -> None: ...

    def color(self) -> QtGui.QColor: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def clone(self) -> 'QgsRasterLineSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setPath(self, path: str|None) -> None: ...
    def path(self) -> str: ...
    @staticmethod
    def resolvePaths(properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsLineburstSymbolLayer(QgsAbstractBrushedLineSymbolLayer):

    def __init__(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., color2: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...

    def setColor2(self, color2: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color2(self) -> QtGui.QColor: ...
    def setColorRamp(self, ramp: QgsColorRamp|None) -> None: ...
    def colorRamp(self) -> QgsColorRamp|None: ...
    def setGradientColorType(self, gradientColorType: Qgis.GradientColorSource) -> None: ...
    def gradientColorType(self) -> Qgis.GradientColorSource: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def clone(self) -> 'QgsLineburstSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsFilledLineSymbolLayer(QgsLineSymbolLayer):

    def __init__(self, width: float = ..., fillSymbol: QgsFillSymbol|None = ...) -> None: ...

    def setPenCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    def penCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def clone(self) -> 'QgsFilledLineSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPolyline(self, points: QtGui.QPolygonF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsMapInfoSymbolConversionContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapInfoSymbolConversionContext') -> None: ...

    def clearWarnings(self) -> None: ...
    def warnings(self) -> list[str]: ...
    def pushWarning(self, warning: str|None) -> None: ...


class QgsMapInfoSymbolConverter(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapInfoSymbolConverter') -> None: ...

    @staticmethod
    def convertMarkerSymbol(identifier: int, context: QgsMapInfoSymbolConversionContext, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, size: float, sizeUnit: Qgis.RenderUnit) -> 'QgsMarkerSymbol|None': ...
    @staticmethod
    def convertFillSymbol(identifier: int, context: QgsMapInfoSymbolConversionContext, foreColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, backColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> QgsFillSymbol|None: ...
    @staticmethod
    def convertLineSymbol(identifier: int, context: QgsMapInfoSymbolConversionContext, foreColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, size: float, sizeUnit: Qgis.RenderUnit, interleaved: bool = ...) -> QgsLineSymbol|None: ...


class QgsMarkerSymbol(QgsSymbol):

    def __init__(self, layers: collections.abc.Iterable[QgsSymbolLayer] = ...) -> None: ...

    def clone(self) -> 'QgsMarkerSymbol|None': ...
    def bounds(self, point: QtCore.QPointF, context: QgsRenderContext, feature: QgsFeature = ...) -> QtCore.QRectF: ...
    def renderPoint(self, point: QtCore.QPointF, f: QgsFeature|None, context: QgsRenderContext, layer: int = ..., selected: bool = ...) -> None: ...
    def scaleMethod(self) -> Qgis.ScaleMethod: ...
    def setScaleMethod(self, scaleMethod: Qgis.ScaleMethod) -> None: ...
    def dataDefinedSize(self) -> QgsProperty: ...
    def setDataDefinedSize(self, property: QgsProperty) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    @typing.overload
    def size(self) -> float: ...
    @typing.overload
    def size(self, context: QgsRenderContext) -> float: ...
    def setSize(self, size: float) -> None: ...
    def setLineAngle(self, lineAngle: float) -> None: ...
    def dataDefinedAngle(self) -> QgsProperty: ...
    def setDataDefinedAngle(self, property: QgsProperty) -> None: ...
    def angle(self) -> float: ...
    def setAngle(self, symbolAngle: float) -> None: ...
    @staticmethod
    def createSimple(properties: dict[str|None, typing.Any]) -> 'QgsMarkerSymbol'|None: ...


class QgsSimpleMarkerSymbolLayerBase(QgsMarkerSymbolLayer):

    def __init__(self, shape: Qgis.MarkerShape = ..., size: float = ..., angle: float = ..., scaleMethod: Qgis.ScaleMethod = ...) -> None: ...

    def calculateOffsetAndRotation(self, context: 'QgsSymbolRenderContext', scaledSize: float, offset: QtCore.QPointF) -> typing.Tuple[bool, float]: ...
    def calculateSize(self, context: 'QgsSymbolRenderContext') -> typing.Tuple[float, bool]: ...
    def shapeToPolygon(self, shape: Qgis.MarkerShape, polygon: QtGui.QPolygonF) -> bool: ...
    def prepareMarkerPath(self, symbol: Qgis.MarkerShape) -> bool: ...
    def prepareMarkerShape(self, shape: Qgis.MarkerShape) -> bool: ...
    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    @staticmethod
    def encodeShape(shape: Qgis.MarkerShape) -> str: ...
    @staticmethod
    def decodeShape(name: str|None) -> typing.Tuple[Qgis.MarkerShape, bool]: ...
    def setShape(self, shape: Qgis.MarkerShape) -> None: ...
    def shape(self) -> Qgis.MarkerShape: ...
    @staticmethod
    def shapeIsFilled(shape: Qgis.MarkerShape) -> bool: ...
    @staticmethod
    def availableShapes() -> list[Qgis.MarkerShape]: ...


class QgsSimpleMarkerSymbolLayer(QgsSimpleMarkerSymbolLayerBase):

    def __init__(self, shape: Qgis.MarkerShape = ..., size: float = ..., angle: float = ..., scaleMethod: Qgis.ScaleMethod = ..., color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., penJoinStyle: QtCore.Qt.PenJoinStyle = ...) -> None: ...

    def prepareCache(self, context: 'QgsSymbolRenderContext') -> bool: ...
    def drawMarker(self, p: QtGui.QPainter|None, context: 'QgsSymbolRenderContext') -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidthUnit(self, u: Qgis.RenderUnit) -> None: ...
    def setStrokeWidth(self, w: float) -> None: ...
    def strokeWidth(self) -> float: ...
    def setPenCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    def penCapStyle(self) -> QtCore.Qt.PenCapStyle: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setStrokeStyle(self, strokeStyle: QtCore.Qt.PenStyle) -> None: ...
    def strokeStyle(self) -> QtCore.Qt.PenStyle: ...
    def setStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def usesMapUnits(self) -> bool: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def writeDxf(self, e: QgsDxfExport, mmMapUnitScaleFactor: float, layerName: str|None, context: 'QgsSymbolRenderContext', shift: QtCore.QPointF = ...) -> bool: ...
    def ogrFeatureStyle(self, mmScaleFactor: float, mapUnitScaleFactor: float) -> str: ...
    @typing.overload
    @deprecated("""""")
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSimpleMarkerSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsFilledMarkerSymbolLayer(QgsSimpleMarkerSymbolLayerBase):

    def __init__(self, shape: Qgis.MarkerShape = ..., size: float = ..., angle: float = ..., scaleMethod: Qgis.ScaleMethod = ...) -> None: ...

    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def estimateMaxBleed(self, context: QgsRenderContext) -> float: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def clone(self) -> 'QgsFilledMarkerSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def stopFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def startFeatureRender(self, feature: QgsFeature, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsSvgMarkerSymbolLayer(QgsMarkerSymbolLayer):

    def __init__(self, path: str|None, size: float = ..., angle: float = ..., scaleMethod: Qgis.ScaleMethod = ...) -> None: ...

    def calculateAspectRatio(self, context: 'QgsSymbolRenderContext', scaledSize: float) -> typing.Tuple[float, bool]: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def prepareExpressions(self, context: 'QgsSymbolRenderContext') -> None: ...
    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def writeDxf(self, e: QgsDxfExport, mmMapUnitScaleFactor: float, layerName: str|None, context: 'QgsSymbolRenderContext', shift: QtCore.QPointF = ...) -> bool: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def setParameters(self, parameters: dict[str|None, QgsProperty]) -> None: ...
    def parameters(self) -> dict[str, QgsProperty]: ...
    def setStrokeWidth(self, w: float) -> None: ...
    def strokeWidth(self) -> float: ...
    def setStrokeColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setFixedAspectRatio(self, ratio: float) -> None: ...
    def fixedAspectRatio(self) -> float: ...
    def setPreservedAspectRatio(self, par: bool) -> bool: ...
    def preservedAspectRatio(self) -> bool: ...
    def updateDefaultAspectRatio(self) -> float: ...
    def defaultAspectRatio(self) -> float: ...
    def setPath(self, path: str|None) -> None: ...
    def path(self) -> str: ...
    @typing.overload
    @deprecated("""""")
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSvgMarkerSymbolLayer|None': ...
    def usesMapUnits(self) -> bool: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def resolvePaths(properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsRasterMarkerSymbolLayer(QgsMarkerSymbolLayer):

    def __init__(self, path: str|None = ..., size: float = ..., angle: float = ..., scaleMethod: Qgis.ScaleMethod = ...) -> None: ...

    def copyCommonProperties(self, other: 'QgsRasterMarkerSymbolLayer|None') -> None: ...
    def setCommonProperties(self, properties: dict[str|None, typing.Any]) -> None: ...
    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def setFixedAspectRatio(self, ratio: float) -> None: ...
    def fixedAspectRatio(self) -> float: ...
    def setPreservedAspectRatio(self, par: bool) -> bool: ...
    def preservedAspectRatio(self) -> bool: ...
    def updateDefaultAspectRatio(self) -> float: ...
    def defaultAspectRatio(self) -> float: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setPath(self, path: str|None) -> None: ...
    def path(self) -> str: ...
    def calculateAspectRatio(self, context: 'QgsSymbolRenderContext', scaledSize: float) -> typing.Tuple[float, bool]: ...
    @typing.overload
    @deprecated("""""")
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def color(self) -> QtGui.QColor: ...
    def usesMapUnits(self) -> bool: ...
    def clone(self) -> 'QgsRasterMarkerSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def resolvePaths(properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsFontMarkerSymbolLayer(QgsMarkerSymbolLayer):

    def __init__(self, fontFamily: str|None = ..., chr: str|None = ..., pointSize: float = ..., color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., angle: float = ...) -> None: ...

    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidth(self, width: float) -> None: ...
    def strokeWidth(self) -> float: ...
    def setStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setCharacter(self, chr: str|None) -> None: ...
    def character(self) -> str: ...
    def setFontStyle(self, style: str|None) -> None: ...
    def fontStyle(self) -> str: ...
    def setFontFamily(self, family: str|None) -> None: ...
    def fontFamily(self) -> str: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def usesMapUnits(self) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def writeSldMarker(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsFontMarkerSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def flags(self) -> Qgis.SymbolLayerFlag: ...
    def layerType(self) -> str: ...
    @staticmethod
    def resolveFonts(properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsAnimatedMarkerSymbolLayer(QgsRasterMarkerSymbolLayer):

    def __init__(self, path: str|None = ..., size: float = ..., angle: float = ...) -> None: ...

    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def frameRate(self) -> float: ...
    def setFrameRate(self, rate: float) -> None: ...
    def clone(self) -> 'QgsAnimatedMarkerSymbolLayer|None': ...
    def properties(self) -> dict[str, typing.Any]: ...
    def layerType(self) -> str: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsMaskMarkerSymbolLayer(QgsMarkerSymbolLayer):

    def __init__(self) -> None: ...

    def setMasks(self, maskedLayers: collections.abc.Iterable['QgsSymbolLayerReference']) -> None: ...
    def clearMasks(self) -> None: ...
    def masks(self) -> list['QgsSymbolLayerReference']: ...
    def enabled(self) -> bool: ...
    def drawPreviewIcon(self, context: 'QgsSymbolRenderContext', size: QtCore.QSize) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def usesMapUnits(self) -> bool: ...
    def bounds(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> QtCore.QRectF: ...
    def renderPoint(self, point: QtCore.QPointF, context: 'QgsSymbolRenderContext') -> None: ...
    def stopRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def startRender(self, context: 'QgsSymbolRenderContext') -> None: ...
    def layerType(self) -> str: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def clone(self) -> 'QgsMaskMarkerSymbolLayer|None': ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsNullSymbolRenderer(QgsFeatureRenderer):

    def __init__(self) -> None: ...

    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsNullSymbolRenderer|None': ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def clone(self) -> QgsFeatureRenderer|None: ...
    def dump(self) -> str: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def willRenderFeature(self, feature: QgsFeature, context: QgsRenderContext) -> bool: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...


class QgsPointDistanceRenderer(QgsFeatureRenderer):

    class GroupedFeature(PyQt6.sip.wrapper):

        feature = ... # type: QgsFeature
        isSelected = ... # type: bool
        label = ... # type: str|None

        @typing.overload
        def __init__(self, feature: QgsFeature, symbol: QgsMarkerSymbol|None, isSelected: bool, label: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsPointDistanceRenderer.GroupedFeature') -> None: ...

        def symbol(self) -> QgsMarkerSymbol|None: ...

    def __init__(self, rendererName: str|None, labelAttributeName: str|None = ...) -> None: ...

    def drawLabels(self, centerPoint: QtCore.QPointF, context: 'QgsSymbolRenderContext', labelShifts: collections.abc.Iterable[QtCore.QPointF], group: collections.abc.Iterable['QgsPointDistanceRenderer.GroupedFeature']) -> None: ...
    def toleranceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setToleranceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def toleranceUnit(self) -> Qgis.RenderUnit: ...
    def setToleranceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def tolerance(self) -> float: ...
    def setTolerance(self, distance: float) -> None: ...
    def labelColor(self) -> QtGui.QColor: ...
    def setLabelColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def minimumLabelScale(self) -> float: ...
    def setMinimumLabelScale(self, scale: float) -> None: ...
    def labelFont(self) -> QtGui.QFont: ...
    def setLabelFont(self, font: QtGui.QFont) -> None: ...
    def labelAttributeName(self) -> str: ...
    def setLabelAttributeName(self, name: str|None) -> None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def filter(self, fields: QgsFields = ...) -> str: ...
    def checkLegendSymbolItem(self, key: str|None, state: bool) -> None: ...
    def legendSymbolItemChecked(self, key: str|None) -> bool: ...
    def legendSymbolItemsCheckable(self) -> bool: ...
    def setLegendSymbolItem(self, key: str|None, symbol: QgsSymbol|None) -> None: ...
    def embeddedRenderer(self) -> QgsFeatureRenderer|None: ...
    def setEmbeddedRenderer(self, r: QgsFeatureRenderer|None) -> None: ...
    def legendSymbolItems(self) -> list[QgsLegendSymbolItem]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def willRenderFeature(self, feature: QgsFeature, context: QgsRenderContext) -> bool: ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def originalSymbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def symbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    def filterNeedsGeometry(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...


class QgsPointClusterRenderer(QgsPointDistanceRenderer):

    def __init__(self) -> None: ...

    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsPointClusterRenderer|None': ...
    def setClusterSymbol(self, symbol: QgsMarkerSymbol|None) -> None: ...
    def clusterSymbol(self) -> QgsMarkerSymbol|None: ...
    @staticmethod
    def create(symbologyElem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def clone(self) -> 'QgsPointClusterRenderer|None': ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...


class QgsPointDisplacementRenderer(QgsPointDistanceRenderer):

    class Placement(enum.IntEnum):
        Ring = ... # type: QgsPointDisplacementRenderer.Placement
        ConcentricRings = ... # type: QgsPointDisplacementRenderer.Placement
        Grid = ... # type: QgsPointDisplacementRenderer.Placement

    def __init__(self, labelAttributeName: str|None = ...) -> None: ...

    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsPointDisplacementRenderer|None': ...
    def setCenterSymbol(self, symbol: QgsMarkerSymbol|None) -> None: ...
    def centerSymbol(self) -> QgsMarkerSymbol|None: ...
    def setPlacement(self, placement: 'QgsPointDisplacementRenderer.Placement') -> None: ...
    def placement(self) -> 'QgsPointDisplacementRenderer.Placement': ...
    def labelDistanceFactor(self) -> float: ...
    def setLabelDistanceFactor(self, factor: float) -> None: ...
    def circleRadiusAddition(self) -> float: ...
    def setCircleRadiusAddition(self, distance: float) -> None: ...
    def circleColor(self) -> QtGui.QColor: ...
    def setCircleColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def circleWidth(self) -> float: ...
    def setCircleWidth(self, width: float) -> None: ...
    @staticmethod
    def create(symbologyElem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def clone(self) -> 'QgsPointDisplacementRenderer|None': ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...


class QgsSymbolLevelItem(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, symbol: QgsSymbol|None, layer: int) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSymbolLevelItem') -> None: ...

    def layer(self) -> int: ...
    def symbol(self) -> QgsSymbol|None: ...


class QgsRendererRange(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, range: QgsClassificationRange, symbol: QgsSymbol|None, render: bool = ..., uuid: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, lowerValue: float, upperValue: float, symbol: QgsSymbol|None, label: str|None, render: bool = ..., uuid: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, range: 'QgsRendererRange') -> None: ...

    def __ge__(self, other: 'QgsRendererRange') -> bool: ...
    def __getitem__(self, a0: int) -> typing.Any: ...
    def __repr__(self) -> typing.Any: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any], firstRange: bool = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, classAttribute: str|None, context: QgsSldExportContext, firstRange: bool = ...) -> bool: ...
    def dump(self) -> str: ...
    def setRenderState(self, render: bool) -> None: ...
    def renderState(self) -> bool: ...
    def setUpperValue(self, upperValue: float) -> None: ...
    def setLowerValue(self, lowerValue: float) -> None: ...
    def setLabel(self, label: str|None) -> None: ...
    def setSymbol(self, s: QgsSymbol|None) -> None: ...
    def label(self) -> str: ...
    def symbol(self) -> QgsSymbol|None: ...
    def upperValue(self) -> float: ...
    def lowerValue(self) -> float: ...
    def uuid(self) -> str: ...
    def __lt__(self, other: 'QgsRendererRange') -> bool: ...


@deprecated("")
class QgsRendererRangeLabelFormat(PyQt6.sip.wrapper):

    MAX_PRECISION = ... # type: int
    MIN_PRECISION = ... # type: int

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, format: str|None, precision: int = ..., trimTrailingZeroes: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRendererRangeLabelFormat') -> None: ...

    def saveToDomElement(self, element: QtXml.QDomElement) -> None: ...
    def setFromDomElement(self, element: QtXml.QDomElement) -> None: ...
    def formatNumber(self, value: float) -> str: ...
    def labelForRange(self, range: QgsRendererRange) -> str: ...
    def labelForLowerUpper(self, lower: float, upper: float) -> str: ...
    def setTrimTrailingZeroes(self, trimTrailingZeroes: bool) -> None: ...
    def trimTrailingZeroes(self) -> bool: ...
    def setPrecision(self, precision: int) -> None: ...
    def precision(self) -> int: ...
    def setFormat(self, format: str|None) -> None: ...
    def format(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsRendererAbstractMetadata(PyQt6.sip.wrapper):

    class LayerType(enum.IntEnum):
        PointLayer = ... # type: QgsRendererAbstractMetadata.LayerType
        LineLayer = ... # type: QgsRendererAbstractMetadata.LayerType
        PolygonLayer = ... # type: QgsRendererAbstractMetadata.LayerType
        All = ... # type: QgsRendererAbstractMetadata.LayerType

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None, icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRendererAbstractMetadata') -> None: ...

    def createRendererFromSld(self, elem: QtXml.QDomElement, geomType: Qgis.GeometryType) -> QgsFeatureRenderer|None: ...
    def createRendererWidget(self, layer: QgsVectorLayer|None, style: 'QgsStyle|None', oldRenderer: QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...
    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def compatibleLayerTypes(self) -> 'QgsRendererAbstractMetadata.LayerType': ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsRendererMetadata(QgsRendererAbstractMetadata):

    def __init__(self, a0: 'QgsRendererMetadata') -> None: ...

    def compatibleLayerTypes(self) -> QgsRendererAbstractMetadata.LayerType: ...
    def createRendererFromSld(self, elem: QtXml.QDomElement, geomType: Qgis.GeometryType) -> QgsFeatureRenderer|None: ...
    def createRendererWidget(self, layer: QgsVectorLayer|None, style: 'QgsStyle|None', renderer: QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...
    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...


class QgsRendererRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @typing.overload
    def renderersList(self, layerTypes: QgsRendererAbstractMetadata.LayerType = ...) -> list[str]: ...
    @typing.overload
    def renderersList(self, layer: QgsVectorLayer|None) -> list[str]: ...
    def rendererMetadata(self, rendererName: str|None) -> QgsRendererAbstractMetadata|None: ...
    def removeRenderer(self, rendererName: str|None) -> bool: ...
    def addRenderer(self, metadata: QgsRendererAbstractMetadata|None) -> bool: ...


class QgsRuleBasedRenderer(QgsFeatureRenderer):

    class FeatureFlags(enum.IntEnum):
        FeatIsSelected = ... # type: QgsRuleBasedRenderer.FeatureFlags
        FeatDrawMarkers = ... # type: QgsRuleBasedRenderer.FeatureFlags

    class FeatureToRender(PyQt6.sip.wrapper):

        feat = ... # type: QgsFeature
        flags = ... # type: int

        @typing.overload
        def __init__(self, _f: QgsFeature, _flags: int) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRuleBasedRenderer.FeatureToRender') -> None: ...

    class RenderJob(PyQt6.sip.wrapper):

        ftr = ... # type: 'QgsRuleBasedRenderer.FeatureToRender'
        symbol = ... # type: QgsSymbol

        @typing.overload
        def __init__(self, _ftr: 'QgsRuleBasedRenderer.FeatureToRender', _s: QgsSymbol|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsRuleBasedRenderer.RenderJob') -> None: ...

    class RenderLevel(PyQt6.sip.wrapper):

        jobs = ... # type: collections.abc.Iterable['QgsRuleBasedRenderer.RenderJob']
        zIndex = ... # type: int

        @typing.overload
        def __init__(self, z: int) -> None: ...
        @typing.overload
        def __init__(self, other: 'QgsRuleBasedRenderer.RenderLevel') -> None: ...

    class Rule(PyQt6.sip.wrapper):

        class RenderResult(enum.IntEnum):
            Filtered = ... # type: QgsRuleBasedRenderer.Rule.RenderResult
            Inactive = ... # type: QgsRuleBasedRenderer.Rule.RenderResult
            Rendered = ... # type: QgsRuleBasedRenderer.Rule.RenderResult

        def __init__(self, symbol: QgsSymbol|None, maximumScale: int = ..., minimumScale: int = ..., filterExp: str|None = ..., label: str|None = ..., description: str|None = ..., elseRule: bool = ...) -> None: ...

        def initFilter(self) -> None: ...
        def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
        def isElse(self) -> bool: ...
        def setIsElse(self, iselse: bool) -> None: ...
        def findRuleByKey(self, key: str|None) -> 'QgsRuleBasedRenderer.Rule|None': ...
        def takeChildAt(self, i: int) -> 'QgsRuleBasedRenderer.Rule|None': ...
        def takeChild(self, rule: 'QgsRuleBasedRenderer.Rule|None') -> 'QgsRuleBasedRenderer.Rule|None': ...
        def removeChildAt(self, i: int) -> None: ...
        def removeChild(self, rule: 'QgsRuleBasedRenderer.Rule|None') -> None: ...
        def insertChild(self, i: int, rule: 'QgsRuleBasedRenderer.Rule|None') -> None: ...
        def appendChild(self, rule: 'QgsRuleBasedRenderer.Rule|None') -> None: ...
        def parent(self) -> 'QgsRuleBasedRenderer.Rule|None': ...
        def descendants(self) -> list['QgsRuleBasedRenderer.Rule']: ...
        def children(self) -> list['QgsRuleBasedRenderer.Rule']: ...
        @staticmethod
        def create(ruleElem: QtXml.QDomElement, symbolMap: typing.Any, reuseId: bool = ..., context: QgsReadWriteContext = ...) -> 'QgsRuleBasedRenderer.Rule|None': ...
        def stopRender(self, context: QgsRenderContext) -> None: ...
        def rulesForFeature(self, feature: QgsFeature, context: QgsRenderContext|None = ..., onlyActive: bool = ...) -> list['QgsRuleBasedRenderer.Rule']: ...
        def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext|None = ...) -> set[str]: ...
        def symbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext|None = ...) -> list[QgsSymbol]: ...
        def willRenderFeature(self, feature: QgsFeature, context: QgsRenderContext|None = ...) -> bool: ...
        def renderFeature(self, featToRender: 'QgsRuleBasedRenderer.FeatureToRender', context: QgsRenderContext, renderQueue: collections.abc.Iterable['QgsRuleBasedRenderer.RenderLevel']) -> 'QgsRuleBasedRenderer.Rule.RenderResult': ...
        def collectZLevels(self) -> typing.Any: ...
        def hasActiveChildren(self) -> bool: ...
        def startRender(self, context: QgsRenderContext, fields: QgsFields, filter: str|None) -> bool: ...
        def save(self, doc: QtXml.QDomDocument, symbolMap: typing.Any) -> QtXml.QDomElement: ...
        @staticmethod
        def createFromSld(element: QtXml.QDomElement, geomType: Qgis.GeometryType) -> 'QgsRuleBasedRenderer.Rule|None': ...
        @typing.overload
        @deprecated("""""")
        def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
        @typing.overload
        def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
        def clone(self) -> 'QgsRuleBasedRenderer.Rule|None': ...
        def setActive(self, state: bool) -> None: ...
        def setDescription(self, description: str|None) -> None: ...
        def setFilterExpression(self, filterExp: str|None) -> None: ...
        def setMaximumScale(self, scale: float) -> None: ...
        def setMinimumScale(self, scale: float) -> None: ...
        def setLabel(self, label: str|None) -> None: ...
        def setSymbol(self, sym: QgsSymbol|None) -> None: ...
        def setRuleKey(self, key: str|None) -> None: ...
        def ruleKey(self) -> str: ...
        def active(self) -> bool: ...
        def description(self) -> str: ...
        def filterExpression(self) -> str: ...
        def filter(self) -> QgsExpression|None: ...
        def minimumScale(self) -> float: ...
        def maximumScale(self) -> float: ...
        def dependsOnScale(self) -> bool: ...
        def label(self) -> str: ...
        def symbol(self) -> QgsSymbol|None: ...
        def isScaleOK(self, scale: float) -> bool: ...
        def isFilterOK(self, f: QgsFeature, context: QgsRenderContext|None = ...) -> bool: ...
        def legendSymbolItems(self, currentLevel: int = ...) -> list[QgsLegendSymbolItem]: ...
        def symbols(self, context: QgsRenderContext = ...) -> list[QgsSymbol]: ...
        def needsGeometry(self) -> bool: ...
        def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
        def dump(self, indent: int = ...) -> str: ...

    @typing.overload
    def __init__(self, root: 'QgsRuleBasedRenderer.Rule|None') -> None: ...
    @typing.overload
    def __init__(self, defaultSymbol: QgsSymbol|None) -> None: ...

    @staticmethod
    def convertToDataDefinedSymbology(symbol: QgsSymbol|None, sizeScaleField: str|None, rotationField: str|None = ...) -> None: ...
    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None, layer: QgsVectorLayer|None = ...) -> 'QgsRuleBasedRenderer|None': ...
    @staticmethod
    def refineRuleScales(initialRule: 'QgsRuleBasedRenderer.Rule|None', scales: collections.abc.Iterable[int]) -> None: ...
    @staticmethod
    def refineRuleRanges(initialRule: 'QgsRuleBasedRenderer.Rule|None', r: QgsGraduatedSymbolRenderer|None) -> None: ...
    @staticmethod
    def refineRuleCategories(initialRule: 'QgsRuleBasedRenderer.Rule|None', r: QgsCategorizedSymbolRenderer|None) -> None: ...
    def rootRule(self) -> 'QgsRuleBasedRenderer.Rule|None': ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def originalSymbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def symbolsForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def willRenderFeature(self, feature: QgsFeature, context: QgsRenderContext) -> bool: ...
    def dump(self) -> str: ...
    def legendSymbolItems(self) -> list[QgsLegendSymbolItem]: ...
    def setLegendSymbolItem(self, key: str|None, symbol: QgsSymbol|None) -> None: ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def checkLegendSymbolItem(self, key: str|None, state: bool = ...) -> None: ...
    def legendSymbolItemChecked(self, key: str|None) -> bool: ...
    def legendSymbolItemsCheckable(self) -> bool: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement, geomType: Qgis.GeometryType) -> QgsFeatureRenderer|None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsRuleBasedRenderer|None': ...
    def filterNeedsGeometry(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def filter(self, fields: QgsFields = ...) -> str: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def canSkipRender(self) -> bool: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def renderFeature(self, feature: QgsFeature, context: QgsRenderContext, layer: int = ..., selected: bool = ..., drawVertexMarker: bool = ...) -> bool: ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...


class QgsSelectiveMaskSource(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, layerId: str|None, sourceType: Qgis.SelectiveMaskSourceType, sourceId: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSelectiveMaskSource') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def setSourceId(self, id: str|None) -> None: ...
    def sourceId(self) -> str: ...
    def setSourceType(self, type: Qgis.SelectiveMaskSourceType) -> None: ...
    def sourceType(self) -> Qgis.SelectiveMaskSourceType: ...
    def setLayerId(self, id: str|None) -> None: ...
    def layerId(self) -> str: ...
    def isValid(self) -> bool: ...


class QgsSelectiveMaskingSourceSet(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSelectiveMaskingSourceSet') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def __len__(self) -> int: ...
    def isEmpty(self) -> bool: ...
    def size(self) -> int: ...
    def __getitem__(self, index: int) -> QgsSelectiveMaskSource: ...
    def readXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, document: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def append(self, source: QgsSelectiveMaskSource) -> None: ...
    def setSources(self, sources: collections.abc.Iterable[QgsSelectiveMaskSource]) -> None: ...
    def sources(self) -> list[QgsSelectiveMaskSource]: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def id(self) -> str: ...
    def setId(self, id: str|None) -> None: ...
    def isValid(self) -> bool: ...


class QgsSingleSymbolRenderer(QgsFeatureRenderer):

    def __init__(self, symbol: QgsSymbol|None) -> None: ...

    def dataDefinedSizeLegend(self) -> QgsDataDefinedSizeLegend|None: ...
    def setDataDefinedSizeLegend(self, settings: QgsDataDefinedSizeLegend|None) -> None: ...
    @staticmethod
    def convertFromRenderer(renderer: QgsFeatureRenderer|None) -> 'QgsSingleSymbolRenderer|None': ...
    def setLegendSymbolItem(self, key: str|None, symbol: QgsSymbol|None) -> None: ...
    def legendKeyToExpression(self, key: str|None, layer: QgsVectorLayer|None) -> typing.Tuple[str, bool]: ...
    def legendKeysForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> set[str]: ...
    def legendSymbolItems(self) -> list[QgsLegendSymbolItem]: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsFeatureRenderer|None: ...
    def symbols(self, context: QgsRenderContext) -> list[QgsSymbol]: ...
    def capabilities(self) -> QgsFeatureRenderer.Capability: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement, geomType: Qgis.GeometryType) -> QgsFeatureRenderer|None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any] = ...) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def clone(self) -> 'QgsSingleSymbolRenderer|None': ...
    def dump(self) -> str: ...
    def setSymbol(self, s: QgsSymbol|None) -> None: ...
    def symbol(self) -> QgsSymbol|None: ...
    def accept(self, visitor: 'QgsStyleEntityVisitorInterface|None') -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def startRender(self, context: QgsRenderContext, fields: QgsFields) -> None: ...
    def originalSymbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def symbolForFeature(self, feature: QgsFeature, context: QgsRenderContext) -> QgsSymbol|None: ...
    def flags(self) -> Qgis.FeatureRendererFlag: ...


class QgsStyle(QtCore.QObject):

    class TextFormatContext(enum.IntEnum):
        Labeling = ... # type: QgsStyle.TextFormatContext

    class StyleEntity(enum.IntEnum):
        SymbolEntity = ... # type: QgsStyle.StyleEntity
        TagEntity = ... # type: QgsStyle.StyleEntity
        ColorrampEntity = ... # type: QgsStyle.StyleEntity
        SmartgroupEntity = ... # type: QgsStyle.StyleEntity
        TextFormatEntity = ... # type: QgsStyle.StyleEntity
        LabelSettingsEntity = ... # type: QgsStyle.StyleEntity
        LegendPatchShapeEntity = ... # type: QgsStyle.StyleEntity
        Symbol3DEntity = ... # type: QgsStyle.StyleEntity

    class SmartGroupTableColumn(enum.IntEnum):
        Id = ... # type: QgsStyle.SmartGroupTableColumn
        Name = ... # type: QgsStyle.SmartGroupTableColumn
        XML = ... # type: QgsStyle.SmartGroupTableColumn

    class LabelSettingsTableColumn(enum.IntEnum):
        Id = ... # type: QgsStyle.LabelSettingsTableColumn
        Name = ... # type: QgsStyle.LabelSettingsTableColumn
        XML = ... # type: QgsStyle.LabelSettingsTableColumn
        FavoriteId = ... # type: QgsStyle.LabelSettingsTableColumn

    class TextFormatTableColumn(enum.IntEnum):
        Id = ... # type: QgsStyle.TextFormatTableColumn
        Name = ... # type: QgsStyle.TextFormatTableColumn
        XML = ... # type: QgsStyle.TextFormatTableColumn
        FavoriteId = ... # type: QgsStyle.TextFormatTableColumn

    class ColorRampTableColumn(enum.IntEnum):
        Id = ... # type: QgsStyle.ColorRampTableColumn
        Name = ... # type: QgsStyle.ColorRampTableColumn
        XML = ... # type: QgsStyle.ColorRampTableColumn
        FavoriteId = ... # type: QgsStyle.ColorRampTableColumn

    class TagmapTableColumn(enum.IntEnum):
        TagId = ... # type: QgsStyle.TagmapTableColumn
        SymbolId = ... # type: QgsStyle.TagmapTableColumn

    class TagTableColumn(enum.IntEnum):
        Id = ... # type: QgsStyle.TagTableColumn
        Name = ... # type: QgsStyle.TagTableColumn

    class SymbolTableColumn(enum.IntEnum):
        Id = ... # type: QgsStyle.SymbolTableColumn
        Name = ... # type: QgsStyle.SymbolTableColumn
        XML = ... # type: QgsStyle.SymbolTableColumn
        FavoriteId = ... # type: QgsStyle.SymbolTableColumn

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    rebuildIconPreviews: typing.ClassVar[QtCore.pyqtSignal]
    labelSettingsChanged: typing.ClassVar[QtCore.pyqtSignal]
    labelSettingsRemoved: typing.ClassVar[QtCore.pyqtSignal]
    labelSettingsAdded: typing.ClassVar[QtCore.pyqtSignal]
    labelSettingsRenamed: typing.ClassVar[QtCore.pyqtSignal]
    textFormatChanged: typing.ClassVar[QtCore.pyqtSignal]
    textFormatRemoved: typing.ClassVar[QtCore.pyqtSignal]
    textFormatAdded: typing.ClassVar[QtCore.pyqtSignal]
    textFormatRenamed: typing.ClassVar[QtCore.pyqtSignal]
    rampChanged: typing.ClassVar[QtCore.pyqtSignal]
    rampRemoved: typing.ClassVar[QtCore.pyqtSignal]
    rampAdded: typing.ClassVar[QtCore.pyqtSignal]
    rampRenamed: typing.ClassVar[QtCore.pyqtSignal]
    symbolRenamed: typing.ClassVar[QtCore.pyqtSignal]
    symbolRemoved: typing.ClassVar[QtCore.pyqtSignal]
    entityChanged: typing.ClassVar[QtCore.pyqtSignal]
    entityRenamed: typing.ClassVar[QtCore.pyqtSignal]
    entityRemoved: typing.ClassVar[QtCore.pyqtSignal]
    entityAdded: typing.ClassVar[QtCore.pyqtSignal]
    favoritedChanged: typing.ClassVar[QtCore.pyqtSignal]
    entityTagsChanged: typing.ClassVar[QtCore.pyqtSignal]
    groupsModified: typing.ClassVar[QtCore.pyqtSignal]
    symbolChanged: typing.ClassVar[QtCore.pyqtSignal]
    symbolSaved: typing.ClassVar[QtCore.pyqtSignal]
    aboutToBeDestroyed: typing.ClassVar[QtCore.pyqtSignal]
    initialized: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def isXmlStyleFile(path: str|None) -> bool: ...
    def importXml(self, filename: str|None) -> bool: ...
    def exportXml(self, filename: str|None) -> bool: ...
    def symbolsOfSmartgroup(self, type: 'QgsStyle.StyleEntity', id: int) -> list[str]: ...
    def smartgroupOperator(self, id: int) -> str: ...
    def smartgroup(self, id: int) -> dict[str, list[str]]: ...
    def smartgroupNames(self) -> list[str]: ...
    def smartgroupsListMap(self) -> dict[int, str]: ...
    def tag(self, id: int) -> str: ...
    def symbolHasTag(self, type: 'QgsStyle.StyleEntity', symbol: str|None, tag: str|None) -> bool: ...
    def isFavorite(self, type: 'QgsStyle.StyleEntity', name: str|None) -> bool: ...
    def tagsOfSymbol(self, type: 'QgsStyle.StyleEntity', symbol: str|None) -> list[str]: ...
    def findSymbols(self, type: 'QgsStyle.StyleEntity', qword: str|None) -> list[str]: ...
    def setFileName(self, filename: str|None) -> None: ...
    def fileName(self) -> str: ...
    def errorString(self) -> str: ...
    @deprecated("""""")
    def save(self, filename: str|None = ...) -> bool: ...
    def load(self, filename: str|None) -> bool: ...
    def createTables(self) -> None: ...
    def createMemoryDatabase(self) -> bool: ...
    def createDatabase(self, filename: str|None) -> bool: ...
    def symbol3DNames(self) -> list[str]: ...
    def renameSymbol3D(self, oldName: str|None, newName: str|None) -> bool: ...
    def saveSymbol3D(self, name: str|None, symbol: QgsAbstract3DSymbol|None, favorite: bool, tags: collections.abc.Iterable[str|None]) -> bool: ...
    @staticmethod
    def defaultTextFormatForProject(project: QgsProject|None, context: 'QgsStyle.TextFormatContext' = ...) -> 'QgsTextFormat': ...
    def defaultTextFormat(self, context: 'QgsStyle.TextFormatContext' = ...) -> 'QgsTextFormat': ...
    def defaultPatchAsQPolygonF(self, type: Qgis.SymbolType, size: QtCore.QSizeF) -> typing.Any: ...
    def defaultPatch(self, type: Qgis.SymbolType, size: QtCore.QSizeF) -> QgsLegendPatchShape: ...
    def previewSymbolForPatchShape(self, shape: QgsLegendPatchShape) -> QgsSymbol|None: ...
    def legendPatchShapeNames(self) -> list[str]: ...
    def renameLegendPatchShape(self, oldName: str|None, newName: str|None) -> bool: ...
    def saveLegendPatchShape(self, name: str|None, shape: QgsLegendPatchShape, favorite: bool, tags: collections.abc.Iterable[str|None]) -> bool: ...
    def renameLabelSettings(self, oldName: str|None, newName: str|None) -> bool: ...
    def removeLabelSettings(self, name: str|None) -> bool: ...
    def saveLabelSettings(self, name: str|None, settings: QgsPalLayerSettings, favorite: bool, tags: collections.abc.Iterable[str|None]) -> bool: ...
    def renameTextFormat(self, oldName: str|None, newName: str|None) -> bool: ...
    def removeTextFormat(self, name: str|None) -> bool: ...
    def saveTextFormat(self, name: str|None, format: 'QgsTextFormat', favorite: bool, tags: collections.abc.Iterable[str|None]) -> bool: ...
    def renameColorRamp(self, oldName: str|None, newName: str|None) -> bool: ...
    def removeColorRamp(self, name: str|None) -> bool: ...
    def saveColorRamp(self, name: str|None, ramp: QgsColorRamp|None, favorite: bool, tags: collections.abc.Iterable[str|None]) -> bool: ...
    def saveSymbol(self, name: str|None, symbol: QgsSymbol|None, favorite: bool, tags: collections.abc.Iterable[str|None]) -> bool: ...
    def removeEntityByName(self, type: 'QgsStyle.StyleEntity', name: str|None) -> bool: ...
    def remove(self, type: 'QgsStyle.StyleEntity', id: int) -> bool: ...
    def rename(self, type: 'QgsStyle.StyleEntity', id: int, newName: str|None) -> bool: ...
    def removeFavorite(self, type: 'QgsStyle.StyleEntity', name: str|None) -> bool: ...
    def addFavorite(self, type: 'QgsStyle.StyleEntity', name: str|None) -> bool: ...
    def symbolsWithTag(self, type: 'QgsStyle.StyleEntity', tagid: int) -> list[str]: ...
    def symbolsOfFavorite(self, type: 'QgsStyle.StyleEntity') -> list[str]: ...
    def allNames(self, type: 'QgsStyle.StyleEntity') -> list[str]: ...
    def smartgroupId(self, smartgroup: str|None) -> int: ...
    def tagId(self, tag: str|None) -> int: ...
    def entityId(self, type: 'QgsStyle.StyleEntity', name: str|None) -> int: ...
    def symbolId(self, name: str|None) -> int: ...
    def symbolNames(self) -> list[str]: ...
    def symbolCount(self) -> int: ...
    def symbolRef(self, name: str|None) -> QgsSymbol|None: ...
    def symbol(self, name: str|None) -> QgsSymbol|None: ...
    def renameSymbol(self, oldName: str|None, newName: str|None) -> bool: ...
    def renameEntity(self, type: 'QgsStyle.StyleEntity', oldName: str|None, newName: str|None) -> bool: ...
    def removeSymbol(self, name: str|None) -> bool: ...
    @typing.overload
    def detagSymbol(self, type: 'QgsStyle.StyleEntity', symbol: str|None, tags: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def detagSymbol(self, type: 'QgsStyle.StyleEntity', symbol: str|None) -> bool: ...
    def tagSymbol(self, type: 'QgsStyle.StyleEntity', symbol: str|None, tags: collections.abc.Iterable[str|None]) -> bool: ...
    @staticmethod
    def defaultStyle(initialize: bool = ...) -> 'QgsStyle|None': ...
    def labelSettingsId(self, name: str|None) -> int: ...
    def labelSettingsNames(self) -> list[str]: ...
    def labelSettingsCount(self) -> int: ...
    def labelSettingsLayerType(self, name: str|None) -> Qgis.GeometryType: ...
    def symbol3DCompatibleGeometryTypes(self, name: str|None) -> list[Qgis.GeometryType]: ...
    def symbol3DCount(self) -> int: ...
    def symbol3D(self, name: str|None) -> QgsAbstract3DSymbol|None: ...
    def legendPatchShapeSymbolType(self, name: str|None) -> Qgis.SymbolType: ...
    def legendPatchShapesCount(self) -> int: ...
    def legendPatchShape(self, name: str|None) -> QgsLegendPatchShape: ...
    def labelSettings(self, name: str|None) -> QgsPalLayerSettings: ...
    def textFormatId(self, name: str|None) -> int: ...
    def textFormatNames(self) -> list[str]: ...
    def textFormatCount(self) -> int: ...
    def textFormat(self, name: str|None) -> 'QgsTextFormat': ...
    def colorrampId(self, name: str|None) -> int: ...
    def colorRampRef(self, name: str|None) -> QgsColorRamp|None: ...
    def colorRampNames(self) -> list[str]: ...
    def colorRampCount(self) -> int: ...
    def colorRamp(self, name: str|None) -> QgsColorRamp|None: ...
    def clear(self) -> None: ...
    def tags(self) -> list[str]: ...
    def addSmartgroup(self, name: str|None, op: str|None, matchTag: collections.abc.Iterable[str|None], noMatchTag: collections.abc.Iterable[str|None], matchName: collections.abc.Iterable[str|None], noMatchName: collections.abc.Iterable[str|None]) -> int: ...
    def addTag(self, tagName: str|None) -> int: ...
    def addSymbol3D(self, name: str|None, symbol: QgsAbstract3DSymbol|None, update: bool = ...) -> bool: ...
    def addLegendPatchShape(self, name: str|None, shape: QgsLegendPatchShape, update: bool = ...) -> bool: ...
    def addLabelSettings(self, name: str|None, settings: QgsPalLayerSettings, update: bool = ...) -> bool: ...
    def addTextFormat(self, name: str|None, format: 'QgsTextFormat', update: bool = ...) -> bool: ...
    def addColorRamp(self, name: str|None, colorRamp: QgsColorRamp|None, update: bool = ...) -> bool: ...
    def addSymbol(self, name: str|None, symbol: QgsSymbol|None, update: bool = ...) -> bool: ...
    def addEntity(self, name: str|None, entity: 'QgsStyleEntityInterface|None', update: bool = ...) -> bool: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def isReadOnly(self) -> bool: ...
    def isInitialized(self) -> bool: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...


class QgsStyleEntityInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleEntityInterface') -> None: ...

    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleSymbolEntity(QgsStyleEntityInterface):

    @typing.overload
    def __init__(self, symbol: QgsSymbol|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleSymbolEntity') -> None: ...

    def symbol(self) -> QgsSymbol|None: ...
    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleColorRampEntity(QgsStyleEntityInterface):

    @typing.overload
    def __init__(self, ramp: QgsColorRamp|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleColorRampEntity') -> None: ...

    def ramp(self) -> QgsColorRamp|None: ...
    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleTextFormatEntity(QgsStyleEntityInterface):

    @typing.overload
    def __init__(self, format: 'QgsTextFormat') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleTextFormatEntity') -> None: ...

    def format(self) -> 'QgsTextFormat': ...
    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleLabelSettingsEntity(QgsStyleEntityInterface):

    @typing.overload
    def __init__(self, settings: QgsPalLayerSettings) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleLabelSettingsEntity') -> None: ...

    def settings(self) -> QgsPalLayerSettings: ...
    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleLegendPatchShapeEntity(QgsStyleEntityInterface):

    @typing.overload
    def __init__(self, shape: QgsLegendPatchShape) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleLegendPatchShapeEntity') -> None: ...

    def shape(self) -> QgsLegendPatchShape: ...
    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleSymbol3DEntity(QgsStyleEntityInterface):

    @typing.overload
    def __init__(self, symbol: QgsAbstract3DSymbol|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleSymbol3DEntity') -> None: ...

    def symbol(self) -> QgsAbstract3DSymbol|None: ...
    def type(self) -> QgsStyle.StyleEntity: ...


class QgsStyleEntityVisitorInterface(PyQt6.sip.wrapper):

    class NodeType(enum.IntEnum):
        Project = ... # type: QgsStyleEntityVisitorInterface.NodeType
        Layer = ... # type: QgsStyleEntityVisitorInterface.NodeType
        SymbolRule = ... # type: QgsStyleEntityVisitorInterface.NodeType
        Layouts = ... # type: QgsStyleEntityVisitorInterface.NodeType
        PrintLayout = ... # type: QgsStyleEntityVisitorInterface.NodeType
        LayoutItem = ... # type: QgsStyleEntityVisitorInterface.NodeType
        Report = ... # type: QgsStyleEntityVisitorInterface.NodeType
        ReportHeader = ... # type: QgsStyleEntityVisitorInterface.NodeType
        ReportFooter = ... # type: QgsStyleEntityVisitorInterface.NodeType
        ReportSection = ... # type: QgsStyleEntityVisitorInterface.NodeType
        Annotations = ... # type: QgsStyleEntityVisitorInterface.NodeType
        Annotation = ... # type: QgsStyleEntityVisitorInterface.NodeType

    class StyleLeaf(PyQt6.sip.wrapper):

        description = ... # type: str|None
        entity = ... # type: QgsStyleEntityInterface
        identifier = ... # type: str|None

        @typing.overload
        def __init__(self, entity: QgsStyleEntityInterface|None, identifier: str|None = ..., description: str|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsStyleEntityVisitorInterface.StyleLeaf') -> None: ...

    class Node(PyQt6.sip.wrapper):

        description = ... # type: str|None
        identifier = ... # type: str|None
        type = ... # type: 'QgsStyleEntityVisitorInterface.NodeType'

        @typing.overload
        def __init__(self, type: 'QgsStyleEntityVisitorInterface.NodeType', identifier: str|None, description: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsStyleEntityVisitorInterface.Node') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsStyleEntityVisitorInterface') -> None: ...

    def visitExit(self, node: 'QgsStyleEntityVisitorInterface.Node') -> bool: ...
    def visitEnter(self, node: 'QgsStyleEntityVisitorInterface.Node') -> bool: ...
    def visit(self, entity: 'QgsStyleEntityVisitorInterface.StyleLeaf') -> bool: ...


class QgsStyleModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        Type = ... # type: QgsStyleModel.CustomRole
        Tag = ... # type: QgsStyleModel.CustomRole
        EntityName = ... # type: QgsStyleModel.CustomRole
        SymbolType = ... # type: QgsStyleModel.CustomRole
        IsFavorite = ... # type: QgsStyleModel.CustomRole
        LayerType = ... # type: QgsStyleModel.CustomRole
        CompatibleGeometryTypes = ... # type: QgsStyleModel.CustomRole
        StyleName = ... # type: QgsStyleModel.CustomRole
        StyleFileName = ... # type: QgsStyleModel.CustomRole
        IsTitle = ... # type: QgsStyleModel.CustomRole

    class Column(enum.IntEnum):
        Name = ... # type: QgsStyleModel.Column
        Tags = ... # type: QgsStyleModel.Column

    def __init__(self, style: QgsStyle|None, parent: QtCore.QObject|None = ...) -> None: ...

    def addTargetScreenProperties(self, properties: QgsScreenProperties) -> None: ...
    def addDesiredIconSize(self, size: QtCore.QSize) -> None: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def style(self) -> QgsStyle|None: ...


class QgsStyleProxyModel(QtCore.QSortFilterProxyModel):

    @typing.overload
    def __init__(self, style: QgsStyle|None, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, model: QgsStyleModel|None, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, model: QgsCombinedStyleModel|None, parent: QtCore.QObject|None = ...) -> None: ...

    def setFilterString(self, filter: str|None) -> None: ...
    def addTargetScreenProperties(self, properties: QgsScreenProperties) -> None: ...
    def addDesiredIconSize(self, size: QtCore.QSize) -> None: ...
    def setFavoritesOnly(self, favoritesOnly: bool) -> None: ...
    def favoritesOnly(self) -> bool: ...
    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def smartGroupId(self) -> int: ...
    def setSmartGroupId(self, id: int) -> None: ...
    def tagString(self) -> str: ...
    def setTagString(self, tag: str|None) -> None: ...
    def tagId(self) -> int: ...
    def setTagId(self, id: int) -> None: ...
    def setLayerType(self, type: Qgis.GeometryType) -> None: ...
    def layerType(self) -> Qgis.GeometryType: ...
    def setSymbolTypeFilterEnabled(self, enabled: bool) -> None: ...
    def symbolTypeFilterEnabled(self) -> bool: ...
    def setSymbolType(self, type: Qgis.SymbolType) -> None: ...
    def symbolType(self) -> Qgis.SymbolType: ...
    def setEntityFilterEnabled(self, enabled: bool) -> None: ...
    def entityFilterEnabled(self) -> bool: ...
    def setEntityFilter(self, filter: QgsStyle.StyleEntity) -> None: ...
    def entityFilter(self) -> QgsStyle.StyleEntity: ...
    def filterString(self) -> str: ...


class QgsSvgCache(QgsAbstractContentCacheBase):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def checkReply(self, reply: QtNetwork.QNetworkReply|None, path: str|None) -> bool: ...
    remoteSvgFetched: typing.ClassVar[QtCore.pyqtSignal]
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def svgContent(self, path: str|None, size: float, fill: QtGui.QColor|QtCore.Qt.GlobalColor|int, stroke: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float, widthScaleFactor: float, fixedAspectRatio: float = ..., blocking: bool = ..., parameters: dict[str|None, str|None] = ...) -> QtCore.QByteArray: ...
    def getImageData(self, path: str|None, blocking: bool = ...) -> QtCore.QByteArray: ...
    def containsParamsV3(self, path: str|None, defaultFillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, defaultStrokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, blocking: bool = ...) -> typing.Tuple[bool, bool, bool, bool, float, bool, bool, bool, bool, float, bool, bool, float]: ...
    def containsParams(self, path: str|None, defaultFillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, defaultStrokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, blocking: bool = ...) -> typing.Tuple[bool, bool, bool, float]: ...
    def svgViewboxSize(self, path: str|None, size: float, fill: QtGui.QColor|QtCore.Qt.GlobalColor|int, stroke: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float, widthScaleFactor: float, fixedAspectRatio: float = ..., blocking: bool = ..., parameters: dict[str|None, str|None] = ...) -> QtCore.QSizeF: ...
    def svgAsPicture(self, path: str|None, size: float, fill: QtGui.QColor|QtCore.Qt.GlobalColor|int, stroke: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float, widthScaleFactor: float, forceVectorOutput: bool = ..., fixedAspectRatio: float = ..., blocking: bool = ..., parameters: dict[str|None, str|None] = ...) -> QtGui.QPicture: ...
    def svgAsImage(self, path: str|None, size: float, fill: QtGui.QColor|QtCore.Qt.GlobalColor|int, stroke: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float, widthScaleFactor: float, fixedAspectRatio: float = ..., blocking: bool = ..., parameters: dict[str|None, str|None] = ...) -> typing.Tuple[QtGui.QImage, bool]: ...


class QgsSymbolAnimationSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSymbolAnimationSettings') -> None: ...

    def frameRate(self) -> float: ...
    def setFrameRate(self, rate: float) -> None: ...
    def isAnimated(self) -> bool: ...
    def setIsAnimated(self, animated: bool) -> None: ...


class QgsSymbolBufferSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSymbolBufferSettings') -> None: ...

    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def setFillSymbol(self, symbol: QgsFillSymbol|None) -> None: ...
    def fillSymbol(self) -> QgsFillSymbol|None: ...
    def setJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def joinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSize(self, size: float) -> None: ...
    def size(self) -> float: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...


class QgsSymbolLayerId(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, index: int) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, indexPath: collections.abc.Iterable[int]) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSymbolLayerId') -> None: ...

    def __ne__(self, other: object): ...
    def __ge__(self, other: 'QgsSymbolLayerId') -> bool: ...
    def __repr__(self) -> typing.Any: ...
    def __lt__(self, other: 'QgsSymbolLayerId') -> bool: ...
    def __eq__(self, other: object): ...
    def symbolLayerIndexPath(self) -> list[int]: ...
    def symbolKey(self) -> str: ...


class QgsSymbolLayerReference(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, layerId: str|None, symbolLayer: QgsSymbolLayerId) -> None: ...
    @typing.overload
    def __init__(self, layerId: str|None, symbolLayerId: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSymbolLayerReference') -> None: ...

    def __ne__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def __eq__(self, other: object): ...
    def symbolLayerIdV2(self) -> str: ...
    @deprecated("""""")
    def symbolLayerId(self) -> QgsSymbolLayerId: ...
    def layerId(self) -> str: ...


class QgsSymbolLayerAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None, type: Qgis.SymbolType) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSymbolLayerAbstractMetadata') -> None: ...

    def resolveFonts(self, properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def resolvePaths(self, properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    def createSymbolLayerFromSld(self, a0: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    def createSymbolLayerWidget(self, a0: QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...
    def createSymbolLayer(self, map: dict[str|None, typing.Any]) -> QgsSymbolLayer|None: ...
    def type(self) -> Qgis.SymbolType: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsSymbolLayerMetadata(QgsSymbolLayerAbstractMetadata):

    def __init__(self, a0: 'QgsSymbolLayerMetadata') -> None: ...

    def resolveFonts(self, properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def resolvePaths(self, properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    def createSymbolLayerFromSld(self, elem: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    def createSymbolLayerWidget(self, vl: QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...
    def createSymbolLayer(self, map: dict[str|None, typing.Any]) -> QgsSymbolLayer|None: ...


class QgsSymbolLayerRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def defaultSymbolLayer(type: Qgis.SymbolType) -> QgsSymbolLayer|None: ...
    def symbolLayersForType(self, type: Qgis.SymbolType) -> list[str]: ...
    def resolveFonts(self, name: str|None, properties: dict[str|None, typing.Any], context: QgsReadWriteContext) -> None: ...
    def resolvePaths(self, name: str|None, properties: dict[str|None, typing.Any], pathResolver: QgsPathResolver, saving: bool) -> None: ...
    def createSymbolLayerFromSld(self, name: str|None, element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    def createSymbolLayer(self, name: str|None, properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...
    def removeSymbolLayerType(self, metadata: QgsSymbolLayerAbstractMetadata|None) -> bool: ...
    def addSymbolLayerType(self, metadata: QgsSymbolLayerAbstractMetadata|None) -> bool: ...
    def symbolLayerMetadata(self, name: str|None) -> QgsSymbolLayerAbstractMetadata|None: ...


class QgsSymbolLayerUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSymbolLayerUtils') -> None: ...

    @staticmethod
    def collectSymbolLayerClipGeometries(context: QgsRenderContext, symbolLayerId: str|None, bounds: QtCore.QRectF) -> list[QgsGeometry]: ...
    @staticmethod
    def clearSymbolLayerMasks(symbol: QgsSymbol|None) -> None: ...
    @typing.overload
    @staticmethod
    def resetSymbolLayerIds(symbol: QgsSymbol|None) -> None: ...
    @typing.overload
    @staticmethod
    def resetSymbolLayerIds(symbolLayer: QgsSymbolLayer|None) -> None: ...
    @typing.overload
    @staticmethod
    def clearSymbolLayerIds(symbol: QgsSymbol|None) -> None: ...
    @typing.overload
    @staticmethod
    def clearSymbolLayerIds(symbolLayer: QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def tileSize(width: int, height: int, angleRad: float) -> typing.Tuple[QtCore.QSize, float]: ...
    @staticmethod
    def evaluatePropertiesMap(propertiesMap: dict[str|None, QgsProperty], context: QgsExpressionContext) -> dict[str, str]: ...
    @staticmethod
    def restrictedSizeSymbol(s: QgsSymbol|None, minSize: float, maxSize: float, context: QgsRenderContext|None) -> typing.Tuple[QgsSymbol|None, float, float, bool]: ...
    @staticmethod
    def rendererFrameRate(renderer: QgsFeatureRenderer|None) -> float: ...
    @staticmethod
    def toSymbolLayerPointers(renderer: QgsFeatureRenderer|None, symbolLayerIds: collections.abc.Iterable[QgsSymbolLayerId]) -> set[QgsSymbolLayer]: ...
    @staticmethod
    def getSvgParametricPath(basePath: str|None, fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def parametricSvgToSld(doc: QtXml.QDomDocument, graphicElem: QtXml.QDomElement, path: str|None, fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, size: float, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float) -> None: ...
    @typing.overload
    @staticmethod
    def parametricSvgToSld(doc: QtXml.QDomDocument, graphicElem: QtXml.QDomElement, path: str|None, fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, size: float, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeWidth: float, context: QgsSldExportContext) -> None: ...
    @staticmethod
    def mergeScaleDependencies(mScaleMinDenom: float, mScaleMaxDenom: float, props: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def applyScaleDependency(doc: QtXml.QDomDocument, ruleElem: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @staticmethod
    def rescaleArrayUom(array: collections.abc.Iterable[float], unit: Qgis.RenderUnit, props: dict[str|None, typing.Any]) -> list[float]: ...
    @staticmethod
    def rescalePointUom(point: QtCore.QPointF, unit: Qgis.RenderUnit, props: dict[str|None, typing.Any]) -> QtCore.QPointF: ...
    @staticmethod
    def rescaleUom(size: float, unit: Qgis.RenderUnit, props: dict[str|None, typing.Any]) -> float: ...
    @staticmethod
    def prettyBreaks(minimum: float, maximum: float, classes: int) -> list[float]: ...
    @staticmethod
    def fieldOrExpressionFromExpression(expression: QgsExpression|None) -> str: ...
    @staticmethod
    def fieldOrExpressionToExpression(fieldOrExpression: str|None) -> QgsExpression|None: ...
    @staticmethod
    def appendPolyline(target: QtGui.QPolygonF, line: QtGui.QPolygonF) -> None: ...
    @staticmethod
    def isSharpCorner(p1: QtCore.QPointF, p2: QtCore.QPointF, p3: QtCore.QPointF) -> bool: ...
    @staticmethod
    def polylineSubstring(polyline: QtGui.QPolygonF, startOffset: float, endOffset: float) -> QtGui.QPolygonF: ...
    @staticmethod
    def polylineLength(polyline: QtGui.QPolygonF) -> float: ...
    @staticmethod
    def pointInPolygon(points: QtGui.QPolygonF, point: QtCore.QPointF) -> bool: ...
    @staticmethod
    def polygonPointOnSurface(points: QtGui.QPolygonF, rings: collections.abc.Iterable[QtGui.QPolygonF] = ...) -> QtCore.QPointF: ...
    @staticmethod
    def polygonCentroid(points: QtGui.QPolygonF) -> QtCore.QPointF: ...
    @typing.overload
    @staticmethod
    def toQPolygonF(geometry: QgsGeometry, type: Qgis.SymbolType) -> typing.Any: ...
    @typing.overload
    @staticmethod
    def toQPolygonF(geometry: QgsAbstractGeometry|None, type: Qgis.SymbolType) -> typing.Any: ...
    @staticmethod
    def svgSymbolPathToName(path: str|None, pathResolver: QgsPathResolver) -> str: ...
    @staticmethod
    def svgSymbolNameToPath(name: str|None, pathResolver: QgsPathResolver) -> str: ...
    @staticmethod
    def listSvgFilesAt(directory: str|None) -> list[str]: ...
    @staticmethod
    def listSvgFiles() -> list[str]: ...
    @staticmethod
    def pointOnLineWithDistance(startPoint: QtCore.QPointF, directionPoint: QtCore.QPointF, distance: float) -> QtCore.QPointF: ...
    @staticmethod
    def sortVariantList(list: collections.abc.Iterable[typing.Any], order: QtCore.Qt.SortOrder) -> None: ...
    @staticmethod
    def condenseFillAndOutline(fill: QgsFillSymbolLayer|None, outline: QgsLineSymbolLayer|None) -> bool: ...
    @staticmethod
    def premultiplyColor(rgb: QtGui.QColor|QtCore.Qt.GlobalColor|int, alpha: int) -> None: ...
    @staticmethod
    def blurImageInPlace(image: QtGui.QImage, rect: QtCore.QRect, radius: int, alphaOnly: bool) -> None: ...
    @staticmethod
    def multiplyImageOpacity(image: QtGui.QImage|None, opacity: float) -> None: ...
    @staticmethod
    def parseColorWithAlpha(colorStr: str|None, strictEval: bool = ...) -> typing.Tuple[QtGui.QColor, bool]: ...
    @staticmethod
    def parseColor(colorStr: str|None, strictEval: bool = ...) -> QtGui.QColor: ...
    @staticmethod
    def importColorsFromGpl(file: QtCore.QFile, name: str|None) -> typing.Tuple[list[tuple[QtGui.QColor, str]], bool]: ...
    @staticmethod
    def saveColorsToGpl(file: QtCore.QFile, paletteName: str|None, colors: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]]) -> bool: ...
    @staticmethod
    def colorListToMimeData(colorList: collections.abc.Iterable[tuple[QtGui.QColor|QtCore.Qt.GlobalColor|int, str|None]], allFormats: bool = ...) -> QtCore.QMimeData|None: ...
    @staticmethod
    def colorListFromMimeData(data: QtCore.QMimeData|None) -> list[tuple[QtGui.QColor, str]]: ...
    @staticmethod
    def colorFromMimeData(data: QtCore.QMimeData|None) -> typing.Tuple[QtGui.QColor, bool]: ...
    @staticmethod
    def colorToMimeData(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> QtCore.QMimeData|None: ...
    @staticmethod
    def parseColorList(colorStr: str|None) -> list[QtGui.QColor]: ...
    @staticmethod
    def colorToName(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> str: ...
    @staticmethod
    def colorRampToVariant(name: str|None, ramp: QgsColorRamp|None) -> typing.Any: ...
    @staticmethod
    def saveColorRamp(name: str|None, ramp: QgsColorRamp|None, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    @typing.overload
    @staticmethod
    def loadColorRamp(element: QtXml.QDomElement) -> QgsColorRamp|None: ...
    @typing.overload
    @staticmethod
    def loadColorRamp(value: typing.Any) -> QgsColorRamp|None: ...
    @staticmethod
    def symbolFromMimeData(data: QtCore.QMimeData|None) -> QgsSymbol|None: ...
    @staticmethod
    def symbolToMimeData(symbol: QgsSymbol|None) -> QtCore.QMimeData|None: ...
    @staticmethod
    def clearSymbolMap(symbols: typing.Any) -> None: ...
    @staticmethod
    def saveSymbols(symbols: typing.Any, tagName: str|None, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def loadSymbols(element: QtXml.QDomElement, context: QgsReadWriteContext) -> typing.Any: ...
    @staticmethod
    def saveProperties(props: dict[str|None, typing.Any], doc: QtXml.QDomDocument, element: QtXml.QDomElement) -> None: ...
    @staticmethod
    def parseProperties(element: QtXml.QDomElement) -> dict[str, typing.Any]: ...
    @staticmethod
    def getVendorOptionList(element: QtXml.QDomElement) -> dict[str, str]: ...
    @staticmethod
    def createVendorOptionElement(doc: QtXml.QDomDocument, name: str|None, value: str|None) -> QtXml.QDomElement: ...
    @staticmethod
    def getSvgParameterList(element: QtXml.QDomElement) -> dict[str, str]: ...
    @staticmethod
    def createSvgParameterElement(doc: QtXml.QDomDocument, name: str|None, value: str|None) -> QtXml.QDomElement: ...
    @staticmethod
    def functionFromSldElement(element: QtXml.QDomElement, function: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def createFunctionElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, function: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    def createFunctionElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, function: str|None, context: QgsSldExportContext) -> bool: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def createExpressionElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, function: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    def createExpressionElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, function: str|None, context: QgsSldExportContext) -> bool: ...
    @staticmethod
    def geometryFromSldElement(element: QtXml.QDomElement, geomFunc: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def createGeometryElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, geomFunc: str|None) -> None: ...
    @typing.overload
    @staticmethod
    def createGeometryElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, geomFunc: str|None, context: QgsSldExportContext) -> None: ...
    @staticmethod
    def onlineResourceFromSldElement(element: QtXml.QDomElement, path: str|None, format: str|None) -> bool: ...
    @staticmethod
    def createOnlineResourceElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, path: str|None, format: str|None) -> None: ...
    @staticmethod
    def createAnchorPointElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, anchor: QtCore.QPointF) -> None: ...
    @staticmethod
    def displacementFromSldElement(element: QtXml.QDomElement, offset: QtCore.QPointF) -> bool: ...
    @staticmethod
    def createDisplacementElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, offset: QtCore.QPointF) -> None: ...
    @staticmethod
    def opacityFromSldElement(element: QtXml.QDomElement, alphaFunc: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def createOpacityElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, alphaFunc: str|None) -> None: ...
    @typing.overload
    @staticmethod
    def createOpacityElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, alphaFunc: str|None, context: QgsSldExportContext) -> None: ...
    @staticmethod
    def rotationFromSldElement(element: QtXml.QDomElement, rotationFunc: str|None) -> bool: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def createRotationElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, rotationFunc: str|None) -> None: ...
    @typing.overload
    @staticmethod
    def createRotationElement(doc: QtXml.QDomDocument, element: QtXml.QDomElement, rotationFunc: str|None, context: QgsSldExportContext) -> None: ...
    @staticmethod
    def ogrFeatureStyleBrush(fillColr: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> str: ...
    @staticmethod
    def ogrFeatureStylePen(width: float, mmScaleFactor: float, mapUnitsScaleFactor: float, c: QtGui.QColor|QtCore.Qt.GlobalColor|int, joinStyle: QtCore.Qt.PenJoinStyle = ..., capStyle: QtCore.Qt.PenCapStyle = ..., offset: float = ..., dashPattern: collections.abc.Iterable[float] = ...) -> str: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def labelTextToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, label: str|None, font: QtGui.QFont, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., size: float = ...) -> None: ...
    @typing.overload
    @staticmethod
    def labelTextToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, label: str|None, font: QtGui.QFont, context: QgsSldExportContext, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., size: float = ...) -> None: ...
    @staticmethod
    def externalMarkerFromSld(element: QtXml.QDomElement, path: str|None, format: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> typing.Tuple[bool, int, float]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def externalMarkerToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, path: str|None, format: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., size: float = ...) -> int: ...
    @typing.overload
    @staticmethod
    def externalMarkerToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, path: str|None, format: str|None, context: QgsSldExportContext, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., size: float = ...) -> int: ...
    @staticmethod
    def wellKnownMarkerFromSld2(element: QtXml.QDomElement, name: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> typing.Tuple[bool, QtCore.Qt.PenStyle, float, float]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def wellKnownMarkerToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, name: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeStyle: QtCore.Qt.PenStyle, strokeWidth: float = ..., size: float = ...) -> None: ...
    @typing.overload
    @staticmethod
    def wellKnownMarkerToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, name: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, strokeStyle: QtCore.Qt.PenStyle, context: QgsSldExportContext, strokeWidth: float = ..., size: float = ...) -> None: ...
    @staticmethod
    def externalGraphicFromSld(element: QtXml.QDomElement, path: str|None, mime: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> typing.Tuple[bool, float]: ...
    @staticmethod
    def externalGraphicToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, path: str|None, mime: str|None, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, size: float = ...) -> None: ...
    @staticmethod
    def lineFromSld(element: QtXml.QDomElement, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, customDashPattern: collections.abc.Iterable[float] = ...) -> typing.Tuple[bool, QtCore.Qt.PenStyle, float, QtCore.Qt.PenJoinStyle|None, QtCore.Qt.PenCapStyle|None, float]: ...
    @staticmethod
    def fillFromSld(element: QtXml.QDomElement, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> typing.Tuple[bool, QtCore.Qt.BrushStyle]: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def fillToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, brushStyle: QtCore.Qt.BrushStyle, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def fillToSld(doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext, brushStyle: QtCore.Qt.BrushStyle, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    @staticmethod
    def needRasterImageFill(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needSvgFill(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needPointPatternFill(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needLinePatternFill(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needMarkerLine(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needEllipseMarker(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needRasterMarker(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needSvgMarker(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def needFontMarker(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def hasWellKnownMark(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def hasExternalGraphicV2(element: QtXml.QDomElement, format: str|None = ...) -> bool: ...
    @staticmethod
    def hasExternalGraphic(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def convertPolygonSymbolizerToPointMarker(element: QtXml.QDomElement, layerList: collections.abc.Iterable[QgsSymbolLayer]) -> bool: ...
    @staticmethod
    def createMarkerLayerFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def createLineLayerFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def createFillLayerFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def createSymbolLayerListFromSld(element: QtXml.QDomElement, geomType: Qgis.GeometryType, layers: collections.abc.Iterable[QgsSymbolLayer]) -> bool: ...
    @staticmethod
    def symbolProperties(symbol: QgsSymbol|None) -> str: ...
    @staticmethod
    def saveSymbol(symbolName: str|None, symbol: QgsSymbol|None, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def loadSymbolLayer(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsSymbolLayer|None: ...
    @staticmethod
    def loadSymbol(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsSymbol|None: ...
    @staticmethod
    def estimateMaxSymbolBleed(symbol: QgsSymbol|None, context: QgsRenderContext) -> float: ...
    @staticmethod
    def drawVertexMarker(x: float, y: float, p: QtGui.QPainter, type: Qgis.VertexMarkerType, markerSize: int) -> None: ...
    @staticmethod
    def drawStippledBackground(painter: QtGui.QPainter|None, rect: QtCore.QRect) -> None: ...
    @staticmethod
    def colorRampPreviewPixmap(ramp: QgsColorRamp|None, size: QtCore.QSize, padding: int = ..., direction: QtCore.Qt.Orientation = ..., flipDirection: bool = ..., drawTransparentBackground: bool = ...) -> QtGui.QPixmap: ...
    @staticmethod
    def colorRampPreviewIcon(ramp: QgsColorRamp|None, size: QtCore.QSize, padding: int = ...) -> QtGui.QIcon: ...
    @staticmethod
    def symbolLayerPreviewIcon(layer: QgsSymbolLayer|None, u: Qgis.RenderUnit, size: QtCore.QSize, scale: QgsMapUnitScale = ..., parentSymbolType: Qgis.SymbolType = ..., mapLayer: QgsMapLayer|None = ..., screen: QgsScreenProperties = ...) -> QtGui.QIcon: ...
    @staticmethod
    def symbolLayerPreviewPicture(layer: QgsSymbolLayer|None, units: Qgis.RenderUnit, size: QtCore.QSize, scale: QgsMapUnitScale = ..., parentSymbolType: Qgis.SymbolType = ...) -> QtGui.QPicture: ...
    @staticmethod
    def symbolPreviewPixmap(symbol: QgsSymbol|None, size: QtCore.QSize, padding: int = ..., customContext: QgsRenderContext|None = ..., selected: bool = ..., expressionContext: QgsExpressionContext|None = ..., shape: QgsLegendPatchShape|None = ..., screen: QgsScreenProperties = ...) -> QtGui.QPixmap: ...
    @staticmethod
    def symbolPreviewIcon(symbol: QgsSymbol|None, size: QtCore.QSize, padding: int = ..., shape: QgsLegendPatchShape|None = ..., screen: QgsScreenProperties = ...) -> QtGui.QIcon: ...
    @staticmethod
    def decodeBlendMode(s: str|None) -> QtGui.QPainter.CompositionMode: ...
    @staticmethod
    def decodeScaleMethod(str: str|None) -> Qgis.ScaleMethod: ...
    @staticmethod
    def encodeScaleMethod(scaleMethod: Qgis.ScaleMethod) -> str: ...
    @staticmethod
    def sizeInPixelsFromSldUom(uom: str|None, size: float) -> float: ...
    @staticmethod
    def decodeSldUom(str: str|None) -> typing.Tuple[Qgis.RenderUnit, float]: ...
    @staticmethod
    def encodeSldUom(unit: Qgis.RenderUnit) -> typing.Tuple[str, float]: ...
    @staticmethod
    def decodeSldRealVector(s: str|None) -> list[float]: ...
    @staticmethod
    def encodeSldRealVector(v: collections.abc.Iterable[float]) -> str: ...
    @staticmethod
    def decodeRealVector(s: str|None) -> list[float]: ...
    @staticmethod
    def encodeRealVector(v: collections.abc.Iterable[float]) -> str: ...
    @staticmethod
    def decodeMapUnitScale(str: str|None) -> QgsMapUnitScale: ...
    @staticmethod
    def encodeMapUnitScale(mapUnitScale: QgsMapUnitScale) -> str: ...
    @staticmethod
    def toSize(value: typing.Any) -> typing.Tuple[QtCore.QSizeF, bool]: ...
    @staticmethod
    def decodeSize(string: str|None) -> QtCore.QSizeF: ...
    @staticmethod
    def encodeSize(size: QtCore.QSizeF) -> str: ...
    @staticmethod
    def toPoint(value: typing.Any) -> typing.Tuple[QtCore.QPointF, bool]: ...
    @staticmethod
    def decodePoint(string: str|None) -> QtCore.QPointF: ...
    @staticmethod
    def encodePoint(point: QtCore.QPointF) -> str: ...
    @staticmethod
    def encodeLineClipMode(mode: Qgis.LineClipMode) -> str: ...
    @staticmethod
    def decodeLineClipMode(string: str|None) -> typing.Tuple[Qgis.LineClipMode, bool]: ...
    @staticmethod
    def encodeMarkerClipMode(mode: Qgis.MarkerClipMode) -> str: ...
    @staticmethod
    def decodeMarkerClipMode(string: str|None) -> typing.Tuple[Qgis.MarkerClipMode, bool]: ...
    @staticmethod
    def decodeArrowType(value: typing.Any) -> typing.Tuple[QgsArrowSymbolLayer.ArrowType, bool]: ...
    @staticmethod
    def decodeArrowHeadType(value: typing.Any) -> typing.Tuple[QgsArrowSymbolLayer.HeadType, bool]: ...
    @staticmethod
    def encodeCoordinateReference(coordinateReference: Qgis.SymbolCoordinateReference) -> str: ...
    @staticmethod
    def decodeCoordinateReference(string: str|None) -> typing.Tuple[Qgis.SymbolCoordinateReference, bool]: ...
    @staticmethod
    def hasSldSymbolizer(element: QtXml.QDomElement) -> bool: ...
    @staticmethod
    def penJoinStyleToJoinStyle(style: QtCore.Qt.PenJoinStyle) -> Qgis.JoinStyle: ...
    @staticmethod
    def penCapStyleToEndCapStyle(style: QtCore.Qt.PenCapStyle) -> Qgis.EndCapStyle: ...
    @staticmethod
    def decodeSldBrushStyle(str: str|None) -> QtCore.Qt.BrushStyle: ...
    @staticmethod
    def encodeSldBrushStyle(style: QtCore.Qt.BrushStyle) -> str: ...
    @staticmethod
    def decodeBrushStyle(str: str|None) -> QtCore.Qt.BrushStyle: ...
    @staticmethod
    def encodeBrushStyle(style: QtCore.Qt.BrushStyle) -> str: ...
    @staticmethod
    def decodeSldLineCapStyle(str: str|None) -> QtCore.Qt.PenCapStyle: ...
    @staticmethod
    def encodeSldLineCapStyle(style: QtCore.Qt.PenCapStyle) -> str: ...
    @staticmethod
    def decodeSldLineJoinStyle(str: str|None) -> QtCore.Qt.PenJoinStyle: ...
    @staticmethod
    def encodeSldLineJoinStyle(style: QtCore.Qt.PenJoinStyle) -> str: ...
    @staticmethod
    def decodePenCapStyle(str: str|None) -> QtCore.Qt.PenCapStyle: ...
    @staticmethod
    def encodePenCapStyle(style: QtCore.Qt.PenCapStyle) -> str: ...
    @staticmethod
    def decodePenJoinStyle(str: str|None) -> QtCore.Qt.PenJoinStyle: ...
    @staticmethod
    def encodePenJoinStyle(style: QtCore.Qt.PenJoinStyle) -> str: ...
    @staticmethod
    def decodePenStyle(str: str|None) -> QtCore.Qt.PenStyle: ...
    @staticmethod
    def encodePenStyle(style: QtCore.Qt.PenStyle) -> str: ...
    @staticmethod
    def decodeSldFontWeight(str: str|None) -> int: ...
    @staticmethod
    def encodeSldFontWeight(weight: int) -> str: ...
    @staticmethod
    def decodeSldFontStyle(str: str|None) -> QtGui.QFont.Style: ...
    @staticmethod
    def encodeSldFontStyle(style: QtGui.QFont.Style) -> str: ...
    @staticmethod
    def decodeSldAlpha(str: str|None) -> int: ...
    @staticmethod
    def encodeSldAlpha(alpha: int) -> str: ...
    @staticmethod
    def decodeColor(str: str|None) -> QtGui.QColor: ...
    @staticmethod
    def encodeColor(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> str: ...


class QgsSymbolRenderContext(PyQt6.sip.wrapper):

    def __init__(self, c: QgsRenderContext, u: Qgis.RenderUnit, opacity: float = ..., selected: bool = ..., renderHints: Qgis.SymbolRenderHint = ..., f: QgsFeature|None = ..., fields: QgsFields = ..., mapUnitScale: QgsMapUnitScale = ...) -> None: ...

    def setPatchShape(self, shape: QgsLegendPatchShape) -> None: ...
    def patchShape(self) -> QgsLegendPatchShape|None: ...
    def setExpressionContextScope(self, contextScope: QgsExpressionContextScope|None) -> None: ...
    def expressionContextScope(self) -> QgsExpressionContextScope|None: ...
    @deprecated("""""")
    def outputPixelSize(self, size: float) -> float: ...
    @deprecated("""""")
    def outputLineWidth(self, width: float) -> float: ...
    def setGeometryPartNum(self, num: int) -> None: ...
    def geometryPartNum(self) -> int: ...
    def setGeometryPartCount(self, count: int) -> None: ...
    def geometryPartCount(self) -> int: ...
    def fields(self) -> QgsFields: ...
    def originalGeometryType(self) -> Qgis.GeometryType: ...
    def setOriginalGeometryType(self, type: Qgis.GeometryType) -> None: ...
    def feature(self) -> QgsFeature|None: ...
    def setFeature(self, f: QgsFeature|None) -> None: ...
    def setRenderHint(self, hint: Qgis.SymbolRenderHint, enabled: bool = ...) -> None: ...
    def setRenderHints(self, hints: Qgis.SymbolRenderHint) -> None: ...
    def forceVectorRendering(self) -> bool: ...
    def renderHints(self) -> Qgis.SymbolRenderHint: ...
    def setSelected(self, selected: bool) -> None: ...
    def selected(self) -> bool: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    @deprecated("""""")
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    @deprecated("""""")
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    @deprecated("""""")
    def setOutputUnit(self, u: Qgis.RenderUnit) -> None: ...
    @deprecated("""""")
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOriginalValueVariable(self, value: typing.Any) -> None: ...
    def renderContext(self) -> QgsRenderContext: ...


class QgsVectorFieldSymbolLayer(QgsMarkerSymbolLayer):

    class AngleUnits(enum.IntEnum):
        Degrees = ... # type: QgsVectorFieldSymbolLayer.AngleUnits
        Radians = ... # type: QgsVectorFieldSymbolLayer.AngleUnits

    class AngleOrientation(enum.IntEnum):
        ClockwiseFromNorth = ... # type: QgsVectorFieldSymbolLayer.AngleOrientation
        CounterclockwiseFromEast = ... # type: QgsVectorFieldSymbolLayer.AngleOrientation

    class VectorFieldType(enum.IntEnum):
        Cartesian = ... # type: QgsVectorFieldSymbolLayer.VectorFieldType
        Polar = ... # type: QgsVectorFieldSymbolLayer.VectorFieldType
        Height = ... # type: QgsVectorFieldSymbolLayer.VectorFieldType

    def __init__(self) -> None: ...

    def bounds(self, a0: QtCore.QPointF, a1: QgsSymbolRenderContext) -> QtCore.QRectF: ...
    def distanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def distanceUnit(self) -> Qgis.RenderUnit: ...
    def setDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def mapUnitScale(self) -> QgsMapUnitScale: ...
    def setMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def outputUnit(self) -> Qgis.RenderUnit: ...
    def setOutputUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def angleUnits(self) -> 'QgsVectorFieldSymbolLayer.AngleUnits': ...
    def setAngleUnits(self, units: 'QgsVectorFieldSymbolLayer.AngleUnits') -> None: ...
    def angleOrientation(self) -> 'QgsVectorFieldSymbolLayer.AngleOrientation': ...
    def setAngleOrientation(self, orientation: 'QgsVectorFieldSymbolLayer.AngleOrientation') -> None: ...
    def vectorFieldType(self) -> 'QgsVectorFieldSymbolLayer.VectorFieldType': ...
    def setVectorFieldType(self, type: 'QgsVectorFieldSymbolLayer.VectorFieldType') -> None: ...
    def scale(self) -> float: ...
    def setScale(self, s: float) -> None: ...
    def yAttribute(self) -> str: ...
    def setYAttribute(self, attribute: str|None) -> None: ...
    def xAttribute(self) -> str: ...
    def setXAttribute(self, attribute: str|None) -> None: ...
    def hasDataDefinedProperties(self) -> bool: ...
    def usedAttributes(self, context: QgsRenderContext) -> set[str]: ...
    def drawPreviewIcon(self, context: QgsSymbolRenderContext, size: QtCore.QSize) -> None: ...
    @typing.overload
    @deprecated("""""")
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, props: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def toSld(self, doc: QtXml.QDomDocument, element: QtXml.QDomElement, context: QgsSldExportContext) -> bool: ...
    def usesMapUnits(self) -> bool: ...
    def properties(self) -> dict[str, typing.Any]: ...
    def clone(self) -> 'QgsVectorFieldSymbolLayer|None': ...
    def stopRender(self, context: QgsSymbolRenderContext) -> None: ...
    def startRender(self, context: QgsSymbolRenderContext) -> None: ...
    def renderPoint(self, point: QtCore.QPointF, context: QgsSymbolRenderContext) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def subSymbol(self) -> QgsSymbol|None: ...
    def setSubSymbol(self, symbol: QgsSymbol|None) -> bool: ...
    def layerType(self) -> str: ...
    @staticmethod
    def createFromSld(element: QtXml.QDomElement) -> QgsSymbolLayer|None: ...
    @staticmethod
    def create(properties: dict[str|None, typing.Any] = ...) -> QgsSymbolLayer|None: ...


class QgsFontDownloadDetails(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, family: str|None, fontUrls: collections.abc.Iterable[str|None], licenseUrl: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFontDownloadDetails') -> None: ...

    def licenseUrl(self) -> str: ...
    def fontUrls(self) -> list[str]: ...
    def standardizedFamily(self) -> str: ...
    def family(self) -> str: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def standardizeFamily(family: str|None) -> str: ...


class QgsFontManager(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    fontDownloadErrorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    fontDownloaded: typing.ClassVar[QtCore.pyqtSignal]
    def removeUserFont(self, path: str|None) -> bool: ...
    def userFontToFamilyMap(self) -> dict[str, list[str]]: ...
    def addUserFontDirectory(self, directory: str|None) -> None: ...
    def installFontsFromData(self, data: QtCore.QByteArray|bytes|bytearray|memoryview, filename: str|None = ..., extension: str|None = ...) -> typing.Tuple[bool, str, list[str], str]: ...
    @typing.overload
    @deprecated("""""")
    def downloadAndInstallFont(self, url: QtCore.QUrl, identifier: str|None = ...) -> None: ...
    @typing.overload
    def downloadAndInstallFont(self, details: QgsFontDownloadDetails, identifier: str|None = ...) -> None: ...
    def detailsForFontDownload(self, family: str|None) -> typing.Tuple[QgsFontDownloadDetails, str]: ...
    @deprecated("""""")
    def urlForFontDownload(self, family: str|None) -> typing.Tuple[str, str]: ...
    def enableFontDownloadsForSession(self) -> None: ...
    def tryToDownloadFontFamily(self, family: str|None) -> typing.Tuple[bool, str]: ...
    def processFontFamilyName(self, name: str|None) -> str: ...
    def setFontFamilyReplacements(self, replacements: dict[str|None, str|None]) -> None: ...
    def addFontFamilyReplacement(self, original: str|None, replacement: str|None) -> None: ...
    def fontFamilyReplacements(self) -> dict[str, str]: ...


class QgsTextBackgroundSettings(PyQt6.sip.wrapper):

    class RotationType(enum.IntEnum):
        RotationSync = ... # type: QgsTextBackgroundSettings.RotationType
        RotationOffset = ... # type: QgsTextBackgroundSettings.RotationType
        RotationFixed = ... # type: QgsTextBackgroundSettings.RotationType

    class SizeType(enum.IntEnum):
        SizeBuffer = ... # type: QgsTextBackgroundSettings.SizeType
        SizeFixed = ... # type: QgsTextBackgroundSettings.SizeType
        SizePercent = ... # type: QgsTextBackgroundSettings.SizeType

    class ShapeType(enum.IntEnum):
        ShapeRectangle = ... # type: QgsTextBackgroundSettings.ShapeType
        ShapeSquare = ... # type: QgsTextBackgroundSettings.ShapeType
        ShapeEllipse = ... # type: QgsTextBackgroundSettings.ShapeType
        ShapeCircle = ... # type: QgsTextBackgroundSettings.ShapeType
        ShapeSVG = ... # type: QgsTextBackgroundSettings.ShapeType
        ShapeMarkerSymbol = ... # type: QgsTextBackgroundSettings.ShapeType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTextBackgroundSettings') -> None: ...

    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def updateDataDefinedProperties(self, context: QgsRenderContext, properties: QgsPropertyCollection) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def readFromLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setPaintEffect(self, effect: QgsPaintEffect|None) -> None: ...
    def paintEffect(self) -> QgsPaintEffect|None: ...
    def setJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def joinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setStrokeWidthMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def strokeWidthMapUnitScale(self) -> QgsMapUnitScale: ...
    def setStrokeWidthUnit(self, units: Qgis.RenderUnit) -> None: ...
    def strokeWidthUnit(self) -> Qgis.RenderUnit: ...
    def setStrokeWidth(self, width: float) -> None: ...
    def strokeWidth(self) -> float: ...
    def setStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setRadiiMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def radiiMapUnitScale(self) -> QgsMapUnitScale: ...
    def setRadiiUnit(self, units: Qgis.RenderUnit) -> None: ...
    def radiiUnit(self) -> Qgis.RenderUnit: ...
    def setRadii(self, radii: QtCore.QSizeF) -> None: ...
    def radii(self) -> QtCore.QSizeF: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetUnit(self, units: Qgis.RenderUnit) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffset(self, offset: QtCore.QPointF) -> None: ...
    def offset(self) -> QtCore.QPointF: ...
    def setRotation(self, rotation: float) -> None: ...
    def rotation(self) -> float: ...
    def setRotationType(self, type: 'QgsTextBackgroundSettings.RotationType') -> None: ...
    def rotationType(self) -> 'QgsTextBackgroundSettings.RotationType': ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSize(self, size: QtCore.QSizeF) -> None: ...
    def size(self) -> QtCore.QSizeF: ...
    def setSizeType(self, type: 'QgsTextBackgroundSettings.SizeType') -> None: ...
    def sizeType(self) -> 'QgsTextBackgroundSettings.SizeType': ...
    def setFillSymbol(self, symbol: QgsFillSymbol|None) -> None: ...
    def fillSymbol(self) -> QgsFillSymbol|None: ...
    def setMarkerSymbol(self, symbol: QgsMarkerSymbol|None) -> None: ...
    def markerSymbol(self) -> QgsMarkerSymbol|None: ...
    def setSvgFile(self, file: str|None) -> None: ...
    def svgFile(self) -> str: ...
    def setType(self, type: 'QgsTextBackgroundSettings.ShapeType') -> None: ...
    def type(self) -> 'QgsTextBackgroundSettings.ShapeType': ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsTextBlock(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, fragment: 'QgsTextFragment') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextBlock') -> None: ...

    def __getitem__(self, index: int) -> 'QgsTextFragment': ...
    def at(self, index: int) -> 'QgsTextFragment': ...
    def __len__(self) -> int: ...
    def hasBackgrounds(self) -> bool: ...
    def applyCapitalization(self, capitalization: Qgis.Capitalization) -> None: ...
    def setBlockFormat(self, format: 'QgsTextBlockFormat') -> None: ...
    def blockFormat(self) -> 'QgsTextBlockFormat': ...
    def size(self) -> int: ...
    def empty(self) -> bool: ...
    def clear(self) -> None: ...
    def insert(self, index: int, fragment: 'QgsTextFragment') -> None: ...
    def append(self, fragment: 'QgsTextFragment') -> None: ...
    def reserve(self, count: int) -> None: ...
    def toPlainText(self) -> str: ...
    @staticmethod
    def fromPlainText(text: str|None, format: 'QgsTextCharacterFormat' = ...) -> 'QgsTextBlock': ...


class QgsTextBlockFormat(PyQt6.sip.wrapper):

    class BooleanValue(enum.Enum):
        NotSet = ... # type: QgsTextBlockFormat.BooleanValue
        SetTrue = ... # type: QgsTextBlockFormat.BooleanValue
        SetFalse = ... # type: QgsTextBlockFormat.BooleanValue

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, format: QtGui.QTextBlockFormat) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextBlockFormat') -> None: ...

    def updateFontForFormat(self, font: QtGui.QFont, context: QgsRenderContext, scaleFactor: float = ...) -> None: ...
    def setBackgroundImagePath(self, path: str|None) -> None: ...
    def backgroundImagePath(self) -> str: ...
    def setBackgroundBrush(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    def backgroundBrush(self) -> QtGui.QBrush: ...
    def hasBackground(self) -> bool: ...
    def setMargins(self, margins: QgsMargins) -> None: ...
    def margins(self) -> QgsMargins: ...
    def setLineHeightPercentage(self, height: float) -> None: ...
    def lineHeightPercentage(self) -> float: ...
    def setLineHeight(self, height: float) -> None: ...
    def lineHeight(self) -> float: ...
    def setHorizontalAlignment(self, alignment: Qgis.TextHorizontalAlignment) -> None: ...
    def horizontalAlignment(self) -> Qgis.TextHorizontalAlignment: ...
    def setHasHorizontalAlignmentSet(self, set: bool) -> None: ...
    def hasHorizontalAlignmentSet(self) -> bool: ...
    def overrideWith(self, other: 'QgsTextBlockFormat') -> None: ...


class QgsTextBufferSettings(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTextBufferSettings') -> None: ...

    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def updateDataDefinedProperties(self, context: QgsRenderContext, properties: QgsPropertyCollection) -> None: ...
    def setPaintEffect(self, effect: QgsPaintEffect|None) -> None: ...
    def paintEffect(self) -> QgsPaintEffect|None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def readFromLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def joinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setFillBufferInterior(self, fill: bool) -> None: ...
    def fillBufferInterior(self) -> bool: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSize(self, size: float) -> None: ...
    def size(self) -> float: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsTextCharacterFormat(PyQt6.sip.wrapper):

    class BooleanValue(enum.Enum):
        NotSet = ... # type: QgsTextCharacterFormat.BooleanValue
        SetTrue = ... # type: QgsTextCharacterFormat.BooleanValue
        SetFalse = ... # type: QgsTextCharacterFormat.BooleanValue

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, format: QtGui.QTextCharFormat) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextCharacterFormat') -> None: ...

    def updateFontForFormat(self, font: QtGui.QFont, context: QgsRenderContext, scaleFactor: float = ...) -> None: ...
    def setBackgroundImagePath(self, path: str|None) -> None: ...
    def backgroundImagePath(self) -> str: ...
    def setBackgroundBrush(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    def backgroundBrush(self) -> QtGui.QBrush: ...
    def hasBackground(self) -> bool: ...
    def setVerticalAlignment(self, alignment: Qgis.TextCharacterVerticalAlignment) -> None: ...
    def verticalAlignment(self) -> Qgis.TextCharacterVerticalAlignment: ...
    def setHasVerticalAlignmentSet(self, set: bool) -> None: ...
    def hasVerticalAlignmentSet(self) -> bool: ...
    def setImageSize(self, size: QtCore.QSizeF) -> None: ...
    def imageSize(self) -> QtCore.QSizeF: ...
    def setImagePath(self, path: str|None) -> None: ...
    def imagePath(self) -> str: ...
    def setOverline(self, enabled: 'QgsTextCharacterFormat.BooleanValue') -> None: ...
    def overline(self) -> 'QgsTextCharacterFormat.BooleanValue': ...
    def setUnderline(self, enabled: 'QgsTextCharacterFormat.BooleanValue') -> None: ...
    def underline(self) -> 'QgsTextCharacterFormat.BooleanValue': ...
    def setStrikeOut(self, enabled: 'QgsTextCharacterFormat.BooleanValue') -> None: ...
    def strikeOut(self) -> 'QgsTextCharacterFormat.BooleanValue': ...
    def setItalic(self, enabled: 'QgsTextCharacterFormat.BooleanValue') -> None: ...
    def italic(self) -> 'QgsTextCharacterFormat.BooleanValue': ...
    def setWordSpacing(self, spacing: float) -> None: ...
    def wordSpacing(self) -> float: ...
    def setFontWeight(self, fontWeight: int) -> None: ...
    def fontWeight(self) -> int: ...
    def setFamily(self, family: str|None) -> None: ...
    def family(self) -> str: ...
    def setFontPercentageSize(self, size: float) -> None: ...
    def fontPercentageSize(self) -> float: ...
    def setFontPointSize(self, size: float) -> None: ...
    def fontPointSize(self) -> float: ...
    def setTextColor(self, textColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def textColor(self) -> QtGui.QColor: ...
    def overrideWith(self, other: 'QgsTextCharacterFormat') -> None: ...


class QgsTextDocument(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTextDocument') -> None: ...
    @typing.overload
    def __init__(self, block: QgsTextBlock) -> None: ...
    @typing.overload
    def __init__(self, fragment: 'QgsTextFragment') -> None: ...

    def hasBackgrounds(self) -> bool: ...
    def applyCapitalization(self, capitalization: Qgis.Capitalization) -> None: ...
    def splitBlocksToDocuments(self) -> list['QgsTextDocument']: ...
    def splitLines(self, wrapCharacter: str|None, autoWrapLength: int = ..., useMaxLineLengthWhenAutoWrapping: bool = ...) -> None: ...
    def toPlainText(self) -> list[str]: ...
    def __len__(self) -> int: ...
    def size(self) -> int: ...
    def __getitem__(self, index: int) -> QgsTextBlock: ...
    def at(self, index: int) -> QgsTextBlock: ...
    def reserve(self, count: int) -> None: ...
    def insert(self, index: int, block: QgsTextBlock) -> None: ...
    def append(self, block: QgsTextBlock) -> None: ...
    @staticmethod
    def fromTextAndFormat(lines: collections.abc.Iterable[str|None], format: 'QgsTextFormat') -> 'QgsTextDocument': ...
    @staticmethod
    def fromHtml(lines: collections.abc.Iterable[str|None]) -> 'QgsTextDocument': ...
    @staticmethod
    def fromPlainText(lines: collections.abc.Iterable[str|None]) -> 'QgsTextDocument': ...


class QgsTextDocumentRenderContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextDocumentRenderContext') -> None: ...

    def setMaximumWidth(self, width: float) -> None: ...
    def maximumWidth(self) -> float: ...
    def setFlags(self, flags: Qgis.TextRendererFlag) -> None: ...
    def flags(self) -> Qgis.TextRendererFlag: ...


class QgsTextDocumentMetrics(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextDocumentMetrics') -> None: ...

    def blockRightMargin(self, blockIndex: int) -> float: ...
    def blockLeftMargin(self, blockIndex: int) -> float: ...
    def blockVerticalMargin(self, blockIndex: int) -> float: ...
    def ascentOffset(self) -> float: ...
    def fragmentFont(self, blockIndex: int, fragmentIndex: int) -> QtGui.QFont: ...
    def blockMaximumAscent(self, blockIndex: int) -> float: ...
    def blockMaximumDescent(self, blockIndex: int) -> float: ...
    def blockMaximumCharacterWidth(self, blockIndex: int) -> float: ...
    def verticalOrientationXOffset(self, blockIndex: int) -> float: ...
    def fragmentDescent(self, blockIndex: int, fragmentIndex: int, mode: Qgis.TextLayoutMode) -> float: ...
    def fragmentAscent(self, blockIndex: int, fragmentIndex: int, mode: Qgis.TextLayoutMode) -> float: ...
    def fragmentFixedHeight(self, blockIndex: int, fragmentIndex: int, mode: Qgis.TextLayoutMode) -> float: ...
    def fragmentVerticalOffset(self, blockIndex: int, fragmentIndex: int, mode: Qgis.TextLayoutMode) -> float: ...
    def fragmentHorizontalAdvance(self, blockIndex: int, fragmentIndex: int, mode: Qgis.TextLayoutMode) -> float: ...
    def baselineOffset(self, blockIndex: int, mode: Qgis.TextLayoutMode) -> float: ...
    def firstLineCapHeight(self) -> float: ...
    def blockHeight(self, blockIndex: int) -> float: ...
    def blockWidth(self, blockIndex: int) -> float: ...
    def outerBounds(self, mode: Qgis.TextLayoutMode, orientation: Qgis.TextOrientation) -> QtCore.QRectF: ...
    def documentSize(self, mode: Qgis.TextLayoutMode, orientation: Qgis.TextOrientation) -> QtCore.QSizeF: ...
    def document(self) -> QgsTextDocument: ...
    def isNullFontSize(self) -> bool: ...
    @staticmethod
    def calculateMetrics(document: QgsTextDocument, format: 'QgsTextFormat', context: QgsRenderContext, scaleFactor: float = ..., documentContext: QgsTextDocumentRenderContext = ...) -> 'QgsTextDocumentMetrics': ...


class QgsTextFormat(PyQt6.sip.wrapper):

    class Tab(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, position: float) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsTextFormat.Tab') -> None: ...

        def __ne__(self, other: object): ...
        def __repr__(self) -> typing.Any: ...
        def __eq__(self, other: object): ...
        def position(self) -> float: ...
        def setPosition(self, position: float) -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTextFormat') -> None: ...

    def asCSS(self, pointToPixelMultiplier: float = ...) -> str: ...
    @staticmethod
    def textFormatPreviewPixmap(format: 'QgsTextFormat', size: QtCore.QSize, previewText: str|None = ..., padding: int = ..., screen: QgsScreenProperties = ...) -> QtGui.QPixmap: ...
    def updateDataDefinedProperties(self, context: QgsRenderContext) -> None: ...
    def setDataDefinedProperties(self, collection: QgsPropertyCollection) -> None: ...
    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def resolvedFontFamily(self) -> str: ...
    def fontFound(self) -> bool: ...
    def hasNonDefaultCompositionMode(self) -> bool: ...
    def containsAdvancedEffects(self) -> bool: ...
    @staticmethod
    def fromMimeData(data: QtCore.QMimeData|None) -> typing.Tuple['QgsTextFormat', bool]: ...
    def toQFont(self) -> QtGui.QFont: ...
    @staticmethod
    def fromQFont(font: QtGui.QFont) -> 'QgsTextFormat': ...
    def toMimeData(self) -> QtCore.QMimeData|None: ...
    def writeXml(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def readFromLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setPreviewBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def previewBackgroundColor(self) -> QtGui.QColor: ...
    def setAllowHtmlFormatting(self, allow: bool) -> None: ...
    def allowHtmlFormatting(self) -> bool: ...
    def setCapitalization(self, capitalization: Qgis.Capitalization) -> None: ...
    def capitalization(self) -> Qgis.Capitalization: ...
    def setOrientation(self, orientation: Qgis.TextOrientation) -> None: ...
    def orientation(self) -> Qgis.TextOrientation: ...
    def setTabStopDistanceMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def tabStopDistanceMapUnitScale(self) -> QgsMapUnitScale: ...
    def setTabStopDistanceUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def tabStopDistanceUnit(self) -> Qgis.RenderUnit: ...
    def setTabPositions(self, positions: collections.abc.Iterable['QgsTextFormat.Tab']) -> None: ...
    def tabPositions(self) -> list['QgsTextFormat.Tab']: ...
    def setTabStopDistance(self, distance: float) -> None: ...
    def tabStopDistance(self) -> float: ...
    def setLineHeightUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def lineHeightUnit(self) -> Qgis.RenderUnit: ...
    def setLineHeight(self, height: float) -> None: ...
    def lineHeight(self) -> float: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setStretchFactor(self, factor: int) -> None: ...
    def stretchFactor(self) -> int: ...
    def setOpacity(self, opacity: float) -> None: ...
    def multiplyOpacity(self, opacityFactor: float) -> None: ...
    def opacity(self) -> float: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSize(self, size: float) -> None: ...
    def size(self) -> float: ...
    def setFamilies(self, families: collections.abc.Iterable[str|None]) -> None: ...
    def families(self) -> list[str]: ...
    def setForcedItalic(self, forced: bool) -> None: ...
    def forcedItalic(self) -> bool: ...
    def setForcedBold(self, forced: bool) -> None: ...
    def forcedBold(self) -> bool: ...
    def setNamedStyle(self, style: str|None) -> None: ...
    def namedStyle(self) -> str: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def scaledFont(self, context: QgsRenderContext, scaleFactor: float = ...) -> QtGui.QFont: ...
    def font(self) -> QtGui.QFont: ...
    def setMask(self, maskSettings: 'QgsTextMaskSettings') -> None: ...
    def mask(self) -> 'QgsTextMaskSettings': ...
    def setShadow(self, shadowSettings: 'QgsTextShadowSettings') -> None: ...
    def shadow(self) -> 'QgsTextShadowSettings': ...
    def setBackground(self, backgroundSettings: QgsTextBackgroundSettings) -> None: ...
    def background(self) -> QgsTextBackgroundSettings: ...
    def setBuffer(self, bufferSettings: QgsTextBufferSettings) -> None: ...
    def buffer(self) -> QgsTextBufferSettings: ...
    def setValid(self) -> None: ...
    def isValid(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsTextFragment(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, text: str|None = ..., format: QgsTextCharacterFormat = ...) -> None: ...
    @typing.overload
    def __init__(self, fragment: QtGui.QTextFragment) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextFragment') -> None: ...

    def applyCapitalization(self, capitalization: Qgis.Capitalization) -> None: ...
    def horizontalAdvance(self, font: QtGui.QFont, context: QgsRenderContext, fontHasBeenUpdatedForFragment: bool = ..., scaleFactor: float = ...) -> float: ...
    def isImage(self) -> bool: ...
    def setCharacterFormat(self, format: QgsTextCharacterFormat) -> None: ...
    def characterFormat(self) -> QgsTextCharacterFormat: ...
    def isWhitespace(self) -> bool: ...
    def isTab(self) -> bool: ...
    def setText(self, text: str|None) -> None: ...
    def text(self) -> str: ...


class QgsTextMaskSettings(PyQt6.sip.wrapper):

    class MaskType(enum.IntEnum):
        MaskBuffer = ... # type: QgsTextMaskSettings.MaskType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTextMaskSettings') -> None: ...

    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def updateDataDefinedProperties(self, context: QgsRenderContext, properties: QgsPropertyCollection) -> None: ...
    def setMaskedSymbolLayers(self, maskedLayers: collections.abc.Iterable[QgsSymbolLayerReference]) -> None: ...
    def maskedSymbolLayers(self) -> list[QgsSymbolLayerReference]: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def setPaintEffect(self, effect: QgsPaintEffect|None) -> None: ...
    def paintEffect(self) -> QgsPaintEffect|None: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def joinStyle(self) -> QtCore.Qt.PenJoinStyle: ...
    def setSizeMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def sizeMapUnitScale(self) -> QgsMapUnitScale: ...
    def setSizeUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def sizeUnit(self) -> Qgis.RenderUnit: ...
    def setSize(self, size: float) -> None: ...
    def size(self) -> float: ...
    def setType(self, type: 'QgsTextMaskSettings.MaskType') -> None: ...
    def type(self) -> 'QgsTextMaskSettings.MaskType': ...
    def setEnabled(self, a0: bool) -> None: ...
    def enabled(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsTextRenderer(PyQt6.sip.wrapper):

    FONT_WORKAROUND_SCALE = ... # type: float
    SUPERSCRIPT_SUBSCRIPT_FONT_SIZE_SCALING_FACTOR = ... # type: float

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextRenderer') -> None: ...

    @staticmethod
    def calculateScaleFactorForFormat(context: QgsRenderContext, format: QgsTextFormat) -> float: ...
    @staticmethod
    def wrappedText(context: QgsRenderContext, text: str|None, width: float, format: QgsTextFormat) -> list[str]: ...
    @staticmethod
    def textRequiresWrapping(context: QgsRenderContext, text: str|None, width: float, format: QgsTextFormat) -> bool: ...
    @typing.overload
    @staticmethod
    def textHeight(context: QgsRenderContext, format: QgsTextFormat, textLines: collections.abc.Iterable[str|None], mode: Qgis.TextLayoutMode = ..., fontMetrics: QtGui.QFontMetricsF|None = ..., flags: Qgis.TextRendererFlag = ..., maxLineWidth: float = ...) -> float: ...
    @typing.overload
    @staticmethod
    def textHeight(context: QgsRenderContext, format: QgsTextFormat, character: str, includeEffects: bool = ...) -> float: ...
    @staticmethod
    def textWidth(context: QgsRenderContext, format: QgsTextFormat, textLines: collections.abc.Iterable[str|None], fontMetrics: QtGui.QFontMetricsF|None = ...) -> float: ...
    @staticmethod
    def fontMetrics(context: QgsRenderContext, format: QgsTextFormat, scaleFactor: float = ...) -> QtGui.QFontMetricsF: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def drawPart(rect: QtCore.QRectF, rotation: float, alignment: Qgis.TextHorizontalAlignment, textLines: collections.abc.Iterable[str|None], context: QgsRenderContext, format: QgsTextFormat, part: Qgis.TextComponent, drawAsOutlines: bool = ...) -> None: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def drawPart(origin: QtCore.QPointF, rotation: float, alignment: Qgis.TextHorizontalAlignment, textLines: collections.abc.Iterable[str|None], context: QgsRenderContext, format: QgsTextFormat, part: Qgis.TextComponent, drawAsOutlines: bool = ...) -> None: ...
    @staticmethod
    def drawDocumentOnLine(line: QtGui.QPolygonF, format: QgsTextFormat, document: QgsTextDocument, context: QgsRenderContext, offsetAlongLine: float = ..., offsetFromLine: float = ..., flags: Qgis.CurvedTextFlag = ...) -> None: ...
    @staticmethod
    def drawTextOnLine(line: QtGui.QPolygonF, text: str|None, context: QgsRenderContext, format: QgsTextFormat, offsetAlongLine: float = ..., offsetFromLine: float = ..., flags: Qgis.CurvedTextFlag = ...) -> None: ...
    @typing.overload
    @staticmethod
    def drawDocument(rect: QtCore.QRectF, format: QgsTextFormat, document: QgsTextDocument, metrics: QgsTextDocumentMetrics, context: QgsRenderContext, horizontalAlignment: Qgis.TextHorizontalAlignment = ..., verticalAlignment: Qgis.TextVerticalAlignment = ..., rotation: float = ..., mode: Qgis.TextLayoutMode = ..., flags: Qgis.TextRendererFlag = ...) -> None: ...
    @typing.overload
    @staticmethod
    def drawDocument(point: QtCore.QPointF, format: QgsTextFormat, document: QgsTextDocument, metrics: QgsTextDocumentMetrics, context: QgsRenderContext, alignment: Qgis.TextHorizontalAlignment, rotation: float, mode: Qgis.TextLayoutMode = ...) -> None: ...
    @typing.overload
    @staticmethod
    def drawText(rect: QtCore.QRectF, rotation: float, alignment: Qgis.TextHorizontalAlignment, textLines: collections.abc.Iterable[str|None], context: QgsRenderContext, format: QgsTextFormat, drawAsOutlines: bool = ..., vAlignment: Qgis.TextVerticalAlignment = ..., flags: Qgis.TextRendererFlag = ..., mode: Qgis.TextLayoutMode = ...) -> None: ...
    @typing.overload
    @staticmethod
    def drawText(point: QtCore.QPointF, rotation: float, alignment: Qgis.TextHorizontalAlignment, textLines: collections.abc.Iterable[str|None], context: QgsRenderContext, format: QgsTextFormat, drawAsOutlines: bool = ...) -> None: ...
    @staticmethod
    def sizeToPixel(size: float, c: QgsRenderContext, unit: Qgis.RenderUnit, mapUnitScale: QgsMapUnitScale = ...) -> int: ...
    @staticmethod
    def convertQtVAlignment(alignment: QtCore.Qt.AlignmentFlag) -> Qgis.TextVerticalAlignment: ...
    @staticmethod
    def convertQtHAlignment(alignment: QtCore.Qt.AlignmentFlag) -> Qgis.TextHorizontalAlignment: ...


class QgsTextRendererUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTextRendererUtils') -> None: ...

    @staticmethod
    def decodeTextOrientation(name: str|None) -> typing.Tuple[Qgis.TextOrientation, bool]: ...
    @staticmethod
    def encodeTextOrientation(orientation: Qgis.TextOrientation) -> str: ...
    @staticmethod
    def decodeShadowPlacementType(string: str|None) -> 'QgsTextShadowSettings.ShadowPlacement': ...
    @staticmethod
    def decodeBackgroundRotationType(string: str|None) -> QgsTextBackgroundSettings.RotationType: ...
    @staticmethod
    def decodeBackgroundSizeType(string: str|None) -> QgsTextBackgroundSettings.SizeType: ...
    @staticmethod
    def decodeShapeType(string: str|None) -> QgsTextBackgroundSettings.ShapeType: ...


class QgsTextShadowSettings(PyQt6.sip.wrapper):

    class ShadowPlacement(enum.IntEnum):
        ShadowLowest = ... # type: QgsTextShadowSettings.ShadowPlacement
        ShadowText = ... # type: QgsTextShadowSettings.ShadowPlacement
        ShadowBuffer = ... # type: QgsTextShadowSettings.ShadowPlacement
        ShadowShape = ... # type: QgsTextShadowSettings.ShadowPlacement

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTextShadowSettings') -> None: ...

    def referencedFields(self, context: QgsRenderContext) -> set[str]: ...
    def updateDataDefinedProperties(self, context: QgsRenderContext, properties: QgsPropertyCollection) -> None: ...
    def writeXml(self, doc: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, elem: QtXml.QDomElement) -> None: ...
    def readFromLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def setBlendMode(self, mode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setScale(self, scale: int) -> None: ...
    def scale(self) -> int: ...
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...
    def setBlurAlphaOnly(self, alphaOnly: bool) -> None: ...
    def blurAlphaOnly(self) -> bool: ...
    def setBlurRadiusMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def blurRadiusMapUnitScale(self) -> QgsMapUnitScale: ...
    def setBlurRadiusUnit(self, units: Qgis.RenderUnit) -> None: ...
    def blurRadiusUnit(self) -> Qgis.RenderUnit: ...
    def setBlurRadius(self, blurRadius: float) -> None: ...
    def blurRadius(self) -> float: ...
    def setOffsetGlobal(self, global_: bool) -> None: ...
    def offsetGlobal(self) -> bool: ...
    def setOffsetMapUnitScale(self, scale: QgsMapUnitScale) -> None: ...
    def offsetMapUnitScale(self) -> QgsMapUnitScale: ...
    def setOffsetUnit(self, units: Qgis.RenderUnit) -> None: ...
    def offsetUnit(self) -> Qgis.RenderUnit: ...
    def setOffsetDistance(self, distance: float) -> None: ...
    def offsetDistance(self) -> float: ...
    def setOffsetAngle(self, angle: int) -> None: ...
    def offsetAngle(self) -> int: ...
    def setShadowPlacement(self, placement: 'QgsTextShadowSettings.ShadowPlacement') -> None: ...
    def shadowPlacement(self) -> 'QgsTextShadowSettings.ShadowPlacement': ...
    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsCesiumUtils(PyQt6.sip.wrapper):

    class B3DMContents(PyQt6.sip.wrapper):

        gltf = ... # type: QtCore.QByteArray|bytes|bytearray|memoryview
        rtcCenter = ... # type: QgsVector3D

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCesiumUtils.B3DMContents') -> None: ...

    class TileContents(PyQt6.sip.wrapper):

        gltf = ... # type: QtCore.QByteArray|bytes|bytearray|memoryview
        rtcCenter = ... # type: QgsVector3D

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCesiumUtils.TileContents') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCesiumUtils') -> None: ...

    @staticmethod
    def extractGltfFromTileContent(tileContent: QtCore.QByteArray|bytes|bytearray|memoryview) -> 'QgsCesiumUtils.TileContents': ...
    @staticmethod
    def extractGltfFromB3dm(tileContent: QtCore.QByteArray|bytes|bytearray|memoryview) -> 'QgsCesiumUtils.B3DMContents': ...
    @staticmethod
    def transformSphere(sphere: QgsSphere, transform: QgsMatrix4x4) -> QgsSphere: ...
    @staticmethod
    def parseSphere(sphere: collections.abc.Iterable[typing.Any]) -> QgsSphere: ...
    @staticmethod
    def parseBox(box: collections.abc.Iterable[typing.Any]) -> QgsOrientedBox3D: ...
    @staticmethod
    def parseRegion(region: collections.abc.Iterable[typing.Any]) -> QgsBox3D: ...


class QgsTiledSceneBoundingVolume(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, box: QgsOrientedBox3D = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTiledSceneBoundingVolume') -> None: ...

    def box(self) -> QgsOrientedBox3D: ...
    def intersects(self, box: QgsOrientedBox3D) -> bool: ...
    def transform(self, transform: QgsMatrix4x4) -> None: ...
    def as2DGeometry(self, transform: QgsCoordinateTransform = ..., direction: Qgis.TransformDirection = ...) -> QgsAbstractGeometry|None: ...
    def bounds(self, transform: QgsCoordinateTransform = ..., direction: Qgis.TransformDirection = ...) -> QgsBox3D: ...


class QgsTiledSceneDataProvider(QgsDataProvider):

    @typing.overload
    def __init__(self, uri: str|None, providerOptions: QgsDataProvider.ProviderOptions, flags: Qgis.DataProviderReadFlag = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTiledSceneDataProvider') -> None: ...

    def zRange(self) -> QgsDoubleRange: ...
    def index(self) -> 'QgsTiledSceneIndex': ...
    def boundingVolume(self) -> QgsTiledSceneBoundingVolume: ...
    def sceneCrs(self) -> QgsCoordinateReferenceSystem: ...
    def clone(self) -> 'QgsTiledSceneDataProvider|None': ...
    def capabilities(self) -> Qgis.TiledSceneProviderCapability: ...


class QgsTiledSceneIndex(PyQt6.sip.wrapper):

    def __init__(self, other: 'QgsTiledSceneIndex') -> None: ...

    def retrieveContent(self, uri: str|None, feedback: QgsFeedback|None = ...) -> QtCore.QByteArray: ...
    def fetchHierarchy(self, id: int, feedback: QgsFeedback|None = ...) -> bool: ...
    def childAvailability(self, id: int) -> Qgis.TileChildrenAvailability: ...
    def getTiles(self, request: 'QgsTiledSceneRequest') -> list[int]: ...
    def childTileIds(self, id: int) -> list[int]: ...
    def parentTileId(self, id: int) -> int: ...
    def getTile(self, id: int) -> 'QgsTiledSceneTile': ...
    def rootTile(self) -> 'QgsTiledSceneTile': ...
    def isValid(self) -> bool: ...


class QgsTiledSceneLayer(QgsMapLayer):

    class LayerOptions(PyQt6.sip.wrapper):

        loadDefaultStyle = ... # type: bool
        skipCrsValidation = ... # type: bool
        transformContext = ... # type: QgsCoordinateTransformContext

        @typing.overload
        def __init__(self, transformContext: QgsCoordinateTransformContext = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsTiledSceneLayer.LayerOptions') -> None: ...

    def __init__(self, uri: str|None = ..., baseName: str|None = ..., provider: str|None = ..., options: 'QgsTiledSceneLayer.LayerOptions' = ...) -> None: ...

    def setRenderer(self, renderer: 'QgsTiledSceneRenderer|None') -> None: ...
    def renderer(self) -> 'QgsTiledSceneRenderer|None': ...
    def properties(self) -> Qgis.MapLayerProperty: ...
    def elevationProperties(self) -> QgsMapLayerElevationProperties|None: ...
    def loadDefaultMetadata(self) -> typing.Tuple[str, bool]: ...
    def createMapRenderer(self, rendererContext: QgsRenderContext) -> QgsMapLayerRenderer|None: ...
    def htmlMetadata(self) -> str: ...
    def loadDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def decodedSource(self, source: str|None, dataProvider: str|None, context: QgsReadWriteContext) -> str: ...
    def encodedSource(self, source: str|None, context: QgsReadWriteContext) -> str: ...
    def setTransformContext(self, transformContext: QgsCoordinateTransformContext) -> None: ...
    def writeStyle(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readStyle(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeXml(self, layerNode: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def readXml(self, layerNode: QtXml.QDomNode, context: QgsReadWriteContext) -> bool: ...
    def dataProvider(self) -> QgsTiledSceneDataProvider|None: ...
    def extent(self) -> QgsRectangle: ...
    def clone(self) -> 'QgsTiledSceneLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsTiledSceneLayerElevationProperties(QgsMapLayerElevationProperties):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def significantZValues(self, layer: QgsMapLayer|None) -> list[float]: ...
    def calculateZRange(self, layer: QgsMapLayer|None) -> QgsDoubleRange: ...
    def htmlSummary(self) -> str: ...
    def clone(self) -> 'QgsTiledSceneLayerElevationProperties|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def hasElevation(self) -> bool: ...


class QgsTiledSceneRenderContext(PyQt6.sip.wrapper):

    def __init__(self, context: QgsRenderContext, feedback: QgsFeedback|None = ...) -> None: ...

    def textureCoordinates(self) -> typing.Tuple[float, float, float, float, float, float]: ...
    def setTextureCoordinates(self, textureX1: float, textureY1: float, textureX2: float, textureY2: float, textureX3: float, textureY3: float) -> None: ...
    def setTextureImage(self, image: QtGui.QImage) -> None: ...
    def textureImage(self) -> QtGui.QImage: ...
    def feedback(self) -> QgsFeedback|None: ...
    def renderContext(self) -> QgsRenderContext: ...


class QgsTiledSceneRenderer(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def saveCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def restoreCommonProperties(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def copyCommonProperties(self, destination: 'QgsTiledSceneRenderer|None') -> None: ...
    def renderLine(self, context: QgsTiledSceneRenderContext, line: QtGui.QPolygonF) -> None: ...
    def renderTriangle(self, context: QgsTiledSceneRenderContext, triangle: QtGui.QPolygonF) -> None: ...
    def legendRuleKeys(self) -> list[str]: ...
    def createLegendNodes(self, nodeLayer: QgsLayerTreeLayer|None) -> list[QgsLayerTreeModelLegendNode]: ...
    def stopRender(self, context: QgsTiledSceneRenderContext) -> None: ...
    def startRender(self, context: QgsTiledSceneRenderContext) -> None: ...
    def isTileBorderRenderingEnabled(self) -> bool: ...
    def setTileBorderRenderingEnabled(self, enabled: bool) -> None: ...
    def setMaximumScreenErrorUnit(self, unit: Qgis.RenderUnit) -> None: ...
    def maximumScreenErrorUnit(self) -> Qgis.RenderUnit: ...
    def setMaximumScreenError(self, error: float) -> None: ...
    def maximumScreenError(self) -> float: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    @staticmethod
    def load(element: QtXml.QDomElement, context: QgsReadWriteContext) -> 'QgsTiledSceneRenderer|None': ...
    def flags(self) -> Qgis.TiledSceneRendererFlag: ...
    def clone(self) -> 'QgsTiledSceneRenderer|None': ...
    def type(self) -> str: ...


class QgsTiledSceneRendererAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None, icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTiledSceneRendererAbstractMetadata') -> None: ...

    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsTiledSceneRenderer|None: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsTiledSceneRendererMetadata(QgsTiledSceneRendererAbstractMetadata):

    def __init__(self, a0: 'QgsTiledSceneRendererMetadata') -> None: ...

    def createRenderer(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsTiledSceneRenderer|None: ...


class QgsTiledSceneRendererRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    @staticmethod
    def defaultRenderer(layer: QgsTiledSceneLayer|None) -> QgsTiledSceneRenderer|None: ...
    def renderersList(self) -> list[str]: ...
    def rendererMetadata(self, rendererName: str|None) -> QgsTiledSceneRendererAbstractMetadata|None: ...
    def removeRenderer(self, rendererName: str|None) -> bool: ...
    def addRenderer(self, metadata: QgsTiledSceneRendererAbstractMetadata|None) -> bool: ...


class QgsTiledSceneRequest(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTiledSceneRequest') -> None: ...

    def setParentTileId(self, id: int) -> None: ...
    def parentTileId(self) -> int: ...
    def feedback(self) -> QgsFeedback|None: ...
    def setFeedback(self, feedback: QgsFeedback|None) -> None: ...
    def setRequiredGeometricError(self, error: float) -> None: ...
    def requiredGeometricError(self) -> float: ...
    def setFilterBox(self, box: QgsOrientedBox3D) -> None: ...
    def filterBox(self) -> QgsOrientedBox3D: ...
    def flags(self) -> Qgis.TiledSceneRequestFlag: ...
    def setFlags(self, flags: Qgis.TiledSceneRequestFlag) -> None: ...


class QgsTiledSceneTextureRenderer(QgsTiledSceneRenderer):

    def __init__(self) -> None: ...

    def setFillSymbol(self, symbol: QgsFillSymbol|None) -> None: ...
    def fillSymbol(self) -> QgsFillSymbol|None: ...
    @staticmethod
    def createDefaultFillSymbol() -> QgsFillSymbol|None: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsTiledSceneRenderer|None: ...
    def stopRender(self, context: QgsTiledSceneRenderContext) -> None: ...
    def startRender(self, context: QgsTiledSceneRenderContext) -> None: ...
    def renderLine(self, context: QgsTiledSceneRenderContext, line: QtGui.QPolygonF) -> None: ...
    def renderTriangle(self, context: QgsTiledSceneRenderContext, triangle: QtGui.QPolygonF) -> None: ...
    def flags(self) -> Qgis.TiledSceneRendererFlag: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> QgsTiledSceneRenderer|None: ...
    def type(self) -> str: ...


class QgsTiledSceneTile(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, id: int) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsTiledSceneTile') -> None: ...

    def setMetadata(self, metadata: dict[str|None, typing.Any]) -> None: ...
    def metadata(self) -> dict[str, typing.Any]: ...
    def setBaseUrl(self, baseUrl: QtCore.QUrl) -> None: ...
    def baseUrl(self) -> QtCore.QUrl: ...
    def setGeometricError(self, error: float) -> None: ...
    def geometricError(self) -> float: ...
    def setResources(self, resources: dict[str|None, typing.Any]) -> None: ...
    def resources(self) -> dict[str, typing.Any]: ...
    def transform(self) -> QgsMatrix4x4|None: ...
    def setTransform(self, transform: QgsMatrix4x4) -> None: ...
    def boundingVolume(self) -> QgsTiledSceneBoundingVolume: ...
    def setBoundingVolume(self, volume: QgsTiledSceneBoundingVolume) -> None: ...
    def setRefinementProcess(self, process: Qgis.TileRefinementProcess) -> None: ...
    def refinementProcess(self) -> Qgis.TileRefinementProcess: ...
    def id(self) -> int: ...
    def isValid(self) -> bool: ...


class QgsTiledSceneWireframeRenderer(QgsTiledSceneRenderer):

    def __init__(self) -> None: ...

    def setUseTextureColors(self, enabled: bool) -> None: ...
    def useTextureColors(self) -> bool: ...
    def setLineSymbol(self, symbol: QgsLineSymbol|None) -> None: ...
    def lineSymbol(self) -> QgsLineSymbol|None: ...
    @staticmethod
    def createDefaultLineSymbol() -> QgsLineSymbol|None: ...
    def setFillSymbol(self, symbol: QgsFillSymbol|None) -> None: ...
    def fillSymbol(self) -> QgsFillSymbol|None: ...
    @staticmethod
    def createDefaultFillSymbol() -> QgsFillSymbol|None: ...
    @staticmethod
    def create(element: QtXml.QDomElement, context: QgsReadWriteContext) -> QgsTiledSceneRenderer|None: ...
    def flags(self) -> Qgis.TiledSceneRendererFlag: ...
    def stopRender(self, context: QgsTiledSceneRenderContext) -> None: ...
    def startRender(self, context: QgsTiledSceneRenderContext) -> None: ...
    def renderLine(self, context: QgsTiledSceneRenderContext, line: QtGui.QPolygonF) -> None: ...
    def renderTriangle(self, context: QgsTiledSceneRenderContext, triangle: QtGui.QPolygonF) -> None: ...
    def save(self, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def clone(self) -> QgsTiledSceneRenderer|None: ...
    def type(self) -> str: ...


class QgsSensorModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        SensorType = ... # type: QgsSensorModel.CustomRole
        SensorId = ... # type: QgsSensorModel.CustomRole
        SensorName = ... # type: QgsSensorModel.CustomRole
        SensorStatus = ... # type: QgsSensorModel.CustomRole
        SensorLastValue = ... # type: QgsSensorModel.CustomRole
        SensorLastTimestamp = ... # type: QgsSensorModel.CustomRole
        Sensor = ... # type: QgsSensorModel.CustomRole

    class Column(enum.IntEnum):
        Name = ... # type: QgsSensorModel.Column
        LastValue = ... # type: QgsSensorModel.Column

    def __init__(self, manager: 'QgsSensorManager|None', parent: QtCore.QObject|None = ...) -> None: ...

    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...


class QgsSensorManager(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    sensorErrorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    sensorDataCaptured: typing.ClassVar[QtCore.pyqtSignal]
    sensorStatusChanged: typing.ClassVar[QtCore.pyqtSignal]
    sensorNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    sensorRemoved: typing.ClassVar[QtCore.pyqtSignal]
    sensorAboutToBeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    sensorAdded: typing.ClassVar[QtCore.pyqtSignal]
    def writeXml(self, document: QtXml.QDomDocument) -> QtXml.QDomElement: ...
    def readXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def sensorsData(self) -> dict[str, 'QgsAbstractSensor.SensorData']: ...
    def sensorData(self, name: str|None) -> 'QgsAbstractSensor.SensorData': ...
    def sensorNames(self) -> list[str]: ...
    def removeSensor(self, id: str|None) -> bool: ...
    def addSensor(self, sensor: 'QgsAbstractSensor|None') -> None: ...
    def sensor(self, id: str|None) -> 'QgsAbstractSensor|None': ...
    def sensors(self) -> list['QgsAbstractSensor']: ...
    def clear(self) -> None: ...


class QgsSensorAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, visibleName: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSensorAbstractMetadata') -> None: ...

    def createSensor(self, parent: QtCore.QObject|None) -> 'QgsAbstractSensor|None': ...
    def visibleName(self) -> str: ...
    def type(self) -> str: ...


class QgsSensorRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    sensorAdded: typing.ClassVar[QtCore.pyqtSignal]
    def sensorTypes(self) -> dict[str, str]: ...
    def createSensor(self, type: str|None, parent: QtCore.QObject|None = ...) -> 'QgsAbstractSensor|None': ...
    def removeSensorType(self, type: str|None) -> bool: ...
    def addSensorType(self, metadata: QgsSensorAbstractMetadata|None) -> bool: ...
    def sensorMetadata(self, type: str|None) -> QgsSensorAbstractMetadata|None: ...
    def populate(self) -> bool: ...


class QgsAbstractSensor(QtCore.QObject):

    class SensorData(PyQt6.sip.wrapper):

        lastTimestamp = ... # type: QtCore.QDateTime|datetime.datetime
        lastValue = ... # type: typing.Any

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractSensor.SensorData') -> None: ...

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def handleDisconnect(self) -> None: ...
    def handleConnect(self) -> None: ...
    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    dataChanged: typing.ClassVar[QtCore.pyqtSignal]
    statusChanged: typing.ClassVar[QtCore.pyqtSignal]
    nameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def readXml(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def errorString(self) -> str: ...
    def setData(self, data: 'QgsAbstractSensor.SensorData') -> None: ...
    def data(self) -> 'QgsAbstractSensor.SensorData': ...
    def disconnectSensor(self) -> None: ...
    def connectSensor(self) -> None: ...
    def setStatus(self, status: Qgis.DeviceConnectionStatus) -> None: ...
    def status(self) -> Qgis.DeviceConnectionStatus: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def type(self) -> str: ...
    def id(self) -> str: ...


class QgsIODeviceSensor(QgsAbstractSensor):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def parseData(self) -> None: ...
    def initIODevice(self, device: QtCore.QIODevice|None) -> None: ...
    def iODevice(self) -> QtCore.QIODevice|None: ...


class QgsTcpSocketSensor(QgsIODeviceSensor):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def handleDisconnect(self) -> None: ...
    def handleConnect(self) -> None: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def setPort(self, port: int) -> None: ...
    def port(self) -> int: ...
    def setHostName(self, hostName: str|None) -> None: ...
    def hostName(self) -> str: ...
    def type(self) -> str: ...
    @staticmethod
    def create(parent: QtCore.QObject|None) -> 'QgsTcpSocketSensor|None': ...


class QgsUdpSocketSensor(QgsIODeviceSensor):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def handleDisconnect(self) -> None: ...
    def handleConnect(self) -> None: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def setPort(self, port: int) -> None: ...
    def port(self) -> int: ...
    def setHostName(self, hostName: str|None) -> None: ...
    def hostName(self) -> str: ...
    def type(self) -> str: ...
    @staticmethod
    def create(parent: QtCore.QObject|None) -> 'QgsUdpSocketSensor|None': ...


class QgsSerialPortSensor(QgsIODeviceSensor):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def parseData(self) -> None: ...
    def handleDisconnect(self) -> None: ...
    def handleConnect(self) -> None: ...
    def readPropertiesFromElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def writePropertiesToElement(self, element: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    def setDelimiter(self, delimiter: QtCore.QByteArray|bytes|bytearray|memoryview) -> None: ...
    def delimiter(self) -> QtCore.QByteArray: ...
    def setBaudRate(self, baudRate: QtSerialPort.QSerialPort.BaudRate) -> None: ...
    def baudRate(self) -> QtSerialPort.QSerialPort.BaudRate: ...
    def setPortName(self, portName: str|None) -> None: ...
    def portName(self) -> str: ...
    def type(self) -> str: ...
    @staticmethod
    def create(parent: QtCore.QObject|None) -> 'QgsSerialPortSensor|None': ...


class QgsSettings(QtCore.QObject):

    class Section(enum.IntEnum):
        NoSection = ... # type: QgsSettings.Section
        Core = ... # type: QgsSettings.Section
        Gui = ... # type: QgsSettings.Section
        Server = ... # type: QgsSettings.Section
        Plugins = ... # type: QgsSettings.Section
        Auth = ... # type: QgsSettings.Section
        App = ... # type: QgsSettings.Section
        Providers = ... # type: QgsSettings.Section
        Expressions = ... # type: QgsSettings.Section
        Misc = ... # type: QgsSettings.Section
        Gps = ... # type: QgsSettings.Section

    @typing.overload
    def __init__(self, organization: str|None, application: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, scope: QtCore.QSettings.Scope, organization: str|None, application: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, format: QtCore.QSettings.Format, scope: QtCore.QSettings.Scope, organization: str|None, application: str|None = ..., parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, fileName: str|None, format: QtCore.QSettings.Format, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def clear(self) -> None: ...
    def prefixedKey(self, key: str|None, section: 'QgsSettings.Section') -> str: ...
    def remove(self, key: str|None, section: 'QgsSettings.Section' = ...) -> None: ...
    def sync(self) -> None: ...
    def fileName(self) -> str: ...
    def contains(self, key: str|None, section: 'QgsSettings.Section' = ...) -> bool: ...
    def value(self, key: str|None, defaultValue: typing.Any = ..., type: typing.Any = ..., section: 'QgsSettings.Section' = ...) -> typing.Any: ...
    def setValue(self, key: str|None, value: typing.Any, section: 'QgsSettings.Section' = ...) -> None: ...
    def origin(self, key: str|None) -> Qgis.SettingsOrigin: ...
    def setArrayIndex(self, i: int) -> None: ...
    def endArray(self) -> None: ...
    def beginWriteArray(self, prefix: str|None, size: int = ...) -> None: ...
    def beginReadArray(self, prefix: str|None) -> int: ...
    @staticmethod
    def setGlobalSettingsPath(path: str|None) -> bool: ...
    @staticmethod
    def globalSettingsPath() -> str: ...
    def globalChildGroups(self) -> list[str]: ...
    def childGroups(self, origin: Qgis.SettingsOrigin = ...) -> list[str]: ...
    def childKeys(self) -> list[str]: ...
    def allKeys(self) -> list[str]: ...
    def group(self) -> str: ...
    def endGroup(self) -> None: ...
    def beginGroup(self, prefix: str|None, section: 'QgsSettings.Section' = ...) -> None: ...


class QgsSettingsEntryBase(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBase') -> None: ...

    def hasChanged(self) -> bool: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    def parent(self) -> 'QgsSettingsTreeNode|None': ...
    def copyValueToKeyIfChanged(self, key: str|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...
    def copyValueToKey(self, key: str|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...
    @typing.overload
    def copyValueFromKey(self, key: str|None, removeSettingAtKey: bool = ...) -> bool: ...
    @typing.overload
    def copyValueFromKey(self, key: str|None, dynamicKeyPartList: collections.abc.Iterable[str|None], removeSettingAtKey: bool = ...) -> bool: ...
    @typing.overload
    def formerValueAsVariant(self, dynamicKeyPart: str|None) -> typing.Any: ...
    @typing.overload
    def formerValueAsVariant(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> typing.Any: ...
    def description(self) -> str: ...
    def settingsType(self) -> Qgis.SettingsType: ...
    def defaultValueAsVariant(self) -> typing.Any: ...
    @typing.overload
    def valueAsVariantWithDefaultOverride(self, defaultValueOverride: typing.Any, dynamicKeyPart: str|None = ...) -> typing.Any: ...
    @typing.overload
    def valueAsVariantWithDefaultOverride(self, defaultValueOverride: typing.Any, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> typing.Any: ...
    @typing.overload
    def valueAsVariant(self, dynamicKeyPart: str|None = ...) -> typing.Any: ...
    @typing.overload
    def valueAsVariant(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> typing.Any: ...
    @typing.overload
    @deprecated("""""")
    def valueAsVariant(self, dynamicKeyPart: str|None, useDefaultValueOverride: bool, defaultValueOverride: typing.Any) -> typing.Any: ...
    @typing.overload
    @deprecated("""""")
    def valueAsVariant(self, dynamicKeyPartList: collections.abc.Iterable[str|None], useDefaultValueOverride: bool, defaultValueOverride: typing.Any) -> typing.Any: ...
    @typing.overload
    def setVariantValue(self, value: typing.Any, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setVariantValue(self, value: typing.Any, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def section(self) -> int: ...
    @typing.overload
    def remove(self, dynamicKeyPart: str|None = ...) -> None: ...
    @typing.overload
    def remove(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> None: ...
    def origin(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> Qgis.SettingsOrigin: ...
    @typing.overload
    def exists(self, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def exists(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def options(self) -> Qgis.SettingsOption: ...
    def hasDynamicKey(self) -> bool: ...
    def definitionKey(self) -> str: ...
    def keyIsValid(self, key: str|None) -> bool: ...
    @typing.overload
    def key(self, dynamicKeyPart: str|None = ...) -> str: ...
    @typing.overload
    def key(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> str: ...
    def name(self) -> str: ...
    def typeId(self) -> str: ...
    @staticmethod
    def dynamicKeyPartToList(dynamicKeyPart: str|None) -> list[str]: ...


@deprecated("")
class QgsSettingsEntryGroup(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, settings: collections.abc.Iterable[QgsSettingsEntryBase]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryGroup') -> None: ...

    @typing.overload
    def removeAllChildrenSettings(self, dynamicKeyPart: str|None = ...) -> None: ...
    @typing.overload
    def removeAllChildrenSettings(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> None: ...
    def removeAllSettingsAtBaseKey(self, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...
    def settings(self) -> list[QgsSettingsEntryBase]: ...
    def baseKey(self, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> str: ...
    def isValid(self) -> bool: ...


class QgsSettingsEntryBaseTemplateQVariantBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateQVariantBase') -> None: ...

    def checkValuePrivate(self, value: typing.Any) -> bool: ...
    def convertToVariant(self, value: typing.Any) -> typing.Any: ...
    def setValuePrivate(self, value: typing.Any, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> typing.Any: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> typing.Any: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> typing.Any: ...
    def defaultValue(self) -> typing.Any: ...
    @typing.overload
    def setValue(self, value: typing.Any, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: typing.Any, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: typing.Any, dynamicKeyPart: str|None = ...) -> typing.Any: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: typing.Any, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> typing.Any: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> typing.Any: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> typing.Any: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryVariant(QgsSettingsEntryBaseTemplateQVariantBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: typing.Any = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryVariant') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> typing.Any: ...
    def settingsType(self) -> Qgis.SettingsType: ...
    def valueAs(self, type: typing.Any) -> typing.Any: ...


class QgsSettingsEntryBaseTemplateQStringBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateQStringBase') -> None: ...

    def checkValuePrivate(self, value: str|None) -> bool: ...
    def convertToVariant(self, value: str|None) -> typing.Any: ...
    def setValuePrivate(self, value: str|None, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> str: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> str: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> str: ...
    def defaultValue(self) -> str: ...
    @typing.overload
    def setValue(self, value: str|None, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: str|None, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: str|None, dynamicKeyPart: str|None = ...) -> str: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: str|None, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> str: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> str: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> str: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryString(QgsSettingsEntryBaseTemplateQStringBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: str|None = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., minLength: int = ..., maxLength: int = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: str|None = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., minLength: int = ..., maxLength: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryString') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> str: ...
    def maxLength(self) -> int: ...
    def minLength(self) -> int: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBaseTemplateQStringListBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateQStringListBase') -> None: ...

    def checkValuePrivate(self, value: collections.abc.Iterable[str|None]) -> bool: ...
    def convertToVariant(self, value: collections.abc.Iterable[str|None]) -> typing.Any: ...
    def setValuePrivate(self, value: collections.abc.Iterable[str|None], dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> list[str]: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> list[str]: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> list[str]: ...
    def defaultValue(self) -> list[str]: ...
    @typing.overload
    def setValue(self, value: collections.abc.Iterable[str|None], dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: collections.abc.Iterable[str|None], dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: collections.abc.Iterable[str|None], dynamicKeyPart: str|None = ...) -> list[str]: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: collections.abc.Iterable[str|None], dynamicKeyPartList: collections.abc.Iterable[str|None]) -> list[str]: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> list[str]: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> list[str]: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryStringList(QgsSettingsEntryBaseTemplateQStringListBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: collections.abc.Iterable[str|None] = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: collections.abc.Iterable[str|None] = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryStringList') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> list[str]: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBaseTemplateboolBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateboolBase') -> None: ...

    def checkValuePrivate(self, value: bool) -> bool: ...
    def convertToVariant(self, value: bool) -> typing.Any: ...
    def setValuePrivate(self, value: bool, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> bool: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def defaultValue(self) -> bool: ...
    @typing.overload
    def setValue(self, value: bool, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: bool, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: bool, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: bool, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBool(QgsSettingsEntryBaseTemplateboolBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: bool = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: bool = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBool') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> bool: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBaseTemplateintBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateintBase') -> None: ...

    def checkValuePrivate(self, value: int) -> bool: ...
    def convertToVariant(self, value: int) -> typing.Any: ...
    def setValuePrivate(self, value: int, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> int: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> int: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> int: ...
    def defaultValue(self) -> int: ...
    @typing.overload
    def setValue(self, value: int, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: int, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: int, dynamicKeyPart: str|None = ...) -> int: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: int, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> int: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> int: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> int: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryInteger(QgsSettingsEntryBaseTemplateintBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: int = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., minValue: int = ..., maxValue: int = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: int = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., minValue: int = ..., maxValue: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryInteger') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> int: ...
    def maxValue(self) -> int: ...
    def minValue(self) -> int: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBaseTemplatedoubleBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplatedoubleBase') -> None: ...

    def checkValuePrivate(self, value: float) -> bool: ...
    def convertToVariant(self, value: float) -> typing.Any: ...
    def setValuePrivate(self, value: float, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> float: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> float: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> float: ...
    def defaultValue(self) -> float: ...
    @typing.overload
    def setValue(self, value: float, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: float, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: float, dynamicKeyPart: str|None = ...) -> float: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: float, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> float: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> float: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> float: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryDouble(QgsSettingsEntryBaseTemplatedoubleBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: float = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., minValue: float = ..., maxValue: float = ..., displayDecimals: int = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: float, description: str|None = ..., options: Qgis.SettingsOption = ..., minValue: float = ..., maxValue: float = ..., displayDecimals: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryDouble') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> float: ...
    def displayHintDecimals(self) -> int: ...
    def setDisplayHintDecimals(self, displayHintDecimals: int) -> None: ...
    def maxValue(self) -> float: ...
    def minValue(self) -> float: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBaseTemplateQColorBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateQColorBase') -> None: ...

    def checkValuePrivate(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> bool: ...
    def convertToVariant(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> typing.Any: ...
    def setValuePrivate(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> QtGui.QColor: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> QtGui.QColor: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> QtGui.QColor: ...
    def defaultValue(self) -> QtGui.QColor: ...
    @typing.overload
    def setValue(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int, dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: QtGui.QColor|QtCore.Qt.GlobalColor|int, dynamicKeyPart: str|None = ...) -> QtGui.QColor: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: QtGui.QColor|QtCore.Qt.GlobalColor|int, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> QtGui.QColor: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> QtGui.QColor: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> QtGui.QColor: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryColor(QgsSettingsEntryBaseTemplateQColorBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., allowAlpha: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., description: str|None = ..., options: Qgis.SettingsOption = ..., allowAlpha: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryColor') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> QtGui.QColor: ...
    def allowAlpha(self) -> bool: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryBaseTemplateQVariantMapBase(QgsSettingsEntryBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, section: str|None, defaultValue: typing.Any, description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryBaseTemplateQVariantMapBase') -> None: ...

    def checkValuePrivate(self, value: dict[str|None, typing.Any]) -> bool: ...
    def convertToVariant(self, value: dict[str|None, typing.Any]) -> typing.Any: ...
    def setValuePrivate(self, value: dict[str|None, typing.Any], dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    def convertFromVariant(self, value: typing.Any) -> dict[str, typing.Any]: ...
    def checkValueVariant(self, value: typing.Any) -> bool: ...
    @typing.overload
    def formerValue(self, dynamicKeyPart: str|None = ...) -> dict[str, typing.Any]: ...
    @typing.overload
    def formerValue(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> dict[str, typing.Any]: ...
    def defaultValue(self) -> dict[str, typing.Any]: ...
    @typing.overload
    def setValue(self, value: dict[str|None, typing.Any], dynamicKeyPart: str|None = ...) -> bool: ...
    @typing.overload
    def setValue(self, value: dict[str|None, typing.Any], dynamicKeyPartList: collections.abc.Iterable[str|None]) -> bool: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: dict[str|None, typing.Any], dynamicKeyPart: str|None = ...) -> dict[str, typing.Any]: ...
    @typing.overload
    def valueWithDefaultOverride(self, defaultValueOverride: dict[str|None, typing.Any], dynamicKeyPartList: collections.abc.Iterable[str|None]) -> dict[str, typing.Any]: ...
    @typing.overload
    def value(self, dynamicKeyPart: str|None = ...) -> dict[str, typing.Any]: ...
    @typing.overload
    def value(self, dynamicKeyPartList: collections.abc.Iterable[str|None]) -> dict[str, typing.Any]: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsEntryVariantMap(QgsSettingsEntryBaseTemplateQVariantMapBase):

    @typing.overload
    def __init__(self, name: str|None, parent: 'QgsSettingsTreeNode|None', defaultValue: dict[str|None, typing.Any] = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, key: str|None, pluginName: str|None, defaultValue: dict[str|None, typing.Any] = ..., description: str|None = ..., options: Qgis.SettingsOption = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEntryVariantMap') -> None: ...

    def convertFromVariant(self, value: typing.Any) -> dict[str, typing.Any]: ...
    def settingsType(self) -> Qgis.SettingsType: ...


class QgsSettingsRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsRegistry') -> None: ...

    @deprecated("""""")
    def addSettingsEntryGroup(self, settingsGroup: QgsSettingsEntryGroup|None) -> None: ...
    def addSettingsEntry(self, settingsEntry: QgsSettingsEntryBase|None) -> bool: ...
    def subRegistries(self) -> list['QgsSettingsRegistry']: ...
    def removeSubRegistry(self, settingsRegistry: 'QgsSettingsRegistry|None') -> None: ...
    def addSubRegistry(self, settingsRegistry: 'QgsSettingsRegistry|None') -> None: ...
    def settingsEntry(self, key: str|None, searchChildRegistries: bool = ...) -> QgsSettingsEntryBase|None: ...
    def settingEntries(self) -> list[QgsSettingsEntryBase]: ...


class QgsSettingsRegistryCore(QgsSettingsRegistry):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsRegistryCore') -> None: ...


class QgsSettingsTree(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsTree') -> None: ...

    @staticmethod
    def unregisterPluginTreeNode(pluginName: str|None) -> None: ...
    @staticmethod
    def createPluginTreeNode(pluginName: str|None) -> 'QgsSettingsTreeNode|None': ...
    @staticmethod
    def node(key: str|None) -> 'QgsSettingsTreeNode|None': ...
    @staticmethod
    def treeRoot() -> 'QgsSettingsTreeNode|None': ...


class QgsSettingsTreeNode(PyQt6.sip.wrapper):

    staticMetaObject = ... # type: QtCore.QMetaObject

    def registerChildNode(self, node: 'QgsSettingsTreeNode|None') -> None: ...
    def __repr__(self) -> typing.Any: ...
    def namedNodesCount(self) -> int: ...
    def completeKey(self) -> str: ...
    def key(self) -> str: ...
    def parent(self) -> 'QgsSettingsTreeNode|None': ...
    def childSetting(self, key: str|None) -> QgsSettingsEntryBase|None: ...
    def childrenSettings(self) -> list[QgsSettingsEntryBase]: ...
    def childNode(self, key: str|None) -> 'QgsSettingsTreeNode|None': ...
    def childrenNodes(self) -> list['QgsSettingsTreeNode']: ...
    def unregisterChildNode(self, node: 'QgsSettingsTreeNode|None') -> None: ...
    def unregisterChildSetting(self, setting: QgsSettingsEntryBase|None, deleteSettingValues: bool = ..., parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> None: ...
    def registerChildSetting(self, setting: QgsSettingsEntryBase|None, key: str|None) -> None: ...
    def type(self) -> Qgis.SettingsTreeNodeType: ...
    def createNamedListNode(self, key: str|None, options: Qgis.SettingsTreeNodeOption = ...) -> 'QgsSettingsTreeNamedListNode|None': ...
    def createChildNode(self, key: str|None) -> 'QgsSettingsTreeNode|None': ...


class QgsSettingsTreeNamedListNode(QgsSettingsTreeNode):

    def initNamedList(self, options: Qgis.SettingsTreeNodeOption) -> None: ...
    def selectedItemSetting(self) -> QgsSettingsEntryString|None: ...
    def deleteAllItems(self, parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> None: ...
    def deleteItem(self, item: str|None, parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> None: ...
    def selectedItem(self, parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> str: ...
    def setSelectedItem(self, item: str|None, parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> None: ...
    @typing.overload
    def items(self, parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> list[str]: ...
    @typing.overload
    def items(self, origin: Qgis.SettingsOrigin, parentsNamedItems: collections.abc.Iterable[str|None] = ...) -> list[str]: ...


class QgsValidityCheckResult(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        Warning = ... # type: QgsValidityCheckResult.Type
        Critical = ... # type: QgsValidityCheckResult.Type

    checkId = ... # type: str|None
    detailedDescription = ... # type: str|None
    title = ... # type: str|None
    type = ... # type: 'QgsValidityCheckResult.Type'

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsValidityCheckResult') -> None: ...


class QgsAbstractValidityCheck(PyQt6.sip.wrapper):

    class Type(enum.IntEnum):
        LayoutCheck = ... # type: QgsAbstractValidityCheck.Type
        UserCheck = ... # type: QgsAbstractValidityCheck.Type

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractValidityCheck') -> None: ...

    def runCheck(self, context: 'QgsValidityCheckContext|None', feedback: QgsFeedback|None) -> list[QgsValidityCheckResult]: ...
    def prepareCheck(self, context: 'QgsValidityCheckContext|None', feedback: QgsFeedback|None) -> bool: ...
    def checkType(self) -> int: ...
    def id(self) -> str: ...
    def create(self) -> 'QgsAbstractValidityCheck|None': ...


class QgsValidityCheckContext(PyQt6.sip.wrapper):

    class ContextType(enum.IntEnum):
        TypeLayoutContext = ... # type: QgsValidityCheckContext.ContextType
        TypeUserContext = ... # type: QgsValidityCheckContext.ContextType

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsValidityCheckContext') -> None: ...

    def type(self) -> int: ...


class QgsLayoutValidityCheckContext(QgsValidityCheckContext):

    layout = ... # type: QgsLayout

    @typing.overload
    def __init__(self, layout: QgsLayout|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutValidityCheckContext') -> None: ...

    def type(self) -> int: ...


class QgsValidityCheckRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def runChecks(self, type: int, context: QgsValidityCheckContext|None, feedback: QgsFeedback|None) -> list[QgsValidityCheckResult]: ...
    def removeCheck(self, check: QgsAbstractValidityCheck|None) -> None: ...
    def addCheck(self, check: QgsAbstractValidityCheck|None) -> None: ...
    @typing.overload
    def checks(self) -> list[QgsAbstractValidityCheck]: ...
    @typing.overload
    def checks(self, type: int) -> list[QgsAbstractValidityCheck]: ...


class QgsFieldDomain(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, fieldType: QtCore.QMetaType.Type) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, name: str|None, description: str|None, fieldType: typing.Any) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFieldDomain') -> None: ...

    def setMergePolicy(self, policy: Qgis.FieldDomainMergePolicy) -> None: ...
    def mergePolicy(self) -> Qgis.FieldDomainMergePolicy: ...
    def setSplitPolicy(self, policy: Qgis.FieldDomainSplitPolicy) -> None: ...
    def splitPolicy(self) -> Qgis.FieldDomainSplitPolicy: ...
    @typing.overload
    def setFieldType(self, type: QtCore.QMetaType.Type) -> None: ...
    @typing.overload
    @deprecated("""""")
    def setFieldType(self, type: typing.Any) -> None: ...
    def fieldType(self) -> QtCore.QMetaType.Type: ...
    def setDescription(self, description: str|None) -> None: ...
    def description(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def typeName(self) -> str: ...
    def type(self) -> Qgis.FieldDomainType: ...
    def clone(self) -> 'QgsFieldDomain|None': ...


class QgsCodedValue(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, code: typing.Any, value: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCodedValue') -> None: ...

    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...
    def __repr__(self) -> typing.Any: ...
    def value(self) -> str: ...
    def code(self) -> typing.Any: ...


class QgsCodedFieldDomain(QgsFieldDomain):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, fieldType: QtCore.QMetaType.Type, values: collections.abc.Iterable[QgsCodedValue]) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, name: str|None, description: str|None, fieldType: typing.Any, values: collections.abc.Iterable[QgsCodedValue]) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def setValues(self, values: collections.abc.Iterable[QgsCodedValue]) -> None: ...
    def values(self) -> list[QgsCodedValue]: ...
    def clone(self) -> 'QgsCodedFieldDomain|None': ...
    def typeName(self) -> str: ...
    def type(self) -> Qgis.FieldDomainType: ...


class QgsRangeFieldDomain(QgsFieldDomain):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, fieldType: QtCore.QMetaType.Type, minimum: typing.Any, minimumIsInclusive: bool, maximum: typing.Any, maximumIsInclusive: bool) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, name: str|None, description: str|None, fieldType: typing.Any, minimum: typing.Any, minimumIsInclusive: bool, maximum: typing.Any, maximumIsInclusive: bool) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def setMaximumIsInclusive(self, inclusive: bool) -> None: ...
    def maximumIsInclusive(self) -> bool: ...
    def setMaximum(self, maximum: typing.Any) -> None: ...
    def maximum(self) -> typing.Any: ...
    def setMinimumIsInclusive(self, inclusive: bool) -> None: ...
    def minimumIsInclusive(self) -> bool: ...
    def setMinimum(self, minimum: typing.Any) -> None: ...
    def minimum(self) -> typing.Any: ...
    def clone(self) -> 'QgsRangeFieldDomain|None': ...
    def typeName(self) -> str: ...
    def type(self) -> Qgis.FieldDomainType: ...


class QgsGlobFieldDomain(QgsFieldDomain):

    @typing.overload
    def __init__(self, name: str|None, description: str|None, fieldType: QtCore.QMetaType.Type, glob: str|None) -> None: ...
    @typing.overload
    @deprecated("""""")
    def __init__(self, name: str|None, description: str|None, fieldType: typing.Any, glob: str|None) -> None: ...

    def __repr__(self) -> typing.Any: ...
    def setGlob(self, glob: str|None) -> None: ...
    def glob(self) -> str: ...
    def clone(self) -> 'QgsGlobFieldDomain|None': ...
    def typeName(self) -> str: ...
    def type(self) -> Qgis.FieldDomainType: ...


class QgsVectorDataProvider(QgsDataProvider, QgsFeatureSink, QgsFeatureSource):

    class NativeType(PyQt6.sip.wrapper):

        mMaxLen = ... # type: int
        mMaxPrec = ... # type: int
        mMinLen = ... # type: int
        mMinPrec = ... # type: int
        mSubType = ... # type: QtCore.QMetaType.Type
        mType = ... # type: QtCore.QMetaType.Type
        mTypeDesc = ... # type: str|None
        mTypeName = ... # type: str|None

        @typing.overload
        def __init__(self, typeDesc: str|None, typeName: str|None, type: QtCore.QMetaType.Type, minLen: int = ..., maxLen: int = ..., minPrec: int = ..., maxPrec: int = ..., subType: QtCore.QMetaType.Type = ...) -> None: ...
        @typing.overload
        def __init__(self, typeDesc: str|None, typeName: str|None, type: typing.Any, minLen: int = ..., maxLen: int = ..., minPrec: int = ..., maxPrec: int = ..., subType: typing.Any = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorDataProvider.NativeType') -> None: ...

    EditingCapabilities = ... # type: int

    def __init__(self, uri: str|None = ..., providerOptions: QgsDataProvider.ProviderOptions = ..., flags: Qgis.DataProviderReadFlag = ...) -> None: ...

    def setNativeTypes(self, nativeTypes: collections.abc.Iterable['QgsVectorDataProvider.NativeType']) -> None: ...
    @typing.overload
    def convertToProviderType(self, geom: QgsGeometry) -> QgsGeometry: ...
    @typing.overload
    @staticmethod
    def convertToProviderType(geometry: QgsGeometry, providerGeometryType: Qgis.WkbType) -> QgsGeometry: ...
    def pushError(self, msg: str|None) -> None: ...
    def fillMinMaxCache(self) -> None: ...
    def clearMinMaxCache(self) -> None: ...
    raiseError: typing.ClassVar[QtCore.pyqtSignal]
    def elevationProperties(self) -> QgsDataProviderElevationProperties|None: ...
    def temporalCapabilities(self) -> 'QgsVectorDataProviderTemporalCapabilities|None': ...
    def handlePostCloneOperations(self, source: 'QgsVectorDataProvider|None') -> None: ...
    def hasMetadata(self) -> bool: ...
    def translateMetadataValue(self, mdKey: str|None, value: typing.Any) -> str: ...
    def translateMetadataKey(self, mdKey: str|None) -> str: ...
    def discoverRelations(self, target: QgsVectorLayer|None, layers: collections.abc.Iterable[QgsVectorLayer]) -> list[QgsRelation]: ...
    def dependencies(self) -> set[QgsMapLayerDependency]: ...
    @deprecated("""""")
    def forceReload(self) -> None: ...
    def transaction(self) -> QgsTransaction|None: ...
    @typing.overload
    @staticmethod
    def convertValue(type: QtCore.QMetaType.Type, value: str|None) -> typing.Any: ...
    @typing.overload
    @staticmethod
    @deprecated("""""")
    def convertValue(type: typing.Any, value: str|None) -> typing.Any: ...
    def createLabeling(self, configuration: dict[str|None, typing.Any] = ...) -> QgsAbstractVectorLayerLabeling|None: ...
    def createRenderer(self, configuration: dict[str|None, typing.Any] = ...) -> QgsFeatureRenderer|None: ...
    def errors(self) -> list[str]: ...
    def clearErrors(self) -> None: ...
    def hasErrors(self) -> bool: ...
    @staticmethod
    def availableEncodings() -> list[str]: ...
    def doesStrictFeatureTypeCheck(self) -> bool: ...
    def nativeTypes(self) -> list['QgsVectorDataProvider.NativeType']: ...
    def supportedType(self, field: QgsField) -> bool: ...
    @deprecated("""""")
    def palAttributeIndexNames(self) -> dict[int, str]: ...
    def geometryColumnName(self) -> str: ...
    def pkAttributeIndexes(self) -> list[int]: ...
    def attributeIndexes(self) -> list[int]: ...
    def fieldNameMap(self) -> typing.Any: ...
    def fieldNameIndex(self, fieldName: str|None) -> int: ...
    def encoding(self) -> str: ...
    def setEncoding(self, e: str|None) -> None: ...
    def attributeEditCapabilities(self) -> Qgis.VectorDataProviderAttributeEditCapability: ...
    def capabilitiesString(self) -> str: ...
    def capabilities(self) -> Qgis.VectorProviderCapability: ...
    def createAttributeIndex(self, field: int) -> bool: ...
    def createSpatialIndex(self) -> bool: ...
    def changeGeometryValues(self, geometry_map: typing.Any) -> bool: ...
    def skipConstraintCheck(self, fieldIndex: int, constraint: QgsFieldConstraints.Constraint, value: typing.Any = ...) -> bool: ...
    def fieldConstraints(self, fieldIndex: int) -> QgsFieldConstraints.Constraint: ...
    def defaultValueClause(self, fieldIndex: int) -> str: ...
    def defaultValue(self, fieldIndex: int) -> typing.Any: ...
    def changeFeatures(self, attr_map: typing.Any, geometry_map: typing.Any) -> bool: ...
    def changeAttributeValues(self, attr_map: typing.Any) -> bool: ...
    def renameAttributes(self, renamedAttributes: dict[int, str|None]) -> bool: ...
    def deleteAttributes(self, attributes: typing.Any) -> bool: ...
    def addAttributes(self, attributes: typing.Any) -> bool: ...
    def cancelReload(self) -> bool: ...
    def truncate(self) -> bool: ...
    def deleteFeatures(self, id: typing.Any) -> bool: ...
    def lastError(self) -> str: ...
    def addFeatures(self, flist: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> typing.Tuple[bool, list[QgsFeature]]: ...
    def enumValues(self, index: int) -> list[str]: ...
    def aggregate(self, aggregate: Qgis.Aggregate, index: int, parameters: QgsAggregateCalculator.AggregateParameters, context: QgsExpressionContext|None, fids: typing.Any = ...) -> typing.Tuple[typing.Any, bool]: ...
    def uniqueStringsMatching(self, index: int, substring: str|None, limit: int = ..., feedback: QgsFeedback|None = ...) -> list[str]: ...
    def maximumValue(self, index: int) -> typing.Any: ...
    def minimumValue(self, index: int) -> typing.Any: ...
    def dataComment(self) -> str: ...
    def sourceName(self) -> str: ...
    def sourceExtent3D(self) -> QgsBox3D: ...
    def sourceExtent(self) -> QgsRectangle: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    def fields(self) -> QgsFields: ...
    def hasFeatures(self) -> Qgis.FeatureAvailability: ...
    def vectorLayerTypeFlags(self) -> Qgis.VectorLayerTypeFlag: ...
    def isSqlQuery(self) -> bool: ...
    def empty(self) -> bool: ...
    def featureCount(self) -> int: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def getFeatures(self, request: QgsFeatureRequest = ...) -> QgsFeatureIterator: ...
    def storageType(self) -> str: ...
    def featureSource(self) -> QgsAbstractFeatureSource|None: ...


class QgsVectorDataProviderTemporalCapabilities(QgsDataProviderTemporalCapabilities):

    @typing.overload
    def __init__(self, enabled: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorDataProviderTemporalCapabilities') -> None: ...

    def setEndField(self, field: str|None) -> None: ...
    def endField(self) -> str: ...
    def setStartField(self, field: str|None) -> None: ...
    def startField(self) -> str: ...
    def availableTemporalRange(self) -> QgsDateTimeRange: ...
    def setAvailableTemporalRange(self, range: QgsDateTimeRange) -> None: ...
    def setMode(self, mode: Qgis.VectorDataProviderTemporalMode) -> None: ...
    def mode(self) -> Qgis.VectorDataProviderTemporalMode: ...


class QgsVectorLayerCache(QtCore.QObject):

    def __init__(self, layer: QgsVectorLayer|None, cacheSize: int, parent: QtCore.QObject|None = ...) -> None: ...

    invalidated: typing.ClassVar[QtCore.pyqtSignal]
    featureAdded: typing.ClassVar[QtCore.pyqtSignal]
    attributeValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    cachedLayerDeleted: typing.ClassVar[QtCore.pyqtSignal]
    finished: typing.ClassVar[QtCore.pyqtSignal]
    def checkInformationCovered(self, featureRequest: QgsFeatureRequest) -> bool: ...
    def featureRemoved(self, fid: int) -> None: ...
    def requestCompleted(self, featureRequest: QgsFeatureRequest, fids: typing.Any) -> None: ...
    def featureCount(self) -> int: ...
    def __bool__(self) -> int: ...
    def __len__(self) -> int: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def fields(self) -> QgsFields: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    def layer(self) -> QgsVectorLayer|None: ...
    def removeCachedFeature(self, fid: int) -> bool: ...
    def completeFeatureAtId(self, featureId: int, skipCache: bool = ...) -> typing.Tuple[bool, QgsFeature]: ...
    def featureAtIdWithAllAttributes(self, featureId: int, skipCache: bool = ...) -> typing.Tuple[bool, QgsFeature]: ...
    def featureAtId(self, featureId: int, skipCache: bool = ...) -> typing.Tuple[bool, QgsFeature]: ...
    def cachedFeatureIds(self) -> typing.Any: ...
    def isFidCached(self, fid: int) -> bool: ...
    def getFeature(self, fid: int) -> QgsFeature: ...
    @typing.overload
    def getFeatures(self, featureRequest: QgsFeatureRequest = ...) -> QgsFeatureIterator: ...
    @typing.overload
    def getFeatures(self, expression: str|None) -> QgsFeatureIterator: ...
    @typing.overload
    def getFeatures(self, fids: typing.Any) -> QgsFeatureIterator: ...
    @typing.overload
    def getFeatures(self, rectangle: QgsRectangle) -> QgsFeatureIterator: ...
    def addCacheIndex(self, cacheIndex: QgsAbstractCacheIndex|None) -> None: ...
    def hasFullCache(self) -> bool: ...
    def setFullCache(self, fullCache: bool) -> None: ...
    def setCacheAddedAttributes(self, cacheAddedAttributes: bool) -> None: ...
    def cacheSubsetOfAttributes(self) -> list[int]: ...
    def setCacheSubsetOfAttributes(self, attributes: collections.abc.Iterable[int]) -> None: ...
    def cacheGeometry(self) -> bool: ...
    def setCacheGeometry(self, cacheGeometry: bool) -> None: ...
    def cacheSize(self) -> int: ...
    def setCacheSize(self, cacheSize: int) -> None: ...


class QgsVectorLayerEditBuffer(QtCore.QObject):

    @typing.overload
    def __init__(self, layer: QgsVectorLayer|None) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...

    def updateLayerFields(self) -> None: ...
    def updateAttributeMapIndex(self, attrs: dict[int, typing.Any], index: int, offset: int) -> None: ...
    def handleAttributeDeleted(self, index: int) -> None: ...
    def handleAttributeAdded(self, index: int, field: QgsField) -> None: ...
    def updateChangedAttributes(self, f: QgsFeature) -> None: ...
    def updateFeatureGeometry(self, f: QgsFeature) -> None: ...
    committedGeometriesChanges: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributeValuesChanges: typing.ClassVar[QtCore.pyqtSignal]
    committedFeaturesRemoved: typing.ClassVar[QtCore.pyqtSignal]
    committedFeaturesAdded: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributesRenamed: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributesAdded: typing.ClassVar[QtCore.pyqtSignal]
    committedAttributesDeleted: typing.ClassVar[QtCore.pyqtSignal]
    attributeRenamed: typing.ClassVar[QtCore.pyqtSignal]
    attributeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    attributeAdded: typing.ClassVar[QtCore.pyqtSignal]
    attributeValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    geometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    featureDeleted: typing.ClassVar[QtCore.pyqtSignal]
    featureAdded: typing.ClassVar[QtCore.pyqtSignal]
    layerModified: typing.ClassVar[QtCore.pyqtSignal]
    def undoIndexChanged(self, index: int) -> None: ...
    def setEditBufferGroup(self, editBufferGroup: 'QgsVectorLayerEditBufferGroup|None') -> None: ...
    def editBufferGroup(self) -> 'QgsVectorLayerEditBufferGroup|None': ...
    def isFeatureDeleted(self, id: int) -> bool: ...
    def deletedFeatureIds(self) -> typing.Any: ...
    def isFeatureGeometryChanged(self, id: int) -> bool: ...
    def changedGeometries(self) -> typing.Any: ...
    def addedAttributes(self) -> typing.Any: ...
    def isAttributeDeleted(self, index: int) -> bool: ...
    def deletedAttributeIds(self) -> list[int]: ...
    def isFeatureAttributesChanged(self, id: int) -> bool: ...
    def changedAttributeValues(self) -> typing.Any: ...
    def isFeatureAdded(self, id: int) -> bool: ...
    def allAddedOrEditedFeatures(self) -> typing.Any: ...
    def addedFeatures(self) -> typing.Any: ...
    def rollBack(self) -> None: ...
    def commitChanges(self, commitErrors: collections.abc.Iterable[str|None]) -> bool: ...
    def renameAttribute(self, attr: int, newName: str|None) -> bool: ...
    def deleteAttribute(self, attr: int) -> bool: ...
    def addAttribute(self, field: QgsField) -> bool: ...
    def changeAttributeValues(self, fid: int, newValues: dict[int, typing.Any], oldValues: dict[int, typing.Any]) -> bool: ...
    def changeAttributeValue(self, fid: int, field: int, newValue: typing.Any, oldValue: typing.Any = ...) -> bool: ...
    def changeGeometry(self, fid: int, geom: QgsGeometry) -> bool: ...
    def deleteFeatures(self, fid: typing.Any) -> bool: ...
    def deleteFeature(self, fid: int) -> bool: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature]) -> bool: ...
    def addFeature(self, f: QgsFeature) -> bool: ...
    def isModified(self) -> bool: ...


class QgsVectorLayerEditBufferGroup(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def isEditing(self) -> bool: ...
    def rollBack(self, stopEditing: bool = ...) -> typing.Tuple[bool, list[str]]: ...
    def commitChanges(self, stopEditing: bool = ...) -> typing.Tuple[bool, list[str]]: ...
    def startEditing(self) -> bool: ...
    def modifiedLayers(self) -> set[QgsVectorLayer]: ...
    def layers(self) -> set[QgsVectorLayer]: ...
    def clear(self) -> None: ...
    def removeLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def addLayer(self, layer: QgsVectorLayer|None) -> None: ...


class QgsVectorLayerEditPassthrough(QgsVectorLayerEditBuffer):

    def __init__(self, layer: QgsVectorLayer|None) -> None: ...

    def update(self, transaction: QgsTransaction|None, sql: str|None, name: str|None) -> bool: ...
    def rollBack(self) -> None: ...
    def commitChanges(self, commitErrors: collections.abc.Iterable[str|None]) -> bool: ...
    def renameAttribute(self, attr: int, newName: str|None) -> bool: ...
    def deleteAttribute(self, attr: int) -> bool: ...
    def addAttribute(self, field: QgsField) -> bool: ...
    def changeAttributeValues(self, fid: int, newValues: dict[int, typing.Any], oldValues: dict[int, typing.Any]) -> bool: ...
    def changeAttributeValue(self, fid: int, field: int, newValue: typing.Any, oldValue: typing.Any = ...) -> bool: ...
    def changeGeometry(self, fid: int, geom: QgsGeometry) -> bool: ...
    def deleteFeatures(self, fids: typing.Any) -> bool: ...
    def deleteFeature(self, fid: int) -> bool: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature]) -> bool: ...
    def addFeature(self, f: QgsFeature) -> bool: ...
    def isModified(self) -> bool: ...


class QgsVectorLayerEditUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, layer: QgsVectorLayer|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorLayerEditUtils') -> None: ...

    def mergeFeatures(self, targetFeatureId: int, mergeFeatureIds: typing.Any, mergeAttributes: typing.Any, unionGeometry: QgsGeometry) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def addTopologicalPoints(self, geom: QgsGeometry) -> int: ...
    @typing.overload
    def addTopologicalPoints(self, p: QgsPointXY) -> int: ...
    @typing.overload
    def addTopologicalPoints(self, p: QgsPoint) -> int: ...
    @typing.overload
    def addTopologicalPoints(self, ps: collections.abc.Iterable[QgsPoint]) -> int: ...
    @typing.overload
    @deprecated("""""")
    def splitFeatures(self, splitLine: collections.abc.Iterable[QgsPointXY], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitFeatures(self, splitLine: collections.abc.Iterable[QgsPoint], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitFeatures(self, curve: QgsCurve|None, preserveCircular: bool = ..., topologicalEditing: bool = ...) -> typing.Tuple[Qgis.GeometryOperationResult, list[QgsPoint]]: ...
    @typing.overload
    @deprecated("""""")
    def splitParts(self, splitLine: collections.abc.Iterable[QgsPointXY], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def splitParts(self, splitLine: collections.abc.Iterable[QgsPoint], topologicalEditing: bool = ...) -> Qgis.GeometryOperationResult: ...
    def translateFeature(self, featureId: int, dx: float, dy: float) -> int: ...
    def addCurvedPart(self, ring: QgsCurve|None, featureId: int) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    @deprecated("""""")
    def addPart(self, ring: collections.abc.Iterable[QgsPointXY], featureId: int) -> Qgis.GeometryOperationResult: ...
    @typing.overload
    def addPart(self, ring: collections.abc.Iterable[QgsPoint], featureId: int) -> Qgis.GeometryOperationResult: ...
    def addCurvedRing(self, ring: QgsCurve|None, targetFeatureIds: typing.Any = ...) -> typing.Tuple[Qgis.GeometryOperationResult, int]: ...
    def addRingV2(self, ring: QgsCurve|None, targetFeatureIds: typing.Any = ...) -> typing.Tuple[Qgis.GeometryOperationResult, typing.Any]: ...
    @typing.overload
    @deprecated("""""")
    def addRing(self, ring: collections.abc.Iterable[QgsPointXY], targetFeatureIds: typing.Any = ...) -> typing.Tuple[Qgis.GeometryOperationResult, int]: ...
    @typing.overload
    def addRing(self, ring: collections.abc.Iterable[QgsPoint], targetFeatureIds: typing.Any = ...) -> typing.Tuple[Qgis.GeometryOperationResult, int]: ...
    def deleteVertex(self, featureId: int, vertex: int) -> Qgis.VectorEditResult: ...
    def moveVertexV2(self, p: QgsPoint, atFeatureId: int, atVertex: int) -> bool: ...
    def moveVertex(self, x: float, y: float, atFeatureId: int, atVertex: int) -> bool: ...
    @typing.overload
    def insertVertex(self, x: float, y: float, atFeatureId: int, beforeVertex: int) -> bool: ...
    @typing.overload
    def insertVertex(self, point: QgsPoint, atFeatureId: int, beforeVertex: int) -> bool: ...


class QgsVectorLayerElevationProperties(QgsMapLayerElevationProperties):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def setShowMarkerSymbolInSurfacePlots(self, show: bool) -> None: ...
    def showMarkerSymbolInSurfacePlots(self) -> bool: ...
    def setElevationLimit(self, limit: float) -> None: ...
    def elevationLimit(self) -> float: ...
    def setProfileSymbology(self, symbology: Qgis.ProfileSurfaceSymbology) -> None: ...
    def profileSymbology(self) -> Qgis.ProfileSurfaceSymbology: ...
    def setProfileMarkerSymbol(self, symbol: QgsMarkerSymbol|None) -> None: ...
    def profileMarkerSymbol(self) -> QgsMarkerSymbol|None: ...
    def setProfileFillSymbol(self, symbol: QgsFillSymbol|None) -> None: ...
    def profileFillSymbol(self) -> QgsFillSymbol|None: ...
    def setProfileLineSymbol(self, symbol: QgsLineSymbol|None) -> None: ...
    def profileLineSymbol(self) -> QgsLineSymbol|None: ...
    def setRespectLayerSymbology(self, enabled: bool) -> None: ...
    def respectLayerSymbology(self) -> bool: ...
    def setCustomTolerance(self, tolerance: float) -> None: ...
    def customTolerance(self) -> float: ...
    def setCustomToleranceEnabled(self, enabled: bool) -> None: ...
    def customToleranceEnabled(self) -> bool: ...
    def setExtrusionHeight(self, height: float) -> None: ...
    def extrusionHeight(self) -> float: ...
    def setExtrusionEnabled(self, enabled: bool) -> None: ...
    def extrusionEnabled(self) -> bool: ...
    def setType(self, type: Qgis.VectorProfileType) -> None: ...
    def type(self) -> Qgis.VectorProfileType: ...
    def setBinding(self, binding: Qgis.AltitudeBinding) -> None: ...
    def binding(self) -> Qgis.AltitudeBinding: ...
    def setClamping(self, clamping: Qgis.AltitudeClamping) -> None: ...
    def clamping(self) -> Qgis.AltitudeClamping: ...
    def showByDefaultInElevationProfilePlots(self) -> bool: ...
    def calculateZRange(self, layer: QgsMapLayer|None) -> QgsDoubleRange: ...
    def isVisibleInZRange(self, range: QgsDoubleRange, layer: QgsMapLayer|None = ...) -> bool: ...
    def htmlSummary(self) -> str: ...
    def clone(self) -> 'QgsVectorLayerElevationProperties|None': ...
    def setDefaultsFromLayer(self, layer: QgsMapLayer|None) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def hasElevation(self) -> bool: ...


class QgsVectorLayerExporter(QgsFeatureSink):

    class OutputField(PyQt6.sip.wrapper):

        expression = ... # type: str|None
        field = ... # type: QgsField

        @typing.overload
        def __init__(self, field: QgsField, expression: str|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayerExporter.OutputField') -> None: ...

    class ExportOptions(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayerExporter.ExportOptions') -> None: ...

        def setOutputFields(self, fields: collections.abc.Iterable['QgsVectorLayerExporter.OutputField']) -> None: ...
        def outputFields(self) -> list['QgsVectorLayerExporter.OutputField']: ...
        def expressionContext(self) -> QgsExpressionContext: ...
        def setExpressionContext(self, context: QgsExpressionContext) -> None: ...
        def filterExpression(self) -> str: ...
        def setFilterExpression(self, expression: str|None) -> None: ...
        def extent(self) -> QgsReferencedRectangle: ...
        def setExtent(self, extent: QgsReferencedRectangle) -> None: ...
        def destinationCrs(self) -> QgsCoordinateReferenceSystem: ...
        def setDestinationCrs(self, crs: QgsCoordinateReferenceSystem) -> None: ...
        def transformContext(self) -> QgsCoordinateTransformContext: ...
        def setTransformContext(self, context: QgsCoordinateTransformContext) -> None: ...
        def selectedOnly(self) -> bool: ...
        def setSelectedOnly(self, selected: bool) -> None: ...

    def __init__(self, uri: str|None, provider: str|None, fields: QgsFields, geometryType: Qgis.WkbType, crs: QgsCoordinateReferenceSystem, overwrite: bool = ..., options: dict[str|None, typing.Any] = ..., sinkFlags: QgsFeatureSink.SinkFlag = ...) -> None: ...

    def flushBuffer(self) -> bool: ...
    def lastError(self) -> str: ...
    def addFeature(self, feature: QgsFeature, flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def attributeEditCapabilities(self) -> Qgis.VectorDataProviderAttributeEditCapability: ...
    def errorCount(self) -> int: ...
    def errorMessage(self) -> str: ...
    def errorCode(self) -> Qgis.VectorExportResult: ...
    @typing.overload
    @staticmethod
    def exportLayer(layer: QgsVectorLayer|None, uri: str|None, providerKey: str|None, destCRS: QgsCoordinateReferenceSystem, onlySelected: bool = ..., options: dict[str|None, typing.Any] = ..., feedback: QgsFeedback|None = ...) -> typing.Tuple[Qgis.VectorExportResult, str]: ...
    @typing.overload
    @staticmethod
    def exportLayer(layer: QgsVectorLayer|None, uri: str|None, providerKey: str|None, exportOptions: 'QgsVectorLayerExporter.ExportOptions', providerOptions: dict[str|None, typing.Any] = ..., feedback: QgsFeedback|None = ...) -> typing.Tuple[Qgis.VectorExportResult, str]: ...


class QgsVectorLayerExporterTask(QgsTask):

    @typing.overload
    def __init__(self, layer: QgsVectorLayer|None, uri: str|None, providerKey: str|None, destinationCrs: QgsCoordinateReferenceSystem, options: dict[str|None, typing.Any] = ..., ownsLayer: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, layer: QgsVectorLayer|None, uri: str|None, providerKey: str|None, exportOptions: QgsVectorLayerExporter.ExportOptions, providerOptions: dict[str|None, typing.Any] = ..., ownsLayer: bool = ...) -> None: ...

    def finished(self, result: bool) -> None: ...
    def run(self) -> bool: ...
    errorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    exportComplete: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    @staticmethod
    def withLayerOwnership(layer: QgsVectorLayer|None, uri: str|None, providerKey: str|None, destinationCrs: QgsCoordinateReferenceSystem, options: dict[str|None, typing.Any] = ...) -> 'QgsVectorLayerExporterTask|None': ...


class QgsVectorLayerFeatureCounter(QgsTask):

    def __init__(self, layer: QgsVectorLayer|None, context: QgsExpressionContext = ..., storeSymbolFids: bool = ...) -> None: ...

    symbolsCounted: typing.ClassVar[QtCore.pyqtSignal]
    def featureIds(self, symbolkey: str|None) -> typing.Any: ...
    def featureCount(self, legendKey: str|None) -> int: ...
    def cancel(self) -> None: ...
    def run(self) -> bool: ...


class QgsVectorLayerFeatureSource(QgsAbstractFeatureSource):

    def __init__(self, layer: QgsVectorLayer|None) -> None: ...

    def id(self) -> str: ...
    def crs(self) -> QgsCoordinateReferenceSystem: ...
    def fields(self) -> QgsFields: ...
    def getFeatures(self, request: QgsFeatureRequest = ...) -> QgsFeatureIterator: ...


class QgsAbstractFeatureIteratorFromSourceQgsVectorLayerFeatureSourceBase(QgsAbstractFeatureIterator):

    @typing.overload
    def __init__(self, source: QgsVectorLayerFeatureSource|None, ownSource: bool, request: QgsFeatureRequest) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractFeatureIteratorFromSourceQgsVectorLayerFeatureSourceBase') -> None: ...

    def iteratorClosed(self) -> None: ...


class QgsVectorLayerFeatureIterator(QgsAbstractFeatureIteratorFromSourceQgsVectorLayerFeatureSourceBase):

    class FetchJoinInfo(PyQt6.sip.wrapper):

        attributes = ... # type: collections.abc.Iterable[int]
        indexOffset = ... # type: int
        joinField = ... # type: int
        joinInfo = ... # type: 'QgsVectorLayerJoinInfo'
        targetField = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayerFeatureIterator.FetchJoinInfo') -> None: ...

        def addJoinedAttributesDirect(self, f: QgsFeature, joinValue: typing.Any) -> None: ...
        def addJoinedAttributesCached(self, f: QgsFeature, joinValue: typing.Any) -> None: ...

    def __init__(self, source: QgsVectorLayerFeatureSource|None, ownSource: bool, request: QgsFeatureRequest) -> None: ...

    def prepareSimplification(self, simplifyMethod: QgsSimplifyMethod) -> bool: ...
    def nextFeatureFilterExpression(self, f: QgsFeature) -> bool: ...
    def fetchFeature(self, feature: QgsFeature) -> bool: ...
    def isValid(self) -> bool: ...
    def close(self) -> bool: ...
    def rewind(self) -> bool: ...


class QgsVectorLayerSelectedFeatureSource(QgsFeatureSource, QgsExpressionContextScopeGenerator):

    def __init__(self, layer: QgsVectorLayer|None) -> None: ...

    def hasSpatialIndex(self) -> Qgis.SpatialIndexPresence: ...
    def createExpressionContextScope(self) -> QgsExpressionContextScope|None: ...
    def sourceName(self) -> str: ...
    def featureCount(self) -> int: ...
    def wkbType(self) -> Qgis.WkbType: ...
    def fields(self) -> QgsFields: ...
    def sourceCrs(self) -> QgsCoordinateReferenceSystem: ...
    def getFeatures(self, request: QgsFeatureRequest = ...) -> QgsFeatureIterator: ...


class QgsVectorLayerJoinBuffer(QtCore.QObject, QgsFeatureSink):

    def __init__(self, layer: QgsVectorLayer|None = ...) -> None: ...

    joinedFieldsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def deleteFeatures(self, fids: typing.Any, context: QgsVectorLayer.DeleteContext|None = ...) -> bool: ...
    def deleteFeature(self, fid: int, context: QgsVectorLayer.DeleteContext|None = ...) -> bool: ...
    def changeAttributeValues(self, fid: int, newValues: dict[int, typing.Any], oldValues: dict[int, typing.Any] = ...) -> bool: ...
    def changeAttributeValue(self, fid: int, field: int, newValue: typing.Any, oldValue: typing.Any = ...) -> bool: ...
    def addFeatures(self, features: collections.abc.Iterable[QgsFeature], flags: QgsFeatureSink.Flag = ...) -> bool: ...
    def clone(self) -> 'QgsVectorLayerJoinBuffer|None': ...
    def isAuxiliaryJoin(self, info: 'QgsVectorLayerJoinInfo') -> bool: ...
    def targetedFeatureOf(self, info: 'QgsVectorLayerJoinInfo|None', feature: QgsFeature) -> QgsFeature: ...
    def joinedFeatureOf(self, info: 'QgsVectorLayerJoinInfo|None', feature: QgsFeature) -> QgsFeature: ...
    def joinsWhereFieldIsId(self, field: QgsField) -> list['QgsVectorLayerJoinInfo']: ...
    @typing.overload
    @staticmethod
    def joinSubsetIndices(joinLayer: QgsVectorLayer|None, joinFieldsSubset: collections.abc.Iterable[str|None]) -> list[int]: ...
    @typing.overload
    @staticmethod
    def joinSubsetIndices(joinLayerFields: QgsFields, joinFieldsSubset: collections.abc.Iterable[str|None]) -> list[int]: ...
    def joinedFieldsOffset(self, info: 'QgsVectorLayerJoinInfo|None', fields: QgsFields) -> int: ...
    def joinForFieldIndex(self, index: int, fields: QgsFields) -> typing.Tuple['QgsVectorLayerJoinInfo|None', int]: ...
    def vectorJoins(self) -> list['QgsVectorLayerJoinInfo']: ...
    def containsJoins(self) -> bool: ...
    def resolveReferences(self, project: QgsProject|None) -> None: ...
    def readXml(self, layer_node: QtXml.QDomNode) -> None: ...
    def writeXml(self, layer_node: QtXml.QDomNode, document: QtXml.QDomDocument) -> None: ...
    def createJoinCaches(self) -> None: ...
    def updateFields(self, fields: QgsFields) -> None: ...
    def removeJoin(self, joinLayerId: str|None) -> bool: ...
    def addJoin(self, joinInfo: 'QgsVectorLayerJoinInfo') -> bool: ...


class QgsVectorLayerJoinInfo(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorLayerJoinInfo') -> None: ...

    def __ne__(self, other: object): ...
    def setJoinFieldNamesSubset(self, fieldNamesSubset: collections.abc.Iterable[str|None]) -> None: ...
    def __eq__(self, other: object): ...
    @typing.overload
    @staticmethod
    def joinFieldNamesSubset(info: 'QgsVectorLayerJoinInfo', blocklisted: bool = ...) -> list[str]: ...
    @typing.overload
    @staticmethod
    def joinFieldNamesSubset(info: 'QgsVectorLayerJoinInfo', joinLayerFields: QgsFields, blocklisted: bool = ...) -> list[str]: ...
    @typing.overload
    def joinFieldNamesSubset(self) -> list[str]: ...
    def hasSubset(self, blocklisted: bool = ...) -> bool: ...
    def joinFieldNamesBlockList(self) -> list[str]: ...
    def setJoinFieldNamesBlockList(self, list: collections.abc.Iterable[str|None]) -> None: ...
    @deprecated("""""")
    def joinFieldNamesBlackList(self) -> list[str]: ...
    @deprecated("""""")
    def setJoinFieldNamesBlackList(self, blackList: collections.abc.Iterable[str|None]) -> None: ...
    def extractJoinedFeature(self, feature: QgsFeature) -> QgsFeature: ...
    def prefixedFieldName(self, field: QgsField) -> str: ...
    def setCascadedDelete(self, enabled: bool) -> None: ...
    def hasCascadedDelete(self) -> bool: ...
    def setUpsertOnEdit(self, enabled: bool) -> None: ...
    def hasUpsertOnEdit(self) -> bool: ...
    def setEditable(self, enabled: bool) -> None: ...
    def isEditable(self) -> bool: ...
    def setDynamicFormEnabled(self, enabled: bool) -> None: ...
    def isDynamicFormEnabled(self) -> bool: ...
    def isUsingMemoryCache(self) -> bool: ...
    def setUsingMemoryCache(self, enabled: bool) -> None: ...
    def prefix(self) -> str: ...
    def setPrefix(self, prefix: str|None) -> None: ...
    def joinFieldName(self) -> str: ...
    def setJoinFieldName(self, fieldName: str|None) -> None: ...
    def targetFieldName(self) -> str: ...
    def setTargetFieldName(self, fieldName: str|None) -> None: ...
    def joinLayerId(self) -> str: ...
    def setJoinLayerId(self, layerId: str|None) -> None: ...
    def joinLayer(self) -> QgsVectorLayer|None: ...
    def setJoinLayer(self, layer: QgsVectorLayer|None) -> None: ...


class QgsVectorLayerSelectionProperties(QgsMapLayerSelectionProperties):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    selectionSymbolChanged: typing.ClassVar[QtCore.pyqtSignal]
    selectionColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    selectionRenderingModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSelectionSymbol(self, symbol: QgsSymbol|None) -> None: ...
    def selectionSymbol(self) -> QgsSymbol|None: ...
    def setSelectionColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def selectionColor(self) -> QtGui.QColor: ...
    def setSelectionRenderingMode(self, mode: Qgis.SelectionRenderingMode) -> None: ...
    def selectionRenderingMode(self) -> Qgis.SelectionRenderingMode: ...
    def clone(self) -> 'QgsVectorLayerSelectionProperties|None': ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...


class QgsVectorLayerTemporalContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorLayerTemporalContext') -> None: ...

    def setLayer(self, layer: QgsVectorLayer|None) -> None: ...
    def layer(self) -> QgsVectorLayer|None: ...


class QgsVectorLayerTemporalProperties(QgsMapLayerTemporalProperties):

    def __init__(self, parent: QtCore.QObject|None = ..., enabled: bool = ...) -> None: ...

    def setDefaultsFromDataProviderTemporalCapabilities(self, capabilities: QgsDataProviderTemporalCapabilities|None) -> None: ...
    def readXml(self, element: QtXml.QDomElement, context: QgsReadWriteContext) -> bool: ...
    def writeXml(self, element: QtXml.QDomElement, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> QtXml.QDomElement: ...
    def guessDefaultsFromFields(self, fields: QgsFields) -> None: ...
    def createFilterString(self, context: QgsVectorLayerTemporalContext, range: QgsDateTimeRange) -> str: ...
    def setAccumulateFeatures(self, accumulate: bool) -> None: ...
    def accumulateFeatures(self) -> bool: ...
    def setFixedDuration(self, duration: float) -> None: ...
    def fixedDuration(self) -> float: ...
    def setDurationUnits(self, units: Qgis.TemporalUnit) -> None: ...
    def durationUnits(self) -> Qgis.TemporalUnit: ...
    def setDurationField(self, field: str|None) -> None: ...
    def durationField(self) -> str: ...
    def setEndExpression(self, endExpression: str|None) -> None: ...
    def endExpression(self) -> str: ...
    def setStartExpression(self, expression: str|None) -> None: ...
    def startExpression(self) -> str: ...
    def setEndField(self, field: str|None) -> None: ...
    def endField(self) -> str: ...
    def setStartField(self, field: str|None) -> None: ...
    def startField(self) -> str: ...
    def fixedTemporalRange(self) -> QgsDateTimeRange: ...
    def setFixedTemporalRange(self, range: QgsDateTimeRange) -> None: ...
    def flags(self) -> QgsTemporalProperty.Flag: ...
    def setLimitMode(self, mode: Qgis.VectorTemporalLimitMode) -> None: ...
    def limitMode(self) -> Qgis.VectorTemporalLimitMode: ...
    def setMode(self, mode: Qgis.VectorTemporalMode) -> None: ...
    def mode(self) -> Qgis.VectorTemporalMode: ...
    def isVisibleInTemporalRange(self, range: QgsDateTimeRange) -> bool: ...


class QgsVectorLayerToolsContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsVectorLayerToolsContext') -> None: ...

    def setHideParent(self, hide: bool) -> None: ...
    def hideParent(self) -> bool: ...
    def setShowModal(self, modal: bool) -> None: ...
    def showModal(self) -> bool: ...
    def setParentWidget(self, parent: QtWidgets.QWidget|None) -> None: ...
    def parentWidget(self) -> QtWidgets.QWidget|None: ...
    def additionalExpressionContextScope(self) -> QgsExpressionContextScope|None: ...
    def setAdditionalExpressionContextScope(self, scope: QgsExpressionContextScope|None) -> None: ...
    def expressionContext(self) -> QgsExpressionContext|None: ...
    def setExpressionContext(self, context: QgsExpressionContext|None) -> None: ...


class QgsVectorLayerUndoCommand(QtGui.QUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None) -> None: ...

    def mergeWith(self, a0: QtGui.QUndoCommand|None) -> bool: ...
    def id(self) -> int: ...
    def layer(self) -> QgsVectorLayer|None: ...


class QgsVectorLayerUndoCommandAddFeature(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, f: QgsFeature) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoCommandDeleteFeature(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fid: int) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoCommandChangeGeometry(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fid: int, newGeom: QgsGeometry) -> None: ...

    def mergeWith(self, other: QtGui.QUndoCommand|None) -> bool: ...
    def id(self) -> int: ...
    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoCommandChangeAttribute(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fid: int, fieldIndex: int, newValue: typing.Any, oldValue: typing.Any) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoCommandAddAttribute(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, field: QgsField) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoCommandDeleteAttribute(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fieldIndex: int) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoCommandRenameAttribute(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fieldIndex: int, newName: str|None) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommand(QgsVectorLayerUndoCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, text: str|None, autocreate: bool = ...) -> None: ...

    def errorMessage(self) -> str: ...
    def setErrorMessage(self, errorMessage: str|None) -> None: ...
    def setError(self) -> None: ...
    def setSavePoint(self, savePointId: str|None = ...) -> bool: ...
    def rollBackToSavePoint(self) -> bool: ...
    def hasError(self) -> bool: ...


class QgsVectorLayerUndoPassthroughCommandAddFeatures(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, features: collections.abc.Iterable[QgsFeature]) -> None: ...

    def features(self) -> list[QgsFeature]: ...
    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandDeleteFeatures(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fids: typing.Any) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandChangeGeometry(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fid: int, geom: QgsGeometry) -> None: ...

    def mergeWith(self, other: QtGui.QUndoCommand|None) -> bool: ...
    def id(self) -> int: ...
    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandChangeAttribute(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fid: int, field: int, newValue: typing.Any) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandChangeAttributes(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, fid: int, newValues: dict[int, typing.Any], oldValues: dict[int, typing.Any] = ...) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandAddAttribute(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, field: QgsField) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandDeleteAttribute(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, attr: int) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandRenameAttribute(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, attr: int, newName: str|None) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUndoPassthroughCommandUpdate(QgsVectorLayerUndoPassthroughCommand):

    def __init__(self, buffer: QgsVectorLayerEditBuffer|None, transaction: QgsTransaction|None, sql: str|None, name: str|None) -> None: ...

    def redo(self) -> None: ...
    def undo(self) -> None: ...


class QgsVectorLayerUtils(PyQt6.sip.wrapper):

    class CascadedFeatureFlag(enum.IntEnum):
        IgnoreAuxiliaryLayers = ... # type: QgsVectorLayerUtils.CascadedFeatureFlag

    class FieldIsEditableFlag(enum.IntFlag):
        IgnoreLayerEditability = ... # type: QgsVectorLayerUtils.FieldIsEditableFlag

    class QgsDuplicateFeatureContext(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayerUtils.QgsDuplicateFeatureContext') -> None: ...

        def duplicatedFeatures(self, layer: QgsVectorLayer|None) -> typing.Any: ...
        def layers(self) -> list[QgsVectorLayer]: ...

    class QgsFeatureData(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, geometry: QgsGeometry = ..., attributes: dict[int, typing.Any] = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorLayerUtils.QgsFeatureData') -> None: ...

        def attributes(self) -> dict[int, typing.Any]: ...
        def geometry(self) -> QgsGeometry: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorLayerUtils') -> None: ...

    @staticmethod
    def fieldToDataArray(fields: QgsFields, fieldName: str|None, it: QgsFeatureIterator, nullValue: typing.Any) -> QtCore.QByteArray: ...
    @staticmethod
    def filterValidFeatureIds(layer: QgsVectorLayer|None, featureIds: typing.Any) -> typing.Any: ...
    @staticmethod
    def guessFriendlyIdentifierField(fields: QgsFields) -> str: ...
    @staticmethod
    def guessFriendlyIdentifierFieldV2(fields: QgsFields) -> typing.Tuple[str, bool]: ...
    @staticmethod
    def impactsCascadeFeatures(layer: QgsVectorLayer|None, fids: typing.Any, project: QgsProject|None, flags: 'QgsVectorLayerUtils.CascadedFeatureFlag' = ...) -> typing.Tuple[bool, 'QgsVectorLayerUtils.QgsDuplicateFeatureContext']: ...
    @staticmethod
    def getFeatureDisplayString(layer: QgsVectorLayer|None, feature: QgsFeature) -> str: ...
    @staticmethod
    def fieldEditabilityDependsOnFeature(layer: QgsVectorLayer|None, fieldIndex: int) -> bool: ...
    @staticmethod
    def fieldIsReadOnly(layer: QgsVectorLayer|None, fieldIndex: int) -> bool: ...
    @staticmethod
    def fieldIsEditable(layer: QgsVectorLayer|None, fieldIndex: int, feature: QgsFeature, flags: 'QgsVectorLayerUtils.FieldIsEditableFlag' = ...) -> bool: ...
    @staticmethod
    def makeFeaturesCompatible(features: collections.abc.Iterable[QgsFeature], layer: QgsVectorLayer|None, sinkFlags: QgsFeatureSink.SinkFlag = ...) -> list[QgsFeature]: ...
    @staticmethod
    def makeFeatureCompatible(feature: QgsFeature, layer: QgsVectorLayer|None, sinkFlags: QgsFeatureSink.SinkFlag = ...) -> list[QgsFeature]: ...
    @staticmethod
    def matchAttributesToFields(feature: QgsFeature, fields: QgsFields) -> None: ...
    @staticmethod
    def duplicateFeature(layer: QgsVectorLayer|None, feature: QgsFeature, project: QgsProject|None, maxDepth: int = ...) -> typing.Tuple[QgsFeature, 'QgsVectorLayerUtils.QgsDuplicateFeatureContext']: ...
    @staticmethod
    def createFeatures(layer: QgsVectorLayer|None, featuresData: collections.abc.Iterable['QgsVectorLayerUtils.QgsFeatureData'], context: QgsExpressionContext|None = ...) -> list[QgsFeature]: ...
    @staticmethod
    def createFeature(layer: QgsVectorLayer|None, geometry: QgsGeometry = ..., attributes: dict[int, typing.Any] = ..., context: QgsExpressionContext|None = ...) -> QgsFeature: ...
    @staticmethod
    def validateAttribute(layer: QgsVectorLayer|None, feature: QgsFeature, attributeIndex: int, strength: QgsFieldConstraints.ConstraintStrength = ..., origin: QgsFieldConstraints.ConstraintOrigin = ...) -> typing.Tuple[bool, list[str]]: ...
    @staticmethod
    def attributeHasConstraints(layer: QgsVectorLayer|None, attributeIndex: int) -> bool: ...
    @staticmethod
    def createUniqueValueFromCache(layer: QgsVectorLayer|None, fieldIndex: int, existingValues: collections.abc.Iterable[typing.Any], seed: typing.Any = ...) -> typing.Any: ...
    @staticmethod
    def createUniqueValue(layer: QgsVectorLayer|None, fieldIndex: int, seed: typing.Any = ...) -> typing.Any: ...
    @staticmethod
    def valueExists(layer: QgsVectorLayer|None, fieldIndex: int, value: typing.Any, ignoreIds: typing.Any = ...) -> bool: ...
    @staticmethod
    def getDoubleValues(layer: QgsVectorLayer|None, fieldOrExpression: str|None, selectedOnly: bool = ..., feedback: QgsFeedback|None = ...) -> typing.Tuple[list[float], bool, int]: ...
    @staticmethod
    def uniqueValues(layer: QgsVectorLayer|None, fieldOrExpression: str|None, selectedOnly: bool = ..., limit: int = ..., feedback: QgsFeedback|None = ...) -> typing.Tuple[list[typing.Any], bool]: ...
    @staticmethod
    def getValues(layer: QgsVectorLayer|None, fieldOrExpression: str|None, selectedOnly: bool = ..., feedback: QgsFeedback|None = ...) -> typing.Tuple[list[typing.Any], bool]: ...
    @staticmethod
    def getValuesIterator(layer: QgsVectorLayer|None, fieldOrExpression: str|None, selectedOnly: bool) -> typing.Tuple[QgsFeatureIterator, bool]: ...


class QgsMapBoxGlStyleConversionContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapBoxGlStyleConversionContext') -> None: ...

    def setLayerId(self, value: str|None) -> None: ...
    def layerId(self) -> str: ...
    @typing.overload
    def setSprites(self, image: QtGui.QImage, definitions: dict[str|None, typing.Any], category: str|None = ...) -> None: ...
    @typing.overload
    def setSprites(self, image: QtGui.QImage, definitions: str|None, category: str|None = ...) -> None: ...
    def spriteDefinitions(self, category: str|None = ...) -> dict[str, typing.Any]: ...
    def spriteImage(self, category: str|None = ...) -> QtGui.QImage: ...
    def spriteCategories(self) -> list[str]: ...
    def setPixelSizeConversionFactor(self, sizeConversionFactor: float) -> None: ...
    def pixelSizeConversionFactor(self) -> float: ...
    def setTargetUnit(self, targetUnit: Qgis.RenderUnit) -> None: ...
    def targetUnit(self) -> Qgis.RenderUnit: ...
    def clearWarnings(self) -> None: ...
    def warnings(self) -> list[str]: ...
    def pushWarning(self, warning: str|None) -> None: ...


class QgsMapBoxGlStyleAbstractSource(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapBoxGlStyleAbstractSource') -> None: ...

    def name(self) -> str: ...
    def setFromJson(self, json: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext|None) -> bool: ...
    def type(self) -> Qgis.MapBoxGlStyleSourceType: ...


class QgsMapBoxGlStyleRasterSource(QgsMapBoxGlStyleAbstractSource):

    @typing.overload
    def __init__(self, name: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapBoxGlStyleRasterSource') -> None: ...

    def toRasterLayer(self) -> QgsRasterLayer|None: ...
    def tiles(self) -> list[str]: ...
    def tileSize(self) -> int: ...
    def maximumZoom(self) -> int: ...
    def minimumZoom(self) -> int: ...
    def attribution(self) -> str: ...
    def setFromJson(self, json: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext|None) -> bool: ...
    def type(self) -> Qgis.MapBoxGlStyleSourceType: ...


class QgsMapBoxGlStyleRasterSubLayer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, id: str|None, source: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapBoxGlStyleRasterSubLayer') -> None: ...

    def dataDefinedProperties(self) -> QgsPropertyCollection: ...
    def source(self) -> str: ...
    def id(self) -> str: ...


class QgsMapBoxGlStyleConverter(PyQt6.sip.wrapper):

    class PropertyType(enum.Enum):
        Color = ... # type: QgsMapBoxGlStyleConverter.PropertyType
        Numeric = ... # type: QgsMapBoxGlStyleConverter.PropertyType
        Opacity = ... # type: QgsMapBoxGlStyleConverter.PropertyType
        Point = ... # type: QgsMapBoxGlStyleConverter.PropertyType
        NumericArray = ... # type: QgsMapBoxGlStyleConverter.PropertyType
        DashArray = ... # type: QgsMapBoxGlStyleConverter.PropertyType

    class Result(enum.IntEnum):
        Success = ... # type: QgsMapBoxGlStyleConverter.Result
        NoLayerList = ... # type: QgsMapBoxGlStyleConverter.Result

    staticMetaObject = ... # type: QtCore.QMetaObject

    def __init__(self) -> None: ...

    @staticmethod
    def retrieveSpriteAsBase64WithProperties(value: typing.Any, context: QgsMapBoxGlStyleConversionContext) -> typing.Tuple[str, QtCore.QSize, str, str]: ...
    @staticmethod
    def retrieveSpriteAsBase64(value: typing.Any, context: QgsMapBoxGlStyleConversionContext) -> str: ...
    @staticmethod
    def retrieveSprite(name: str|None, context: QgsMapBoxGlStyleConversionContext, spriteSize: QtCore.QSize) -> QtGui.QImage: ...
    @staticmethod
    def parseExpression(expression: collections.abc.Iterable[typing.Any], context: QgsMapBoxGlStyleConversionContext, colorExpected: bool = ...) -> str: ...
    @staticmethod
    def parseJoinStyle(style: str|None) -> QtCore.Qt.PenJoinStyle: ...
    @staticmethod
    def parseCapStyle(style: str|None) -> QtCore.Qt.PenCapStyle: ...
    @staticmethod
    def interpolateExpression(zoomMin: float, zoomMax: float, valueMin: typing.Any, valueMax: typing.Any, base: float, multiplier: float = ..., contextPtr: QgsMapBoxGlStyleConversionContext|None = ...) -> str: ...
    @staticmethod
    def colorAsHslaComponents(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> typing.Tuple[int, int, int, int]: ...
    @staticmethod
    def parseColor(color: typing.Any, context: QgsMapBoxGlStyleConversionContext) -> QtGui.QColor: ...
    @staticmethod
    def parseColorExpression(colorExpression: typing.Any, context: QgsMapBoxGlStyleConversionContext) -> str: ...
    @staticmethod
    def parseInterpolateListByZoom(json: collections.abc.Iterable[typing.Any], type: 'QgsMapBoxGlStyleConverter.PropertyType', context: QgsMapBoxGlStyleConversionContext, multiplier: float = ..., maxOpacity: int = ...) -> typing.Tuple[QgsProperty, QtGui.QColor|None, float]: ...
    @staticmethod
    def parseStepList(json: collections.abc.Iterable[typing.Any], type: 'QgsMapBoxGlStyleConverter.PropertyType', context: QgsMapBoxGlStyleConversionContext, multiplier: float = ..., maxOpacity: int = ...) -> typing.Tuple[QgsProperty, QtGui.QColor|None, float]: ...
    @staticmethod
    def parseMatchList(json: collections.abc.Iterable[typing.Any], type: 'QgsMapBoxGlStyleConverter.PropertyType', context: QgsMapBoxGlStyleConversionContext, multiplier: float = ..., maxOpacity: int = ...) -> typing.Tuple[QgsProperty, QtGui.QColor|None, float]: ...
    @staticmethod
    def parseValueList(json: collections.abc.Iterable[typing.Any], type: 'QgsMapBoxGlStyleConverter.PropertyType', context: QgsMapBoxGlStyleConversionContext, multiplier: float = ..., maxOpacity: int = ...) -> typing.Tuple[QgsProperty, QtGui.QColor|None, float]: ...
    @staticmethod
    def parseLabelStops(stops: collections.abc.Iterable[typing.Any], context: QgsMapBoxGlStyleConversionContext) -> str: ...
    @staticmethod
    def parseStringStops(stops: collections.abc.Iterable[typing.Any], context: QgsMapBoxGlStyleConversionContext, conversionMap: dict[str|None, typing.Any]) -> typing.Tuple[str, str]: ...
    @staticmethod
    def parseStops(base: float, stops: collections.abc.Iterable[typing.Any], multiplier: float, context: QgsMapBoxGlStyleConversionContext) -> str: ...
    @staticmethod
    def parseArrayStops(stops: collections.abc.Iterable[typing.Any], context: QgsMapBoxGlStyleConversionContext, multiplier: float = ...) -> str: ...
    @staticmethod
    def parsePointStops(base: float, stops: collections.abc.Iterable[typing.Any], context: QgsMapBoxGlStyleConversionContext, multiplier: float = ...) -> str: ...
    @staticmethod
    def parseInterpolateStringByZoom(json: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext, conversionMap: dict[str|None, typing.Any]) -> typing.Tuple[QgsProperty, str]: ...
    @staticmethod
    def parseInterpolatePointByZoom(json: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext, multiplier: float = ...) -> typing.Tuple[QgsProperty, QtCore.QPointF|None]: ...
    @staticmethod
    def parseOpacityStops(base: float, stops: collections.abc.Iterable[typing.Any], maxOpacity: int, context: QgsMapBoxGlStyleConversionContext) -> str: ...
    @staticmethod
    def parseInterpolateOpacityByZoom(json: dict[str|None, typing.Any], maxOpacity: int, contextPtr: QgsMapBoxGlStyleConversionContext|None = ...) -> QgsProperty: ...
    @staticmethod
    def parseInterpolateByZoom(json: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext, multiplier: float = ...) -> typing.Tuple[QgsProperty, float]: ...
    @staticmethod
    def parseInterpolateColorByZoom(json: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext) -> typing.Tuple[QgsProperty, QtGui.QColor|None]: ...
    @staticmethod
    def parseSymbolLayerAsRenderer(jsonLayer: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext) -> typing.Tuple[bool, 'QgsVectorTileBasicRendererStyle']: ...
    @staticmethod
    def parseSymbolLayer(jsonLayer: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext) -> typing.Tuple['QgsVectorTileBasicRendererStyle', bool, 'QgsVectorTileBasicLabelingStyle', bool]: ...
    @staticmethod
    def parseCircleLayer(jsonLayer: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext) -> typing.Tuple[bool, 'QgsVectorTileBasicRendererStyle']: ...
    @staticmethod
    def parseLineLayer(jsonLayer: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext) -> typing.Tuple[bool, 'QgsVectorTileBasicRendererStyle']: ...
    @staticmethod
    def parseFillLayer(jsonLayer: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext, isBackgroundStyle: bool = ...) -> typing.Tuple[bool, 'QgsVectorTileBasicRendererStyle']: ...
    def parseLayers(self, layers: collections.abc.Iterable[typing.Any], context: QgsMapBoxGlStyleConversionContext|None = ...) -> None: ...
    def parseRasterSource(self, source: dict[str|None, typing.Any], name: str|None, context: QgsMapBoxGlStyleConversionContext|None = ...) -> None: ...
    def parseSources(self, sources: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext|None = ...) -> None: ...
    def createSubLayers(self) -> list[QgsMapLayer]: ...
    def rasterSubLayers(self) -> list[QgsMapBoxGlStyleRasterSubLayer]: ...
    def sources(self) -> list[QgsMapBoxGlStyleAbstractSource]: ...
    def labeling(self) -> 'QgsVectorTileLabeling|None': ...
    def renderer(self) -> 'QgsVectorTileRenderer|None': ...
    def warnings(self) -> list[str]: ...
    def errorMessage(self) -> str: ...
    @typing.overload
    def convert(self, style: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext|None = ...) -> 'QgsMapBoxGlStyleConverter.Result': ...
    @typing.overload
    def convert(self, style: str|None, context: QgsMapBoxGlStyleConversionContext|None = ...) -> 'QgsMapBoxGlStyleConverter.Result': ...


class QgsVectorTileBasicLabelingStyle(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileBasicLabelingStyle') -> None: ...

    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def isActive(self, zoomLevel: int) -> bool: ...
    def maxZoomLevel(self) -> int: ...
    def setMaxZoomLevel(self, maxZoom: int) -> None: ...
    def minZoomLevel(self) -> int: ...
    def setMinZoomLevel(self, minZoom: int) -> None: ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def filterExpression(self) -> str: ...
    def setFilterExpression(self, expr: str|None) -> None: ...
    def geometryType(self) -> Qgis.GeometryType: ...
    def setGeometryType(self, geomType: Qgis.GeometryType) -> None: ...
    def layerName(self) -> str: ...
    def setLayerName(self, name: str|None) -> None: ...
    def styleName(self) -> str: ...
    def setStyleName(self, name: str|None) -> None: ...
    def labelSettings(self) -> QgsPalLayerSettings: ...
    def setLabelSettings(self, settings: QgsPalLayerSettings) -> None: ...


class QgsVectorTileLabeling(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileLabeling') -> None: ...

    def resolveReferences(self, project: QgsProject) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def clone(self) -> 'QgsVectorTileLabeling|None': ...
    def type(self) -> str: ...


class QgsVectorTileBasicLabeling(QgsVectorTileLabeling):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileBasicLabeling') -> None: ...

    def style(self, index: int) -> QgsVectorTileBasicLabelingStyle: ...
    def setStyle(self, index: int, style: QgsVectorTileBasicLabelingStyle) -> None: ...
    def styles(self) -> list[QgsVectorTileBasicLabelingStyle]: ...
    def setStyles(self, styles: collections.abc.Iterable[QgsVectorTileBasicLabelingStyle]) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def clone(self) -> QgsVectorTileLabeling|None: ...
    def type(self) -> str: ...


class QgsVectorTileBasicRendererStyle(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, stName: str|None = ..., laName: str|None = ..., geomType: Qgis.GeometryType = ...) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsVectorTileBasicRendererStyle') -> None: ...

    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def isActive(self, zoomLevel: int) -> bool: ...
    def maxZoomLevel(self) -> int: ...
    def setMaxZoomLevel(self, maxZoom: int) -> None: ...
    def minZoomLevel(self) -> int: ...
    def setMinZoomLevel(self, minZoom: int) -> None: ...
    def isEnabled(self) -> bool: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def symbol(self) -> QgsSymbol|None: ...
    def setSymbol(self, sym: QgsSymbol|None) -> None: ...
    def filterExpression(self) -> str: ...
    def setFilterExpression(self, expr: str|None) -> None: ...
    def geometryType(self) -> Qgis.GeometryType: ...
    def setGeometryType(self, geomType: Qgis.GeometryType) -> None: ...
    def layerName(self) -> str: ...
    def setLayerName(self, name: str|None) -> None: ...
    def styleName(self) -> str: ...
    def setStyleName(self, name: str|None) -> None: ...


class QgsVectorTileRenderer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileRenderer') -> None: ...

    def resolveReferences(self, project: QgsProject) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def renderSelectedFeatures(self, selection: collections.abc.Iterable[QgsFeature], context: QgsRenderContext) -> None: ...
    def willRenderFeature(self, feature: QgsFeature, tileZoom: int, layerName: str|None, context: QgsRenderContext) -> bool: ...
    def renderTile(self, tile: 'QgsVectorTileRendererData', context: QgsRenderContext) -> None: ...
    def renderBackground(self, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def requiredLayers(self, context: QgsRenderContext, tileZoom: int) -> set[str]: ...
    def startRender(self, context: QgsRenderContext, tileZoom: int, tileRange: QgsTileRange) -> None: ...
    def clone(self) -> 'QgsVectorTileRenderer|None': ...
    def type(self) -> str: ...


class QgsVectorTileBasicRenderer(QgsVectorTileRenderer):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileBasicRenderer') -> None: ...

    @staticmethod
    def simpleStyleWithRandomColors() -> list[QgsVectorTileBasicRendererStyle]: ...
    @staticmethod
    def simpleStyle(polygonFillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, polygonStrokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, polygonStrokeWidth: float, lineStrokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, lineStrokeWidth: float, pointFillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, pointStrokeColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, pointSize: float) -> list[QgsVectorTileBasicRendererStyle]: ...
    def style(self, index: int) -> QgsVectorTileBasicRendererStyle: ...
    def setStyle(self, index: int, style: QgsVectorTileBasicRendererStyle) -> None: ...
    def styles(self) -> list[QgsVectorTileBasicRendererStyle]: ...
    def setStyles(self, styles: collections.abc.Iterable[QgsVectorTileBasicRendererStyle]) -> None: ...
    def readXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, context: QgsReadWriteContext) -> None: ...
    def willRenderFeature(self, feature: QgsFeature, tileZoom: int, layerName: str|None, context: QgsRenderContext) -> bool: ...
    def renderSelectedFeatures(self, selection: collections.abc.Iterable[QgsFeature], context: QgsRenderContext) -> None: ...
    def renderTile(self, tile: 'QgsVectorTileRendererData', context: QgsRenderContext) -> None: ...
    def renderBackground(self, context: QgsRenderContext) -> None: ...
    def stopRender(self, context: QgsRenderContext) -> None: ...
    def requiredLayers(self, context: QgsRenderContext, tileZoom: int) -> set[str]: ...
    def startRender(self, context: QgsRenderContext, tileZoom: int, tileRange: QgsTileRange) -> None: ...
    def clone(self) -> 'QgsVectorTileBasicRenderer|None': ...
    def type(self) -> str: ...


class QgsVectorTileLayer(QgsMapLayer):

    class LayerOptions(PyQt6.sip.wrapper):

        transformContext = ... # type: QgsCoordinateTransformContext

        @typing.overload
        def __init__(self, transformContext: QgsCoordinateTransformContext = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorTileLayer.LayerOptions') -> None: ...

    def __init__(self, path: str|None = ..., baseName: str|None = ..., options: 'QgsVectorTileLayer.LayerOptions' = ...) -> None: ...

    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def removeSelection(self) -> None: ...
    def selectByGeometry(self, geometry: QgsGeometry, context: QgsSelectionContext, behavior: Qgis.SelectBehavior = ..., relationship: Qgis.SelectGeometryRelationship = ..., flags: Qgis.SelectionFlag = ..., renderContext: QgsRenderContext|None = ...) -> None: ...
    def selectedFeatureCount(self) -> int: ...
    def selectedFeatures(self) -> list[QgsFeature]: ...
    def isTileBorderRenderingEnabled(self) -> bool: ...
    def setTileBorderRenderingEnabled(self, enabled: bool) -> None: ...
    def setLabelsEnabled(self, enabled: bool) -> None: ...
    def labelsEnabled(self) -> bool: ...
    def labeling(self) -> QgsVectorTileLabeling|None: ...
    def setLabeling(self, labeling: QgsVectorTileLabeling|None) -> None: ...
    def renderer(self) -> QgsVectorTileRenderer|None: ...
    def setRenderer(self, r: QgsVectorTileRenderer|None) -> None: ...
    def sourceMaxZoom(self) -> int: ...
    def sourceMinZoom(self) -> int: ...
    def sourcePath(self) -> str: ...
    def sourceType(self) -> str: ...
    def tileMatrixSet(self) -> 'QgsVectorTileMatrixSet': ...
    def htmlMetadata(self) -> str: ...
    def decodedSource(self, source: str|None, provider: str|None, context: QgsReadWriteContext) -> str: ...
    def encodedSource(self, source: str|None, context: QgsReadWriteContext) -> str: ...
    def loadDefaultMetadata(self) -> typing.Tuple[str, bool]: ...
    def loadDefaultStyleAndSubLayers(self, error: str|None, warnings: collections.abc.Iterable[str|None]) -> typing.Tuple[bool, list[QgsMapLayer]]: ...
    def properties(self) -> Qgis.MapLayerProperty: ...
    def loadDefaultStyle(self) -> typing.Tuple[str, bool]: ...
    def setTransformContext(self, transformContext: QgsCoordinateTransformContext) -> None: ...
    def writeSymbology(self, node: QtXml.QDomNode, doc: QtXml.QDomDocument, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def readSymbology(self, node: QtXml.QDomNode, errorMessage: str|None, context: QgsReadWriteContext, categories: QgsMapLayer.StyleCategory = ...) -> bool: ...
    def writeXml(self, layerNode: QtXml.QDomNode, doc: QtXml.QDomDocument, context: QgsReadWriteContext) -> bool: ...
    def readXml(self, layerNode: QtXml.QDomNode, context: QgsReadWriteContext) -> bool: ...
    def createMapRenderer(self, rendererContext: QgsRenderContext) -> QgsMapLayerRenderer|None: ...
    def dataProvider(self) -> QgsDataProvider|None: ...
    def clone(self) -> 'QgsVectorTileLayer|None': ...
    def __repr__(self) -> typing.Any: ...


class QgsVectorTileMatrixSet(QgsTileMatrixSet):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileMatrixSet') -> None: ...

    def fromEsriJson(self, json: dict[str|None, typing.Any], rootTileMap: dict[str|None, typing.Any] = ...) -> bool: ...
    @staticmethod
    def fromWebMercator(minimumZoom: int = ..., maximumZoom: int = ...) -> 'QgsVectorTileMatrixSet': ...


class QgsVectorTileRendererData(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, id: QgsTileXYZ) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileRendererData') -> None: ...

    def layerFeatures(self, layerName: str|None) -> list[QgsFeature]: ...
    def layers(self) -> list[str]: ...
    def fields(self) -> dict[str, QgsFields]: ...
    def setFields(self, fields: dict[str|None, QgsFields]) -> None: ...
    def renderZoomLevel(self) -> int: ...
    def setRenderZoomLevel(self, level: int) -> None: ...
    def tilePolygon(self) -> QtGui.QPolygon: ...
    def setTilePolygon(self, polygon: QtGui.QPolygon) -> None: ...
    def id(self) -> QgsTileXYZ: ...


class QgsVectorTileUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileUtils') -> None: ...

    @staticmethod
    def resolveMapboxUri(uri: str|None, accessToken: str|None) -> str: ...
    @staticmethod
    def loadSprites(styleDefinition: dict[str|None, typing.Any], context: QgsMapBoxGlStyleConversionContext, styleUrl: str|None = ...) -> None: ...
    @staticmethod
    def checkXYZUrlTemplate(url: str|None) -> bool: ...
    @staticmethod
    def formatXYZUrlTemplate(url: str|None, tile: QgsTileXYZ, tileMatrix: QgsTileMatrix) -> str: ...
    @staticmethod
    def makeVectorLayerForTile(mvt: QgsVectorTileLayer|None, tileID: QgsTileXYZ, layerName: str|None) -> QgsVectorLayer|None: ...
    @staticmethod
    def scaleToZoomLevel(mapScale: float, sourceMinZoom: int, sourceMaxZoom: int, z0Scale: float = ...) -> int: ...
    @staticmethod
    def scaleToZoom(mapScale: float, z0Scale: float = ...) -> float: ...
    @staticmethod
    def makeQgisFields(flds: collections.abc.Iterable[str|None]) -> QgsFields: ...
    @staticmethod
    def tilePolygon(id: QgsTileXYZ, ct: QgsCoordinateTransform, tm: QgsTileMatrix, mtp: QgsMapToPixel) -> QtGui.QPolygon: ...
    @staticmethod
    def sortTilesByDistanceFromCenter(tiles: collections.abc.Iterable[QgsTileXYZ], center: QtCore.QPointF) -> None: ...
    @staticmethod
    def updateUriSources(uri: str|None, forceUpdate: bool = ...) -> str: ...


class QgsVectorTileWriter(PyQt6.sip.wrapper):

    class Layer(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self, layer: QgsVectorLayer|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsVectorTileWriter.Layer') -> None: ...

        def setMaxZoom(self, maxzoom: int) -> None: ...
        def maxZoom(self) -> int: ...
        def setMinZoom(self, minzoom: int) -> None: ...
        def minZoom(self) -> int: ...
        def setLayerName(self, name: str|None) -> None: ...
        def layerName(self) -> str: ...
        def setFilterExpression(self, expr: str|None) -> None: ...
        def filterExpression(self) -> str: ...
        def layer(self) -> QgsVectorLayer|None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsVectorTileWriter') -> None: ...

    def writeSingleTile(self, tileID: QgsTileXYZ, feedback: QgsFeedback|None = ..., buffer: int = ..., resolution: int = ...) -> QtCore.QByteArray: ...
    def fullExtent(self) -> QgsRectangle: ...
    def errorMessage(self) -> str: ...
    def writeTiles(self, feedback: QgsFeedback|None = ...) -> bool: ...
    def setRootTileMatrix(self, tileMatrix: QgsTileMatrix) -> bool: ...
    def setTransformContext(self, transformContext: QgsCoordinateTransformContext) -> None: ...
    def setMetadata(self, metadata: dict[str|None, typing.Any]) -> None: ...
    def setLayers(self, layers: collections.abc.Iterable['QgsVectorTileWriter.Layer']) -> None: ...
    def setMaxZoom(self, maxZoom: int) -> None: ...
    def setMinZoom(self, minZoom: int) -> None: ...
    def setExtent(self, extent: QgsRectangle) -> None: ...
    def setDestinationUri(self, uri: str|None) -> None: ...


class QgsVtpkTiles(PyQt6.sip.wrapper):

    def __init__(self, filename: str|None) -> None: ...

    def tileData(self, z: int, x: int, y: int) -> QtCore.QByteArray: ...
    def extent(self, context: QgsCoordinateTransformContext) -> QgsRectangle: ...
    def crs(self) -> QgsCoordinateReferenceSystem: ...
    def matrixSet(self) -> QgsVectorTileMatrixSet: ...
    def rootTileMap(self) -> dict[str, typing.Any]: ...
    def layerMetadata(self) -> QgsLayerMetadata: ...
    def spriteImage(self) -> QtGui.QImage: ...
    def spriteDefinition(self) -> dict[str, typing.Any]: ...
    def styleDefinition(self) -> dict[str, typing.Any]: ...
    def metadata(self) -> dict[str, typing.Any]: ...
    def isOpen(self) -> bool: ...
    def open(self) -> bool: ...


class QgsAuthCertUtils(PyQt6.sip.wrapper):

    class ConstraintGroup(enum.IntEnum):
        KeyUsage = ... # type: QgsAuthCertUtils.ConstraintGroup
        ExtendedKeyUsage = ... # type: QgsAuthCertUtils.ConstraintGroup

    class CertUsageType(enum.IntEnum):
        UndeterminedUsage = ... # type: QgsAuthCertUtils.CertUsageType
        AnyOrUnspecifiedUsage = ... # type: QgsAuthCertUtils.CertUsageType
        CertAuthorityUsage = ... # type: QgsAuthCertUtils.CertUsageType
        CertIssuerUsage = ... # type: QgsAuthCertUtils.CertUsageType
        TlsServerUsage = ... # type: QgsAuthCertUtils.CertUsageType
        TlsServerEvUsage = ... # type: QgsAuthCertUtils.CertUsageType
        TlsClientUsage = ... # type: QgsAuthCertUtils.CertUsageType
        CodeSigningUsage = ... # type: QgsAuthCertUtils.CertUsageType
        EmailProtectionUsage = ... # type: QgsAuthCertUtils.CertUsageType
        TimeStampingUsage = ... # type: QgsAuthCertUtils.CertUsageType
        CRLSigningUsage = ... # type: QgsAuthCertUtils.CertUsageType

    class CertTrustPolicy(enum.IntEnum):
        DefaultTrust = ... # type: QgsAuthCertUtils.CertTrustPolicy
        Trusted = ... # type: QgsAuthCertUtils.CertTrustPolicy
        Untrusted = ... # type: QgsAuthCertUtils.CertTrustPolicy
        NoPolicy = ... # type: QgsAuthCertUtils.CertTrustPolicy

    class CaCertSource(enum.IntEnum):
        SystemRoot = ... # type: QgsAuthCertUtils.CaCertSource
        FromFile = ... # type: QgsAuthCertUtils.CaCertSource
        InDatabase = ... # type: QgsAuthCertUtils.CaCertSource
        Connection = ... # type: QgsAuthCertUtils.CaCertSource

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAuthCertUtils') -> None: ...

    @staticmethod
    def validatePKIBundle(bundle: 'QgsPkiBundle', useIntermediates: bool = ..., trustRootCa: bool = ...) -> list[str]: ...
    @staticmethod
    def validateCertChain(certificateChain: collections.abc.Iterable[QtNetwork.QSslCertificate], hostName: str|None = ..., trustRootCa: bool = ...) -> list[QtNetwork.QSslError]: ...
    @staticmethod
    def certIsViable(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def certViabilityErrors(cert: QtNetwork.QSslCertificate) -> list[QtNetwork.QSslError]: ...
    @staticmethod
    def certIsCurrent(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def sslErrorEnumString(errenum: QtNetwork.QSslError.SslError) -> str: ...
    @staticmethod
    def certificateIsSslClient(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def certificateIsSslServer(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def certificateIsAuthorityOrIssuer(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def certificateIsIssuer(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def certificateIsAuthority(cert: QtNetwork.QSslCertificate) -> bool: ...
    @staticmethod
    def certificateUsageTypes(cert: QtNetwork.QSslCertificate) -> list['QgsAuthCertUtils.CertUsageType']: ...
    @staticmethod
    def shaHexForCert(cert: QtNetwork.QSslCertificate, formatted: bool = ...) -> str: ...
    @staticmethod
    def getColonDelimited(txt: str|None) -> str: ...
    @staticmethod
    def getCertTrustName(trust: 'QgsAuthCertUtils.CertTrustPolicy') -> str: ...
    @staticmethod
    def resolvedCertName(cert: QtNetwork.QSslCertificate, issuer: bool = ...) -> str: ...
    @staticmethod
    def getCaSourceName(source: 'QgsAuthCertUtils.CaCertSource', single: bool = ...) -> str: ...
    @staticmethod
    def pemTextToTempFile(name: str|None, pemtext: QtCore.QByteArray|bytes|bytearray|memoryview) -> str: ...
    @staticmethod
    def certsToPemText(certs: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> QtCore.QByteArray: ...
    @staticmethod
    def pkcs12BundleCas(bundlepath: str|None, bundlepass: str|None = ...) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def pkcs12BundleToPem(bundlepath: str|None, bundlepass: str|None = ..., reencrypt: bool = ...) -> list[str]: ...
    @staticmethod
    def pemIsPkcs8(keyPemTxt: str|None) -> bool: ...
    @staticmethod
    def certKeyBundleToPem(certpath: str|None, keypath: str|None, keypass: str|None = ..., reencrypt: bool = ...) -> list[str]: ...
    @staticmethod
    def casRemoveSelfSigned(caList: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def certsFromString(pemtext: str|None) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def keyFromFile(keypath: str|None, keypass: str|None = ..., algtype: str|None = ...) -> QtNetwork.QSslKey: ...
    @staticmethod
    def casMerge(bundle1: collections.abc.Iterable[QtNetwork.QSslCertificate], bundle2: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def certFromFile(certpath: str|None) -> QtNetwork.QSslCertificate: ...
    @staticmethod
    def casFromFile(certspath: str|None) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def certsFromFile(certspath: str|None) -> list[QtNetwork.QSslCertificate]: ...
    @staticmethod
    def fileData(path: str|None) -> QtCore.QByteArray: ...
    @staticmethod
    def mapDigestToSslConfigs(configs: collections.abc.Iterable['QgsAuthConfigSslServer']) -> dict[str, 'QgsAuthConfigSslServer']: ...
    @staticmethod
    def mapDigestToCerts(certs: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> dict[str, QtNetwork.QSslCertificate]: ...
    @staticmethod
    def getSslProtocolName(protocol: QtNetwork.QSsl.SslProtocol) -> str: ...


class QgsAuthMethodConfig(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, method: str|None = ..., version: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAuthMethodConfig') -> None: ...

    def readXml(self, element: QtXml.QDomElement) -> bool: ...
    def writeXml(self, parentElement: QtXml.QDomElement, document: QtXml.QDomDocument) -> bool: ...
    @staticmethod
    def uriToResource(accessurl: str|None, resource: str|None, withpath: bool = ...) -> bool: ...
    def clearConfigMap(self) -> None: ...
    def hasConfig(self, key: str|None) -> bool: ...
    def configList(self, key: str|None) -> list[str]: ...
    def config(self, key: str|None, defaultvalue: str|None = ...) -> str: ...
    def removeConfig(self, key: str|None) -> int: ...
    def setConfigList(self, key: str|None, value: collections.abc.Iterable[str|None]) -> None: ...
    def setConfig(self, key: str|None, value: str|None) -> None: ...
    def setConfigMap(self, map: dict[str|None, str|None]) -> None: ...
    def configMap(self) -> dict[str, str]: ...
    def loadConfigString(self, configstr: str|None) -> None: ...
    def configString(self) -> str: ...
    def isValid(self, validateid: bool = ...) -> bool: ...
    def setVersion(self, version: int) -> None: ...
    def version(self) -> int: ...
    def setMethod(self, method: str|None) -> None: ...
    def method(self) -> str: ...
    def setUri(self, uri: str|None) -> None: ...
    def uri(self) -> str: ...
    def setName(self, name: str|None) -> None: ...
    def name(self) -> str: ...
    def setId(self, id: str|None) -> None: ...
    def id(self) -> str: ...
    def __ne__(self, other: object): ...
    def __eq__(self, other: object): ...


class QgsPkiBundle(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, clientCert: QtNetwork.QSslCertificate = ..., clientKey: QtNetwork.QSslKey = ..., caChain: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPkiBundle') -> None: ...

    def setCaChain(self, cachain: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> None: ...
    def caChain(self) -> list[QtNetwork.QSslCertificate]: ...
    def setClientKey(self, certkey: QtNetwork.QSslKey) -> None: ...
    def clientKey(self) -> QtNetwork.QSslKey: ...
    def setClientCert(self, cert: QtNetwork.QSslCertificate) -> None: ...
    def clientCert(self) -> QtNetwork.QSslCertificate: ...
    def certId(self) -> str: ...
    def isValid(self) -> bool: ...
    def isNull(self) -> bool: ...
    @staticmethod
    def fromPkcs12Paths(bundlepath: str|None, bundlepass: str|None = ...) -> 'QgsPkiBundle': ...
    @staticmethod
    def fromPemPaths(certPath: str|None, keyPath: str|None, keyPass: str|None = ..., caChain: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> 'QgsPkiBundle': ...


class QgsPkiConfigBundle(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, config: QgsAuthMethodConfig, cert: QtNetwork.QSslCertificate, certkey: QtNetwork.QSslKey, cachain: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsPkiConfigBundle') -> None: ...

    def setCaChain(self, caChain: collections.abc.Iterable[QtNetwork.QSslCertificate]) -> None: ...
    def caChain(self) -> list[QtNetwork.QSslCertificate]: ...
    def setClientCertKey(self, certkey: QtNetwork.QSslKey) -> None: ...
    def clientCertKey(self) -> QtNetwork.QSslKey: ...
    def setClientCert(self, cert: QtNetwork.QSslCertificate) -> None: ...
    def clientCert(self) -> QtNetwork.QSslCertificate: ...
    def setConfig(self, config: QgsAuthMethodConfig) -> None: ...
    def config(self) -> QgsAuthMethodConfig: ...
    def isValid(self) -> bool: ...


class QgsAuthConfigSslServer(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAuthConfigSslServer') -> None: ...

    def isNull(self) -> bool: ...
    def loadConfigString(self, config: str|None = ...) -> None: ...
    def configString(self) -> str: ...
    def setQtVersion(self, version: int) -> None: ...
    def qtVersion(self) -> int: ...
    def setVersion(self, version: int) -> None: ...
    def version(self) -> int: ...
    def setSslPeerVerifyDepth(self, depth: int) -> None: ...
    def sslPeerVerifyDepth(self) -> int: ...
    def setSslPeerVerifyMode(self, mode: QtNetwork.QSslSocket.PeerVerifyMode) -> None: ...
    def sslPeerVerifyMode(self) -> QtNetwork.QSslSocket.PeerVerifyMode: ...
    def setSslIgnoredErrorEnums(self, errors: collections.abc.Iterable[QtNetwork.QSslError.SslError]) -> None: ...
    def sslIgnoredErrorEnums(self) -> list[QtNetwork.QSslError.SslError]: ...
    def sslIgnoredErrors(self) -> list[QtNetwork.QSslError]: ...
    def setSslProtocol(self, protocol: QtNetwork.QSsl.SslProtocol) -> None: ...
    def sslProtocol(self) -> QtNetwork.QSsl.SslProtocol: ...
    def setSslHostPort(self, hostport: str|None) -> None: ...
    def sslHostPort(self) -> str: ...
    def setSslCertificate(self, cert: QtNetwork.QSslCertificate) -> None: ...
    def sslCertificate(self) -> QtNetwork.QSslCertificate: ...


class QgsAuthConfigurationStorage(QtCore.QObject):

    class MasterPasswordConfig(PyQt6.sip.wrapper):

        civ = ... # type: str|None
        hash = ... # type: str|None
        salt = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAuthConfigurationStorage.MasterPasswordConfig') -> None: ...

    class SettingParameter(PyQt6.sip.wrapper):

        description = ... # type: str|None
        name = ... # type: str|None
        type = ... # type: typing.Any

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAuthConfigurationStorage.SettingParameter') -> None: ...

    def __init__(self, settings: dict[str|None, typing.Any]) -> None: ...

    def loggerTag(self) -> str: ...
    def setError(self, error: str|None, level: Qgis.MessageLevel = ...) -> None: ...
    def setCapabilities(self, capabilities: Qgis.AuthConfigurationStorageCapability) -> None: ...
    sslCertTrustPolicyChanged: typing.ClassVar[QtCore.pyqtSignal]
    sslCertCustomConfigChanged: typing.ClassVar[QtCore.pyqtSignal]
    certAuthorityChanged: typing.ClassVar[QtCore.pyqtSignal]
    certIdentityChanged: typing.ClassVar[QtCore.pyqtSignal]
    readOnlyChanged: typing.ClassVar[QtCore.pyqtSignal]
    authSettingsChanged: typing.ClassVar[QtCore.pyqtSignal]
    masterPasswordChanged: typing.ClassVar[QtCore.pyqtSignal]
    methodConfigChanged: typing.ClassVar[QtCore.pyqtSignal]
    storageChanged: typing.ClassVar[QtCore.pyqtSignal]
    messageLog: typing.ClassVar[QtCore.pyqtSignal]
    def clearMethodConfigs(self) -> bool: ...
    def erase(self) -> bool: ...
    def clearMasterPasswords(self) -> bool: ...
    def storeMasterPassword(self, config: 'QgsAuthConfigurationStorage.MasterPasswordConfig') -> bool: ...
    def masterPasswords(self) -> list['QgsAuthConfigurationStorage.MasterPasswordConfig']: ...
    def certTrustPolicyExists(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def removeCertTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def loadCertTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> QgsAuthCertUtils.CertTrustPolicy: ...
    def storeCertTrustPolicy(self, cert: QtNetwork.QSslCertificate, policy: QgsAuthCertUtils.CertTrustPolicy) -> bool: ...
    def caCerts(self) -> list[QtNetwork.QSslCertificate]: ...
    def caCertsPolicy(self) -> dict[str, QgsAuthCertUtils.CertTrustPolicy]: ...
    def removeCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def certAuthorityExists(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def loadCertAuthority(self, id: str|None) -> QtNetwork.QSslCertificate: ...
    def certAuthorityIds(self) -> list[str]: ...
    def storeCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def removeSslCertCustomConfig(self, id: str|None, hostport: str|None) -> bool: ...
    def sslCertCustomConfigExists(self, id: str|None, hostport: str|None) -> bool: ...
    def sslCertCustomConfigIds(self) -> list[str]: ...
    def sslCertCustomConfigs(self) -> list[QgsAuthConfigSslServer]: ...
    def loadSslCertCustomConfigByHost(self, hostport: str|None) -> QgsAuthConfigSslServer: ...
    def loadSslCertCustomConfig(self, id: str|None, hostport: str|None) -> QgsAuthConfigSslServer: ...
    def storeSslCertCustomConfig(self, config: QgsAuthConfigSslServer) -> bool: ...
    def certIdentityExists(self, id: str|None) -> bool: ...
    def certIdentityIds(self) -> list[str]: ...
    def certIdentities(self) -> list[QtNetwork.QSslCertificate]: ...
    def loadCertIdentityBundle(self, id: str|None) -> tuple[QtNetwork.QSslCertificate, str]: ...
    def loadCertIdentity(self, id: str|None) -> QtNetwork.QSslCertificate: ...
    @typing.overload
    def removeCertIdentity(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    @typing.overload
    def removeCertIdentity(self, id: str|None) -> bool: ...
    def storeCertIdentity(self, cert: QtNetwork.QSslCertificate, keyPem: str|None) -> bool: ...
    def authSettingExists(self, key: str|None) -> bool: ...
    def removeAuthSetting(self, key: str|None) -> bool: ...
    def loadAuthSetting(self, key: str|None) -> str: ...
    def storeAuthSetting(self, key: str|None, value: str|None) -> bool: ...
    def methodConfigExists(self, id: str|None) -> bool: ...
    def removeMethodConfig(self, id: str|None) -> bool: ...
    def storeMethodConfig(self, config: QgsAuthMethodConfig, payload: str|None) -> bool: ...
    def loadMethodConfig(self, id: str|None, full: bool = ...) -> typing.Tuple[QgsAuthMethodConfig, str]: ...
    def authMethodConfigsWithPayload(self) -> dict[str, QgsAuthMethodConfig]: ...
    def authMethodConfigs(self, allowedMethods: collections.abc.Iterable[str|None] = ...) -> dict[str, QgsAuthMethodConfig]: ...
    def isReadOnly(self) -> bool: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def isEnabled(self) -> bool: ...
    def isEncrypted(self) -> bool: ...
    def settingsParameters(self) -> list['QgsAuthConfigurationStorage.SettingParameter']: ...
    def settings(self) -> dict[str, typing.Any]: ...
    def capabilities(self) -> Qgis.AuthConfigurationStorageCapability: ...
    def isReady(self) -> bool: ...
    def lastError(self) -> str: ...
    def initialize(self) -> bool: ...
    def id(self) -> str: ...
    def description(self) -> str: ...
    def type(self) -> str: ...
    def name(self) -> str: ...


class QgsAuthConfigurationStorageRegistry(QtCore.QObject):

    def __init__(self) -> None: ...

    storageRemoved: typing.ClassVar[QtCore.pyqtSignal]
    storageChanged: typing.ClassVar[QtCore.pyqtSignal]
    storageAdded: typing.ClassVar[QtCore.pyqtSignal]
    def setStorageOrder(self, orderIds: collections.abc.Iterable[str|None]) -> None: ...
    def storage(self, id: str|None) -> QgsAuthConfigurationStorage|None: ...
    def firstReadyStorageWithCapability(self, capability: Qgis.AuthConfigurationStorageCapability) -> QgsAuthConfigurationStorage|None: ...
    def readyStoragesWithCapability(self, capability: Qgis.AuthConfigurationStorageCapability) -> list[QgsAuthConfigurationStorage]: ...
    def readyStorages(self) -> list[QgsAuthConfigurationStorage]: ...
    def storages(self) -> list[QgsAuthConfigurationStorage]: ...
    def removeStorage(self, id: str|None) -> bool: ...
    def addStorage(self, storage: QgsAuthConfigurationStorage|None) -> bool: ...


class QgsAuthMethod(QtCore.QObject):

    class Expansion(enum.IntEnum):
        NetworkRequest = ... # type: QgsAuthMethod.Expansion
        NetworkReply = ... # type: QgsAuthMethod.Expansion
        DataSourceUri = ... # type: QgsAuthMethod.Expansion
        GenericDataSourceUri = ... # type: QgsAuthMethod.Expansion
        NetworkProxy = ... # type: QgsAuthMethod.Expansion
        All = ... # type: QgsAuthMethod.Expansion

    def __init__(self) -> None: ...

    def setDataProviders(self, dataproviders: collections.abc.Iterable[str|None]) -> None: ...
    def setExpansions(self, expansions: 'QgsAuthMethod.Expansion') -> None: ...
    def setVersion(self, version: int) -> None: ...
    @staticmethod
    def authMethodTag() -> str: ...
    def updateMethodConfig(self, mconfig: QgsAuthMethodConfig) -> None: ...
    def clearCachedConfig(self, authcfg: str|None) -> None: ...
    def updateNetworkProxy(self, proxy: QtNetwork.QNetworkProxy, authcfg: str|None, dataprovider: str|None = ...) -> bool: ...
    def updateDataSourceUriItems(self, connectionItems: collections.abc.Iterable[str|None], authcfg: str|None, dataprovider: str|None = ...) -> bool: ...
    def updateNetworkReply(self, reply: QtNetwork.QNetworkReply|None, authcfg: str|None, dataprovider: str|None = ...) -> bool: ...
    def updateNetworkRequest(self, request: QtNetwork.QNetworkRequest, authcfg: str|None, dataprovider: str|None = ...) -> bool: ...
    def supportedDataProviders(self) -> list[str]: ...
    def supportedExpansions(self) -> 'QgsAuthMethod.Expansion': ...
    def editWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def version(self) -> int: ...
    def displayDescription(self) -> str: ...
    def description(self) -> str: ...
    def key(self) -> str: ...


class QgsAuthConfigurationStorageDb(QgsAuthConfigurationStorage):

    @typing.overload
    def __init__(self, settings: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, uri: str|None) -> None: ...

    def checkCapabilities(self) -> None: ...
    def createCertTables(self) -> bool: ...
    def createConfigTables(self) -> bool: ...
    def authDbTransactionQuery(self, query: QtSql.QSqlQuery|None) -> bool: ...
    def authDbQuery(self, query: QtSql.QSqlQuery|None, sql: str|None = ...) -> bool: ...
    def authDbOpen(self) -> bool: ...
    def quotedQualifiedIdentifier(self, identifier: str|None, isIndex: bool = ...) -> str: ...
    def tableExists(self, table: str|None) -> bool: ...
    def masterPasswordTableName(self) -> str: ...
    def certTrustPolicyTableName(self) -> str: ...
    def sslCertCustomConfigTableName(self) -> str: ...
    def certAuthorityTableName(self) -> str: ...
    def certIdentityTableName(self) -> str: ...
    def authSettingsTableName(self) -> str: ...
    def methodConfigTableName(self) -> str: ...
    def clearMasterPasswords(self) -> bool: ...
    def storeMasterPassword(self, config: QgsAuthConfigurationStorage.MasterPasswordConfig) -> bool: ...
    def masterPasswords(self) -> list[QgsAuthConfigurationStorage.MasterPasswordConfig]: ...
    def certTrustPolicyExists(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def removeCertTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def loadCertTrustPolicy(self, cert: QtNetwork.QSslCertificate) -> QgsAuthCertUtils.CertTrustPolicy: ...
    def storeCertTrustPolicy(self, cert: QtNetwork.QSslCertificate, policy: QgsAuthCertUtils.CertTrustPolicy) -> bool: ...
    def caCerts(self) -> list[QtNetwork.QSslCertificate]: ...
    def caCertsPolicy(self) -> dict[str, QgsAuthCertUtils.CertTrustPolicy]: ...
    def removeCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def certAuthorityExists(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def loadCertAuthority(self, id: str|None) -> QtNetwork.QSslCertificate: ...
    def certAuthorityIds(self) -> list[str]: ...
    def storeCertAuthority(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    def removeSslCertCustomConfig(self, id: str|None, hostport: str|None) -> bool: ...
    def sslCertCustomConfigExists(self, id: str|None, hostport: str|None) -> bool: ...
    def sslCertCustomConfigs(self) -> list[QgsAuthConfigSslServer]: ...
    def loadSslCertCustomConfigByHost(self, hostport: str|None) -> QgsAuthConfigSslServer: ...
    def loadSslCertCustomConfig(self, id: str|None, hostport: str|None) -> QgsAuthConfigSslServer: ...
    def sslCertCustomConfigIds(self) -> list[str]: ...
    def storeSslCertCustomConfig(self, config: QgsAuthConfigSslServer) -> bool: ...
    def certIdentityExists(self, id: str|None) -> bool: ...
    def certIdentityIds(self) -> list[str]: ...
    def certIdentities(self) -> list[QtNetwork.QSslCertificate]: ...
    def loadCertIdentityBundle(self, id: str|None) -> tuple[QtNetwork.QSslCertificate, str]: ...
    def loadCertIdentity(self, id: str|None) -> QtNetwork.QSslCertificate: ...
    @typing.overload
    def removeCertIdentity(self, cert: QtNetwork.QSslCertificate) -> bool: ...
    @typing.overload
    def removeCertIdentity(self, id: str|None) -> bool: ...
    def storeCertIdentity(self, cert: QtNetwork.QSslCertificate, keyPem: str|None) -> bool: ...
    def settingsParameters(self) -> list[QgsAuthConfigurationStorage.SettingParameter]: ...
    def initialize(self) -> bool: ...
    def isReady(self) -> bool: ...
    def erase(self) -> bool: ...
    def clearMethodConfigs(self) -> bool: ...
    def authSettingExists(self, key: str|None) -> bool: ...
    def removeAuthSetting(self, key: str|None) -> bool: ...
    def loadAuthSetting(self, key: str|None) -> str: ...
    def storeAuthSetting(self, key: str|None, value: str|None) -> bool: ...
    def methodConfigExists(self, id: str|None) -> bool: ...
    def removeMethodConfig(self, id: str|None) -> bool: ...
    def storeMethodConfig(self, mconfig: QgsAuthMethodConfig, payload: str|None) -> bool: ...
    def loadMethodConfig(self, id: str|None, full: bool = ...) -> typing.Tuple[QgsAuthMethodConfig, str]: ...
    def authMethodConfigsWithPayload(self) -> dict[str, QgsAuthMethodConfig]: ...
    def authMethodConfigs(self, allowedMethods: collections.abc.Iterable[str|None] = ...) -> dict[str, QgsAuthMethodConfig]: ...
    def id(self) -> str: ...
    def description(self) -> str: ...
    def type(self) -> str: ...
    def name(self) -> str: ...
    def authDatabaseConnection(self) -> QtSql.QSqlDatabase: ...


class QgsWebEnginePage(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    loadFinished: typing.ClassVar[QtCore.pyqtSignal]
    loadProgress: typing.ClassVar[QtCore.pyqtSignal]
    loadStarted: typing.ClassVar[QtCore.pyqtSignal]
    def render(self, painter: QtGui.QPainter|None, painterRect: QtCore.QRectF) -> bool: ...
    def documentSize(self) -> QtCore.QSize: ...
    def setUrl(self, url: QtCore.QUrl, blocking: bool = ...) -> bool: ...
    def setHtml(self, html: str|None, baseUrl: QtCore.QUrl = ..., blocking: bool = ...) -> bool: ...
    def setContent(self, data: QtCore.QByteArray|bytes|bytearray|memoryview, mimeType: str|None = ..., baseUrl: QtCore.QUrl = ..., blocking: bool = ...) -> bool: ...


GEOCRS_ID = ... # type: int
GEOSRID = ... # type: int
GEO_EPSG_CRS_ID = ... # type: int


def stringToSymbolLayerReferenceList(a0: str|None) -> list[QgsSymbolLayerReference]: ...
def symbolLayerReferenceListToString(a0: collections.abc.Iterable[QgsSymbolLayerReference]) -> str: ...
def compareWkt(a: str|None, b: str|None, tolerance: float = ...) -> bool: ...
@deprecated("""""")
def qgsVsiPrefix(path: str|None) -> str: ...
def qgsVariantGreaterThan(lhs: typing.Any, rhs: typing.Any) -> bool: ...
def qgsVariantEqual(lhs: typing.Any, rhs: typing.Any) -> bool: ...
def qgsVariantLessThan(lhs: typing.Any, rhs: typing.Any) -> bool: ...
def qgsVariantCompare(lhs: typing.Any, rhs: typing.Any, strictTypeCheck: bool = ...) -> int: ...
def qgsPermissiveToLongLong(string: str|None) -> typing.Tuple[int, bool]: ...
def qgsPermissiveToInt(string: str|None) -> typing.Tuple[int, bool]: ...
def qgsPermissiveToDouble(string: str|None) -> typing.Tuple[float, bool]: ...
def qgsRound(number: float, places: int) -> float: ...
def qgsDoubleNearSig(a: float, b: float, significantDigits: int = ...) -> bool: ...
def qgsFloatNear(a: float, b: float, epsilon: float = ...) -> bool: ...
def qgsDoubleNear(a: float, b: float, epsilon: float = ...) -> bool: ...
def qgsNanCompatibleEquals(a: float, b: float) -> bool: ...
def qgsDoubleToString(a: float, precision: int = ...) -> str: ...
@typing.overload
def qHash(variant: typing.Any) -> int: ...
@typing.overload
def qHash(id: QgsPointCloudNodeId, seed: int = ...) -> int: ...
@typing.overload
def qHash(id: QgsSymbolLayerId) -> int: ...
@typing.overload
def qHash(r: QgsSymbolLayerReference) -> int: ...
