# The PEP 484 type hints stub file for the _gui module.
#
# Generated by SIP 6.15.3


import collections, re, typing, enum

try:
    from warnings import deprecated
except ImportError:
    pass

import PyQt6.sip

from PyQt6 import QtCore
from PyQt6 import QtXml
from PyQt6 import QtNetwork
from PyQt6 import QtGui
from PyQt6 import QtWidgets
from PyQt6 import QtSql
from PyQt6 import QtPrintSupport
from PyQt6 import QtPositioning
from PyQt6 import QtMultimedia
from PyQt6 import QtSerialPort
from qgis import _core
from PyQt6 import Qsci

# Support for QDate, QDateTime and QTime.
import datetime

# Convenient type aliases.
PYQT_SIGNAL = typing.Union[QtCore.pyqtSignal, QtCore.pyqtBoundSignal]
PYQT_SLOT = typing.Union[collections.abc.Callable[..., Any], QtCore.pyqtBoundSignal]


class QgisInterface(QtCore.QObject):

    def __init__(self) -> None: ...

    layerSavedAs: typing.ClassVar[QtCore.pyqtSignal]
    newProjectCreated: typing.ClassVar[QtCore.pyqtSignal]
    projectRead: typing.ClassVar[QtCore.pyqtSignal]
    initializationCompleted: typing.ClassVar[QtCore.pyqtSignal]
    layoutDesignerClosed: typing.ClassVar[QtCore.pyqtSignal]
    layoutDesignerWillBeClosed: typing.ClassVar[QtCore.pyqtSignal]
    layoutDesignerOpened: typing.ClassVar[QtCore.pyqtSignal]
    currentThemeChanged: typing.ClassVar[QtCore.pyqtSignal]
    currentLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    def blockActiveLayerChanges(self, blocked: bool) -> None: ...
    @deprecated("""""")
    def setGpsPanelConnection(self, connection: _core.QgsGpsConnection|None) -> None: ...
    def browserModel(self) -> 'QgsBrowserGuiModel|None': ...
    def askForDatumTransform(self, sourceCrs: _core.QgsCoordinateReferenceSystem, destinationCrs: _core.QgsCoordinateReferenceSystem) -> bool: ...
    def invalidateLocatorResults(self) -> None: ...
    def deregisterLocatorFilter(self, filter: _core.QgsLocatorFilter|None) -> None: ...
    def registerLocatorFilter(self, filter: _core.QgsLocatorFilter|None) -> None: ...
    def locatorSearch(self, searchText: str|None) -> None: ...
    def preloadForm(self, uifile: str|None) -> None: ...
    def getFeatureForm(self, l: _core.QgsVectorLayer|None, f: _core.QgsFeature) -> 'QgsAttributeDialog|None': ...
    def openFeatureForm(self, l: _core.QgsVectorLayer|None, f: _core.QgsFeature, updateFeatureOnly: bool = ..., showModal: bool = ...) -> bool: ...
    @deprecated("""""")
    def openURL(self, url: str|None, useQgisDocDirectory: bool = ...) -> None: ...
    def unregisterCustomLayoutDropHandler(self, handler: 'QgsLayoutCustomDropHandler|None') -> None: ...
    def registerCustomLayoutDropHandler(self, handler: 'QgsLayoutCustomDropHandler|None') -> None: ...
    def unregisterCustomProjectOpenHandler(self, handler: 'QgsCustomProjectOpenHandler|None') -> None: ...
    def registerCustomProjectOpenHandler(self, handler: 'QgsCustomProjectOpenHandler|None') -> None: ...
    def unregisterCustomDropHandler(self, handler: 'QgsCustomDropHandler|None') -> None: ...
    def registerCustomDropHandler(self, handler: 'QgsCustomDropHandler|None') -> None: ...
    def unregisterMapToolHandler(self, handler: 'QgsAbstractMapToolHandler|None') -> None: ...
    def registerMapToolHandler(self, handler: 'QgsAbstractMapToolHandler|None') -> None: ...
    def unregisterApplicationExitBlocker(self, blocker: 'QgsApplicationExitBlockerInterface|None') -> None: ...
    def registerApplicationExitBlocker(self, blocker: 'QgsApplicationExitBlockerInterface|None') -> None: ...
    def showApiDocumentation(self, api: _core.Qgis.DocumentationApi = ..., browser: _core.Qgis.DocumentationBrowser = ..., object: str|None = ..., module: str|None = ...) -> None: ...
    def unregisterDevToolWidgetFactory(self, factory: 'QgsDevToolWidgetFactory|None') -> None: ...
    def registerDevToolWidgetFactory(self, factory: 'QgsDevToolWidgetFactory|None') -> None: ...
    def unregisterProjectPropertiesWidgetFactory(self, factory: 'QgsOptionsWidgetFactory|None') -> None: ...
    def registerProjectPropertiesWidgetFactory(self, factory: 'QgsOptionsWidgetFactory|None') -> None: ...
    def unregisterOptionsWidgetFactory(self, factory: 'QgsOptionsWidgetFactory|None') -> None: ...
    def registerOptionsWidgetFactory(self, factory: 'QgsOptionsWidgetFactory|None') -> None: ...
    def unregisterMapLayerConfigWidgetFactory(self, factory: 'QgsMapLayerConfigWidgetFactory|None') -> None: ...
    def registerMapLayerConfigWidgetFactory(self, factory: 'QgsMapLayerConfigWidgetFactory|None') -> None: ...
    def unregisterMainWindowAction(self, action: QtGui.QAction|None) -> bool: ...
    def registerMainWindowAction(self, action: QtGui.QAction|None, defaultShortcut: str|None) -> bool: ...
    def removeWindow(self, action: QtGui.QAction|None) -> None: ...
    def addWindow(self, action: QtGui.QAction|None) -> None: ...
    def showAttributeTable(self, l: _core.QgsVectorLayer|None, filterExpression: str|None = ...) -> QtWidgets.QDialog|None: ...
    def showLayerProperties(self, l: _core.QgsMapLayer|None, page: str|None = ...) -> None: ...
    def removeDockWidget(self, dockwidget: QtWidgets.QDockWidget|None) -> None: ...
    def addTabifiedDockWidget(self, area: QtCore.Qt.DockWidgetArea, dockwidget: QtWidgets.QDockWidget|None, tabifyWith: collections.abc.Iterable[str|None] = ..., raiseTab: bool = ...) -> None: ...
    def addDockWidget(self, area: QtCore.Qt.DockWidgetArea, dockwidget: QtWidgets.QDockWidget|None) -> None: ...
    def removePluginMeshMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def addPluginToMeshMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def removePluginWebMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def addPluginToWebMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def removePluginVectorMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def addPluginToVectorMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def removePluginRasterMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def addPluginToRasterMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def removePluginDatabaseMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def addPluginToDatabaseMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def removeAddLayerAction(self, action: QtGui.QAction|None) -> None: ...
    def insertAddLayerAction(self, action: QtGui.QAction|None) -> None: ...
    def removePluginMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def addPluginToMenu(self, name: str|None, action: QtGui.QAction|None) -> None: ...
    def saveStyleSheetOptions(self, opts: dict[str|None, typing.Any]) -> None: ...
    def buildStyleSheet(self, opts: dict[str|None, typing.Any]) -> None: ...
    def showProjectPropertiesDialog(self, currentPage: str|None = ...) -> None: ...
    def showOptionsDialog(self, parent: QtWidgets.QWidget|None = ..., currentPage: str|None = ...) -> None: ...
    def openLayoutDesigner(self, layout: _core.QgsMasterLayoutInterface|None) -> 'QgsLayoutDesignerInterface|None': ...
    def showLayoutManager(self) -> None: ...
    def addUserInputWidget(self, widget: QtWidgets.QWidget|None) -> None: ...
    def openMessageLog(self, tabName: str|None = ...) -> None: ...
    @typing.overload
    def addToolBar(self, name: str|None) -> QtWidgets.QToolBar|None: ...
    @typing.overload
    def addToolBar(self, toolbar: QtWidgets.QToolBar|None, area: QtCore.Qt.ToolBarArea = ...) -> None: ...
    def removeWebToolBarIcon(self, qAction: QtGui.QAction|None) -> None: ...
    def addWebToolBarWidget(self, widget: QtWidgets.QWidget|None) -> QtGui.QAction|None: ...
    def addWebToolBarIcon(self, qAction: QtGui.QAction|None) -> int: ...
    def removeDatabaseToolBarIcon(self, qAction: QtGui.QAction|None) -> None: ...
    def addDatabaseToolBarWidget(self, widget: QtWidgets.QWidget|None) -> QtGui.QAction|None: ...
    def addDatabaseToolBarIcon(self, qAction: QtGui.QAction|None) -> int: ...
    def removeVectorToolBarIcon(self, qAction: QtGui.QAction|None) -> None: ...
    def addVectorToolBarWidget(self, widget: QtWidgets.QWidget|None) -> QtGui.QAction|None: ...
    def addVectorToolBarIcon(self, qAction: QtGui.QAction|None) -> int: ...
    def removeRasterToolBarIcon(self, qAction: QtGui.QAction|None) -> None: ...
    def addRasterToolBarIcon(self, qAction: QtGui.QAction|None) -> int: ...
    def addRasterToolBarWidget(self, widget: QtWidgets.QWidget|None) -> QtGui.QAction|None: ...
    def removeToolBarIcon(self, qAction: QtGui.QAction|None) -> None: ...
    def addToolBarWidget(self, widget: QtWidgets.QWidget|None) -> QtGui.QAction|None: ...
    def addToolBarIcon(self, qAction: QtGui.QAction|None) -> int: ...
    def pasteFromClipboard(self, a0: _core.QgsMapLayer|None) -> None: ...
    def copySelectionToClipboard(self, a0: _core.QgsMapLayer|None) -> None: ...
    def setActiveLayer(self, a0: _core.QgsMapLayer|None) -> bool: ...
    def reloadConnections(self) -> None: ...
    def newProject(self, promptToSaveFlag: bool = ...) -> bool: ...
    def addProject(self, project: str|None) -> bool: ...
    def addTiledSceneLayer(self, url: str|None, baseName: str|None, providerKey: str|None) -> _core.QgsTiledSceneLayer|None: ...
    def addPointCloudLayer(self, url: str|None, baseName: str|None, providerKey: str|None) -> _core.QgsPointCloudLayer|None: ...
    def addVectorTileLayer(self, url: str|None, baseName: str|None) -> _core.QgsVectorTileLayer|None: ...
    def addMeshLayer(self, url: str|None, baseName: str|None, providerKey: str|None) -> _core.QgsMeshLayer|None: ...
    @typing.overload
    def addRasterLayer(self, rasterLayerPath: str|None, baseName: str|None = ...) -> _core.QgsRasterLayer|None: ...
    @typing.overload
    def addRasterLayer(self, url: str|None, layerName: str|None, providerKey: str|None) -> _core.QgsRasterLayer|None: ...
    def addVectorLayer(self, vectorLayerPath: str|None, baseName: str|None, providerKey: str|None) -> _core.QgsVectorLayer|None: ...
    def zoomToActiveLayer(self) -> None: ...
    def zoomToNext(self) -> None: ...
    def zoomToPrevious(self) -> None: ...
    def zoomFull(self) -> None: ...
    def userProfileManager(self) -> _core.QgsUserProfileManager|None: ...
    def layerTreeInsertionPoint(self) -> _core.QgsLayerTreeRegistryBridge.InsertionPoint: ...
    def takeAppScreenShots(self, saveDirectory: str|None, categories: int = ...) -> None: ...
    def statusBarIface(self) -> 'QgsStatusBar|None': ...
    def messageTimeout(self) -> int: ...
    def vectorLayerTools(self) -> _core.QgsVectorLayerTools|None: ...
    @deprecated("""""")
    def actionRegularPolygonCenterCorner(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionRegularPolygonCenterPoint(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionRegularPolygon2Points(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionRectangle3PointsProjected(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionRectangle3PointsDistance(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionRectangleExtent(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionRectangleCenterPoint(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionEllipseFoci(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionEllipseExtent(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionEllipseCenterPoint(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionEllipseCenter2Points(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionCircleCenterPoint(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionCircle2TangentsPoint(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionCircle3Tangents(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionCircle3Points(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionCircle2Points(self) -> QtGui.QAction|None: ...
    def actionAbout(self) -> QtGui.QAction|None: ...
    def actionCheckQgisVersion(self) -> QtGui.QAction|None: ...
    def actionQgisHomePage(self) -> QtGui.QAction|None: ...
    def actionHelpContents(self) -> QtGui.QAction|None: ...
    def actionCustomProjection(self) -> QtGui.QAction|None: ...
    def actionOptions(self) -> QtGui.QAction|None: ...
    def actionToggleFullScreen(self) -> QtGui.QAction|None: ...
    def actionShowPythonDialog(self) -> QtGui.QAction|None: ...
    def actionPluginListSeparator(self) -> QtGui.QAction|None: ...
    def actionManagePlugins(self) -> QtGui.QAction|None: ...
    def actionShowSelectedLayers(self) -> QtGui.QAction|None: ...
    def actionHideDeselectedLayers(self) -> QtGui.QAction|None: ...
    def actionToggleSelectedLayersIndependently(self) -> QtGui.QAction|None: ...
    def actionToggleSelectedLayers(self) -> QtGui.QAction|None: ...
    def actionHideSelectedLayers(self) -> QtGui.QAction|None: ...
    def actionShowAllLayers(self) -> QtGui.QAction|None: ...
    def actionHideAllLayers(self) -> QtGui.QAction|None: ...
    def actionRemoveAllFromOverview(self) -> QtGui.QAction|None: ...
    def actionAddAllToOverview(self) -> QtGui.QAction|None: ...
    def actionAddToOverview(self) -> QtGui.QAction|None: ...
    def actionLayerProperties(self) -> QtGui.QAction|None: ...
    def actionDuplicateLayer(self) -> QtGui.QAction|None: ...
    def actionLayerSaveAs(self) -> QtGui.QAction|None: ...
    def actionCancelAllEdits(self) -> QtGui.QAction|None: ...
    def actionCancelEdits(self) -> QtGui.QAction|None: ...
    def actionRollbackAllEdits(self) -> QtGui.QAction|None: ...
    def actionRollbackEdits(self) -> QtGui.QAction|None: ...
    def actionSaveAllEdits(self) -> QtGui.QAction|None: ...
    def actionSaveEdits(self) -> QtGui.QAction|None: ...
    def actionAllEdits(self) -> QtGui.QAction|None: ...
    def actionSaveActiveLayerEdits(self) -> QtGui.QAction|None: ...
    def actionToggleEditing(self) -> QtGui.QAction|None: ...
    def actionOpenStatisticalSummary(self) -> QtGui.QAction|None: ...
    def actionOpenFieldCalculator(self) -> QtGui.QAction|None: ...
    def actionOpenTable(self) -> QtGui.QAction|None: ...
    def actionPasteLayerStyle(self) -> QtGui.QAction|None: ...
    def actionCopyLayerStyle(self) -> QtGui.QAction|None: ...
    def actionAddAmsLayer(self) -> QtGui.QAction|None: ...
    def actionAddAfsLayer(self) -> QtGui.QAction|None: ...
    def actionAddPointCloudLayer(self) -> QtGui.QAction|None: ...
    def actionAddVectorTileLayer(self) -> QtGui.QAction|None: ...
    def actionAddXyzLayer(self) -> QtGui.QAction|None: ...
    def actionAddWmsLayer(self) -> QtGui.QAction|None: ...
    def actionAddPgLayer(self) -> QtGui.QAction|None: ...
    def actionAddRasterLayer(self) -> QtGui.QAction|None: ...
    def actionAddOgrLayer(self) -> QtGui.QAction|None: ...
    def actionNewVectorLayer(self) -> QtGui.QAction|None: ...
    def actionDraw(self) -> QtGui.QAction|None: ...
    def actionShowBookmarks(self) -> QtGui.QAction|None: ...
    def actionNewBookmark(self) -> QtGui.QAction|None: ...
    def actionMapTips(self) -> QtGui.QAction|None: ...
    def actionZoomActualSize(self) -> QtGui.QAction|None: ...
    def actionZoomNext(self) -> QtGui.QAction|None: ...
    def actionZoomLast(self) -> QtGui.QAction|None: ...
    def actionZoomToSelected(self) -> QtGui.QAction|None: ...
    def actionZoomToLayers(self) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionZoomToLayer(self) -> QtGui.QAction|None: ...
    def actionZoomFullExtent(self) -> QtGui.QAction|None: ...
    def actionMeasureArea(self) -> QtGui.QAction|None: ...
    def actionMeasure(self) -> QtGui.QAction|None: ...
    def actionFeatureAction(self) -> QtGui.QAction|None: ...
    def actionIdentify(self) -> QtGui.QAction|None: ...
    def actionSelectRadius(self) -> QtGui.QAction|None: ...
    def actionSelectFreehand(self) -> QtGui.QAction|None: ...
    def actionSelectPolygon(self) -> QtGui.QAction|None: ...
    def actionSelectRectangle(self) -> QtGui.QAction|None: ...
    def actionSelect(self) -> QtGui.QAction|None: ...
    def actionZoomOut(self) -> QtGui.QAction|None: ...
    def actionZoomIn(self) -> QtGui.QAction|None: ...
    def actionPanToSelected(self) -> QtGui.QAction|None: ...
    def actionPan(self) -> QtGui.QAction|None: ...
    def mapToolActionGroup(self) -> QtGui.QActionGroup|None: ...
    def actionVertexToolActiveLayer(self) -> QtGui.QAction|None: ...
    def actionVertexTool(self) -> QtGui.QAction|None: ...
    def actionDeletePart(self) -> QtGui.QAction|None: ...
    def actionDeleteRing(self) -> QtGui.QAction|None: ...
    def actionSimplifyFeature(self) -> QtGui.QAction|None: ...
    def actionAddPart(self) -> QtGui.QAction|None: ...
    def actionAddRing(self) -> QtGui.QAction|None: ...
    def actionSplitParts(self) -> QtGui.QAction|None: ...
    def actionSplitFeatures(self) -> QtGui.QAction|None: ...
    def actionMoveFeature(self) -> QtGui.QAction|None: ...
    def actionDeleteSelected(self) -> QtGui.QAction|None: ...
    def actionAddFeature(self) -> QtGui.QAction|None: ...
    def actionPasteFeatures(self) -> QtGui.QAction|None: ...
    def actionCopyFeatures(self) -> QtGui.QAction|None: ...
    def actionCutFeatures(self) -> QtGui.QAction|None: ...
    def actionExit(self) -> QtGui.QAction|None: ...
    def actionShowLayoutManager(self) -> QtGui.QAction|None: ...
    def actionCreatePrintLayout(self) -> QtGui.QAction|None: ...
    def actionProjectProperties(self) -> QtGui.QAction|None: ...
    def actionSaveMapAsImage(self) -> QtGui.QAction|None: ...
    def actionSaveProjectAs(self) -> QtGui.QAction|None: ...
    def actionSaveProject(self) -> QtGui.QAction|None: ...
    def actionOpenProject(self) -> QtGui.QAction|None: ...
    def actionNewProject(self) -> QtGui.QAction|None: ...
    def webToolBar(self) -> QtWidgets.QToolBar|None: ...
    def databaseToolBar(self) -> QtWidgets.QToolBar|None: ...
    def vectorToolBar(self) -> QtWidgets.QToolBar|None: ...
    def rasterToolBar(self) -> QtWidgets.QToolBar|None: ...
    def helpToolBar(self) -> QtWidgets.QToolBar|None: ...
    def pluginToolBar(self) -> QtWidgets.QToolBar|None: ...
    def selectionToolBar(self) -> QtWidgets.QToolBar|None: ...
    def attributesToolBar(self) -> QtWidgets.QToolBar|None: ...
    def shapeDigitizeToolBar(self) -> QtWidgets.QToolBar|None: ...
    def advancedDigitizeToolBar(self) -> QtWidgets.QToolBar|None: ...
    def digitizeToolBar(self) -> QtWidgets.QToolBar|None: ...
    def mapNavToolToolBar(self) -> QtWidgets.QToolBar|None: ...
    def openDataSourceManagerPage(self, pageName: str|None) -> None: ...
    def dataSourceManagerToolBar(self) -> QtWidgets.QToolBar|None: ...
    def layerToolBar(self) -> QtWidgets.QToolBar|None: ...
    def fileToolBar(self) -> QtWidgets.QToolBar|None: ...
    def helpMenu(self) -> QtWidgets.QMenu|None: ...
    def windowMenu(self) -> QtWidgets.QMenu|None: ...
    def firstRightStandardMenu(self) -> QtWidgets.QMenu|None: ...
    def meshMenu(self) -> QtWidgets.QMenu|None: ...
    def webMenu(self) -> QtWidgets.QMenu|None: ...
    def vectorMenu(self) -> QtWidgets.QMenu|None: ...
    def databaseMenu(self) -> QtWidgets.QMenu|None: ...
    def rasterMenu(self) -> QtWidgets.QMenu|None: ...
    def pluginHelpMenu(self) -> QtWidgets.QMenu|None: ...
    def pluginMenu(self) -> QtWidgets.QMenu|None: ...
    def settingsMenu(self) -> QtWidgets.QMenu|None: ...
    def addLayerMenu(self) -> QtWidgets.QMenu|None: ...
    def newLayerMenu(self) -> QtWidgets.QMenu|None: ...
    def layerMenu(self) -> QtWidgets.QMenu|None: ...
    def viewMenu(self) -> QtWidgets.QMenu|None: ...
    def editMenu(self) -> QtWidgets.QMenu|None: ...
    def createProjectModelSubMenu(self, title: str|None) -> QtWidgets.QMenu|None: ...
    def projectModelsMenu(self) -> QtWidgets.QMenu|None: ...
    def removeProjectExportAction(self, action: QtGui.QAction|None) -> None: ...
    def addProjectExportAction(self, action: QtGui.QAction|None) -> None: ...
    def removeProjectImportAction(self, action: QtGui.QAction|None) -> None: ...
    def addProjectImportAction(self, action: QtGui.QAction|None) -> None: ...
    def projectImportExportMenu(self) -> QtWidgets.QMenu|None: ...
    def projectMenu(self) -> QtWidgets.QMenu|None: ...
    def cadDockWidget(self) -> 'QgsAdvancedDigitizingDockWidget|None': ...
    def defaultStyleSheetFont(self) -> QtGui.QFont: ...
    def defaultStyleSheetOptions(self) -> dict[str, typing.Any]: ...
    def openLayoutDesigners(self) -> list['QgsLayoutDesignerInterface']: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def mainWindow(self) -> QtWidgets.QWidget|None: ...
    def layerTreeCanvasBridge(self) -> 'QgsLayerTreeMapCanvasBridge|None': ...
    def activeDecorations(self) -> list[_core.QgsMapDecoration]: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def activeLayer(self) -> _core.QgsMapLayer|None: ...
    def editableLayers(self, modified: bool = ...) -> list[_core.QgsMapLayer]: ...
    def iconSize(self, dockedToolbar: bool = ...) -> QtCore.QSize: ...
    def closeMapCanvas3D(self, name: str|None) -> None: ...
    def createNewMapCanvas3D(self, name: str|None, sceneMode: _core.Qgis.SceneMode = ...) -> Qgs3DMapCanvas|None: ...
    def mapCanvases3D(self) -> list[Qgs3DMapCanvas]: ...
    def closeMapCanvas(self, name: str|None) -> None: ...
    def createNewMapCanvas(self, name: str|None) -> 'QgsMapCanvas|None': ...
    def mapCanvases(self) -> list['QgsMapCanvas']: ...
    def removeCustomActionForLayerType(self, action: QtGui.QAction|None) -> bool: ...
    def addCustomActionForLayer(self, action: QtGui.QAction|None, layer: _core.QgsMapLayer|None) -> None: ...
    def addCustomActionForLayerType(self, action: QtGui.QAction|None, menu: str|None, type: _core.Qgis.LayerType, allLayers: bool) -> None: ...
    def gpsTools(self) -> 'QgsGpsToolsInterface|None': ...
    def layerTreeView(self) -> 'QgsLayerTreeView|None': ...
    def pluginManagerInterface(self) -> 'QgsPluginManagerInterface|None': ...


class Qgs3DSymbolWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def symbolType(self) -> str: ...
    def symbol(self) -> _core.QgsAbstract3DSymbol|None: ...
    def setSymbol(self, symbol: _core.QgsAbstract3DSymbol|None, layer: _core.QgsVectorLayer|None) -> None: ...


class Qgs3DSymbolDialog(QtWidgets.QDialog):

    def __init__(self, symbol: _core.QgsAbstract3DSymbol|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def symbol(self) -> _core.QgsAbstract3DSymbol|None: ...


class QgsAbstractDataSourceWidget(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., widgetMode: _core.QgsProviderRegistry.WidgetMode = ...) -> None: ...

    def addButton(self) -> QtWidgets.QPushButton|None: ...
    def setupButtons(self, buttonBox: QtWidgets.QDialogButtonBox|None) -> None: ...
    def browserModel(self) -> _core.QgsBrowserModel|None: ...
    def widgetMode(self) -> _core.QgsProviderRegistry.WidgetMode: ...
    pushMessage: typing.ClassVar[QtCore.pyqtSignal]
    enableButtons: typing.ClassVar[QtCore.pyqtSignal]
    progressMessage: typing.ClassVar[QtCore.pyqtSignal]
    progress: typing.ClassVar[QtCore.pyqtSignal]
    replaceVectorLayer: typing.ClassVar[QtCore.pyqtSignal]
    addVectorLayers: typing.ClassVar[QtCore.pyqtSignal]
    addLayer: typing.ClassVar[QtCore.pyqtSignal]
    addPointCloudLayer: typing.ClassVar[QtCore.pyqtSignal]
    addVectorTileLayer: typing.ClassVar[QtCore.pyqtSignal]
    addMeshLayer: typing.ClassVar[QtCore.pyqtSignal]
    addVectorLayer: typing.ClassVar[QtCore.pyqtSignal]
    addRasterLayers: typing.ClassVar[QtCore.pyqtSignal]
    addRasterLayer: typing.ClassVar[QtCore.pyqtSignal]
    addDatabaseLayers: typing.ClassVar[QtCore.pyqtSignal]
    connectionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def configureFromUri(self, uri: str|None) -> bool: ...
    def reset(self) -> None: ...
    def addButtonClicked(self) -> None: ...
    def refresh(self) -> None: ...
    def setMapCanvas(self, mapCanvas: 'QgsMapCanvas|None') -> None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def setBrowserModel(self, model: _core.QgsBrowserModel|None) -> None: ...


class QgsAbstractMapToolHandler(PyQt6.sip.wrapper):

    class Context(PyQt6.sip.wrapper):

        dummy = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAbstractMapToolHandler.Context') -> None: ...

    @typing.overload
    def __init__(self, tool: 'QgsMapTool|None', action: QtGui.QAction|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractMapToolHandler') -> None: ...

    def setLayerForTool(self, layer: _core.QgsMapLayer|None) -> None: ...
    def isCompatibleWithLayer(self, layer: _core.QgsMapLayer|None, context: 'QgsAbstractMapToolHandler.Context') -> bool: ...
    def action(self) -> QtGui.QAction|None: ...
    def mapTool(self) -> 'QgsMapTool|None': ...


class QgsMapCanvasItem(QtWidgets.QGraphicsItem):

    def __init__(self, mapCanvas: 'QgsMapCanvas|None') -> None: ...

    def toCanvasCoordinates(self, point: _core.QgsPointXY) -> QtCore.QPointF: ...
    def toMapCoordinates(self, point: QtCore.QPoint) -> _core.QgsPointXY: ...
    def setRect(self, r: _core.QgsRectangle, resetRotation: bool = ...) -> None: ...
    def rect(self) -> _core.QgsRectangle: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def updatePosition(self) -> None: ...
    def setRenderContextVariables(self, p: QtGui.QPainter|None, context: _core.QgsRenderContext) -> bool: ...
    def updateCanvas(self) -> None: ...
    @typing.overload
    def paint(self, painter: QtGui.QPainter|None) -> None: ...
    @typing.overload
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...


class QgsAdvancedDigitizingCanvasItem(QgsMapCanvasItem):

    def __init__(self, canvas: 'QgsMapCanvas|None', cadDockWidget: 'QgsAdvancedDigitizingDockWidget|None') -> None: ...

    def updatePosition(self) -> None: ...
    def paint(self, painter: QtGui.QPainter|None) -> None: ...


class QgsDockWidget(QtWidgets.QDockWidget):

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    openedStateChanged: typing.ClassVar[QtCore.pyqtSignal]
    opened: typing.ClassVar[QtCore.pyqtSignal]
    closedStateChanged: typing.ClassVar[QtCore.pyqtSignal]
    closed: typing.ClassVar[QtCore.pyqtSignal]
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def closeEvent(self, a0: QtGui.QCloseEvent|None) -> None: ...
    def toggleUserVisible(self) -> None: ...
    def setUserVisible(self, visible: bool) -> None: ...
    def toggleVisibilityAction(self) -> QtGui.QAction|None: ...
    def setToggleVisibilityAction(self, action: QtGui.QAction|None) -> None: ...
    def isUserVisible(self) -> bool: ...


class QgsAdvancedDigitizingDockWidget(QgsDockWidget):

    class WidgetSetMode(enum.IntEnum):
        ReturnPressed = ... # type: QgsAdvancedDigitizingDockWidget.WidgetSetMode
        FocusOut = ... # type: QgsAdvancedDigitizingDockWidget.WidgetSetMode
        TextEdited = ... # type: QgsAdvancedDigitizingDockWidget.WidgetSetMode

    class CadCapacity(enum.IntEnum):
        AbsoluteAngle = ... # type: QgsAdvancedDigitizingDockWidget.CadCapacity
        RelativeAngle = ... # type: QgsAdvancedDigitizingDockWidget.CadCapacity
        RelativeCoordinates = ... # type: QgsAdvancedDigitizingDockWidget.CadCapacity
        Distance = ... # type: QgsAdvancedDigitizingDockWidget.CadCapacity

    class CadConstraint(PyQt6.sip.wrapper):

        class LockMode(enum.IntEnum):
            NoLock = ... # type: QgsAdvancedDigitizingDockWidget.CadConstraint.LockMode
            SoftLock = ... # type: QgsAdvancedDigitizingDockWidget.CadConstraint.LockMode
            HardLock = ... # type: QgsAdvancedDigitizingDockWidget.CadConstraint.LockMode

        @typing.overload
        def __init__(self, lineEdit: QtWidgets.QLineEdit|None, lockerButton: QtWidgets.QToolButton|None, relativeButton: QtWidgets.QToolButton|None = ..., repeatingLockButton: QtWidgets.QToolButton|None = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAdvancedDigitizingDockWidget.CadConstraint') -> None: ...

        @staticmethod
        def removeSuffix(text: str|None, constraintType: _core.Qgis.CadConstraintType) -> str: ...
        def setMapCanvas(self, mapCanvas: 'QgsMapCanvas|None') -> None: ...
        def setCadConstraintType(self, constraintType: _core.Qgis.CadConstraintType) -> None: ...
        def cadConstraintType(self) -> _core.Qgis.CadConstraintType: ...
        def setPrecision(self, precision: int) -> None: ...
        def precision(self) -> int: ...
        def toggleRelative(self) -> None: ...
        def toggleLocked(self) -> None: ...
        def displayValue(self) -> str: ...
        def setValue(self, value: float, updateWidget: bool = ...) -> None: ...
        def setRelative(self, relative: bool) -> None: ...
        def setRepeatingLock(self, repeating: bool) -> None: ...
        def setLockMode(self, mode: 'QgsAdvancedDigitizingDockWidget.CadConstraint.LockMode') -> None: ...
        def lineEdit(self) -> QtWidgets.QLineEdit|None: ...
        def value(self) -> float: ...
        def relative(self) -> bool: ...
        def isRepeatingLock(self) -> bool: ...
        def isLocked(self) -> bool: ...
        def lockMode(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint.LockMode': ...

    def __init__(self, canvas: 'QgsMapCanvas|None', parent: QtWidgets.QWidget|None = ..., userInputWidget: 'QgsUserInputWidget|None' = ...) -> None: ...

    valueCommonAngleSnappingChanged: typing.ClassVar[QtCore.pyqtSignal]
    focusOnWeightRequested: typing.ClassVar[QtCore.pyqtSignal]
    focusOnDistanceRequested: typing.ClassVar[QtCore.pyqtSignal]
    focusOnAngleRequested: typing.ClassVar[QtCore.pyqtSignal]
    focusOnMRequested: typing.ClassVar[QtCore.pyqtSignal]
    focusOnZRequested: typing.ClassVar[QtCore.pyqtSignal]
    focusOnYRequested: typing.ClassVar[QtCore.pyqtSignal]
    focusOnXRequested: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedWeight: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedDistance: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedAngle: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedM: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedZ: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedY: typing.ClassVar[QtCore.pyqtSignal]
    enabledChangedX: typing.ClassVar[QtCore.pyqtSignal]
    softLockXyChanged: typing.ClassVar[QtCore.pyqtSignal]
    softLockLineExtensionChanged: typing.ClassVar[QtCore.pyqtSignal]
    relativeAngleChanged: typing.ClassVar[QtCore.pyqtSignal]
    relativeMChanged: typing.ClassVar[QtCore.pyqtSignal]
    relativeZChanged: typing.ClassVar[QtCore.pyqtSignal]
    relativeYChanged: typing.ClassVar[QtCore.pyqtSignal]
    relativeXChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockDistanceChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockAngleChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockMChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockZChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockYChanged: typing.ClassVar[QtCore.pyqtSignal]
    lockXChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueTotalLengthChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueAreaChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueWeightChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueBearingChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueDistanceChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueAngleChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueMChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueZChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueYChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueXChanged: typing.ClassVar[QtCore.pyqtSignal]
    cadEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    pointChanged: typing.ClassVar[QtCore.pyqtSignal]
    pointChangedV2: typing.ClassVar[QtCore.pyqtSignal]
    popWarning: typing.ClassVar[QtCore.pyqtSignal]
    pushWarning: typing.ClassVar[QtCore.pyqtSignal]
    def formatCommonAngleSnapping(self, angle: float) -> str: ...
    def capacities(self) -> 'QgsAdvancedDigitizingDockWidget.CadCapacity': ...
    def weight(self) -> str: ...
    def setWeight(self, value: str|None, enabled: bool) -> None: ...
    def getLineM(self) -> float: ...
    def getLineZ(self) -> float: ...
    def setDistance(self, value: str|None, mode: 'QgsAdvancedDigitizingDockWidget.WidgetSetMode') -> None: ...
    def setAngle(self, value: str|None, mode: 'QgsAdvancedDigitizingDockWidget.WidgetSetMode') -> None: ...
    def setM(self, value: str|None, mode: 'QgsAdvancedDigitizingDockWidget.WidgetSetMode') -> None: ...
    def setZ(self, value: str|None, mode: 'QgsAdvancedDigitizingDockWidget.WidgetSetMode') -> None: ...
    def setY(self, value: str|None, mode: 'QgsAdvancedDigitizingDockWidget.WidgetSetMode') -> None: ...
    def setX(self, value: str|None, mode: 'QgsAdvancedDigitizingDockWidget.WidgetSetMode') -> None: ...
    def updateCadPaintItem(self) -> None: ...
    def disable(self) -> None: ...
    def enable(self) -> None: ...
    def enableAction(self) -> QtGui.QAction|None: ...
    def snappedSegment(self) -> list[_core.QgsPointXY]: ...
    def snappedToVertex(self) -> bool: ...
    def pointsCount(self) -> int: ...
    @deprecated("""""")
    def penultimatePoint(self) -> typing.Tuple[_core.QgsPointXY, bool]: ...
    def penultimatePointV2(self) -> typing.Tuple[_core.QgsPoint, bool]: ...
    @deprecated("""""")
    def previousPoint(self) -> typing.Tuple[_core.QgsPointXY, bool]: ...
    def previousPointV2(self) -> typing.Tuple[_core.QgsPoint, bool]: ...
    @deprecated("""""")
    def currentPoint(self) -> typing.Tuple[_core.QgsPointXY, bool]: ...
    def currentPointLayerCoordinates(self, layer: _core.QgsMapLayer|None) -> _core.QgsPoint: ...
    def currentPointV2(self) -> typing.Tuple[_core.QgsPoint, bool]: ...
    def setPoints(self, points: collections.abc.Iterable[_core.QgsPointXY]) -> None: ...
    def updateCurrentPoint(self, point: _core.QgsPoint) -> None: ...
    def removePreviousPoint(self) -> None: ...
    def addPoint(self, point: _core.QgsPointXY) -> None: ...
    def clearPoints(self) -> None: ...
    def clearLockedSnapVertices(self, force: bool = ...) -> None: ...
    def lockedSnapVertices(self) -> list[_core.QgsPointLocator.Match]: ...
    def mapPointMatch(self) -> _core.QgsPointLocator.Match: ...
    def toggleConstraintDistance(self) -> None: ...
    def softLockY(self) -> float: ...
    def softLockX(self) -> float: ...
    def constraintXyVertex(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def lineExtensionSide(self) -> _core.Qgis.LineExtensionSide: ...
    def constraintLineExtension(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def commonAngleConstraint(self) -> bool: ...
    def constraintM(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def constraintZ(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def constraintY(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def constraintX(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def constraintDistance(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def constraintAngle(self) -> 'QgsAdvancedDigitizingDockWidget.CadConstraint|None': ...
    def betweenLineConstraint(self) -> _core.Qgis.BetweenLineConstraint: ...
    def recordConstructionGuides(self) -> bool: ...
    def snapToConstructionGuides(self) -> bool: ...
    def showConstructionGuides(self) -> bool: ...
    def constructionGuidesLayer(self) -> _core.QgsVectorLayer|None: ...
    def constructionMode(self) -> bool: ...
    def setEnabledM(self, enable: bool) -> None: ...
    def setEnabledZ(self, enable: bool) -> None: ...
    def switchZM(self) -> None: ...
    def cadEnabled(self) -> bool: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def clear(self) -> None: ...
    def releaseLocks(self, releaseRepeatingLocks: bool = ...) -> None: ...
    def floater(self) -> 'QgsAdvancedDigitizingFloater|None': ...
    def tool(self) -> 'QgsAdvancedDigitizingTool|None': ...
    def setTool(self, tool: 'QgsAdvancedDigitizingTool|None') -> None: ...
    def processCanvasReleaseEvent(self, event: 'QgsMapMouseEvent|None') -> None: ...
    def processCanvasMoveEvent(self, event: 'QgsMapMouseEvent|None') -> None: ...
    def processCanvasPressEvent(self, event: 'QgsMapMouseEvent|None') -> None: ...
    def alignToSegment(self, e: 'QgsMapMouseEvent|None', lockMode: 'QgsAdvancedDigitizingDockWidget.CadConstraint.LockMode' = ...) -> bool: ...
    def applyConstraints(self, e: 'QgsMapMouseEvent|None') -> bool: ...
    def canvasKeyPressEventFilter(self, e: QtGui.QKeyEvent|None) -> bool: ...


class QgsAdvancedDigitizingFloater(QtWidgets.QWidget):

    class FloaterItem(enum.IntFlag):
        XCoordinate = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        YCoordinate = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        MCoordinate = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        ZCoordinate = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        Angle = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        CommonAngleSnapping = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        Distance = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        Bearing = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        Weight = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        Area = ... # type: QgsAdvancedDigitizingFloater.FloaterItem
        TotalLength = ... # type: QgsAdvancedDigitizingFloater.FloaterItem

    def __init__(self, canvas: 'QgsMapCanvas|None', cadDockWidget: QgsAdvancedDigitizingDockWidget|None) -> None: ...

    def focusOnWeight(self) -> None: ...
    def enabledChangedWeight(self, enabled: bool) -> None: ...
    def changeWeight(self, text: str|None) -> None: ...
    def setItemMeasurementType(self, item: 'QgsAdvancedDigitizingFloater.FloaterItem', type: _core.Qgis.CadMeasurementDisplayType) -> None: ...
    def setItemVisibility(self, item: 'QgsAdvancedDigitizingFloater.FloaterItem', visible: bool) -> None: ...
    def setActive(self, active: bool) -> None: ...
    @staticmethod
    def itemSupportsMeasurementType(item: 'QgsAdvancedDigitizingFloater.FloaterItem') -> bool: ...
    def itemMeasurementDisplayType(self, item: 'QgsAdvancedDigitizingFloater.FloaterItem') -> _core.Qgis.CadMeasurementDisplayType: ...
    def itemVisibility(self, item: 'QgsAdvancedDigitizingFloater.FloaterItem') -> bool: ...
    def active(self) -> bool: ...


class QgsAdvancedDigitizingTool(QtCore.QObject):

    def __init__(self, canvas: 'QgsMapCanvas|None', cadDockWidget: QgsAdvancedDigitizingDockWidget|None) -> None: ...

    paintRequested: typing.ClassVar[QtCore.pyqtSignal]
    def canvasReleaseEvent(self, event: 'QgsMapMouseEvent|None') -> None: ...
    def canvasMoveEvent(self, event: 'QgsMapMouseEvent|None') -> None: ...
    def canvasPressEvent(self, event: 'QgsMapMouseEvent|None') -> None: ...
    def paint(self, painter: QtGui.QPainter|None) -> None: ...
    def createWidget(self) -> QtWidgets.QWidget|None: ...
    def cadDockWidget(self) -> QgsAdvancedDigitizingDockWidget|None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...


class QgsAdvancedDigitizingToolAbstractMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, visibleName: str|None, icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAdvancedDigitizingToolAbstractMetadata') -> None: ...

    def createTool(self, canvas: 'QgsMapCanvas|None', cadDockWidget: QgsAdvancedDigitizingDockWidget|None) -> QgsAdvancedDigitizingTool|None: ...
    def icon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def name(self) -> str: ...


class QgsAdvancedDigitizingToolsRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def toolMetadataNames(self) -> list[str]: ...
    def toolMetadata(self, name: str|None) -> QgsAdvancedDigitizingToolAbstractMetadata|None: ...
    def removeTool(self, name: str|None) -> bool: ...
    def addTool(self, toolMetaData: QgsAdvancedDigitizingToolAbstractMetadata|None) -> bool: ...
    def addDefaultTools(self) -> None: ...


class QgsAggregateToolButton(QtWidgets.QToolButton):

    def __init__(self) -> None: ...

    activeChanged: typing.ClassVar[QtCore.pyqtSignal]
    aggregateChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAggregate(self, aggregate: str|None) -> None: ...
    def aggregate(self) -> str: ...
    def active(self) -> bool: ...
    def setActive(self, active: bool) -> None: ...
    def type(self) -> QtCore.QMetaType.Type: ...
    @typing.overload
    def setType(self, type: QtCore.QMetaType.Type) -> None: ...
    @typing.overload
    @deprecated("""""")
    def setType(self, type: typing.Any) -> None: ...


class QgsAlignmentComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def customizeAlignmentDisplay(self, alignment: QtCore.Qt.AlignmentFlag, text: str|None = ..., icon: QtGui.QIcon = ...) -> None: ...
    def verticalAlignment(self) -> _core.Qgis.TextVerticalAlignment: ...
    def horizontalAlignment(self) -> _core.Qgis.TextHorizontalAlignment: ...
    @typing.overload
    def setCurrentAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    @typing.overload
    def setCurrentAlignment(self, alignment: _core.Qgis.TextHorizontalAlignment) -> None: ...
    @typing.overload
    def setCurrentAlignment(self, alignment: _core.Qgis.TextVerticalAlignment) -> None: ...
    def currentAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def setAvailableAlignments(self, alignments: QtCore.Qt.AlignmentFlag) -> None: ...


class QgsApplicationExitBlockerInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsApplicationExitBlockerInterface') -> None: ...

    def allowExit(self) -> bool: ...


class QgsMapLayerActionContextGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerActionContextGenerator') -> None: ...

    def createActionContext(self) -> 'QgsMapLayerActionContext': ...


class QgsAttributeDialog(QtWidgets.QDialog, QgsMapLayerActionContextGenerator):

    def __init__(self, vl: _core.QgsVectorLayer|None, thepFeature: _core.QgsFeature|None, featureOwner: bool, parent: QtWidgets.QWidget|None = ..., showDialogButtons: bool = ..., context: 'QgsAttributeEditorContext' = ...) -> None: ...

    def show(self) -> None: ...
    def reject(self) -> None: ...
    def accept(self) -> None: ...
    def createActionContext(self) -> 'QgsMapLayerActionContext': ...
    def setExtraContextScope(self, extraScope: _core.QgsExpressionContextScope|None) -> None: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...
    def setEditCommandMessage(self, message: str|None) -> None: ...
    def setMode(self, mode: 'QgsAttributeEditorContext.Mode') -> None: ...
    def editable(self) -> bool: ...
    def feature(self) -> _core.QgsFeature|None: ...
    def attributeForm(self) -> 'QgsAttributeForm|None': ...
    def setHighlight(self, h: 'QgsHighlight|None') -> None: ...


class QgsAttributeEditorContext(PyQt6.sip.wrapper):

    class FormMode(enum.IntEnum):
        Embed = ... # type: QgsAttributeEditorContext.FormMode
        StandaloneDialog = ... # type: QgsAttributeEditorContext.FormMode
        Popup = ... # type: QgsAttributeEditorContext.FormMode

    class RelationMode(enum.IntEnum):
        Undefined = ... # type: QgsAttributeEditorContext.RelationMode
        Multiple = ... # type: QgsAttributeEditorContext.RelationMode
        Single = ... # type: QgsAttributeEditorContext.RelationMode

    class Mode(enum.IntEnum):
        SingleEditMode = ... # type: QgsAttributeEditorContext.Mode
        AddFeatureMode = ... # type: QgsAttributeEditorContext.Mode
        FixAttributeMode = ... # type: QgsAttributeEditorContext.Mode
        MultiEditMode = ... # type: QgsAttributeEditorContext.Mode
        SearchMode = ... # type: QgsAttributeEditorContext.Mode
        AggregateSearchMode = ... # type: QgsAttributeEditorContext.Mode
        IdentifyMode = ... # type: QgsAttributeEditorContext.Mode
        PreviewMode = ... # type: QgsAttributeEditorContext.Mode

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, parentContext: 'QgsAttributeEditorContext', formMode: 'QgsAttributeEditorContext.FormMode') -> None: ...
    @typing.overload
    def __init__(self, parentContext: 'QgsAttributeEditorContext', relation: _core.QgsRelation, relationMode: 'QgsAttributeEditorContext.RelationMode', widgetMode: 'QgsAttributeEditorContext.FormMode') -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeEditorContext') -> None: ...

    def mainMessageBar(self) -> 'QgsMessageBar|None': ...
    def setMainMessageBar(self, messageBar: 'QgsMessageBar|None') -> None: ...
    def attributeFormModeString(self) -> str: ...
    def setAttributeFormMode(self, attributeFormMode: 'QgsAttributeEditorContext.Mode') -> None: ...
    def attributeFormMode(self) -> 'QgsAttributeEditorContext.Mode': ...
    def setParentFormFeature(self, feature: _core.QgsFeature) -> None: ...
    def parentFormFeature(self) -> _core.QgsFeature: ...
    def setFormFeature(self, feature: _core.QgsFeature) -> None: ...
    def formFeature(self) -> _core.QgsFeature: ...
    def parentContext(self) -> 'QgsAttributeEditorContext|None': ...
    def setAllowCustomUi(self, allow: bool) -> None: ...
    def allowCustomUi(self) -> bool: ...
    def setFormMode(self, mode: 'QgsAttributeEditorContext.FormMode') -> None: ...
    def formMode(self) -> 'QgsAttributeEditorContext.FormMode': ...
    def relationMode(self) -> 'QgsAttributeEditorContext.RelationMode': ...
    def relation(self) -> _core.QgsRelation: ...
    def setRelation(self, relation: _core.QgsRelation, mode: 'QgsAttributeEditorContext.RelationMode') -> None: ...
    def vectorLayerTools(self) -> _core.QgsVectorLayerTools|None: ...
    def setVectorLayerTools(self, vlTools: _core.QgsVectorLayerTools|None) -> None: ...
    def cadDockWidget(self) -> QgsAdvancedDigitizingDockWidget|None: ...
    def setCadDockWidget(self, cadDockWidget: QgsAdvancedDigitizingDockWidget|None) -> None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def setMapCanvas(self, mapCanvas: 'QgsMapCanvas|None') -> None: ...
    def distanceArea(self) -> _core.QgsDistanceArea: ...
    def setDistanceArea(self, distanceArea: _core.QgsDistanceArea) -> None: ...


class QgsAttributeForm(QtWidgets.QWidget):

    class FilterType(enum.IntEnum):
        ReplaceFilter = ... # type: QgsAttributeForm.FilterType
        FilterAnd = ... # type: QgsAttributeForm.FilterType
        FilterOr = ... # type: QgsAttributeForm.FilterType

    class Mode(enum.IntEnum):
        SingleEditMode = ... # type: QgsAttributeForm.Mode
        AddFeatureMode = ... # type: QgsAttributeForm.Mode
        MultiEditMode = ... # type: QgsAttributeForm.Mode
        SearchMode = ... # type: QgsAttributeForm.Mode
        AggregateSearchMode = ... # type: QgsAttributeForm.Mode
        IdentifyMode = ... # type: QgsAttributeForm.Mode

    def __init__(self, vl: _core.QgsVectorLayer|None, feature: _core.QgsFeature = ..., context: QgsAttributeEditorContext = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def parentFormValueChanged(self, attribute: str|None, newValue: typing.Any) -> None: ...
    def refreshFeature(self) -> None: ...
    def resetSearch(self) -> None: ...
    def resetValues(self) -> None: ...
    def saveWithDetails(self) -> typing.Tuple[bool, str]: ...
    def save(self) -> bool: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def changeGeometry(self, geometry: _core.QgsGeometry) -> None: ...
    def changeAttribute(self, field: str|None, value: typing.Any, hintText: str|None = ...) -> None: ...
    openFilteredFeaturesAttributeTable: typing.ClassVar[QtCore.pyqtSignal]
    flashFeatures: typing.ClassVar[QtCore.pyqtSignal]
    zoomToFeatures: typing.ClassVar[QtCore.pyqtSignal]
    closed: typing.ClassVar[QtCore.pyqtSignal]
    modeChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterExpressionSet: typing.ClassVar[QtCore.pyqtSignal]
    featureSaved: typing.ClassVar[QtCore.pyqtSignal]
    rememberLastWidgetValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    widgetValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    attributeChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def createFeature(layer: _core.QgsVectorLayer|None, geometry: _core.QgsGeometry, attributes: dict[int, typing.Any], context: _core.QgsExpressionContext) -> _core.QgsFeature: ...
    def needsGeometry(self) -> bool: ...
    def setExtraContextScope(self, extraScope: _core.QgsExpressionContextScope|None) -> None: ...
    def aggregateFilter(self) -> str: ...
    def setMessageBar(self, messageBar: 'QgsMessageBar|None') -> None: ...
    def setMultiEditFeatureIds(self, fids: typing.Any) -> None: ...
    def eventFilter(self, object: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def setEditCommandMessage(self, message: str|None) -> None: ...
    def setMode(self, mode: QgsAttributeEditorContext.Mode) -> None: ...
    def mode(self) -> QgsAttributeEditorContext.Mode: ...
    def editable(self) -> bool: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def addInterface(self, iface: 'QgsAttributeFormInterface|None') -> None: ...
    def disconnectButtonBox(self) -> None: ...
    def showButtonBox(self) -> None: ...
    def hideButtonBox(self) -> None: ...
    def displayWarning(self, message: str|None) -> None: ...
    def currentFormFeature(self) -> _core.QgsFeature: ...
    def feature(self) -> _core.QgsFeature: ...


class QgsAttributeFormWidget(QtWidgets.QWidget):

    class Mode(enum.IntEnum):
        DefaultMode = ... # type: QgsAttributeFormWidget.Mode
        MultiEditMode = ... # type: QgsAttributeFormWidget.Mode
        SearchMode = ... # type: QgsAttributeFormWidget.Mode
        AggregateSearchMode = ... # type: QgsAttributeFormWidget.Mode

    def __init__(self, widget: 'QgsWidgetWrapper|None', form: QgsAttributeForm|None) -> None: ...

    def setVisiblePageForMode(self, mode: 'QgsAttributeFormWidget.Mode') -> None: ...
    def setSearchWidgetToolButtonVisible(self, searchWidgetToolButtonVisible: bool) -> None: ...
    def searchWidgetToolButtonVisible(self) -> bool: ...
    def resetSearch(self) -> None: ...
    def searchWidgetWrappers(self) -> list['QgsSearchWidgetWrapper']: ...
    def addAdditionalSearchWidgetWrapper(self, wrapper: 'QgsSearchWidgetWrapper|None') -> None: ...
    def setSearchWidgetWrapper(self, wrapper: 'QgsSearchWidgetWrapper|None') -> None: ...
    def form(self) -> QgsAttributeForm|None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def mode(self) -> 'QgsAttributeFormWidget.Mode': ...
    def setMode(self, mode: 'QgsAttributeFormWidget.Mode') -> None: ...
    def currentFilterExpression(self) -> str: ...
    def createSearchWidgetWrappers(self) -> None: ...


class QgsAttributeFormEditorWidget(QgsAttributeFormWidget):

    def __init__(self, editorWidget: 'QgsEditorWidgetWrapper|None', widgetType: str|None, form: QgsAttributeForm|None) -> None: ...

    rememberLastValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    valuesChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def changesCommitted(self) -> None: ...
    def setIsMixed(self, mixed: bool) -> None: ...
    def editorWidget(self) -> 'QgsEditorWidgetWrapper|None': ...
    def setRememberLastValue(self, remember: bool) -> None: ...
    def setConstraintResultVisible(self, editable: bool) -> None: ...
    def setConstraintStatus(self, constraint: str|None, description: str|None, err: str|None, result: 'QgsEditorWidgetWrapper.ConstraintResult') -> None: ...
    def currentValue(self) -> typing.Any: ...
    def hasChanged(self) -> bool: ...
    def initialize(self, initialValue: typing.Any, mixedValues: bool = ..., additionalFieldValues: collections.abc.Iterable[typing.Any] = ...) -> None: ...
    def createSearchWidgetWrappers(self, context: QgsAttributeEditorContext = ...) -> None: ...


class QgsAttributeFormInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, form: QgsAttributeForm|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAttributeFormInterface') -> None: ...

    def feature(self) -> _core.QgsFeature: ...
    def form(self) -> QgsAttributeForm|None: ...
    def featureChanged(self) -> None: ...
    def initForm(self) -> None: ...
    def acceptChanges(self, feature: _core.QgsFeature) -> bool: ...


class QgsAttributeFormRelationEditorWidget(QgsAttributeFormWidget):

    def __init__(self, wrapper: 'QgsRelationWidgetWrapper|None', form: QgsAttributeForm|None) -> None: ...

    def setMultiEditFeatureIds(self, fids: typing.Any) -> None: ...
    def currentFilterExpression(self) -> str: ...
    def createSearchWidgetWrappers(self, context: QgsAttributeEditorContext = ...) -> None: ...


class QgsAttributeTypeLoadDialog(QtWidgets.QDialog):

    def __init__(self, vl: _core.QgsVectorLayer|None) -> None: ...

    def insertNull(self) -> bool: ...
    def valueMap(self) -> dict[str, typing.Any]: ...
    def setVectorLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def accept(self) -> None: ...


class QgsBlendModeComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def updateModes(self) -> None: ...
    def showClippingModes(self) -> bool: ...
    def setShowClippingModes(self, show: bool) -> None: ...
    def setBlendMode(self, blendMode: QtGui.QPainter.CompositionMode) -> None: ...
    def blendMode(self) -> QtGui.QPainter.CompositionMode: ...


class QgsBrowserDockWidget(QgsDockWidget):

    def __init__(self, name: str|None, browserModel: 'QgsBrowserGuiModel|None', parent: QtWidgets.QWidget|None = ...) -> None: ...

    connectionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    handleDropUriList: typing.ClassVar[QtCore.pyqtSignal]
    openFile: typing.ClassVar[QtCore.pyqtSignal]
    @deprecated("""""")
    def splitterMoved(self) -> None: ...
    @deprecated("""""")
    def selectionChanged(self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection) -> None: ...
    @deprecated("""""")
    def toggleFastScan(self) -> None: ...
    @deprecated("""""")
    def hideItem(self) -> None: ...
    @deprecated("""""")
    def showProperties(self) -> None: ...
    @deprecated("""""")
    def addSelectedLayers(self) -> None: ...
    @deprecated("""""")
    def updateProjectHome(self) -> None: ...
    @deprecated("""""")
    def setActiveIndex(self, index: QtCore.QModelIndex) -> None: ...
    @deprecated("""""")
    def setFilter(self) -> None: ...
    @deprecated("""""")
    def setCaseSensitive(self, caseSensitive: bool) -> None: ...
    @deprecated("""""")
    def setFilterSyntax(self, a0: QtGui.QAction|None) -> None: ...
    @deprecated("""""")
    def enablePropertiesWidget(self, enable: bool) -> None: ...
    @deprecated("""""")
    def showFilterWidget(self, visible: bool) -> None: ...
    def refresh(self) -> None: ...
    @deprecated("""""")
    def removeFavorite(self) -> None: ...
    @deprecated("""""")
    def addFavorite(self) -> None: ...
    @deprecated("""""")
    def showContextMenu(self, a0: QtCore.QPoint) -> None: ...
    @deprecated("""""")
    def addLayerAtIndex(self, index: QtCore.QModelIndex) -> bool: ...
    def setDisabledDataItemsKeys(self, filter: collections.abc.Iterable[str|None]) -> None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None') -> None: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...
    @typing.overload
    @deprecated("""""")
    def addFavoriteDirectory(self, favDir: str|None, name: str|None = ...) -> None: ...
    @typing.overload
    @deprecated("""""")
    def addFavoriteDirectory(self) -> None: ...
    def browserWidget(self) -> 'QgsBrowserWidget|None': ...


class QgsPanelWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def acceptPanel(self) -> None: ...
    def openPanel(self, panel: 'QgsPanelWidget|None') -> None: ...
    widgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    showPanel: typing.ClassVar[QtCore.pyqtSignal]
    panelAccepted: typing.ClassVar[QtCore.pyqtSignal]
    def menuButtonMenu(self) -> QtWidgets.QMenu|None: ...
    def menuButtonTooltip(self) -> str: ...
    @staticmethod
    def findParentPanel(widget: QtWidgets.QWidget|None) -> 'QgsPanelWidget|None': ...
    def autoDelete(self) -> bool: ...
    def setAutoDelete(self, autoDelete: bool) -> None: ...
    def dockMode(self) -> bool: ...
    def applySizeConstraintsToStack(self) -> bool: ...
    def setDockMode(self, dockMode: bool) -> None: ...
    def connectChildPanel(self, panel: 'QgsPanelWidget|None') -> None: ...
    def connectChildPanels(self, panels: collections.abc.Iterable['QgsPanelWidget']) -> None: ...
    def panelTitle(self) -> str: ...
    def setPanelTitle(self, panelTitle: str|None) -> None: ...


class QgsBrowserWidget(QgsPanelWidget):

    def __init__(self, browserModel: 'QgsBrowserGuiModel|None', parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def refresh(self) -> None: ...
    def setDisabledDataItemsKeys(self, filter: collections.abc.Iterable[str|None]) -> None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None') -> None: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...


class QgsBrowserGuiModel(_core.QgsBrowserModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def setMapCanvas(self, canvas: 'QgsMapCanvas|None') -> None: ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsBrowserTreeView(QtWidgets.QTreeView):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def rowsInserted(self, parentIndex: QtCore.QModelIndex, start: int, end: int) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def expandPath(self, path: str|None, selectPath: bool = ...) -> None: ...
    def setSelectedItem(self, item: _core.QgsDataItem|None) -> bool: ...
    def setSettingsSection(self, section: str|None) -> None: ...
    def hasExpandedDescendant(self, index: QtCore.QModelIndex) -> bool: ...
    def hideEvent(self, e: QtGui.QHideEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def browserModel(self) -> QgsBrowserGuiModel|None: ...
    def setBrowserModel(self, model: QgsBrowserGuiModel|None) -> None: ...
    def setModel(self, model: QtCore.QAbstractItemModel|None) -> None: ...


class QgsBusyIndicatorDialog(QtWidgets.QDialog):

    def __init__(self, message: str|None = ..., parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def setMessage(self, message: str|None) -> None: ...
    def message(self) -> str: ...


class QgsCharacterSelectorDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def selectCharacter(self, font: QtGui.QFont, style: str|None, initialSelection: str = ...) -> typing.Tuple[str, bool]: ...


class QgsCheckableComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def deselectAllOptions(self) -> None: ...
    def selectAllOptions(self) -> None: ...
    def showContextMenu(self, pos: QtCore.QPoint) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def setCheckedItems(self, items: collections.abc.Iterable[str|None]) -> None: ...
    checkedItemsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def eventFilter(self, object: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def hidePopup(self) -> None: ...
    def toggleItemCheckState(self, index: int) -> None: ...
    def setItemCheckState(self, index: int, state: QtCore.Qt.CheckState) -> None: ...
    def itemCheckState(self, index: int) -> QtCore.Qt.CheckState: ...
    def checkedItemsData(self) -> list[typing.Any]: ...
    def checkedItems(self) -> list[str]: ...
    def addItemWithCheckState(self, text: str|None, state: QtCore.Qt.CheckState, userData: typing.Any = ...) -> None: ...
    def setDefaultText(self, text: str|None) -> None: ...
    def defaultText(self) -> str: ...
    def setSeparator(self, separator: str|None) -> None: ...
    def separator(self) -> str: ...


class QgsGroupBoxCollapseButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def setShiftDown(self, shiftdown: bool) -> None: ...
    def shiftDown(self) -> bool: ...
    def setAltDown(self, updown: bool) -> None: ...
    def altDown(self) -> bool: ...


class QgsCollapsibleGroupBoxBasic(QtWidgets.QGroupBox):

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def clearModifiers(self) -> None: ...
    def titleRect(self) -> QtCore.QRect: ...
    def updateStyle(self) -> None: ...
    def changeEvent(self, event: QtCore.QEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def collapseExpandFixes(self) -> None: ...
    def setStyleSheet(self, style: str|None) -> None: ...
    def toggleCollapsed(self) -> None: ...
    def checkClicked(self, ckd: bool) -> None: ...
    def checkToggled(self, ckd: bool) -> None: ...
    collapsedStateChanged: typing.ClassVar[QtCore.pyqtSignal]
    def scrollOnExpand(self) -> bool: ...
    def setScrollOnExpand(self, scroll: bool) -> None: ...
    def setSyncGroup(self, grp: str|None) -> None: ...
    def syncGroup(self) -> str: ...
    def setCollapsed(self, collapse: bool) -> None: ...
    def isCollapsed(self) -> bool: ...


class QgsCollapsibleGroupBox(QgsCollapsibleGroupBoxBasic):

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ..., settings: _core.QgsSettings|None = ...) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, parent: QtWidgets.QWidget|None = ..., settings: _core.QgsSettings|None = ...) -> None: ...

    def saveKey(self) -> str: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def saveState(self) -> None: ...
    def loadState(self) -> None: ...
    def settingGroup(self) -> str: ...
    def setSettingGroup(self, group: str|None) -> None: ...
    def saveCheckedState(self) -> bool: ...
    def saveCollapsedState(self) -> bool: ...
    def setSaveCheckedState(self, save: bool) -> None: ...
    def setSaveCollapsedState(self, save: bool) -> None: ...
    def setSettings(self, settings: _core.QgsSettings|None) -> None: ...


class QgsColorBrewerColorRampWidget(QgsPanelWidget):

    def __init__(self, ramp: _core.QgsColorBrewerColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setRamp(self, ramp: _core.QgsColorBrewerColorRamp) -> None: ...
    def ramp(self) -> _core.QgsColorBrewerColorRamp: ...


class QgsColorBrewerColorRampDialog(QtWidgets.QDialog):

    def __init__(self, ramp: _core.QgsColorBrewerColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def setRamp(self, ramp: _core.QgsColorBrewerColorRamp) -> None: ...
    def ramp(self) -> _core.QgsColorBrewerColorRamp: ...


class QgsColorButton(QtWidgets.QToolButton):

    class Behavior(enum.IntEnum):
        ShowDialog = ... # type: QgsColorButton.Behavior
        SignalOnly = ... # type: QgsColorButton.Behavior

    def __init__(self, parent: QtWidgets.QWidget|None = ..., cdt: str|None = ..., registry: _core.QgsColorSchemeRegistry|None = ...) -> None: ...

    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def dropEvent(self, e: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    @staticmethod
    def transparentBackground() -> QtGui.QPixmap: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def changeEvent(self, e: QtCore.QEvent|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...
    unlinked: typing.ClassVar[QtCore.pyqtSignal]
    cleared: typing.ClassVar[QtCore.pyqtSignal]
    colorClicked: typing.ClassVar[QtCore.pyqtSignal]
    colorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def unlink(self) -> None: ...
    def setToNull(self) -> None: ...
    def setToDefaultColor(self) -> None: ...
    def setToNoColor(self) -> None: ...
    def activatePicker(self) -> None: ...
    def pasteColor(self) -> None: ...
    def copyColor(self) -> None: ...
    def setButtonBackground(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @staticmethod
    def createMenuIcon(color: QtGui.QColor|QtCore.Qt.GlobalColor|int, showChecks: bool = ...) -> QtGui.QPixmap: ...
    def linkedProjectColorName(self) -> str: ...
    def linkToProjectColor(self, name: str|None) -> None: ...
    def colorSchemeRegistry(self) -> _core.QgsColorSchemeRegistry|None: ...
    def setColorSchemeRegistry(self, registry: _core.QgsColorSchemeRegistry|None) -> None: ...
    def context(self) -> str: ...
    def setContext(self, context: str|None) -> None: ...
    def noColorString(self) -> str: ...
    def isNull(self) -> bool: ...
    def showNull(self) -> bool: ...
    def setShowNull(self, showNull: bool, nullString: str|None = ...) -> None: ...
    def setNoColorString(self, noColorString: str|None) -> None: ...
    def showNoColor(self) -> bool: ...
    def setShowNoColor(self, showNoColorOption: bool) -> None: ...
    def defaultColor(self) -> QtGui.QColor: ...
    def setDefaultColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def behavior(self) -> 'QgsColorButton.Behavior': ...
    def setBehavior(self, behavior: 'QgsColorButton.Behavior') -> None: ...
    def showMenu(self) -> bool: ...
    def setShowMenu(self, showMenu: bool) -> None: ...
    def colorDialogTitle(self) -> str: ...
    def setColorDialogTitle(self, title: str|None) -> None: ...
    def allowOpacity(self) -> bool: ...
    def setAllowOpacity(self, allowOpacity: bool) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsColorDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...

    def closeEvent(self, e: QtGui.QCloseEvent|None) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    currentColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def getColor(initialColor: QtGui.QColor|QtCore.Qt.GlobalColor|int, parent: QtWidgets.QWidget|None, title: str|None = ..., allowOpacity: bool = ...) -> QtGui.QColor: ...
    def setAllowOpacity(self, allowOpacity: bool) -> None: ...
    def setTitle(self, title: str|None) -> None: ...
    def color(self) -> QtGui.QColor: ...


class QgsColorRampButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., dialogTitle: str|None = ...) -> None: ...

    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def changeEvent(self, e: QtCore.QEvent|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...
    colorRampChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setToNull(self) -> None: ...
    def setToDefaultColorRamp(self) -> None: ...
    def setButtonBackground(self, colorramp: _core.QgsColorRamp|None = ...) -> None: ...
    def setColorRampFromName(self, name: str|None = ...) -> None: ...
    def setRandomColorRamp(self) -> None: ...
    def setColorRamp(self, colorramp: _core.QgsColorRamp|None) -> None: ...
    def colorRampName(self) -> str: ...
    def setColorRampName(self, name: str|None) -> None: ...
    def showGradientOnly(self) -> bool: ...
    def setShowGradientOnly(self, gradientonly: bool) -> None: ...
    def context(self) -> str: ...
    def setContext(self, context: str|None) -> None: ...
    def isNull(self) -> bool: ...
    def showNull(self) -> bool: ...
    def setShowNull(self, showNull: bool) -> None: ...
    def isRandomColorRamp(self) -> bool: ...
    def showRandomColorRamp(self) -> bool: ...
    def setShowRandomColorRamp(self, showRandom: bool) -> None: ...
    def defaultColorRamp(self) -> _core.QgsColorRamp|None: ...
    def setDefaultColorRamp(self, colorramp: _core.QgsColorRamp|None) -> None: ...
    def showMenu(self) -> bool: ...
    def setShowMenu(self, showMenu: bool) -> None: ...
    def setAcceptLiveUpdates(self, accept: bool) -> None: ...
    def acceptLiveUpdates(self) -> bool: ...
    def colorRampDialogTitle(self) -> str: ...
    def setColorRampDialogTitle(self, title: str|None) -> None: ...
    def colorRamp(self) -> _core.QgsColorRamp|None: ...
    def sizeHint(self) -> QtCore.QSize: ...


class QgsColorRampLegendNodeWidget(QgsPanelWidget):

    class Capability(enum.IntFlag):
        Prefix = ... # type: QgsColorRampLegendNodeWidget.Capability
        Suffix = ... # type: QgsColorRampLegendNodeWidget.Capability
        NumberFormat = ... # type: QgsColorRampLegendNodeWidget.Capability
        DefaultMinimum = ... # type: QgsColorRampLegendNodeWidget.Capability
        DefaultMaximum = ... # type: QgsColorRampLegendNodeWidget.Capability
        AllCapabilities = ... # type: QgsColorRampLegendNodeWidget.Capability

    def __init__(self, parent: QtWidgets.QWidget|None = ..., capabilities: 'QgsColorRampLegendNodeWidget.Capability' = ...) -> None: ...

    def setUseContinuousRampCheckBoxVisibility(self, visible: bool) -> None: ...
    def setSettings(self, settings: _core.QgsColorRampLegendNodeSettings) -> None: ...
    def settings(self) -> _core.QgsColorRampLegendNodeSettings: ...


class QgsColorRampLegendNodeDialog(QtWidgets.QDialog):

    def __init__(self, settings: _core.QgsColorRampLegendNodeSettings, parent: QtWidgets.QWidget|None = ..., capabilities: QgsColorRampLegendNodeWidget.Capability = ...) -> None: ...

    def setUseContinuousRampCheckBoxVisibility(self, visible: bool) -> None: ...
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def settings(self) -> _core.QgsColorRampLegendNodeSettings: ...


class QgsColorSwatchDelegate(QtWidgets.QAbstractItemDelegate):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def editorEvent(self, event: QtCore.QEvent|None, model: QtCore.QAbstractItemModel|None, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> bool: ...
    def sizeHint(self, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> QtCore.QSize: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> None: ...


class QgsColorSchemeModel(QtCore.QAbstractItemModel):

    def __init__(self, scheme: _core.QgsColorScheme|None, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def isDirty(self) -> bool: ...
    def addColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, label: str|None = ..., allowDuplicate: bool = ...) -> None: ...
    def baseColor(self) -> QtGui.QColor: ...
    def context(self) -> str: ...
    def setScheme(self, scheme: _core.QgsColorScheme|None, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    def colors(self) -> list[tuple[QtGui.QColor, str]]: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def insertRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def mimeTypes(self) -> list[str]: ...
    def supportedDropActions(self) -> QtCore.Qt.DropAction: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...


class QgsColorSchemeList(QtWidgets.QTreeView):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., scheme: _core.QgsColorScheme|None = ..., context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    colorSelected: typing.ClassVar[QtCore.pyqtSignal]
    def showExportColorsDialog(self) -> None: ...
    def showImportColorsDialog(self) -> None: ...
    def copyColors(self) -> None: ...
    def pasteColors(self) -> None: ...
    def addColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, label: str|None = ..., allowDuplicate: bool = ...) -> None: ...
    def removeSelection(self) -> None: ...
    def setScheme(self, scheme: _core.QgsColorScheme|None, context: str|None = ..., baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ...) -> None: ...
    def scheme(self) -> _core.QgsColorScheme|None: ...
    def isDirty(self) -> bool: ...
    def exportColorsToGpl(self, file: QtCore.QFile) -> bool: ...
    def importColorsFromGpl(self, file: QtCore.QFile) -> bool: ...
    def saveColorsToScheme(self) -> bool: ...


class QgsColorSwatchGrid(QtWidgets.QWidget):

    def __init__(self, scheme: _core.QgsColorScheme|None, context: str|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def focusInEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    hovered: typing.ClassVar[QtCore.pyqtSignal]
    colorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refreshColors(self) -> None: ...
    def colors(self) -> list[tuple[QtGui.QColor, str]]: ...
    def setBaseColor(self, baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def baseColor(self) -> QtGui.QColor: ...
    def setContext(self, context: str|None) -> None: ...
    def context(self) -> str: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsColorSwatchGridAction(QtWidgets.QWidgetAction):

    def __init__(self, scheme: _core.QgsColorScheme|None, menu: QtWidgets.QMenu|None = ..., context: str|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    colorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refreshColors(self) -> None: ...
    def dismissOnColorSelection(self) -> bool: ...
    def setDismissOnColorSelection(self, dismiss: bool) -> None: ...
    def setContext(self, context: str|None) -> None: ...
    def context(self) -> str: ...
    def baseColor(self) -> QtGui.QColor: ...
    def setBaseColor(self, baseColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...


class QgsColorWidget(QtWidgets.QWidget):

    class ComponentUnit(enum.Enum):
        Scaled0to255 = ... # type: QgsColorWidget.ComponentUnit
        Percent = ... # type: QgsColorWidget.ComponentUnit
        Degree = ... # type: QgsColorWidget.ComponentUnit

    class ColorComponent(enum.IntEnum):
        Multiple = ... # type: QgsColorWidget.ColorComponent
        Red = ... # type: QgsColorWidget.ColorComponent
        Green = ... # type: QgsColorWidget.ColorComponent
        Blue = ... # type: QgsColorWidget.ColorComponent
        Hue = ... # type: QgsColorWidget.ColorComponent
        Saturation = ... # type: QgsColorWidget.ColorComponent
        Value = ... # type: QgsColorWidget.ColorComponent
        Alpha = ... # type: QgsColorWidget.ColorComponent
        Cyan = ... # type: QgsColorWidget.ColorComponent
        Magenta = ... # type: QgsColorWidget.ColorComponent
        Yellow = ... # type: QgsColorWidget.ColorComponent
        Black = ... # type: QgsColorWidget.ColorComponent

    def __init__(self, parent: QtWidgets.QWidget|None = ..., component: 'QgsColorWidget.ColorComponent' = ...) -> None: ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def dropEvent(self, e: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    @staticmethod
    def transparentBackground() -> QtGui.QPixmap: ...
    @typing.overload
    def colorSpec(self) -> QtGui.QColor.Spec: ...
    @typing.overload
    @staticmethod
    def colorSpec(component: 'QgsColorWidget.ColorComponent') -> QtGui.QColor.Spec: ...
    @staticmethod
    def alterColorF(color: QtGui.QColor|QtCore.Qt.GlobalColor|int, component: 'QgsColorWidget.ColorComponent', newValue: float) -> None: ...
    @staticmethod
    @deprecated("""""")
    def alterColor(color: QtGui.QColor|QtCore.Qt.GlobalColor|int, component: 'QgsColorWidget.ColorComponent', newValue: int) -> None: ...
    def hueF(self) -> float: ...
    @deprecated("""""")
    def hue(self) -> int: ...
    @typing.overload
    def componentRange(self) -> int: ...
    @typing.overload
    @staticmethod
    def componentRange(component: 'QgsColorWidget.ColorComponent') -> int: ...
    hovered: typing.ClassVar[QtCore.pyqtSignal]
    colorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setComponentValueF(self, value: float) -> None: ...
    @deprecated("""""")
    def setComponentValue(self, value: int) -> None: ...
    def setComponent(self, component: 'QgsColorWidget.ColorComponent') -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, emitSignals: bool = ...) -> None: ...
    @staticmethod
    def componentUnit(component: 'QgsColorWidget.ColorComponent') -> 'QgsColorWidget.ComponentUnit': ...
    @staticmethod
    def createDragIcon(color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> QtGui.QPixmap: ...
    @typing.overload
    def componentValueF(self) -> float: ...
    @typing.overload
    def componentValueF(self, component: 'QgsColorWidget.ColorComponent') -> float: ...
    @typing.overload
    @deprecated("""""")
    def componentValue(self) -> int: ...
    @typing.overload
    @deprecated("""""")
    def componentValue(self, component: 'QgsColorWidget.ColorComponent') -> int: ...
    def component(self) -> 'QgsColorWidget.ColorComponent': ...
    def color(self) -> QtGui.QColor: ...


class QgsColorWidgetAction(QtWidgets.QWidgetAction):

    def __init__(self, colorWidget: QgsColorWidget|None, menu: QtWidgets.QMenu|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    colorChanged: typing.ClassVar[QtCore.pyqtSignal]
    def dismissOnColorSelection(self) -> bool: ...
    def setDismissOnColorSelection(self, dismiss: bool) -> None: ...
    def colorWidget(self) -> QgsColorWidget|None: ...


class QgsColorWheel(QgsColorWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, emitSignals: bool = ...) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...


class QgsColorBox(QgsColorWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., component: QgsColorWidget.ColorComponent = ...) -> None: ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, emitSignals: bool = ...) -> None: ...
    def setComponent(self, component: QgsColorWidget.ColorComponent) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...


class QgsColorRampWidget(QgsColorWidget):

    class Orientation(enum.IntEnum):
        Horizontal = ... # type: QgsColorRampWidget.Orientation
        Vertical = ... # type: QgsColorRampWidget.Orientation

    def __init__(self, parent: QtWidgets.QWidget|None = ..., component: QgsColorWidget.ColorComponent = ..., orientation: 'QgsColorRampWidget.Orientation' = ...) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    valueChangedF: typing.ClassVar[QtCore.pyqtSignal]
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMarkerSize(self, markerSize: int) -> None: ...
    def showFrame(self) -> bool: ...
    def setShowFrame(self, showFrame: bool) -> None: ...
    def interiorMargin(self) -> int: ...
    def setInteriorMargin(self, margin: int) -> None: ...
    def orientation(self) -> 'QgsColorRampWidget.Orientation': ...
    def setOrientation(self, orientation: 'QgsColorRampWidget.Orientation') -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...


class QgsColorSliderWidget(QgsColorWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., component: QgsColorWidget.ColorComponent = ...) -> None: ...

    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, emitSignals: bool = ...) -> None: ...
    def setComponentValueF(self, value: float) -> None: ...
    def setComponent(self, component: QgsColorWidget.ColorComponent) -> None: ...


class QgsColorTextWidget(QgsColorWidget):

    class ColorTextFormat(enum.IntEnum):
        HexRgb = ... # type: QgsColorTextWidget.ColorTextFormat
        HexRgbA = ... # type: QgsColorTextWidget.ColorTextFormat
        Rgb = ... # type: QgsColorTextWidget.ColorTextFormat
        Rgba = ... # type: QgsColorTextWidget.ColorTextFormat

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def setAllowOpacity(self, allowOpacity: bool) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, emitSignals: bool = ...) -> None: ...


class QgsColorPreviewWidget(QgsColorWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def setColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color2(self) -> QtGui.QColor: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...


class QgsCompoundColorWidget(QgsPanelWidget):

    class Layout(enum.IntEnum):
        LayoutDefault = ... # type: QgsCompoundColorWidget.Layout
        LayoutVertical = ... # type: QgsCompoundColorWidget.Layout

    def __init__(self, parent: QtWidgets.QWidget|None = ..., color: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., layout: 'QgsCompoundColorWidget.Layout' = ...) -> None: ...

    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def hideEvent(self, e: QtGui.QHideEvent|None) -> None: ...
    def setPreviousColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    currentColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def removeUserPalette(scheme: _core.QgsUserColorScheme|None, parent: QtWidgets.QWidget|None) -> bool: ...
    @staticmethod
    def createNewUserPalette(parent: QtWidgets.QWidget|None) -> _core.QgsUserColorScheme|None: ...
    @staticmethod
    def importUserPaletteFromFile(parent: QtWidgets.QWidget|None) -> _core.QgsUserColorScheme|None: ...
    def setDiscarded(self, discarded: bool) -> None: ...
    def setColorModelEditable(self, colorModelEditable: bool) -> None: ...
    def setAllowOpacity(self, allowOpacity: bool) -> None: ...
    def color(self) -> QtGui.QColor: ...


class QgsConfigureShortcutsDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., manager: 'QgsShortcutsManager|None' = ...) -> None: ...

    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...


class QgsCredentialDialog(QtWidgets.QDialog, _core.QgsCredentials):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def requestMasterPassword(self, password: str|None, stored: bool = ...) -> typing.Tuple[bool, str]: ...
    def request(self, realm: str|None, username: str|None, password: str|None, message: str|None = ...) -> typing.Tuple[bool, str, str]: ...


class QgsCurveEditorWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., curve: _core.QgsCurveTransform = ...) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setMaxHistogramValueRange(self, maxValueRange: float) -> None: ...
    def setMinHistogramValueRange(self, minValueRange: float) -> None: ...
    def maxHistogramValueRange(self) -> float: ...
    def minHistogramValueRange(self) -> float: ...
    def setHistogramSource(self, layer: _core.QgsVectorLayer|None, expression: str|None) -> None: ...
    def setCurve(self, curve: _core.QgsCurveTransform) -> None: ...
    def curve(self) -> _core.QgsCurveTransform: ...


class QgsCustomDropHandler(QtCore.QObject):

    def __init__(self) -> None: ...

    def handleCustomUriCanvasDrop(self, uri: _core.QgsMimeDataUtils.Uri, canvas: 'QgsMapCanvas|None') -> bool: ...
    def canHandleCustomUriCanvasDrop(self, uri: _core.QgsMimeDataUtils.Uri, canvas: 'QgsMapCanvas|None') -> bool: ...
    def handleFileDrop(self, file: str|None) -> bool: ...
    def handleMimeDataV2(self, data: QtCore.QMimeData|None) -> bool: ...
    @deprecated("""""")
    def handleMimeData(self, data: QtCore.QMimeData|None) -> None: ...
    def canHandleMimeData(self, data: QtCore.QMimeData|None) -> bool: ...
    def handleCustomUriDrop(self, uri: _core.QgsMimeDataUtils.Uri) -> None: ...
    def customUriProviderKey(self) -> str: ...


class QgsCustomProjectOpenHandler(QtCore.QObject):

    def __init__(self) -> None: ...

    def icon(self) -> QtGui.QIcon: ...
    def createDocumentThumbnailAfterOpen(self) -> bool: ...
    def filters(self) -> list[str]: ...
    def handleProjectOpen(self, file: str|None) -> bool: ...


class QgsDatabaseSchemaComboBox(QtWidgets.QWidget):

    @typing.overload
    def __init__(self, provider: str|None, connection: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    schemaChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refreshSchemas(self) -> None: ...
    def setConnectionName(self, connection: str|None, provider: str|None = ...) -> None: ...
    def setSchema(self, schema: str|None) -> None: ...
    def comboBox(self) -> QtWidgets.QComboBox|None: ...
    def currentSchema(self) -> str: ...
    def allowEmptySchema(self) -> bool: ...
    def setAllowEmptySchema(self, allowEmpty: bool) -> None: ...


class QgsDatabaseTableComboBox(QtWidgets.QWidget):

    @typing.overload
    def __init__(self, provider: str|None, connection: str|None, schema: str|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None, schema: str|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    tableChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refreshTables(self) -> None: ...
    def setSchema(self, schema: str|None) -> None: ...
    def setConnectionName(self, connection: str|None, provider: str|None = ...) -> None: ...
    def setTable(self, table: str|None, schema: str|None = ...) -> None: ...
    def comboBox(self) -> QtWidgets.QComboBox|None: ...
    def currentSchema(self) -> str: ...
    def currentTable(self) -> str: ...
    def allowEmptyTable(self) -> bool: ...
    def setAllowEmptyTable(self, allowEmpty: bool) -> None: ...


class QgsDataItemGuiContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataItemGuiContext') -> None: ...

    def setView(self, view: QgsBrowserTreeView|None) -> None: ...
    def view(self) -> QgsBrowserTreeView|None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None') -> None: ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...


class QgsDataItemGuiProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataItemGuiProvider') -> None: ...

    @staticmethod
    def notify(title: str|None, message: str|None, context: QgsDataItemGuiContext, level: _core.Qgis.MessageLevel = ..., duration: int = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...
    def createParamWidget(self, item: _core.QgsDataItem|None, context: QgsDataItemGuiContext) -> QtWidgets.QWidget|None: ...
    def handleDrop(self, item: _core.QgsDataItem|None, context: QgsDataItemGuiContext, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction) -> bool: ...
    def acceptDrop(self, item: _core.QgsDataItem|None, context: QgsDataItemGuiContext) -> bool: ...
    def handleDoubleClick(self, item: _core.QgsDataItem|None, context: QgsDataItemGuiContext) -> bool: ...
    def deleteLayer(self, item: _core.QgsLayerItem|None, context: QgsDataItemGuiContext) -> bool: ...
    def rename(self, item: _core.QgsDataItem|None, name: str|None, context: QgsDataItemGuiContext) -> bool: ...
    def precedenceWhenPopulatingMenus(self) -> int: ...
    def populateContextMenu(self, item: _core.QgsDataItem|None, menu: QtWidgets.QMenu|None, selectedItems: collections.abc.Iterable[_core.QgsDataItem], context: QgsDataItemGuiContext) -> None: ...
    def name(self) -> str: ...


class QgsDataItemGuiProviderRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def initializeFromProviderGuiRegistry(self, providerGuiRegistry: 'QgsProviderGuiRegistry|None') -> None: ...
    def removeProvider(self, provider: QgsDataItemGuiProvider|None) -> None: ...
    def addProvider(self, provider: QgsDataItemGuiProvider|None) -> None: ...
    def providers(self) -> list[QgsDataItemGuiProvider]: ...


class QgsDataItemGuiProviderUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDataItemGuiProviderUtils') -> None: ...


class QgsDataSourceSelectWidget(QgsPanelWidget):

    def __init__(self, browserModel: QgsBrowserGuiModel|None = ..., setFilterByLayerType: bool = ..., layerType: _core.Qgis.LayerType = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    itemTriggered: typing.ClassVar[QtCore.pyqtSignal]
    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    validationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def setFilter(self) -> None: ...
    def setCaseSensitive(self, caseSensitive: bool) -> None: ...
    def setFilterSyntax(self, a0: QtGui.QAction|None) -> None: ...
    def showFilterWidget(self, visible: bool) -> None: ...
    def uri(self) -> _core.QgsMimeDataUtils.Uri: ...
    def expandPath(self, path: str|None, selectPath: bool = ...) -> None: ...
    def setDescription(self, description: str|None) -> None: ...
    def setLayerTypeFilter(self, layerType: _core.Qgis.LayerType) -> None: ...


class QgsDataSourceSelectDialog(QtWidgets.QDialog):

    def __init__(self, browserModel: QgsBrowserGuiModel|None = ..., setFilterByLayerType: bool = ..., layerType: _core.Qgis.LayerType = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setFilter(self) -> None: ...
    def setCaseSensitive(self, caseSensitive: bool) -> None: ...
    def setFilterSyntax(self, a0: QtGui.QAction|None) -> None: ...
    def showFilterWidget(self, visible: bool) -> None: ...
    def uri(self) -> _core.QgsMimeDataUtils.Uri: ...
    def expandPath(self, path: str|None, selectPath: bool = ...) -> None: ...
    def setDescription(self, description: str|None) -> None: ...
    def setLayerTypeFilter(self, layerType: _core.Qgis.LayerType) -> None: ...


class QgsDbRelationWidget(QtWidgets.QWidget):

    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    validityChanged: typing.ClassVar[QtCore.pyqtSignal]
    def isValid(self) -> bool: ...
    def relationship(self) -> _core.QgsWeakRelation: ...
    def setRelationship(self, relationship: _core.QgsWeakRelation) -> None: ...


class QgsDbRelationDialog(QtWidgets.QDialog):

    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def relationship(self) -> _core.QgsWeakRelation: ...
    def setRelationship(self, relationship: _core.QgsWeakRelation) -> None: ...


class QgsScrollBarHighlight(PyQt6.sip.wrapper):

    class Priority(enum.IntEnum):
        Invalid = ... # type: QgsScrollBarHighlight.Priority
        LowPriority = ... # type: QgsScrollBarHighlight.Priority
        NormalPriority = ... # type: QgsScrollBarHighlight.Priority
        HighPriority = ... # type: QgsScrollBarHighlight.Priority
        HighestPriority = ... # type: QgsScrollBarHighlight.Priority

    category = ... # type: int
    color = ... # type: QtGui.QColor|QtCore.Qt.GlobalColor|int
    position = ... # type: int
    priority = ... # type: 'QgsScrollBarHighlight.Priority'

    @typing.overload
    def __init__(self, category: int, position: int, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, priority: 'QgsScrollBarHighlight.Priority' = ...) -> None: ...
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScrollBarHighlight') -> None: ...


class QgsScrollBarHighlightController(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsScrollBarHighlightController') -> None: ...

    def removeAllHighlights(self) -> None: ...
    def removeHighlights(self, category: int) -> None: ...
    def addHighlight(self, highlight: QgsScrollBarHighlight) -> None: ...
    def setMargin(self, margin: float) -> None: ...
    def margin(self) -> float: ...
    def setVisibleRange(self, visibleRange: float) -> None: ...
    def visibleRange(self) -> float: ...
    def setLineHeight(self, height: float) -> None: ...
    def lineHeight(self) -> float: ...
    def setScrollArea(self, scrollArea: QtWidgets.QAbstractScrollArea|None) -> None: ...
    def scrollArea(self) -> QtWidgets.QAbstractScrollArea|None: ...
    def scrollBar(self) -> QtWidgets.QScrollBar|None: ...


class QgsNewDatabaseTableNameWidget(QgsPanelWidget):

    def __init__(self, browserModel: QgsBrowserGuiModel|None = ..., providersFilter: collections.abc.Iterable[str|None] = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    accepted: typing.ClassVar[QtCore.pyqtSignal]
    uriChanged: typing.ClassVar[QtCore.pyqtSignal]
    providerKeyChanged: typing.ClassVar[QtCore.pyqtSignal]
    tableNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    schemaNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    validationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def validationError(self) -> str: ...
    def isValid(self) -> bool: ...
    def dataProviderKey(self) -> str: ...
    def table(self) -> str: ...
    def uri(self) -> str: ...
    def schema(self) -> str: ...
    def setAcceptButtonVisible(self, visible: bool) -> None: ...


class QgsNewDatabaseTableNameDialog(QtWidgets.QDialog):

    def __init__(self, browserModel: QgsBrowserGuiModel|None = ..., providersFilter: collections.abc.Iterable[str|None] = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def validationError(self) -> str: ...
    def isValid(self) -> bool: ...
    def dataProviderKey(self) -> str: ...
    def table(self) -> str: ...
    def uri(self) -> str: ...
    def schema(self) -> str: ...


class QgsDatabaseSchemaSelectionDialog(QtWidgets.QDialog):

    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def selectedSchema(self) -> str: ...


class QgsDetailedItemData(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDetailedItemData') -> None: ...

    def isRenderedAsWidget(self) -> bool: ...
    def isEnabled(self) -> bool: ...
    def isChecked(self) -> bool: ...
    def isCheckable(self) -> bool: ...
    def icon(self) -> QtGui.QPixmap: ...
    def category(self) -> str: ...
    def detail(self) -> str: ...
    def title(self) -> str: ...
    def setRenderAsWidget(self, flag: bool) -> None: ...
    def setEnabled(self, flag: bool) -> None: ...
    def setChecked(self, flag: bool) -> None: ...
    def setCheckable(self, flag: bool) -> None: ...
    def setIcon(self, icon: QtGui.QPixmap) -> None: ...
    def setCategory(self, category: str|None) -> None: ...
    def setDetail(self, detail: str|None) -> None: ...
    def setTitle(self, title: str|None) -> None: ...


class QgsDetailedItemDelegate(QtWidgets.QAbstractItemDelegate):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def horizontalSpacing(self) -> int: ...
    def setHorizontalSpacing(self, value: int) -> None: ...
    def verticalSpacing(self) -> int: ...
    def setVerticalSpacing(self, value: int) -> None: ...
    def sizeHint(self, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> QtCore.QSize: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> None: ...


class QgsDetailedItemWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setChecked(self, flag: bool) -> None: ...
    def setData(self, data: QgsDetailedItemData) -> None: ...


class QgsDial(QtWidgets.QDial):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def variantValue(self) -> typing.Any: ...
    def setValue(self, value: typing.Any) -> None: ...
    def singleStep(self) -> typing.Any: ...
    def setSingleStep(self, step: typing.Any) -> None: ...
    def maximum(self) -> typing.Any: ...
    def setMaximum(self, max: typing.Any) -> None: ...
    def minimum(self) -> typing.Any: ...
    def setMinimum(self, min: typing.Any) -> None: ...


class QgsDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., buttons: QtWidgets.QDialogButtonBox.StandardButton = ..., orientation: QtCore.Qt.Orientation = ...) -> None: ...

    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def layout(self) -> QtWidgets.QVBoxLayout|None: ...


class QgsDirectionalLightWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    directionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEnableAzimuth(self, enable: bool) -> None: ...
    def altitude(self) -> float: ...
    def setAltitude(self, altitude: float) -> None: ...
    def azimuth(self) -> float: ...
    def setAzimuth(self, azimuth: float) -> None: ...


class QgsDoubleValidator(QtGui.QRegularExpressionValidator):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None) -> None: ...
    @typing.overload
    def __init__(self, expression: QtCore.QRegularExpression, bottom: float, top: float, parent: QtCore.QObject|None) -> None: ...
    @typing.overload
    def __init__(self, bottom: float, top: float, parent: QtCore.QObject|None) -> None: ...
    @typing.overload
    def __init__(self, bottom: float, top: float, decimal: int, parent: QtCore.QObject|None) -> None: ...
    @typing.overload
    def __init__(self, decimal: int, parent: QtCore.QObject|None) -> None: ...

    def top(self) -> float: ...
    def bottom(self) -> float: ...
    def setRange(self, bottom: float, top: float) -> None: ...
    def setTop(self, top: float) -> None: ...
    def setBottom(self, bottom: float) -> None: ...
    @staticmethod
    def toDouble(input: str|None) -> float: ...
    def validate(self, input: str|None) -> QtGui.QValidator.State: ...
    def setMaxDecimals(self, maxDecimals: int) -> None: ...


class QgsEncodingFileDialog(QtWidgets.QFileDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., caption: str|None = ..., directory: str|None = ..., filter: str|None = ..., encoding: str|None = ...) -> None: ...

    def pbnCancelAll_clicked(self) -> None: ...
    def saveUsedEncoding(self) -> None: ...
    def cancelAll(self) -> bool: ...
    def addCancelAll(self) -> None: ...
    def encoding(self) -> str: ...


class QgsEncodingSelectionDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., caption: str|None = ..., encoding: str|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def setEncoding(self, encoding: str|None) -> None: ...
    def encoding(self) -> str: ...


class QgsErrorDialog(QtWidgets.QDialog):

    def __init__(self, error: _core.QgsError, title: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    @staticmethod
    def show(error: _core.QgsError, title: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...


class QgsExpressionBuilderDialog(QtWidgets.QDialog):

    def __init__(self, layer: _core.QgsVectorLayer|None, startText: str|None = ..., parent: QtWidgets.QWidget|None = ..., key: str|None = ..., context: _core.QgsExpressionContext = ...) -> None: ...

    def reject(self) -> None: ...
    def accept(self) -> None: ...
    def done(self, r: int) -> None: ...
    allowEvalErrorsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAllowEvalErrors(self, allowEvalErrors: bool) -> None: ...
    def allowEvalErrors(self) -> bool: ...
    def setGeomCalculator(self, da: _core.QgsDistanceArea) -> None: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext) -> None: ...
    def expressionContext(self) -> _core.QgsExpressionContext: ...
    def setExpectedOutputFormat(self, expected: str|None) -> None: ...
    def expectedOutputFormat(self) -> str: ...
    def expressionText(self) -> str: ...
    def setExpressionText(self, text: str|None) -> None: ...
    def expressionBuilder(self) -> 'QgsExpressionBuilderWidget|None': ...


class QgsExpressionStoreDialog(QtWidgets.QDialog):

    def __init__(self, label: str|None, expression: str|None, helpText: str|None, existingLabels: collections.abc.Iterable[str|None] = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def helpText(self) -> str: ...
    def label(self) -> str: ...
    def expression(self) -> str: ...


class QgsExpressionBuilderWidget(QtWidgets.QWidget):

    class Flag(enum.IntEnum):
        LoadNothing = ... # type: QgsExpressionBuilderWidget.Flag
        LoadRecent = ... # type: QgsExpressionBuilderWidget.Flag
        LoadUserExpressions = ... # type: QgsExpressionBuilderWidget.Flag
        LoadAll = ... # type: QgsExpressionBuilderWidget.Flag

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    parserErrorChanged: typing.ClassVar[QtCore.pyqtSignal]
    evalErrorChanged: typing.ClassVar[QtCore.pyqtSignal]
    expressionParsed: typing.ClassVar[QtCore.pyqtSignal]
    def findExpressions(self, label: str|None) -> list['QgsExpressionItem']: ...
    def editSelectedUserExpression(self) -> None: ...
    def removeSelectedUserExpression(self) -> None: ...
    def storeCurrentUserExpression(self) -> None: ...
    def setAutoSave(self, enabled: bool) -> None: ...
    def autosave(self) -> None: ...
    def loadAllUsedValues(self) -> None: ...
    def loadSampleUsedValues(self) -> None: ...
    def loadAllValues(self) -> None: ...
    def loadSampleValues(self) -> None: ...
    def setExpressionPreviewVisible(self, isVisible: bool) -> None: ...
    def parserError(self) -> bool: ...
    def evalError(self) -> bool: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def project(self) -> _core.QgsProject|None: ...
    @deprecated("""""")
    def model(self) -> QtGui.QStandardItemModel|None: ...
    def saveProjectFunctionsEntry(self) -> None: ...
    def updateFunctionFileList(self, path: str|None) -> None: ...
    def loadFunctionCode(self, code: str|None) -> None: ...
    def loadCodeFromProjectFunctions(self) -> None: ...
    def loadCodeFromFile(self, path: str|None) -> None: ...
    def saveFunctionFile(self, fileName: str|None) -> None: ...
    def newFunctionFile(self, fileName: str|None = ...) -> None: ...
    @deprecated("""""")
    def removeFromUserExpressions(self, label: str|None) -> None: ...
    @deprecated("""""")
    def saveToUserExpressions(self, label: str|None, expression: str|None, helpText: str|None) -> None: ...
    @deprecated("""""")
    def loadUserExpressions(self) -> None: ...
    def expressionTree(self) -> 'QgsExpressionTreeView|None': ...
    @deprecated("""""")
    def loadRecent(self, collection: str|None = ...) -> None: ...
    @deprecated("""""")
    def saveToRecent(self, collection: str|None = ...) -> None: ...
    def setCustomPreviewGenerator(self, label: str|None, choices: collections.abc.Iterable[tuple[str|None, typing.Any]], a2: typing.Callable[..., None]) -> None: ...
    def isExpressionValid(self) -> bool: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext) -> None: ...
    def expressionContext(self) -> _core.QgsExpressionContext: ...
    def setExpectedOutputFormat(self, expected: str|None) -> None: ...
    def expectedOutputFormat(self) -> str: ...
    def setExpressionText(self, expression: str|None) -> None: ...
    def expressionText(self) -> str: ...
    def setGeomCalculator(self, da: _core.QgsDistanceArea) -> None: ...
    @deprecated("""""")
    def loadFieldsAndValues(self, fieldValues: dict[str|None, collections.abc.Iterable[str|None]]) -> None: ...
    @typing.overload
    @deprecated("""""")
    def loadFieldNames(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def loadFieldNames(self, fields: _core.QgsFields) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def initWithFields(self, fields: _core.QgsFields, context: _core.QgsExpressionContext = ..., recentCollection: str|None = ..., flags: 'QgsExpressionBuilderWidget.Flag' = ...) -> None: ...
    def initWithLayer(self, layer: _core.QgsVectorLayer|None, context: _core.QgsExpressionContext = ..., recentCollection: str|None = ..., flags: 'QgsExpressionBuilderWidget.Flag' = ...) -> None: ...
    def init(self, context: _core.QgsExpressionContext = ..., recentCollection: str|None = ..., flags: 'QgsExpressionBuilderWidget.Flag' = ...) -> None: ...


class QgsExpressionHighlighter(QtGui.QSyntaxHighlighter):

    def __init__(self, parent: QtGui.QTextDocument|None = ...) -> None: ...

    def highlightBlock(self, text: str|None) -> None: ...
    def addFields(self, fieldList: collections.abc.Iterable[str|None]) -> None: ...


class QgsExpressionLineEdit(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def changeEvent(self, event: QtCore.QEvent|None) -> None: ...
    def setExpression(self, expression: str|None) -> None: ...
    expressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def isValidExpression(self) -> typing.Tuple[bool, str]: ...
    def expression(self) -> str: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def setGeomCalculator(self, distanceArea: _core.QgsDistanceArea) -> None: ...
    def setExpectedOutputFormat(self, expected: str|None) -> None: ...
    def expectedOutputFormat(self) -> str: ...
    def setMultiLine(self, multiLine: bool) -> None: ...
    def expressionDialogTitle(self) -> str: ...
    def setExpressionDialogTitle(self, title: str|None) -> None: ...


class QgsExpressionPreviewWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setCurrentFeature(self, feature: _core.QgsFeature) -> None: ...
    toolTipChanged: typing.ClassVar[QtCore.pyqtSignal]
    parserErrorChanged: typing.ClassVar[QtCore.pyqtSignal]
    evalErrorChanged: typing.ClassVar[QtCore.pyqtSignal]
    expressionParsed: typing.ClassVar[QtCore.pyqtSignal]
    def currentPreviewText(self) -> str: ...
    def parserErrors(self) -> list[_core.QgsExpression.ParserError]: ...
    def rootNode(self) -> _core.QgsExpressionNode|None: ...
    def parserError(self) -> bool: ...
    def evalError(self) -> bool: ...
    def setGeomCalculator(self, da: _core.QgsDistanceArea) -> None: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext) -> None: ...
    def expressionContext(self) -> _core.QgsExpressionContext: ...
    def setExpressionText(self, expression: str|None) -> None: ...
    def setCustomPreviewGenerator(self, label: str|None, choices: collections.abc.Iterable[tuple[str|None, typing.Any]], a2: typing.Callable[..., None]) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...


class QgsExpressionSelectionDialog(QtWidgets.QDialog):

    def __init__(self, layer: _core.QgsVectorLayer|None, startText: str|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def done(self, r: int) -> None: ...
    def closeEvent(self, closeEvent: QtGui.QCloseEvent|None) -> None: ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None') -> None: ...
    def setMessageBar(self, messageBar: 'QgsMessageBar|None') -> None: ...
    def setGeomCalculator(self, da: _core.QgsDistanceArea) -> None: ...
    def expressionText(self) -> str: ...
    def setExpressionText(self, text: str|None) -> None: ...
    def expressionBuilder(self) -> QgsExpressionBuilderWidget|None: ...


class QgsExpressionItem(QtGui.QStandardItem):

    class ItemType(enum.IntEnum):
        Header = ... # type: QgsExpressionItem.ItemType
        Field = ... # type: QgsExpressionItem.ItemType
        ExpressionNode = ... # type: QgsExpressionItem.ItemType

    CUSTOM_SORT_ROLE = ... # type: int
    ITEM_NAME_ROLE = ... # type: int
    ITEM_TYPE_ROLE = ... # type: int
    LAYER_ID_ROLE = ... # type: int
    SEARCH_TAGS_ROLE = ... # type: int

    @typing.overload
    def __init__(self, label: str|None, expressionText: str|None, helpText: str|None, itemType: 'QgsExpressionItem.ItemType' = ...) -> None: ...
    @typing.overload
    def __init__(self, label: str|None, expressionText: str|None, itemType: 'QgsExpressionItem.ItemType' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsExpressionItem') -> None: ...

    def getItemType(self) -> 'QgsExpressionItem.ItemType': ...
    def setHelpText(self, helpText: str|None) -> None: ...
    def getHelpText(self) -> str: ...
    def getExpressionText(self) -> str: ...


class QgsExpressionItemSearchProxy(QtCore.QSortFilterProxyModel):

    def __init__(self) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def setFilterString(self, string: str|None) -> None: ...
    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...


class QgsExpressionTreeView(QtWidgets.QTreeView):

    class MenuProvider(PyQt6.sip.wrapper):

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsExpressionTreeView.MenuProvider') -> None: ...

        def createContextMenu(self, item: QgsExpressionItem|None) -> QtWidgets.QMenu|None: ...

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setSearchText(self, text: str|None) -> None: ...
    currentExpressionItemChanged: typing.ClassVar[QtCore.pyqtSignal]
    expressionItemDoubleClicked: typing.ClassVar[QtCore.pyqtSignal]
    def loadExpressionsFromJson(self, expressionsDocument: QtCore.QJsonDocument) -> None: ...
    def exportUserExpressions(self) -> QtCore.QJsonDocument: ...
    def findExpressions(self, label: str|None) -> list[QgsExpressionItem]: ...
    def loadUserExpressions(self) -> None: ...
    def removeFromUserExpressions(self, label: str|None) -> None: ...
    def saveToUserExpressions(self, label: str|None, expression: str|None, helpText: str|None) -> None: ...
    def saveToRecent(self, expressionText: str|None, collection: str|None = ...) -> None: ...
    def loadRecent(self, collection: str|None = ...) -> None: ...
    def currentItem(self) -> QgsExpressionItem|None: ...
    def refresh(self) -> None: ...
    def setMenuProvider(self, provider: 'QgsExpressionTreeView.MenuProvider|None') -> None: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def project(self) -> _core.QgsProject|None: ...
    def expressionContext(self) -> _core.QgsExpressionContext: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext) -> None: ...
    def loadFieldNames(self, fields: _core.QgsFields) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...


class QgsExtentGroupBox(QgsCollapsibleGroupBox):

    class ExtentState(enum.IntEnum):
        OriginalExtent = ... # type: QgsExtentGroupBox.ExtentState
        CurrentExtent = ... # type: QgsExtentGroupBox.ExtentState
        UserExtent = ... # type: QgsExtentGroupBox.ExtentState
        ProjectLayerExtent = ... # type: QgsExtentGroupBox.ExtentState
        DrawOnCanvas = ... # type: QgsExtentGroupBox.ExtentState

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    extentLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    extentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setRatio(self, ratio: QtCore.QSize) -> None: ...
    def setOutputExtentFromDrawOnCanvas(self) -> None: ...
    def setOutputExtentFromLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def setOutputExtentFromUser(self, extent: _core.QgsRectangle, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setOutputExtentFromCurrent(self) -> None: ...
    def setOutputExtentFromOriginal(self) -> None: ...
    def ratio(self) -> QtCore.QSize: ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None', drawOnCanvasOption: bool = ...) -> None: ...
    def titleBase(self) -> str: ...
    def setTitleBase(self, title: str|None) -> None: ...
    def extentState(self) -> 'QgsExtentGroupBox.ExtentState': ...
    def outputCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def outputExtent(self) -> _core.QgsRectangle: ...
    def setOutputCrs(self, outputCrs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def currentCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def currentExtent(self) -> _core.QgsRectangle: ...
    def setCurrentExtent(self, currentExtent: _core.QgsRectangle, currentCrs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def originalCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def originalExtent(self) -> _core.QgsRectangle: ...
    def setOriginalExtent(self, originalExtent: _core.QgsRectangle, originalCrs: _core.QgsCoordinateReferenceSystem) -> None: ...


class QgsExtentWidget(QtWidgets.QWidget):

    class WidgetStyle(enum.IntEnum):
        CondensedStyle = ... # type: QgsExtentWidget.WidgetStyle
        ExpandedStyle = ... # type: QgsExtentWidget.WidgetStyle

    class ExtentState(enum.IntEnum):
        OriginalExtent = ... # type: QgsExtentWidget.ExtentState
        CurrentExtent = ... # type: QgsExtentWidget.ExtentState
        UserExtent = ... # type: QgsExtentWidget.ExtentState
        ProjectLayerExtent = ... # type: QgsExtentWidget.ExtentState
        DrawOnCanvas = ... # type: QgsExtentWidget.ExtentState

    def __init__(self, parent: QtWidgets.QWidget|None = ..., style: 'QgsExtentWidget.WidgetStyle' = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, event: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    extentLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    toggleDialogVisibility: typing.ClassVar[QtCore.pyqtSignal]
    validationChanged: typing.ClassVar[QtCore.pyqtSignal]
    extentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def clear(self) -> None: ...
    def setRatio(self, ratio: QtCore.QSize) -> None: ...
    def setOutputExtentFromDrawOnCanvas(self) -> None: ...
    def setOutputExtentFromLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def setOutputExtentFromUser(self, extent: _core.QgsRectangle, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setOutputExtentFromCurrent(self) -> None: ...
    def setOutputExtentFromOriginal(self) -> None: ...
    def setNullValueAllowed(self, allowed: bool, notSetText: str|None = ...) -> None: ...
    def isValid(self) -> bool: ...
    def extentLayerName(self) -> str: ...
    def ratio(self) -> QtCore.QSize: ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None', drawOnCanvasOption: bool = ...) -> None: ...
    def extentState(self) -> 'QgsExtentWidget.ExtentState': ...
    def outputCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def outputExtent(self) -> _core.QgsRectangle: ...
    def setOutputCrs(self, outputCrs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def currentCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def currentExtent(self) -> _core.QgsRectangle: ...
    def setCurrentExtent(self, currentExtent: _core.QgsRectangle, currentCrs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def originalCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def originalExtent(self) -> _core.QgsRectangle: ...
    def setOriginalExtent(self, originalExtent: _core.QgsRectangle, originalCrs: _core.QgsCoordinateReferenceSystem) -> None: ...


class QgsExternalResourceWidget(QtWidgets.QWidget):

    class DocumentViewerContent(enum.IntEnum):
        NoContent = ... # type: QgsExternalResourceWidget.DocumentViewerContent
        Image = ... # type: QgsExternalResourceWidget.DocumentViewerContent
        Web = ... # type: QgsExternalResourceWidget.DocumentViewerContent
        Audio = ... # type: QgsExternalResourceWidget.DocumentViewerContent
        Video = ... # type: QgsExternalResourceWidget.DocumentViewerContent

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, messageBar: 'QgsMessageBar|None') -> None: ...
    def storageAuthConfigId(self) -> str: ...
    def setStorageAuthConfigId(self, authCfg: str|None) -> None: ...
    def storageType(self) -> str: ...
    def setStorageType(self, storageType: str|None) -> None: ...
    def setDefaultRoot(self, defaultRoot: str|None) -> None: ...
    def defaultRoot(self) -> str: ...
    def setRelativeStorage(self, relativeStorage: 'QgsFileWidget.RelativeStorage') -> None: ...
    def relativeStorage(self) -> 'QgsFileWidget.RelativeStorage': ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def setDocumentViewerWidth(self, width: int) -> None: ...
    def documentViewerWidth(self) -> int: ...
    def setDocumentViewerHeight(self, height: int) -> None: ...
    def documentViewerHeight(self) -> int: ...
    def setDocumentViewerContent(self, content: 'QgsExternalResourceWidget.DocumentViewerContent') -> None: ...
    def documentViewerContent(self) -> 'QgsExternalResourceWidget.DocumentViewerContent': ...
    def setFileWidgetVisible(self, visible: bool) -> None: ...
    def fileWidgetVisible(self) -> bool: ...
    def fileWidget(self) -> 'QgsExternalStorageFileWidget|None': ...
    def setDocumentPath(self, documentPath: typing.Any) -> None: ...
    @typing.overload
    def documentPath(self, type: QtCore.QMetaType.Type = ...) -> typing.Any: ...
    @typing.overload
    @deprecated("""""")
    def documentPath(self, type: typing.Any) -> typing.Any: ...


class QgsFeaturePickerWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    showBrowserButtonsChanged: typing.ClassVar[QtCore.pyqtSignal]
    fetchLimitChanged: typing.ClassVar[QtCore.pyqtSignal]
    fetchGeometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    allowNullChanged: typing.ClassVar[QtCore.pyqtSignal]
    featureChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    displayExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerChanged: typing.ClassVar[QtCore.pyqtSignal]
    modelUpdated: typing.ClassVar[QtCore.pyqtSignal]
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def currentModelIndex(self) -> QtCore.QModelIndex: ...
    def setShowBrowserButtons(self, showBrowserButtons: bool) -> None: ...
    def showBrowserButtons(self) -> bool: ...
    def setFetchLimit(self, fetchLimit: int) -> None: ...
    def fetchLimit(self) -> int: ...
    def setFetchGeometry(self, fetchGeometry: bool) -> None: ...
    def fetchGeometry(self) -> bool: ...
    def setAllowNull(self, allowNull: bool) -> None: ...
    def allowNull(self) -> bool: ...
    def setFilterExpression(self, filterExpression: str|None) -> None: ...
    def nullIndex(self) -> int: ...
    def filterExpression(self) -> str: ...
    def setDisplayExpression(self, displayExpression: str|None) -> None: ...
    def displayExpression(self) -> str: ...
    def feature(self) -> _core.QgsFeature: ...
    def setFeature(self, featureId: int) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...


class QgsFeatureListComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    currentFeatureFoundChanged: typing.ClassVar[QtCore.pyqtSignal]
    currentFeatureChanged: typing.ClassVar[QtCore.pyqtSignal]
    allowNullChanged: typing.ClassVar[QtCore.pyqtSignal]
    identifierFieldChanged: typing.ClassVar[QtCore.pyqtSignal]
    identifierValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    parentFormFeatureChanged: typing.ClassVar[QtCore.pyqtSignal]
    formFeatureChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    displayExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    sourceLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    modelUpdated: typing.ClassVar[QtCore.pyqtSignal]
    def setSortOrder(self, sortOrder: QtCore.Qt.SortOrder) -> None: ...
    def sortOrder(self) -> QtCore.Qt.SortOrder: ...
    def setOrderExpression(self, orderExpression: str|None) -> None: ...
    def orderExpression(self) -> str: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def currentModelIndex(self) -> QtCore.QModelIndex: ...
    def setIdentifierFields(self, identifierFields: collections.abc.Iterable[str|None]) -> None: ...
    @deprecated("""""")
    def setIdentifierField(self, identifierField: str|None) -> None: ...
    def identifierFields(self) -> list[str]: ...
    @deprecated("""""")
    def identifierField(self) -> str: ...
    def setFetchLimit(self, fetchLimit: int) -> None: ...
    def fetchLimit(self) -> int: ...
    def setAllowNull(self, allowNull: bool) -> None: ...
    def allowNull(self) -> bool: ...
    def currentFeatureRequest(self) -> _core.QgsFeatureRequest: ...
    def setIdentifierValuesToNull(self) -> None: ...
    def setIdentifierValues(self, identifierValues: collections.abc.Iterable[typing.Any]) -> None: ...
    @deprecated("""""")
    def setIdentifierValue(self, identifierValue: typing.Any) -> None: ...
    def identifierValues(self) -> list[typing.Any]: ...
    @deprecated("""""")
    def identifierValue(self) -> typing.Any: ...
    def setParentFormFeature(self, feature: _core.QgsFeature) -> None: ...
    def parentFormFeature(self) -> _core.QgsFeature: ...
    def setFormFeature(self, feature: _core.QgsFeature) -> None: ...
    def formFeature(self) -> _core.QgsFeature: ...
    def setFilterExpression(self, filterExpression: str|None) -> None: ...
    def filterExpression(self) -> str: ...
    def nullIndex(self) -> int: ...
    def setDisplayExpression(self, displayExpression: str|None) -> None: ...
    def displayExpression(self) -> str: ...
    def setCurrentFeature(self, feature: _core.QgsFeature) -> None: ...
    def setSourceLayer(self, sourceLayer: _core.QgsVectorLayer|None) -> None: ...
    def sourceLayer(self) -> _core.QgsVectorLayer|None: ...


class QgsFeatureSelectionDlg(QtWidgets.QDialog):

    def __init__(self, vl: _core.QgsVectorLayer|None, context: QgsAttributeEditorContext, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def keyPressEvent(self, evt: QtGui.QKeyEvent|None) -> None: ...
    def setFilterExpression(self, filter: str|None, type: QgsAttributeForm.FilterType) -> None: ...
    def setSelectedFeatures(self, ids: typing.Any) -> None: ...
    def selectedFeatures(self) -> typing.Any: ...


class QgsFieldComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def indexChanged(self, i: int) -> None: ...
    def setField(self, fieldName: str|None) -> None: ...
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    fieldChanged: typing.ClassVar[QtCore.pyqtSignal]
    def fields(self) -> _core.QgsFields: ...
    def setFields(self, fields: _core.QgsFields) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def currentField(self) -> str: ...
    def allowEmptyFieldName(self) -> bool: ...
    def setAllowEmptyFieldName(self, allowEmpty: bool) -> None: ...
    def filters(self) -> _core.QgsFieldProxyModel.Filter: ...
    def setFilters(self, filters: _core.QgsFieldProxyModel.Filter) -> None: ...


class QgsFieldDomainWidget(QtWidgets.QWidget):

    def __init__(self, type: _core.Qgis.FieldDomainType, parent: QtWidgets.QWidget|None = ...) -> None: ...

    validityChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setPoliciesEditable(self, editable: bool) -> None: ...
    def setNameEditable(self, editable: bool) -> None: ...
    def isValid(self) -> bool: ...
    def createFieldDomain(self) -> _core.QgsFieldDomain|None: ...
    def setFieldDomain(self, domain: _core.QgsFieldDomain|None) -> None: ...


class QgsFieldDomainDialog(QtWidgets.QDialog):

    def __init__(self, type: _core.Qgis.FieldDomainType, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def setPoliciesEditable(self, editable: bool) -> None: ...
    def setNameEditable(self, editable: bool) -> None: ...
    def createFieldDomain(self) -> _core.QgsFieldDomain|None: ...
    def setFieldDomain(self, domain: _core.QgsFieldDomain|None) -> None: ...


class QgsFieldExpressionWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def eventFilter(self, watched: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def changeEvent(self, event: QtCore.QEvent|None) -> None: ...
    def isExpressionValid(self, expressionStr: str|None) -> bool: ...
    def updateLineEditStyle(self, expression: str|None = ...) -> None: ...
    def currentFieldChanged(self) -> None: ...
    def expressionEditingFinished(self) -> None: ...
    def expressionEdited(self, expression: str|None) -> None: ...
    def editExpression(self) -> None: ...
    def setExpression(self, expression: str|None) -> None: ...
    def setFields(self, fields: _core.QgsFields) -> None: ...
    def setField(self, fieldName: str|None) -> None: ...
    def setRow(self, row: int) -> None: ...
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    buttonVisibleChanged: typing.ClassVar[QtCore.pyqtSignal]
    allowEvalErrorsChanged: typing.ClassVar[QtCore.pyqtSignal]
    fieldChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setButtonVisible(self, visible: bool) -> None: ...
    def buttonVisible(self) -> bool: ...
    def setAllowEvalErrors(self, allowEvalErrors: bool) -> None: ...
    def allowEvalErrors(self) -> bool: ...
    def setCustomPreviewGenerator(self, label: str|None, choices: collections.abc.Iterable[tuple[str|None, typing.Any]], a2: typing.Callable[..., None]) -> None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def expression(self) -> str: ...
    def asExpression(self) -> str: ...
    def currentText(self) -> str: ...
    def isExpression(self) -> bool: ...
    def isValidExpression(self, expressionError: str|None = ...) -> bool: ...
    def currentField(self) -> typing.Tuple[str, bool, bool]: ...
    def setGeomCalculator(self, da: _core.QgsDistanceArea) -> None: ...
    def filters(self) -> _core.QgsFieldProxyModel.Filter: ...
    def setLeftHandButtonStyle(self, isLeft: bool) -> None: ...
    def allowEmptyFieldName(self) -> bool: ...
    def setAllowEmptyFieldName(self, allowEmpty: bool) -> None: ...
    def setFilters(self, filters: _core.QgsFieldProxyModel.Filter) -> None: ...
    def expressionDialogTitle(self) -> str: ...
    def appendScope(self, scope: _core.QgsExpressionContextScope|None) -> None: ...
    def setExpressionDialogTitle(self, title: str|None) -> None: ...


class QgsFieldMappingWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., sourceFields: _core.QgsFields = ..., destinationFields: _core.QgsFields = ..., expressions: dict[str|None, str|None] = ..., nativeTypes: collections.abc.Iterable[_core.QgsVectorDataProvider.NativeType] = ...) -> None: ...

    def invertSelection(self) -> None: ...
    def moveSelectedFieldsDown(self) -> bool: ...
    def moveSelectedFieldsUp(self) -> bool: ...
    def removeSelectedFields(self) -> bool: ...
    def appendField(self, field: _core.QgsField, expression: str|None = ...) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def scrollTo(self, index: QtCore.QModelIndex) -> None: ...
    def setNativeTypes(self, nativeTypes: collections.abc.Iterable[_core.QgsVectorDataProvider.NativeType]) -> None: ...
    def setDestinationFields(self, destinationFields: _core.QgsFields, expressions: dict[str|None, str|None] = ...) -> None: ...
    def sourceLayer(self) -> _core.QgsVectorLayer|None: ...
    def setSourceLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def setSourceFields(self, sourceFields: _core.QgsFields) -> None: ...
    def selectionModel(self) -> QtCore.QItemSelectionModel|None: ...
    def setFieldPropertyMap(self, map: dict[str|None, _core.QgsProperty]) -> None: ...
    def fieldPropertyMap(self) -> dict[str, _core.QgsProperty]: ...
    def mapping(self) -> list['QgsFieldMappingModel.Field']: ...
    def model(self) -> 'QgsFieldMappingModel|None': ...
    def destinationEditable(self) -> bool: ...
    def setDestinationEditable(self, editable: bool) -> None: ...


class QgsFieldMappingModel(QtCore.QAbstractTableModel):

    class ColumnDataIndex(enum.IntEnum):
        SourceExpression = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationName = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationType = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationLength = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationPrecision = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationConstraints = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationAlias = ... # type: QgsFieldMappingModel.ColumnDataIndex
        DestinationComment = ... # type: QgsFieldMappingModel.ColumnDataIndex

    class Field(PyQt6.sip.wrapper):

        expression = ... # type: str|None
        field = ... # type: _core.QgsField
        originalName = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsFieldMappingModel.Field') -> None: ...

    def __init__(self, sourceFields: _core.QgsFields = ..., destinationFields: _core.QgsFields = ..., expressions: dict[str|None, str|None] = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def setDestinationFields(self, destinationFields: _core.QgsFields, expressions: dict[str|None, str|None] = ...) -> None: ...
    def setBaseExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def contextGenerator(self) -> _core.QgsExpressionContextGenerator|None: ...
    def setSourceFields(self, sourceFields: _core.QgsFields) -> None: ...
    def moveDown(self, index: QtCore.QModelIndex) -> bool: ...
    def moveUp(self, index: QtCore.QModelIndex) -> bool: ...
    def removeField(self, index: QtCore.QModelIndex) -> bool: ...
    def appendField(self, field: _core.QgsField, expression: str|None = ...) -> None: ...
    def setFieldPropertyMap(self, map: dict[str|None, _core.QgsProperty]) -> None: ...
    def fieldPropertyMap(self) -> dict[str, _core.QgsProperty]: ...
    def mapping(self) -> list['QgsFieldMappingModel.Field']: ...
    def sourceFields(self) -> _core.QgsFields: ...
    @staticmethod
    def supportedDataTypes() -> list[_core.QgsVectorDataProvider.NativeType]: ...
    @staticmethod
    def dataTypes() -> dict[QtCore.QMetaType.Type, str]: ...
    def setDestinationEditable(self, editable: bool) -> None: ...
    def destinationEditable(self) -> bool: ...
    def setNativeTypes(self, nativeTypes: collections.abc.Iterable[_core.QgsVectorDataProvider.NativeType]) -> None: ...


class QgsFieldValidator(QtGui.QValidator):

    def __init__(self, parent: QtCore.QObject|None, field: _core.QgsField, defaultValue: str|None, dateFormat: str|None = ...) -> None: ...

    def dateFormat(self) -> str: ...
    def fixup(self, s: typing.Any) -> None: ...
    def validate(self, s: typing.Any, i: int) -> typing.Tuple[QtGui.QValidator.State, str, int]: ...


class QgsFilterLineEdit(QtWidgets.QLineEdit):

    class ClearMode(enum.IntEnum):
        ClearToNull = ... # type: QgsFilterLineEdit.ClearMode
        ClearToDefault = ... # type: QgsFilterLineEdit.ClearMode

    def __init__(self, parent: QtWidgets.QWidget|None = ..., nullValue: str|None = ...) -> None: ...

    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def focusInEvent(self, e: QtGui.QFocusEvent|None) -> None: ...
    selectOnFocusChanged: typing.ClassVar[QtCore.pyqtSignal]
    showSpinnerChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    cleared: typing.ClassVar[QtCore.pyqtSignal]
    def restoreState(self) -> None: ...
    def storeState(self) -> None: ...
    def clearValue(self) -> None: ...
    def hasStateStored(self) -> bool: ...
    def event(self, event: QtCore.QEvent|None) -> bool: ...
    def setSelectOnFocus(self, selectOnFocus: bool) -> None: ...
    def selectOnFocus(self) -> bool: ...
    def setShowSpinner(self, showSpinner: bool) -> None: ...
    def showSpinner(self) -> bool: ...
    def isNull(self) -> bool: ...
    def value(self) -> str: ...
    def setValue(self, value: str|None) -> None: ...
    def defaultValue(self) -> str: ...
    def setDefaultValue(self, defaultValue: str|None) -> None: ...
    def showSearchIcon(self) -> bool: ...
    def setShowSearchIcon(self, visible: bool) -> None: ...
    def nullValue(self) -> str: ...
    def setNullValue(self, nullValue: str|None) -> None: ...
    def setClearMode(self, mode: 'QgsFilterLineEdit.ClearMode') -> None: ...
    def clearMode(self) -> 'QgsFilterLineEdit.ClearMode': ...
    def setShowClearButton(self, visible: bool) -> None: ...
    def showClearButton(self) -> bool: ...


class QgsFieldValuesLineEdit(QgsFilterLineEdit):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    attributeIndexChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerChanged: typing.ClassVar[QtCore.pyqtSignal]
    def attributeIndex(self) -> int: ...
    def setAttributeIndex(self, index: int) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...


class QgsAbstractFileContentSourceLineEdit(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    sourceChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSource(self, source: str|None) -> None: ...
    def setPropertyOverrideToolButtonVisible(self, visible: bool) -> None: ...
    def propertyOverrideToolButton(self) -> 'QgsPropertyOverrideButton|None': ...
    def setLastPathSettingsKey(self, key: str|None) -> None: ...
    def source(self) -> str: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...


class QgsPictureSourceLineEditBase(QgsAbstractFileContentSourceLineEdit):

    class Format(enum.IntEnum):
        Svg = ... # type: QgsPictureSourceLineEditBase.Format
        Image = ... # type: QgsPictureSourceLineEditBase.Format
        AnimatedImage = ... # type: QgsPictureSourceLineEditBase.Format

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, format: 'QgsPictureSourceLineEditBase.Format', parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setMode(self, format: 'QgsPictureSourceLineEditBase.Format') -> None: ...


class QgsSvgSourceLineEdit(QgsPictureSourceLineEditBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsImageSourceLineEdit(QgsPictureSourceLineEditBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsAnimatedImageSourceLineEdit(QgsPictureSourceLineEditBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsFileDownloaderDialog(QtWidgets.QProgressDialog):

    def __init__(self, url: QtCore.QUrl, outputFileName: str|None, authcfg: str|None = ...) -> None: ...

    downloadProgress: typing.ClassVar[QtCore.pyqtSignal]
    downloadError: typing.ClassVar[QtCore.pyqtSignal]
    downloadCanceled: typing.ClassVar[QtCore.pyqtSignal]
    downloadExited: typing.ClassVar[QtCore.pyqtSignal]
    downloadCompleted: typing.ClassVar[QtCore.pyqtSignal]


class QgsFileWidget(QtWidgets.QWidget):

    class RelativeStorage(enum.IntEnum):
        Absolute = ... # type: QgsFileWidget.RelativeStorage
        RelativeProject = ... # type: QgsFileWidget.RelativeStorage
        RelativeDefaultPath = ... # type: QgsFileWidget.RelativeStorage

    class StorageMode(enum.IntEnum):
        GetFile = ... # type: QgsFileWidget.StorageMode
        GetDirectory = ... # type: QgsFileWidget.StorageMode
        GetMultipleFiles = ... # type: QgsFileWidget.StorageMode
        SaveFile = ... # type: QgsFileWidget.StorageMode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def minimumSizeHint(self) -> QtCore.QSize: ...
    def relativePath(self, filePath: str|None, removeRelative: bool) -> str: ...
    def toUrl(self, path: str|None) -> str: ...
    def setFilePaths(self, filePaths: collections.abc.Iterable[str|None]) -> None: ...
    @staticmethod
    def isMultiFiles(path: str|None) -> bool: ...
    def setSelectedFileNames(self, fileNames: collections.abc.Iterable[str|None]) -> None: ...
    def updateLayout(self) -> None: ...
    fileChanged: typing.ClassVar[QtCore.pyqtSignal]
    def lineEdit(self) -> QgsFilterLineEdit|None: ...
    def setRelativeStorage(self, relativeStorage: 'QgsFileWidget.RelativeStorage') -> None: ...
    def relativeStorage(self) -> 'QgsFileWidget.RelativeStorage': ...
    def setStorageMode(self, storageMode: 'QgsFileWidget.StorageMode') -> None: ...
    def storageMode(self) -> 'QgsFileWidget.StorageMode': ...
    def setDefaultRoot(self, defaultRoot: str|None) -> None: ...
    def defaultRoot(self) -> str: ...
    def setFullUrl(self, fullUrl: bool) -> None: ...
    def fullUrl(self) -> bool: ...
    def setUseLink(self, useLink: bool) -> None: ...
    def useLink(self) -> bool: ...
    def setFileWidgetButtonVisible(self, visible: bool) -> None: ...
    def fileWidgetButtonVisible(self) -> bool: ...
    def confirmOverwrite(self) -> bool: ...
    def setConfirmOverwrite(self, confirmOverwrite: bool) -> None: ...
    def selectedFilter(self) -> str: ...
    def setSelectedFilter(self, selectedFilter: str|None) -> None: ...
    def setOptions(self, options: QtWidgets.QFileDialog.Option) -> None: ...
    def options(self) -> QtWidgets.QFileDialog.Option: ...
    def setFilter(self, filter: str|None) -> None: ...
    def filter(self) -> str: ...
    def setDialogTitle(self, title: str|None) -> None: ...
    def dialogTitle(self) -> str: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def setFilePath(self, path: str|None) -> None: ...
    @staticmethod
    def splitFilePaths(path: str|None) -> list[str]: ...
    def filePath(self) -> str: ...


class QgsExternalStorageFileWidget(QgsFileWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    def addFileWidgetScope(self) -> None: ...
    def setSelectedFileNames(self, fileNames: collections.abc.Iterable[str|None]) -> None: ...
    def updateLayout(self) -> None: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    @staticmethod
    def createFileWidgetScope() -> _core.QgsExpressionContextScope|None: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, messageBar: 'QgsMessageBar|None') -> None: ...
    def expressionContext(self) -> _core.QgsExpressionContext: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext) -> None: ...
    def storageUrlExpression(self) -> _core.QgsExpression|None: ...
    def storageUrlExpressionString(self) -> str: ...
    def setStorageUrlExpression(self, urlExpression: str|None) -> None: ...
    def storageAuthConfigId(self) -> str: ...
    def setStorageAuthConfigId(self, authCfg: str|None) -> None: ...
    def externalStorage(self) -> _core.QgsExternalStorage|None: ...
    def storageType(self) -> str: ...
    def setStorageType(self, storageType: str|None) -> None: ...


class QgsFindFilesByPatternWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    findComplete: typing.ClassVar[QtCore.pyqtSignal]
    def files(self) -> list[str]: ...


class QgsFindFilesByPatternDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def files(self) -> list[str]: ...


class QgsFloatingWidget(QtWidgets.QWidget):

    class AnchorPoint(enum.IntEnum):
        TopLeft = ... # type: QgsFloatingWidget.AnchorPoint
        TopMiddle = ... # type: QgsFloatingWidget.AnchorPoint
        TopRight = ... # type: QgsFloatingWidget.AnchorPoint
        MiddleLeft = ... # type: QgsFloatingWidget.AnchorPoint
        Middle = ... # type: QgsFloatingWidget.AnchorPoint
        MiddleRight = ... # type: QgsFloatingWidget.AnchorPoint
        BottomLeft = ... # type: QgsFloatingWidget.AnchorPoint
        BottomMiddle = ... # type: QgsFloatingWidget.AnchorPoint
        BottomRight = ... # type: QgsFloatingWidget.AnchorPoint

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def resizeEvent(self, e: QtGui.QResizeEvent|None) -> None: ...
    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    anchorWidgetPointChanged: typing.ClassVar[QtCore.pyqtSignal]
    anchorPointChanged: typing.ClassVar[QtCore.pyqtSignal]
    anchorWidgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setAnchorWidgetPoint(self, point: 'QgsFloatingWidget.AnchorPoint') -> None: ...
    def anchorWidgetPoint(self) -> 'QgsFloatingWidget.AnchorPoint': ...
    def setAnchorPoint(self, point: 'QgsFloatingWidget.AnchorPoint') -> None: ...
    def anchorPoint(self) -> 'QgsFloatingWidget.AnchorPoint': ...
    def anchorWidget(self) -> QtWidgets.QWidget|None: ...
    def setAnchorWidget(self, widget: QtWidgets.QWidget|None) -> None: ...


class QgsFocusWatcher(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    focusOut: typing.ClassVar[QtCore.pyqtSignal]
    focusIn: typing.ClassVar[QtCore.pyqtSignal]
    focusChanged: typing.ClassVar[QtCore.pyqtSignal]
    def eventFilter(self, obj: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...


class QgsFontButton(QtWidgets.QToolButton):

    class Mode(enum.IntEnum):
        ModeTextRenderer = ... # type: QgsFontButton.Mode
        ModeQFont = ... # type: QgsFontButton.Mode

    def __init__(self, parent: QtWidgets.QWidget|None = ..., dialogTitle: str|None = ...) -> None: ...

    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def dropEvent(self, e: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def changeEvent(self, e: QtCore.QEvent|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def pasteColor(self) -> None: ...
    def copyColor(self) -> None: ...
    def pasteFormat(self) -> None: ...
    def copyFormat(self) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setCurrentFont(self, font: QtGui.QFont) -> None: ...
    def setToNullFormat(self) -> None: ...
    def setTextFormat(self, format: _core.QgsTextFormat) -> None: ...
    def showNullFormat(self) -> bool: ...
    def setNoFormatString(self, string: str|None) -> None: ...
    def setShowNullFormat(self, show: bool) -> None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def currentFont(self) -> QtGui.QFont: ...
    def textFormat(self) -> _core.QgsTextFormat: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...
    def setMapCanvas(self, canvas: 'QgsMapCanvas|None') -> None: ...
    def mapCanvas(self) -> 'QgsMapCanvas|None': ...
    def dialogTitle(self) -> str: ...
    def setDialogTitle(self, title: str|None) -> None: ...
    def setMode(self, mode: 'QgsFontButton.Mode') -> None: ...
    def mode(self) -> 'QgsFontButton.Mode': ...
    def sizeHint(self) -> QtCore.QSize: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsFormAnnotation(_core.QgsAnnotation):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def renderAnnotation(self, context: _core.QgsRenderContext, size: QtCore.QSizeF) -> None: ...
    @staticmethod
    def create() -> 'QgsFormAnnotation|None': ...
    def setAssociatedFeature(self, feature: _core.QgsFeature) -> None: ...
    def readXml(self, itemElem: QtXml.QDomElement, context: _core.QgsReadWriteContext) -> None: ...
    def writeXml(self, elem: QtXml.QDomElement, doc: QtXml.QDomDocument, context: _core.QgsReadWriteContext) -> None: ...
    def designerForm(self) -> str: ...
    def setDesignerForm(self, uiFile: str|None) -> None: ...
    def preferredFrameSize(self) -> QtCore.QSizeF: ...
    def minimumFrameSize(self) -> QtCore.QSizeF: ...
    def clone(self) -> 'QgsFormAnnotation|None': ...


class QgsGeocoderLocatorFilter(_core.QgsAbstractGeocoderLocatorFilter):

    def __init__(self, name: str|None, displayName: str|None, prefix: str|None, geocoder: _core.QgsGeocoderInterface|None, canvas: 'QgsMapCanvas|None', boundingBox: _core.QgsRectangle = ...) -> None: ...

    def clone(self) -> _core.QgsLocatorFilter|None: ...


class QgsGeometryRubberBand(QgsMapCanvasItem):

    class IconType(enum.IntEnum):
        ICON_NONE = ... # type: QgsGeometryRubberBand.IconType
        ICON_CROSS = ... # type: QgsGeometryRubberBand.IconType
        ICON_X = ... # type: QgsGeometryRubberBand.IconType
        ICON_BOX = ... # type: QgsGeometryRubberBand.IconType
        ICON_CIRCLE = ... # type: QgsGeometryRubberBand.IconType
        ICON_FULL_BOX = ... # type: QgsGeometryRubberBand.IconType

    def __init__(self, mapCanvas: 'QgsMapCanvas|None', geomType: _core.Qgis.GeometryType = ...) -> None: ...

    def setGeometryType(self, geometryType: _core.Qgis.GeometryType) -> None: ...
    def geometryType(self) -> _core.Qgis.GeometryType: ...
    def paint(self, painter: QtGui.QPainter|None) -> None: ...
    def updatePosition(self) -> None: ...
    def setVertexDrawingEnabled(self, isVerticesDrawn: bool) -> None: ...
    def setIconType(self, iconType: 'QgsGeometryRubberBand.IconType') -> None: ...
    def setBrushStyle(self, brushStyle: QtCore.Qt.BrushStyle) -> None: ...
    def setLineStyle(self, penStyle: QtCore.Qt.PenStyle) -> None: ...
    def setStrokeWidth(self, width: int) -> None: ...
    def setStrokeColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setFillColor(self, c: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def moveVertex(self, id: _core.QgsVertexId, newPos: _core.QgsPoint) -> None: ...
    def geometry(self) -> _core.QgsAbstractGeometry|None: ...
    def setGeometry(self, geom: _core.QgsAbstractGeometry|None) -> None: ...


class QgsGeometryWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    geometryValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def copyAsGeoJson(self) -> None: ...
    def copyAsWkt(self) -> None: ...
    def clearGeometry(self) -> None: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def isReadOnly(self) -> bool: ...
    def acceptedWkbTypes(self) -> list[_core.Qgis.WkbType]: ...
    def setAcceptedWkbTypes(self, types: collections.abc.Iterable[_core.Qgis.WkbType]) -> None: ...
    def geometryValue(self) -> _core.QgsReferencedGeometry: ...
    def setGeometryValue(self, geometry: _core.QgsReferencedGeometry) -> None: ...


class QgsGpsToolsInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsGpsToolsInterface') -> None: ...

    def setGpsTrackLineSymbol(self, symbol: _core.QgsLineSymbol|None) -> None: ...
    def createFeatureFromGpsTrack(self) -> None: ...
    def setGpsPanelConnection(self, connection: _core.QgsGpsConnection|None) -> None: ...


class QgsGradientColorRampDialog(QtWidgets.QDialog):

    def __init__(self, ramp: _core.QgsGradientColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor1(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def setRamp(self, ramp: _core.QgsGradientColorRamp) -> None: ...
    def ramp(self) -> _core.QgsGradientColorRamp: ...


class QgsGradientStopEditor(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., ramp: _core.QgsGradientColorRamp|None = ...) -> None: ...

    def dropEvent(self, e: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseDoubleClickEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    selectedStopChanged: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor1(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def deleteSelectedStop(self) -> None: ...
    def setSelectedStopDetails(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int, offset: float) -> None: ...
    def setSelectedStopDirection(self, direction: _core.Qgis.AngularDirection) -> None: ...
    def setSelectedStopColorSpec(self, spec: QtGui.QColor.Spec) -> None: ...
    def setSelectedStopOffset(self, offset: float) -> None: ...
    def setSelectedStopColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def selectedStop(self) -> _core.QgsGradientStop: ...
    def selectStop(self, index: int) -> None: ...
    def gradientRamp(self) -> _core.QgsGradientColorRamp: ...
    def setGradientRamp(self, ramp: _core.QgsGradientColorRamp) -> None: ...


class QgsGroupWmsDataDialog(QtWidgets.QDialog):

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...
    @typing.overload
    def __init__(self, serverProperties: _core.QgsMapLayerServerProperties, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def serverProperties(self) -> _core.QgsMapLayerServerProperties|None: ...
    def hasTimeDimension(self) -> bool: ...
    def setHasTimeDimension(self, hasTimeDimension: bool) -> None: ...
    @deprecated("""""")
    def setGroupAbstract(self, abstract: str|None) -> None: ...
    @deprecated("""""")
    def setGroupShortName(self, shortName: str|None) -> None: ...
    @deprecated("""""")
    def setGroupTitle(self, title: str|None) -> None: ...
    def groupAbstract(self) -> str: ...
    def groupShortName(self) -> str: ...
    def groupTitle(self) -> str: ...


class QgsGui(QtCore.QObject):

    class HigFlag(enum.IntEnum):
        HigMenuTextIsTitleCase = ... # type: QgsGui.HigFlag
        HigDialogTitleIsTitleCase = ... # type: QgsGui.HigFlag

    class ProjectCrsBehavior(enum.IntEnum):
        UseCrsOfFirstLayerAdded = ... # type: QgsGui.ProjectCrsBehavior
        UsePresetCrs = ... # type: QgsGui.ProjectCrsBehavior

    optionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def hasWebEngine() -> bool: ...
    @staticmethod
    def findScreenAt(point: QtCore.QPoint) -> QtGui.QScreen|None: ...
    @staticmethod
    def sampleColor(point: QtCore.QPoint) -> QtGui.QColor: ...
    @staticmethod
    def higFlags() -> 'QgsGui.HigFlag': ...
    @staticmethod
    def storedQueryManager() -> 'QgsStoredQueryManager|None': ...
    @staticmethod
    def inputControllerManager() -> 'QgsInputControllerManager|None': ...
    @staticmethod
    def setWindowManager(manager: 'QgsWindowManagerInterface|None') -> None: ...
    @staticmethod
    def windowManager() -> 'QgsWindowManagerInterface|None': ...
    @staticmethod
    def enableAutoGeometryRestore(widget: QtWidgets.QWidget|None, key: str|None = ...) -> None: ...
    @staticmethod
    def settingsEditorWidgetRegistry() -> 'QgsSettingsEditorWidgetRegistry|None': ...
    @staticmethod
    def historyProviderRegistry() -> 'QgsHistoryProviderRegistry|None': ...
    @staticmethod
    def relationWidgetRegistry() -> 'QgsRelationWidgetRegistry|None': ...
    @staticmethod
    def sourceWidgetProviderRegistry() -> 'QgsProviderSourceWidgetProviderRegistry|None': ...
    @staticmethod
    def subsetStringEditorProviderRegistry() -> 'QgsSubsetStringEditorProviderRegistry|None': ...
    @staticmethod
    def sensorGuiRegistry() -> 'QgsSensorGuiRegistry|None': ...
    @staticmethod
    def providerGuiRegistry() -> 'QgsProviderGuiRegistry|None': ...
    @staticmethod
    def projectStorageGuiRegistry() -> 'QgsProjectStorageGuiRegistry|None': ...
    @staticmethod
    def dataItemGuiProviderRegistry() -> QgsDataItemGuiProviderRegistry|None: ...
    @staticmethod
    def processingFavoriteAlgorithmManager() -> 'QgsProcessingFavoriteAlgorithmManager|None': ...
    @staticmethod
    def processingRecentAlgorithmLog() -> 'QgsProcessingRecentAlgorithmLog|None': ...
    @staticmethod
    def codeEditorColorSchemeRegistry() -> 'QgsCodeEditorColorSchemeRegistry|None': ...
    @staticmethod
    def numericFormatGuiRegistry() -> 'QgsNumericFormatGuiRegistry|None': ...
    @staticmethod
    def processingGuiRegistry() -> 'QgsProcessingGuiRegistry|None': ...
    @staticmethod
    def advancedDigitizingToolsRegistry() -> QgsAdvancedDigitizingToolsRegistry|None: ...
    @staticmethod
    def annotationItemGuiRegistry() -> 'QgsAnnotationItemGuiRegistry|None': ...
    @staticmethod
    def layoutItemGuiRegistry() -> 'QgsLayoutItemGuiRegistry|None': ...
    @staticmethod
    def mapLayerActionRegistry() -> 'QgsMapLayerActionRegistry|None': ...
    @staticmethod
    def layerTreeEmbeddedWidgetRegistry() -> 'QgsLayerTreeEmbeddedWidgetRegistry|None': ...
    @staticmethod
    def shortcutsManager() -> 'QgsShortcutsManager|None': ...
    @staticmethod
    def sourceSelectProviderRegistry() -> 'QgsSourceSelectProviderRegistry|None': ...
    @staticmethod
    def editorWidgetRegistry() -> 'QgsEditorWidgetRegistry|None': ...
    @staticmethod
    def settingsRegistryGui() -> 'QgsSettingsRegistryGui|None': ...
    @staticmethod
    def instance() -> 'QgsGui|None': ...


class QgsHelp(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHelp') -> None: ...

    @staticmethod
    def helpUrl(key: str|None) -> QtCore.QUrl: ...
    @staticmethod
    def openHelp(key: str|None) -> None: ...


class QgsHighlight(QgsMapCanvasItem):

    @typing.overload
    def __init__(self, mapCanvas: 'QgsMapCanvas|None', geom: _core.QgsGeometry, layer: _core.QgsMapLayer|None) -> None: ...
    @typing.overload
    def __init__(self, mapCanvas: 'QgsMapCanvas|None', feature: _core.QgsFeature, layer: _core.QgsVectorLayer|None) -> None: ...

    def updateRect(self) -> None: ...
    def paint(self, p: QtGui.QPainter|None) -> None: ...
    def applyDefaultStyle(self) -> None: ...
    def updatePosition(self) -> None: ...
    def layer(self) -> _core.QgsMapLayer|None: ...
    def setMinWidth(self, width: float) -> None: ...
    def setBuffer(self, buffer: float) -> None: ...
    def buffer(self) -> float: ...
    def setWidth(self, width: int) -> None: ...
    def width(self) -> int: ...
    def setFillColor(self, fillColor: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...


class QgsHighlightableLineEdit(QgsFilterLineEdit):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...
    def setHighlighted(self, highlighted: bool) -> None: ...
    def isHighlighted(self) -> bool: ...


class QgsHistogramWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsVectorLayer|None = ..., fieldOrExp: str|None = ...) -> None: ...

    def drawHistogram(self) -> None: ...
    def setSourceFieldExp(self, fieldOrExp: str|None) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def refresh(self) -> None: ...
    def refreshValues(self) -> None: ...
    def setYAxisTitle(self, title: str|None) -> None: ...
    def yAxisTitle(self) -> str: ...
    def setXAxisTitle(self, title: str|None) -> None: ...
    def xAxisTitle(self) -> str: ...
    def graduatedRanges(self) -> list[_core.QgsRendererRange]: ...
    def setGraduatedRanges(self, ranges: collections.abc.Iterable[_core.QgsRendererRange]) -> None: ...
    def brush(self) -> QtGui.QBrush: ...
    def setBrush(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    def pen(self) -> QtGui.QPen: ...
    def setPen(self, pen: QtGui.QPen|QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def sourceFieldExp(self) -> str: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...


class QgsHttpHeaderWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @deprecated("""""")
    def updateSettings(self, settings: _core.QgsSettings, key: str|None) -> None: ...
    @deprecated("""""")
    def setFromSettings(self, settings: _core.QgsSettings, key: str|None) -> None: ...
    def setHeaders(self, headers: _core.QgsHttpHeaders) -> None: ...
    def httpHeaders(self) -> _core.QgsHttpHeaders: ...


class QgsIdentifyMenu(QtWidgets.QMenu):

    class MenuLevel(enum.IntEnum):
        LayerLevel = ... # type: QgsIdentifyMenu.MenuLevel
        FeatureLevel = ... # type: QgsIdentifyMenu.MenuLevel

    class ActionData(PyQt6.sip.wrapper):

        mAllResults = ... # type: bool
        mFeatureId = ... # type: int
        mIsExternalAction = ... # type: bool
        mIsValid = ... # type: bool
        mLayer = ... # type: _core.QgsMapLayer
        mLevel = ... # type: 'QgsIdentifyMenu.MenuLevel'
        mMapLayerAction = ... # type: 'QgsMapLayerAction'

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, layer: _core.QgsMapLayer|None, mapLayerAction: 'QgsMapLayerAction|None' = ...) -> None: ...
        @typing.overload
        def __init__(self, layer: _core.QgsMapLayer|None, fid: int, mapLayerAction: 'QgsMapLayerAction|None' = ...) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsIdentifyMenu.ActionData') -> None: ...

    def __init__(self, canvas: 'QgsMapCanvas|None') -> None: ...

    def closeEvent(self, e: QtGui.QCloseEvent|None) -> None: ...
    messageDiscarded: typing.ClassVar[QtCore.pyqtSignal]
    messageEmitted: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    @deprecated("""""")
    def styleHighlight(highlight: QgsHighlight|None) -> None: ...
    def exec(self, idResults: collections.abc.Iterable['QgsMapToolIdentify.IdentifyResult'], pos: QtCore.QPoint) -> list['QgsMapToolIdentify.IdentifyResult']: ...
    def removeCustomActions(self) -> None: ...
    def addCustomAction(self, action: 'QgsMapLayerAction|None') -> None: ...
    def maxFeatureDisplay(self) -> int: ...
    def setMaxFeatureDisplay(self, maxFeatureDisplay: int) -> None: ...
    def maxLayerDisplay(self) -> int: ...
    def setMaxLayerDisplay(self, maxLayerDisplay: int) -> None: ...
    def resultsIfExternalAction(self) -> bool: ...
    def setResultsIfExternalAction(self, resultsIfExternalAction: bool) -> None: ...
    def showFeatureActions(self) -> bool: ...
    def setShowFeatureActions(self, showFeatureActions: bool) -> None: ...
    def expressionContextScope(self) -> _core.QgsExpressionContextScope: ...
    def setExpressionContextScope(self, scope: _core.QgsExpressionContextScope) -> None: ...
    def execWithSingleResult(self) -> bool: ...
    def setExecWithSingleResult(self, execWithSingleResult: bool) -> None: ...
    def allowMultipleReturn(self) -> bool: ...
    def setAllowMultipleReturn(self, multipleReturn: bool) -> None: ...
    @staticmethod
    def findFeaturesOnCanvas(event: 'QgsMapMouseEvent|None', canvas: 'QgsMapCanvas|None', geometryTypes: collections.abc.Iterable[_core.Qgis.GeometryType]) -> list['QgsMapToolIdentify.IdentifyResult']: ...


class QgsTableWidgetBase(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def init(self, model: QtCore.QAbstractTableModel|None) -> None: ...
    def setReadOnly(self, readOnly: bool) -> None: ...
    def isReadOnly(self) -> bool: ...


class QgsKeyValueWidget(QgsTableWidgetBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setReadOnly(self, readOnly: bool) -> None: ...
    def map(self) -> dict[str, typing.Any]: ...
    def setMap(self, map: dict[str|None, typing.Any]) -> None: ...


class QgsLayerMetadataSearchWidget(QgsAbstractDataSourceWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., widgetMode: _core.QgsProviderRegistry.WidgetMode = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def reset(self) -> None: ...
    def addButtonClicked(self) -> None: ...
    def refresh(self) -> None: ...
    def updateExtentFilter(self, index: int) -> None: ...
    def setMapCanvas(self, mapCanvas: 'QgsMapCanvas|None') -> None: ...


class QgsLayerMetadataResultsModel(QtCore.QAbstractTableModel):

    class Sections(enum.IntEnum):
        Identifier = ... # type: QgsLayerMetadataResultsModel.Sections
        Title = ... # type: QgsLayerMetadataResultsModel.Sections
        Abstract = ... # type: QgsLayerMetadataResultsModel.Sections
        DataProviderName = ... # type: QgsLayerMetadataResultsModel.Sections
        GeometryType = ... # type: QgsLayerMetadataResultsModel.Sections

    class CustomRole(enum.IntEnum):
        Metadata = ... # type: QgsLayerMetadataResultsModel.CustomRole

    def __init__(self, searchContext: _core.QgsMetadataSearchContext, parent: QtCore.QObject|None = ...) -> None: ...

    progressChanged: typing.ClassVar[QtCore.pyqtSignal]
    def cancel(self) -> None: ...
    def resultsReady(self, results: _core.QgsLayerMetadataSearchResults) -> None: ...
    def reloadAsync(self) -> None: ...
    def reload(self) -> None: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...


class QgsLayerMetadataResultsProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setFilterMapLayerType(self, mapLayerType: _core.Qgis.LayerType) -> None: ...
    def setFilterString(self, filterString: str|None) -> None: ...
    def setFilterGeometryType(self, geometryType: _core.Qgis.GeometryType) -> None: ...
    def setFilterExtent(self, extent: _core.QgsRectangle) -> None: ...
    def setFilterMapLayerTypeEnabled(self, enabled: bool) -> None: ...
    def setFilterGeometryTypeEnabled(self, enabled: bool) -> None: ...
    def filterString(self) -> str: ...


class QgsOptionsDialogBase(QtWidgets.QDialog):

    def __init__(self, settingsKey: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., settings: _core.QgsSettings|None = ...) -> None: ...

    def registerTextSearchWidgets(self) -> None: ...
    def updateWindowTitle(self) -> None: ...
    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def warnAboutMissingObjects(self) -> None: ...
    def optionsStackedWidget_WidgetRemoved(self, index: int) -> None: ...
    def optionsStackedWidget_CurrentChanged(self, index: int) -> None: ...
    def updateOptionsListVerticalTabs(self) -> None: ...
    def searchText(self, text: str|None) -> None: ...
    def insertPage(self, title: str|None, tooltip: str|None, icon: QtGui.QIcon, widget: QtWidgets.QWidget|None, before: str|None, path: collections.abc.Iterable[str|None] = ..., key: str|None = ...) -> None: ...
    def addPage(self, title: str|None, tooltip: str|None, icon: QtGui.QIcon, widget: QtWidgets.QWidget|None, path: collections.abc.Iterable[str|None] = ..., key: str|None = ...) -> None: ...
    def setCurrentPage(self, page: str|None) -> None: ...
    def iconOnly(self) -> bool: ...
    def resizeAlltabs(self, index: int) -> None: ...
    def restoreLastPage(self) -> None: ...
    def restoreOptionsBaseUi(self, title: str|None = ...) -> None: ...
    def setSettings(self, settings: _core.QgsSettings|None) -> None: ...
    def initOptionsBase(self, restoreUi: bool = ..., title: str|None = ...) -> None: ...


class QgsLayerPropertiesDialog(QgsOptionsDialogBase):

    def __init__(self, layer: _core.QgsMapLayer|None, canvas: 'QgsMapCanvas|None', settingsKey: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., settings: _core.QgsSettings|None = ...) -> None: ...

    def openUrl(self, url: QtCore.QUrl) -> None: ...
    def optionsStackedWidget_CurrentChanged(self, index: int) -> None: ...
    def rollback(self) -> None: ...
    def storeCurrentStyleForUndo(self) -> None: ...
    def refocusDialog(self) -> None: ...
    def initialize(self) -> None: ...
    def loadDefaultStyle(self) -> None: ...
    def saveStyleAsDefault(self) -> None: ...
    def saveStyleToFile(self) -> None: ...
    def loadStyleFromFile(self) -> None: ...
    def loadDefaultMetadata(self) -> None: ...
    def saveMetadataAsDefault(self) -> None: ...
    def saveMetadataToFile(self) -> None: ...
    def loadMetadataFromFile(self) -> None: ...
    def saveStyleAs(self) -> None: ...
    def loadStyle(self) -> None: ...
    def saveDefaultStyle(self) -> None: ...
    def addPropertiesPageFactory(self, factory: 'QgsMapLayerConfigWidgetFactory|None') -> None: ...
    def setMetadataWidget(self, widget: 'QgsMetadataWidget|None', page: QtWidgets.QWidget|None) -> None: ...


class QgsLegendFilterButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    expressionTextChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setVectorLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def vectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def setExpressionText(self, expression: str|None) -> None: ...
    def expressionText(self) -> str: ...


class QgsLegendPatchShapeButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., dialogTitle: str|None = ...) -> None: ...

    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def changeEvent(self, e: QtCore.QEvent|None) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setToDefault(self) -> None: ...
    def setShape(self, shape: _core.QgsLegendPatchShape) -> None: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...
    def shape(self) -> _core.QgsLegendPatchShape: ...
    def dialogTitle(self) -> str: ...
    def setDialogTitle(self, title: str|None) -> None: ...
    def setPreviewSymbol(self, symbol: _core.QgsSymbol|None) -> None: ...
    def symbolType(self) -> _core.Qgis.SymbolType: ...
    def setSymbolType(self, type: _core.Qgis.SymbolType) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsLegendPatchShapeWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., shape: _core.QgsLegendPatchShape = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setShape(self, shape: _core.QgsLegendPatchShape) -> None: ...
    def shape(self) -> _core.QgsLegendPatchShape: ...


class QgsLegendPatchShapeDialog(QtWidgets.QDialog):

    def __init__(self, shape: _core.QgsLegendPatchShape, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def shape(self) -> _core.QgsLegendPatchShape: ...


class QgsLimitedRandomColorRampWidget(QgsPanelWidget):

    def __init__(self, ramp: _core.QgsLimitedRandomColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setVal2(self, val: int) -> None: ...
    def setVal1(self, val: int) -> None: ...
    def setSat2(self, val: int) -> None: ...
    def setSat1(self, val: int) -> None: ...
    def setHue2(self, val: int) -> None: ...
    def setHue1(self, val: int) -> None: ...
    def setCount(self, val: int) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setRamp(self, ramp: _core.QgsLimitedRandomColorRamp) -> None: ...
    def ramp(self) -> _core.QgsLimitedRandomColorRamp: ...


class QgsLimitedRandomColorRampDialog(QtWidgets.QDialog):

    def __init__(self, ramp: _core.QgsLimitedRandomColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def setRamp(self, ramp: _core.QgsLimitedRandomColorRamp) -> None: ...
    def ramp(self) -> _core.QgsLimitedRandomColorRamp: ...


class QgsListWidget(QgsTableWidgetBase):

    def __init__(self, subType: QtCore.QMetaType.Type, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setReadOnly(self, readOnly: bool) -> None: ...
    def valid(self) -> bool: ...
    def list(self) -> list[typing.Any]: ...
    def setList(self, list: collections.abc.Iterable[typing.Any]) -> None: ...


class QgsLongLongValidator(QtGui.QValidator):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None) -> None: ...
    @typing.overload
    def __init__(self, bottom: int, top: int, parent: QtCore.QObject|None) -> None: ...

    def top(self) -> int: ...
    def bottom(self) -> int: ...
    def setRange(self, bottom: int, top: int) -> None: ...
    def setTop(self, top: int) -> None: ...
    def setBottom(self, bottom: int) -> None: ...
    def validate(self, input: str|None) -> typing.Tuple[QtGui.QValidator.State, int]: ...


class QgsLUDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def setUpperValue(self, val: str|None) -> None: ...
    def upperValueDouble(self) -> float: ...
    def upperValue(self) -> str: ...
    def setLowerValue(self, val: str|None) -> None: ...
    def lowerValueDouble(self) -> float: ...
    def lowerValue(self) -> str: ...


class QgsManageConnectionsDialog(QtWidgets.QDialog):

    class Type(enum.IntEnum):
        WMS = ... # type: QgsManageConnectionsDialog.Type
        PostGIS = ... # type: QgsManageConnectionsDialog.Type
        WFS = ... # type: QgsManageConnectionsDialog.Type
        MSSQL = ... # type: QgsManageConnectionsDialog.Type
        WCS = ... # type: QgsManageConnectionsDialog.Type
        Oracle = ... # type: QgsManageConnectionsDialog.Type
        HANA = ... # type: QgsManageConnectionsDialog.Type
        XyzTiles = ... # type: QgsManageConnectionsDialog.Type
        ArcgisMapServer = ... # type: QgsManageConnectionsDialog.Type
        ArcgisFeatureServer = ... # type: QgsManageConnectionsDialog.Type
        VectorTile = ... # type: QgsManageConnectionsDialog.Type
        TiledScene = ... # type: QgsManageConnectionsDialog.Type
        SensorThings = ... # type: QgsManageConnectionsDialog.Type
        CloudStorage = ... # type: QgsManageConnectionsDialog.Type
        STAC = ... # type: QgsManageConnectionsDialog.Type

    class Mode(enum.IntEnum):
        Export = ... # type: QgsManageConnectionsDialog.Mode
        Import = ... # type: QgsManageConnectionsDialog.Mode

    def __init__(self, parent: QtWidgets.QWidget|None = ..., mode: 'QgsManageConnectionsDialog.Mode' = ..., type: 'QgsManageConnectionsDialog.Type' = ..., fileName: str|None = ...) -> None: ...

    def selectionChanged(self) -> None: ...
    def clearSelection(self) -> None: ...
    def selectAll(self) -> None: ...
    def doExportImport(self) -> None: ...


class QgsMapCanvas(QtWidgets.QGraphicsView, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def updateCanvasItemPositions(self) -> None: ...
    def emitExtentsChanged(self) -> None: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def moveCanvasContents(self, reset: bool = ...) -> None: ...
    def viewportEvent(self, event: QtCore.QEvent|None) -> bool: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...
    def resizeEvent(self, e: QtGui.QResizeEvent|None) -> None: ...
    def wheelEvent(self, e: QtGui.QWheelEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def keyReleaseEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...
    contextMenuAboutToShow: typing.ClassVar[QtCore.pyqtSignal]
    zRangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    temporalRangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    tapAndHoldGestureOccurred: typing.ClassVar[QtCore.pyqtSignal]
    panDistanceBearingChanged: typing.ClassVar[QtCore.pyqtSignal]
    renderErrorOccurred: typing.ClassVar[QtCore.pyqtSignal]
    messageEmitted: typing.ClassVar[QtCore.pyqtSignal]
    themeChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerStyleOverridesChanged: typing.ClassVar[QtCore.pyqtSignal]
    currentLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    transformContextChanged: typing.ClassVar[QtCore.pyqtSignal]
    destinationCrsChanged: typing.ClassVar[QtCore.pyqtSignal]
    zoomNextStatusChanged: typing.ClassVar[QtCore.pyqtSignal]
    zoomLastStatusChanged: typing.ClassVar[QtCore.pyqtSignal]
    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapToolSet: typing.ClassVar[QtCore.pyqtSignal]
    keyReleased: typing.ClassVar[QtCore.pyqtSignal]
    keyPressed: typing.ClassVar[QtCore.pyqtSignal]
    layersChanged: typing.ClassVar[QtCore.pyqtSignal]
    mapRefreshCanceled: typing.ClassVar[QtCore.pyqtSignal]
    renderStarting: typing.ClassVar[QtCore.pyqtSignal]
    mapCanvasRefreshed: typing.ClassVar[QtCore.pyqtSignal]
    renderComplete: typing.ClassVar[QtCore.pyqtSignal]
    canvasColorChanged: typing.ClassVar[QtCore.pyqtSignal]
    magnificationChanged: typing.ClassVar[QtCore.pyqtSignal]
    rotationChanged: typing.ClassVar[QtCore.pyqtSignal]
    extentsChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleLockChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    xyCoordinates: typing.ClassVar[QtCore.pyqtSignal]
    def setZRange(self, range: _core.QgsDoubleRange) -> None: ...
    def zRange(self) -> _core.QgsDoubleRange: ...
    def zoomResolutions(self) -> list[float]: ...
    def zoomOutFactor(self) -> float: ...
    def zoomInFactor(self) -> float: ...
    def setZoomResolutions(self, resolutions: collections.abc.Iterable[float]) -> None: ...
    @typing.overload
    def zoomToSelected(self, layer: _core.QgsMapLayer|None = ...) -> None: ...
    @typing.overload
    def zoomToSelected(self, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def zoomOut(self) -> None: ...
    def zoomIn(self) -> None: ...
    def setScaleLocked(self, isLocked: bool) -> None: ...
    def setMagnificationFactor(self, factor: float, center: _core.QgsPointXY|None = ...) -> None: ...
    def writeProject(self, a0: QtXml.QDomDocument) -> None: ...
    def readProject(self, a0: QtXml.QDomDocument) -> None: ...
    def stopRendering(self) -> None: ...
    def setRenderFlag(self, flag: bool) -> None: ...
    def layerStateChange(self) -> None: ...
    def saveAsImage(self, fileName: str|None, QPixmap: QtGui.QPixmap|None = ..., a2: str|None = ...) -> None: ...
    def selectionChangedSlot(self) -> None: ...
    def redrawAllLayers(self) -> None: ...
    def refreshAllLayers(self) -> None: ...
    def refresh(self) -> None: ...
    def setStatusBar(self, bar: 'QgsStatusBar|None') -> None: ...
    def statusBar(self) -> 'QgsStatusBar|None': ...
    def setMapController(self, controller: 'QgsAbstract2DMapController|None') -> None: ...
    def allowInteraction(self, interaction: 'QgsMapCanvasInteractionBlocker.Interaction') -> bool: ...
    def removeInteractionBlocker(self, blocker: 'QgsMapCanvasInteractionBlocker|None') -> None: ...
    def installInteractionBlocker(self, blocker: 'QgsMapCanvasInteractionBlocker|None') -> None: ...
    def temporalRange(self) -> _core.QgsDateTimeRange: ...
    def setTemporalRange(self, range: _core.QgsDateTimeRange) -> None: ...
    def setPreviewJobsEnabled(self, enabled: bool) -> None: ...
    def previewJobsEnabled(self) -> bool: ...
    def setSelectiveMaskingSourceSets(self, sets: collections.abc.Iterable[_core.QgsSelectiveMaskingSourceSet]) -> None: ...
    def labelingEngineSettings(self) -> _core.QgsLabelingEngineSettings: ...
    def setLabelingEngineSettings(self, settings: _core.QgsLabelingEngineSettings) -> None: ...
    def setAnnotationsVisible(self, visible: bool) -> None: ...
    def annotationsVisible(self) -> bool: ...
    def annotationItems(self) -> list['QgsMapCanvasAnnotationItem']: ...
    def setSegmentationToleranceType(self, type: _core.QgsAbstractGeometry.SegmentationToleranceType) -> None: ...
    def setSegmentationTolerance(self, tolerance: float) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def defaultExpressionContextScope(self) -> _core.QgsExpressionContextScope|None: ...
    def expressionContextScope(self) -> _core.QgsExpressionContextScope: ...
    def setExpressionContextScope(self, scope: _core.QgsExpressionContextScope) -> None: ...
    def setSnappingUtils(self, utils: _core.QgsSnappingUtils|None) -> None: ...
    def snappingUtils(self) -> _core.QgsSnappingUtils|None: ...
    def previewMode(self) -> 'QgsPreviewEffect.PreviewMode': ...
    def setPreviewMode(self, mode: 'QgsPreviewEffect.PreviewMode') -> None: ...
    def previewModeEnabled(self) -> bool: ...
    def setPreviewModeEnabled(self, previewEnabled: bool) -> None: ...
    def mouseLastXY(self) -> QtCore.QPoint: ...
    def panAction(self, event: QtGui.QMouseEvent|None) -> None: ...
    def panActionEnd(self, releasePoint: QtCore.QPoint) -> None: ...
    def enableMapTileRendering(self, flag: bool) -> None: ...
    def antiAliasingEnabled(self) -> bool: ...
    def enableAntiAliasing(self, flag: bool) -> None: ...
    def scaleLocked(self) -> bool: ...
    def zoomToFeatureExtent(self, rect: _core.QgsRectangle) -> None: ...
    def zoomWithCenter(self, x: int, y: int, zoomIn: bool) -> None: ...
    def zoomByFactor(self, scaleFactor: float, center: _core.QgsPointXY|None = ..., ignoreScaleLock: bool = ...) -> None: ...
    def zoomScale(self, scale: float, ignoreScaleLock: bool = ...) -> None: ...
    def setWheelFactor(self, factor: float) -> None: ...
    def currentLayer(self) -> _core.QgsMapLayer|None: ...
    def isDrawing(self) -> bool: ...
    def getCoordinateTransform(self) -> _core.QgsMapToPixel|None: ...
    def theme(self) -> str: ...
    def setTheme(self, theme: str|None) -> None: ...
    def setLayerStyleOverrides(self, overrides: dict[str|None, str|None]) -> None: ...
    def layerStyleOverrides(self) -> dict[str, str]: ...
    def mapUnits(self) -> _core.Qgis.DistanceUnit: ...
    def renderFlag(self) -> bool: ...
    def isFrozen(self) -> bool: ...
    def freeze(self, frozen: bool = ...) -> None: ...
    def layers(self, expandGroupLayers: bool = ...) -> list[_core.QgsMapLayer]: ...
    def layerCount(self) -> int: ...
    @typing.overload
    def layer(self, index: int) -> _core.QgsMapLayer|None: ...
    @typing.overload
    def layer(self, id: str|None) -> _core.QgsMapLayer|None: ...
    def updateScale(self) -> None: ...
    def selectionColor(self) -> QtGui.QColor: ...
    def setSelectionColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def canvasColor(self) -> QtGui.QColor: ...
    def setCanvasColor(self, _newVal: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def project(self) -> _core.QgsProject|None: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def mapTool(self) -> 'QgsMapTool|None': ...
    def unsetMapTool(self, mapTool: 'QgsMapTool|None') -> None: ...
    def setMapTool(self, mapTool: 'QgsMapTool|None', clean: bool = ...) -> None: ...
    def flashGeometries(self, geometries: collections.abc.Iterable[_core.QgsGeometry], crs: _core.QgsCoordinateReferenceSystem = ..., startColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., endColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., flashes: int = ..., duration: int = ...) -> None: ...
    def flashFeatureIds(self, layer: _core.QgsVectorLayer|None, ids: typing.Any, startColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., endColor: QtGui.QColor|QtCore.Qt.GlobalColor|int = ..., flashes: int = ..., duration: int = ...) -> None: ...
    @typing.overload
    def panToSelected(self, layer: _core.QgsMapLayer|None = ...) -> None: ...
    @typing.overload
    def panToSelected(self, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def panToFeatureIds(self, layer: _core.QgsVectorLayer|None, ids: typing.Any, alwaysRecenter: bool = ...) -> None: ...
    def zoomToFeatureIds(self, layer: _core.QgsVectorLayer|None, ids: typing.Any) -> None: ...
    def clearExtentHistory(self) -> None: ...
    def zoomToNextExtent(self) -> None: ...
    def zoomToPreviousExtent(self) -> None: ...
    def zoomToProjectExtent(self) -> None: ...
    def zoomToFullExtent(self) -> None: ...
    def center(self) -> _core.QgsPointXY: ...
    def setCenter(self, center: _core.QgsPointXY) -> None: ...
    def setRotation(self, degrees: float) -> None: ...
    def rotation(self) -> float: ...
    def setReferencedExtent(self, extent: _core.QgsReferencedRectangle) -> bool: ...
    def setExtent(self, r: _core.QgsRectangle, magnified: bool = ...) -> None: ...
    def projectExtent(self) -> _core.QgsRectangle: ...
    def fullExtent(self) -> _core.QgsRectangle: ...
    def extent(self) -> _core.QgsRectangle: ...
    def mapUnitsPerPixel(self) -> float: ...
    def scale(self) -> float: ...
    def mapUpdateInterval(self) -> int: ...
    def setMapUpdateInterval(self, timeMilliseconds: int) -> None: ...
    def isParallelRenderingEnabled(self) -> bool: ...
    def setParallelRenderingEnabled(self, enabled: bool) -> None: ...
    def waitWhileRendering(self) -> None: ...
    def cache(self) -> _core.QgsMapRendererCache|None: ...
    def clearCache(self) -> None: ...
    def isCachingEnabled(self) -> bool: ...
    def setCachingEnabled(self, enabled: bool) -> None: ...
    def renderedItemResults(self, allowOutdatedResults: bool = ...) -> _core.QgsRenderedItemResults|None: ...
    def labelingResults(self, allowOutdatedResults: bool = ...) -> _core.QgsLabelingResults|None: ...
    def setMapSettingsFlags(self, flags: _core.Qgis.MapSettingsFlag) -> None: ...
    def setDestinationCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def temporalController(self) -> _core.QgsTemporalController|None: ...
    def setTemporalController(self, controller: _core.QgsTemporalController|None) -> None: ...
    def mapSettings(self) -> _core.QgsMapSettings: ...
    def setCurrentLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def flags(self) -> _core.Qgis.MapCanvasFlag: ...
    def setFlags(self, flags: _core.Qgis.MapCanvasFlag) -> None: ...
    def setLayers(self, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def magnificationFactor(self) -> float: ...
    def addOverlayWidget(self, widget: QtWidgets.QWidget|None, edge: QtCore.Qt.Edge) -> None: ...


class QgsMapCanvasAnnotationItem(QtCore.QObject, QgsMapCanvasItem):

    class MouseMoveAction(enum.IntEnum):
        NoAction = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        MoveMapPosition = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        MoveFramePosition = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameUp = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameDown = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameLeft = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameRight = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameLeftUp = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameRightUp = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameLeftDown = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction
        ResizeFrameRightDown = ... # type: QgsMapCanvasAnnotationItem.MouseMoveAction

    def __init__(self, annotation: _core.QgsAnnotation|None, mapCanvas: QgsMapCanvas|None) -> None: ...

    def cursorShapeForAction(self, moveAction: 'QgsMapCanvasAnnotationItem.MouseMoveAction') -> QtCore.Qt.CursorShape: ...
    def moveActionForPosition(self, pos: QtCore.QPointF) -> 'QgsMapCanvasAnnotationItem.MouseMoveAction': ...
    def paint(self, painter: QtGui.QPainter|None) -> None: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def updatePosition(self) -> None: ...
    def annotation(self) -> _core.QgsAnnotation|None: ...


class QgsMapCanvasInteractionBlocker(PyQt6.sip.wrapper):

    class Interaction(enum.IntFlag):
        MapPanOnSingleClick = ... # type: QgsMapCanvasInteractionBlocker.Interaction

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapCanvasInteractionBlocker') -> None: ...

    def blockCanvasInteraction(self, interaction: 'QgsMapCanvasInteractionBlocker.Interaction') -> bool: ...


class QgsMapCanvasSnappingUtils(_core.QgsSnappingUtils):

    def __init__(self, canvas: QgsMapCanvas|None, parent: QtCore.QObject|None = ...) -> None: ...

    def prepareIndexProgress(self, index: int) -> None: ...
    def prepareIndexStarting(self, count: int) -> None: ...


class QgsMapCanvasTracer(_core.QgsTracer):

    def __init__(self, canvas: QgsMapCanvas|None, messageBar: 'QgsMessageBar|None' = ...) -> None: ...

    def configure(self) -> None: ...
    def reportError(self, err: _core.QgsTracer.PathError, addingVertex: bool) -> None: ...
    @staticmethod
    def tracerForCanvas(canvas: QgsMapCanvas|None) -> 'QgsMapCanvasTracer|None': ...
    def setActionEnableSnapping(self, action: QtGui.QAction|None) -> None: ...
    def actionEnableSnapping(self) -> QtGui.QAction|None: ...
    def setActionEnableTracing(self, action: QtGui.QAction|None) -> None: ...
    def actionEnableTracing(self) -> QtGui.QAction|None: ...


class QgsMapCanvasUtils(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapCanvasUtils') -> None: ...

    @staticmethod
    def filterForLayer(canvas: QgsMapCanvas|None, layer: _core.QgsVectorLayer|None) -> str: ...
    @staticmethod
    def flashMatchingFeatures(canvas: QgsMapCanvas|None, layer: _core.QgsVectorLayer|None, filter: str|None) -> int: ...
    @staticmethod
    def zoomToMatchingFeatures(canvas: QgsMapCanvas|None, layer: _core.QgsVectorLayer|None, filter: str|None) -> int: ...


class QgsMapLayerComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def rowsChanged(self) -> None: ...
    def indexChanged(self, i: int) -> None: ...
    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...
    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, event: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    layerChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def layer(self, layerIndex: int) -> _core.QgsMapLayer|None: ...
    def currentLayer(self) -> _core.QgsMapLayer|None: ...
    def additionalLayers(self) -> list[_core.QgsMapLayer]: ...
    def setAdditionalLayers(self, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def additionalItems(self) -> list[str]: ...
    def setAdditionalItems(self, items: collections.abc.Iterable[str|None]) -> None: ...
    def showCrs(self) -> bool: ...
    def setShowCrs(self, showCrs: bool) -> None: ...
    def allowEmptyLayer(self) -> bool: ...
    def setAllowEmptyLayer(self, allowEmpty: bool, text: str|None = ..., icon: QtGui.QIcon = ...) -> None: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def excludedProviders(self) -> list[str]: ...
    def setExcludedProviders(self, providers: collections.abc.Iterable[str|None]) -> None: ...
    def exceptedLayerList(self) -> list[_core.QgsMapLayer]: ...
    def setExceptedLayerList(self, layerList: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def filters(self) -> _core.Qgis.LayerFilter: ...
    @typing.overload
    def setFilters(self, filters: _core.Qgis.LayerFilter) -> None: ...
    @typing.overload
    @deprecated("""""")
    def setFilters(self, filters: int) -> None: ...


class QgsMapLayerConfigWidgetContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerConfigWidgetContext') -> None: ...

    def layerTreeGroup(self) -> _core.QgsLayerTreeGroup|None: ...
    def setLayerTreeGroup(self, group: _core.QgsLayerTreeGroup|None) -> None: ...
    def messageBar(self) -> 'QgsMessageBar|None': ...
    def setMessageBar(self, bar: 'QgsMessageBar|None') -> None: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def setAnnotationId(self, id: str|None) -> None: ...
    def annotationId(self) -> str: ...


class QgsMapLayerConfigWidget(QgsPanelWidget):

    def __init__(self, layer: _core.QgsMapLayer|None, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def focusDefaultWidget(self) -> None: ...
    def apply(self) -> None: ...
    def setMapLayerConfigWidgetContext(self, context: QgsMapLayerConfigWidgetContext) -> None: ...
    def syncToLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def shouldTriggerLayerRepaint(self) -> bool: ...


class QgsMapLayerConfigWidgetFactory(PyQt6.sip.wrapper):

    class ParentPage(enum.IntEnum):
        NoParent = ... # type: QgsMapLayerConfigWidgetFactory.ParentPage
        Temporal = ... # type: QgsMapLayerConfigWidgetFactory.ParentPage

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, icon: QtGui.QIcon) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerConfigWidgetFactory') -> None: ...

    def createWidget(self, layer: _core.QgsMapLayer|None, canvas: QgsMapCanvas|None, dockWidget: bool = ..., parent: QtWidgets.QWidget|None = ...) -> QgsMapLayerConfigWidget|None: ...
    def parentPage(self) -> 'QgsMapLayerConfigWidgetFactory.ParentPage': ...
    def supportsLayerTreeGroup(self, group: _core.QgsLayerTreeGroup|None) -> bool: ...
    def supportsLayer(self, layer: _core.QgsMapLayer|None) -> bool: ...
    def setSupportLayerPropertiesDialog(self, supports: bool) -> None: ...
    def layerPropertiesPagePositionHint(self) -> str: ...
    def supportLayerPropertiesDialog(self) -> bool: ...
    def setSupportsStyleDock(self, supports: bool) -> None: ...
    def supportsStyleDock(self) -> bool: ...
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...


class QgsMapLayerStyleCategoriesModel(QtCore.QAbstractListModel):

    class Role(enum.IntEnum):
        NameRole = ... # type: QgsMapLayerStyleCategoriesModel.Role

    def __init__(self, type: _core.Qgis.LayerType, parent: QtCore.QObject|None = ...) -> None: ...

    def flags(self, a0: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, a0: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, a0: QtCore.QModelIndex = ...) -> int: ...
    def setShowAllCategories(self, showAll: bool) -> None: ...
    def categories(self) -> _core.QgsMapLayer.StyleCategory: ...
    def setCategories(self, categories: _core.QgsMapLayer.StyleCategory) -> None: ...


class QgsCategoryDisplayLabelDelegate(QtWidgets.QItemDelegate):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def sizeHint(self, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> QtCore.QSize: ...
    def drawDisplay(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionViewItem, rect: QtCore.QRect, text: str|None) -> None: ...


class QgsMapLayerStyleManagerWidget(QgsMapLayerConfigWidget):

    def __init__(self, layer: _core.QgsMapLayer|None, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def apply(self) -> None: ...


class QgsMapMouseEvent(QtGui.QMouseEvent):

    @typing.overload
    def __init__(self, mapCanvas: QgsMapCanvas|None, event: QtGui.QMouseEvent|None) -> None: ...
    @typing.overload
    def __init__(self, mapCanvas: QgsMapCanvas|None, type: QtCore.QEvent.Type, pos: QtCore.QPoint, button: QtCore.Qt.MouseButton = ..., buttons: QtCore.Qt.MouseButton = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> None: ...

    def snapToGrid(self, precision: float, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def originalPixelPoint(self) -> QtCore.QPoint: ...
    def pixelPoint(self) -> QtCore.QPoint: ...
    def originalMapPoint(self) -> _core.QgsPointXY: ...
    def setMapPoint(self, point: _core.QgsPointXY) -> None: ...
    def mapPointMatch(self) -> _core.QgsPointLocator.Match: ...
    def mapPoint(self) -> _core.QgsPointXY: ...
    def isSnapped(self) -> bool: ...
    def snapPoint(self) -> _core.QgsPointXY: ...


class QgsMapOverviewCanvas(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., mapCanvas: QgsMapCanvas|None = ...) -> None: ...

    def updatePanningWidget(self, pos: QtCore.QPoint) -> None: ...
    def wheelEvent(self, e: QtGui.QWheelEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, e: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def paintEvent(self, pe: QtGui.QPaintEvent|None) -> None: ...
    def transformContextChanged(self) -> None: ...
    def destinationCrsChanged(self) -> None: ...
    def drawExtentRect(self) -> None: ...
    def layerRepaintRequested(self, deferred: bool = ...) -> None: ...
    def mapRenderingFinished(self) -> None: ...
    def updateFullExtent(self) -> None: ...
    def enableAntiAliasing(self, flag: bool) -> None: ...
    def layers(self) -> list[_core.QgsMapLayer]: ...
    def setLayers(self, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def refresh(self) -> None: ...


class QgsMapTip(QtWidgets.QWidget):

    def __init__(self) -> None: ...

    @staticmethod
    def rasterMapTipPreviewText(layer: _core.QgsMapLayer|None, mapCanvas: QgsMapCanvas|None, mapTemplate: str|None) -> str: ...
    @staticmethod
    def vectorMapTipPreviewText(layer: _core.QgsMapLayer|None, mapCanvas: QgsMapCanvas|None, mapTemplate: str|None, displayExpression: str|None) -> str: ...
    def clear(self, mpMapCanvas: QgsMapCanvas|None = ..., msDelay: int = ...) -> None: ...
    def showMapTip(self, thepLayer: _core.QgsMapLayer|None, mapPosition: _core.QgsPointXY, pixelPosition: QtCore.QPoint, mpMapCanvas: QgsMapCanvas|None) -> None: ...


class QgsMediaWidget(QtWidgets.QWidget):

    class Mode(enum.IntEnum):
        Audio = ... # type: QgsMediaWidget.Mode
        Video = ... # type: QgsMediaWidget.Mode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def mediaPlayer(self) -> QtMultimedia.QMediaPlayer|None: ...
    def setVideoHeight(self, height: int) -> None: ...
    def videoHeight(self) -> int: ...
    def setMode(self, mode: 'QgsMediaWidget.Mode') -> None: ...
    def mode(self) -> 'QgsMediaWidget.Mode': ...
    def setMediaPath(self, path: str|None) -> None: ...
    def mediaPath(self) -> str: ...


class QgsMenuHeader(QtWidgets.QWidget):

    def __init__(self, text: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsMenuHeaderWidgetAction(QtWidgets.QWidgetAction):

    def __init__(self, text: str|None, parent: QtCore.QObject|None = ...) -> None: ...


class QgsMessageBar(QtWidgets.QFrame):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def pushCritical(self, title: str|None, message: str|None) -> None: ...
    def pushWarning(self, title: str|None, message: str|None) -> None: ...
    def pushInfo(self, title: str|None, message: str|None) -> None: ...
    def pushSuccess(self, title: str|None, message: str|None) -> None: ...
    def clearWidgets(self) -> bool: ...
    widgetRemoved: typing.ClassVar[QtCore.pyqtSignal]
    widgetAdded: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def defaultMessageTimeout(level: _core.Qgis.MessageLevel = ...) -> int: ...
    def items(self) -> list['QgsMessageBarItem']: ...
    def currentItem(self) -> 'QgsMessageBarItem|None': ...
    @typing.overload
    def pushMessage(self, text: str|None, level: _core.Qgis.MessageLevel = ..., duration: int = ...) -> None: ...
    @typing.overload
    def pushMessage(self, title: str|None, text: str|None, level: _core.Qgis.MessageLevel = ..., duration: int = ...) -> None: ...
    @typing.overload
    def pushMessage(self, title: str|None, text: str|None, showMore: str|None, level: _core.Qgis.MessageLevel = ..., duration: int = ...) -> None: ...
    @typing.overload
    @staticmethod
    def createMessage(text: str|None, parent: QtWidgets.QWidget|None = ...) -> 'QgsMessageBarItem|None': ...
    @typing.overload
    @staticmethod
    def createMessage(title: str|None, text: str|None, parent: QtWidgets.QWidget|None = ...) -> 'QgsMessageBarItem|None': ...
    @typing.overload
    @staticmethod
    def createMessage(widget: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None = ...) -> 'QgsMessageBarItem|None': ...
    @typing.overload
    def popWidget(self, item: 'QgsMessageBarItem|None') -> bool: ...
    @typing.overload
    def popWidget(self) -> bool: ...
    def pushWidget(self, widget: QtWidgets.QWidget|None, level: _core.Qgis.MessageLevel = ..., duration: int = ...) -> 'QgsMessageBarItem|None': ...
    def pushItem(self, item: 'QgsMessageBarItem|None') -> None: ...


class QgsMessageBarItem(QtWidgets.QWidget):

    @typing.overload
    def __init__(self, text: str|None, level: _core.Qgis.MessageLevel = ..., duration: int = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, text: str|None, level: _core.Qgis.MessageLevel = ..., duration: int = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, text: str|None, widget: QtWidgets.QWidget|None, level: _core.Qgis.MessageLevel = ..., duration: int = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, widget: QtWidgets.QWidget|None, level: _core.Qgis.MessageLevel = ..., duration: int = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    styleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def dismiss(self) -> None: ...
    def getStyleSheet(self) -> str: ...
    def duration(self) -> int: ...
    def setDuration(self, duration: int) -> 'QgsMessageBarItem|None': ...
    def icon(self) -> QtGui.QIcon: ...
    def setIcon(self, icon: QtGui.QIcon) -> 'QgsMessageBarItem|None': ...
    def widget(self) -> QtWidgets.QWidget|None: ...
    def setWidget(self, widget: QtWidgets.QWidget|None) -> 'QgsMessageBarItem|None': ...
    def level(self) -> _core.Qgis.MessageLevel: ...
    def setLevel(self, level: _core.Qgis.MessageLevel) -> 'QgsMessageBarItem|None': ...
    def title(self) -> str: ...
    def setTitle(self, title: str|None) -> 'QgsMessageBarItem|None': ...
    def text(self) -> str: ...
    def setText(self, text: str|None) -> 'QgsMessageBarItem|None': ...


class QgsMessageLogViewer(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def eventFilter(self, obj: QtCore.QObject|None, ev: QtCore.QEvent|None) -> bool: ...
    def reject(self) -> None: ...
    def closeEvent(self, e: QtGui.QCloseEvent|None) -> None: ...
    def showTab(self, tag: str|None) -> None: ...
    def logMessage(self, message: str|None, tag: str|None, level: _core.Qgis.MessageLevel, format: _core.Qgis.StringFormat = ...) -> None: ...


class QgsMessageViewer(QtWidgets.QDialog, _core.QgsMessageOutput):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., deleteOnClose: bool = ...) -> None: ...

    def setCheckBoxQgsSettingsLabel(self, label: str|None) -> None: ...
    def checkBoxState(self) -> QtCore.Qt.CheckState: ...
    def setCheckBoxState(self, state: QtCore.Qt.CheckState) -> None: ...
    def setCheckBoxVisible(self, visible: bool) -> None: ...
    def setCheckBoxText(self, text: str|None) -> None: ...
    def setMessageAsPlainText(self, msg: str|None) -> None: ...
    def setMessageAsHtml(self, msg: str|None) -> None: ...
    def setTitle(self, title: str|None) -> None: ...
    def showMessage(self, blocking: bool = ...) -> None: ...
    def appendMessage(self, message: str|None) -> None: ...
    def setMessage(self, message: str|None, format: _core.Qgis.StringFormat) -> None: ...


class QgsMetadataWidget(QtWidgets.QWidget):

    class Mode(enum.IntEnum):
        LayerMetadata = ... # type: QgsMetadataWidget.Mode
        ProjectMetadata = ... # type: QgsMetadataWidget.Mode

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsMapLayer|None = ...) -> None: ...

    titleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    @staticmethod
    def parseTypes() -> dict[str, str]: ...
    @staticmethod
    def parseMimeTypes() -> list[str]: ...
    @staticmethod
    def parseLinkTypes() -> list[str]: ...
    @staticmethod
    def parseLicenses() -> list[str]: ...
    @staticmethod
    def parseLanguages() -> dict[str, str]: ...
    def acceptMetadata(self) -> None: ...
    def crsChanged(self) -> None: ...
    def checkMetadata(self) -> bool: ...
    def saveMetadata(self, metadata: _core.QgsAbstractMetadataBase|None) -> None: ...
    def metadata(self) -> _core.QgsAbstractMetadataBase|None: ...
    def setMetadata(self, metadata: _core.QgsAbstractMetadataBase|None) -> None: ...
    def mode(self) -> 'QgsMetadataWidget.Mode': ...
    def setMode(self, mode: 'QgsMetadataWidget.Mode') -> None: ...


class QgsNewAuxiliaryFieldDialog(QtWidgets.QDialog):

    def __init__(self, definition: _core.QgsPropertyDefinition, layer: _core.QgsVectorLayer|None, nameOnly: bool = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def accept(self) -> None: ...
    def propertyDefinition(self) -> _core.QgsPropertyDefinition: ...


class QgsNewAuxiliaryLayerDialog(QtWidgets.QDialog):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def accept(self) -> None: ...


class QgsNewGeoPackageLayerDialog(QtWidgets.QDialog):

    class OverwriteBehavior(enum.IntEnum):
        Prompt = ... # type: QgsNewGeoPackageLayerDialog.OverwriteBehavior
        Overwrite = ... # type: QgsNewGeoPackageLayerDialog.OverwriteBehavior
        AddNewLayer = ... # type: QgsNewGeoPackageLayerDialog.OverwriteBehavior

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def setAddToProject(self, addToProject: bool) -> None: ...
    def setOverwriteBehavior(self, behavior: 'QgsNewGeoPackageLayerDialog.OverwriteBehavior') -> None: ...
    def lockDatabasePath(self) -> None: ...
    def setDatabasePath(self, path: str|None) -> None: ...
    def databasePath(self) -> str: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...


class QgsNewVectorTableDialog(QtWidgets.QDialog):

    def __init__(self, conn: _core.QgsAbstractDatabaseProviderConnection|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def validationErrors(self) -> list[str]: ...
    def createSpatialIndex(self) -> bool: ...
    def setFields(self, fields: _core.QgsFields) -> None: ...
    def geometryType(self) -> _core.Qgis.WkbType: ...
    def fields(self) -> _core.QgsFields: ...
    def geometryColumnName(self) -> str: ...
    def schemaName(self) -> str: ...
    def tableName(self) -> str: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setGeometryType(self, type: _core.Qgis.WkbType) -> None: ...
    def setTableName(self, name: str|None) -> None: ...
    def setSchemaName(self, name: str|None) -> None: ...


class QgsNewHttpConnection(QtWidgets.QDialog):

    class WfsVersionIndex(enum.IntEnum):
        WFS_VERSION_MAX = ... # type: QgsNewHttpConnection.WfsVersionIndex
        WFS_VERSION_1_0 = ... # type: QgsNewHttpConnection.WfsVersionIndex
        WFS_VERSION_1_1 = ... # type: QgsNewHttpConnection.WfsVersionIndex
        WFS_VERSION_2_0 = ... # type: QgsNewHttpConnection.WfsVersionIndex
        WFS_VERSION_API_FEATURES_1_0 = ... # type: QgsNewHttpConnection.WfsVersionIndex

    class Flag(enum.IntEnum):
        FlagShowTestConnection = ... # type: QgsNewHttpConnection.Flag
        FlagHideAuthenticationGroup = ... # type: QgsNewHttpConnection.Flag
        FlagShowHttpSettings = ... # type: QgsNewHttpConnection.Flag

    class ConnectionType(enum.IntEnum):
        ConnectionWfs = ... # type: QgsNewHttpConnection.ConnectionType
        ConnectionWms = ... # type: QgsNewHttpConnection.ConnectionType
        ConnectionWcs = ... # type: QgsNewHttpConnection.ConnectionType
        ConnectionOther = ... # type: QgsNewHttpConnection.ConnectionType

    def __init__(self, parent: QtWidgets.QWidget|None = ..., types: 'QgsNewHttpConnection.ConnectionType' = ..., settingsKey: str|None = ..., connectionName: str|None = ..., flags: 'QgsNewHttpConnection.Flag' = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def updateServiceSpecificSettings(self) -> None: ...
    def wmsSettingsKey(self, base: str|None, connectionName: str|None) -> str: ...
    def wfsSettingsKey(self, base: str|None, connectionName: str|None) -> str: ...
    def preferredHttpMethod(self) -> _core.Qgis.HttpMethod: ...
    def invertAxisOrientation(self) -> bool: ...
    def ignoreAxisOrientation(self) -> bool: ...
    def testConnectButton(self) -> QtWidgets.QPushButton|None: ...
    def validate(self) -> bool: ...
    def accept(self) -> None: ...
    def originalConnectionName(self) -> str: ...
    def url(self) -> str: ...
    def name(self) -> str: ...


class QgsNewMemoryLayerDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def fields(self) -> _core.QgsFields: ...
    def layerName(self) -> str: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def selectedType(self) -> _core.Qgis.WkbType: ...
    @staticmethod
    def runAndCreateLayer(parent: QtWidgets.QWidget|None = ..., defaultCrs: _core.QgsCoordinateReferenceSystem = ...) -> _core.QgsVectorLayer|None: ...


class QgsNewNameDialog(QgsDialog):

    def __init__(self, source: str|None = ..., initial: str|None = ..., extensions: collections.abc.Iterable[str|None] = ..., existing: collections.abc.Iterable[str|None] = ..., cs: QtCore.Qt.CaseSensitivity = ..., parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    @staticmethod
    def matching(newNames: collections.abc.Iterable[str|None], existingNames: collections.abc.Iterable[str|None], cs: QtCore.Qt.CaseSensitivity = ...) -> list[str]: ...
    @staticmethod
    def fullNames(name: str|None, extensions: collections.abc.Iterable[str|None]) -> list[str]: ...
    @staticmethod
    def highlightText(text: str|None) -> str: ...
    def nameChanged(self) -> None: ...
    newNameChanged: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def exists(name: str|None, extensions: collections.abc.Iterable[str|None], existing: collections.abc.Iterable[str|None], cs: QtCore.Qt.CaseSensitivity = ...) -> bool: ...
    def name(self) -> str: ...
    def setShowExistingNamesCompleter(self, show: bool) -> None: ...
    def setRegularExpression(self, expression: str|None) -> None: ...
    def conflictingNameWarning(self) -> str: ...
    def setConflictingNameWarning(self, string: str|None) -> None: ...
    def allowEmptyName(self) -> bool: ...
    def setAllowEmptyName(self, allowed: bool) -> None: ...
    def overwriteEnabled(self) -> bool: ...
    def setOverwriteEnabled(self, enabled: bool) -> None: ...
    def hintString(self) -> str: ...
    def setHintString(self, hintString: str|None) -> None: ...


class QgsNewVectorLayerDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def setFilename(self, filename: str|None) -> None: ...
    def filename(self) -> str: ...
    def selectedFileEncoding(self) -> str: ...
    def selectedFileFormat(self) -> str: ...
    def attributes(self, at: collections.abc.Iterable[tuple[str|None, str|None]]) -> None: ...
    def selectedType(self) -> _core.Qgis.WkbType: ...
    @staticmethod
    def execAndCreateLayer(parent: QtWidgets.QWidget|None = ..., initialPath: str|None = ..., crs: _core.QgsCoordinateReferenceSystem = ...) -> typing.Tuple[str, str, str]: ...
    @staticmethod
    @deprecated("""""")
    def runAndCreateLayer(parent: QtWidgets.QWidget|None = ..., enc: str|None = ..., crs: _core.QgsCoordinateReferenceSystem = ..., initialPath: str|None = ...) -> str: ...


class QgsOpacityWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    opacityChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setOpacity(self, opacity: float) -> None: ...
    def opacity(self) -> float: ...


class QgsOptionsDialogHighlightWidget(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, widget: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightWidget') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...
    def widget(self) -> QtWidgets.QWidget|None: ...
    def searchHighlight(self, text: str|None) -> bool: ...
    def isValid(self) -> bool: ...
    @staticmethod
    def createWidget(widget: QtWidgets.QWidget|None) -> 'QgsOptionsDialogHighlightWidget|None': ...


class QgsOptionsDialogHighlightLabel(QgsOptionsDialogHighlightWidget):

    @typing.overload
    def __init__(self, label: QtWidgets.QLabel|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightLabel') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...


class QgsOptionsDialogHighlightCheckBox(QgsOptionsDialogHighlightWidget):

    @typing.overload
    def __init__(self, checkBox: QtWidgets.QCheckBox|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightCheckBox') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...


class QgsOptionsDialogHighlightButton(QgsOptionsDialogHighlightWidget):

    @typing.overload
    def __init__(self, button: QtWidgets.QAbstractButton|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightButton') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...


class QgsOptionsDialogHighlightGroupBox(QgsOptionsDialogHighlightWidget):

    @typing.overload
    def __init__(self, groupBox: QtWidgets.QGroupBox|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightGroupBox') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...


class QgsOptionsDialogHighlightTree(QgsOptionsDialogHighlightWidget):

    @typing.overload
    def __init__(self, treeView: QtWidgets.QTreeView|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightTree') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...


class QgsOptionsDialogHighlightTable(QgsOptionsDialogHighlightWidget):

    @typing.overload
    def __init__(self, tableView: QtWidgets.QTableView|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsOptionsDialogHighlightTable') -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...


class QgsOptionsPageWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def registerHighlightWidget(self, highlightWidget: QgsOptionsDialogHighlightWidget|None) -> None: ...
    def cancel(self) -> None: ...
    def apply(self) -> None: ...
    def isValid(self) -> bool: ...
    def helpKey(self) -> str: ...


class QgsOptionsWidgetFactory(QtCore.QObject):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, title: str|None, icon: QtGui.QIcon, key: str|None = ...) -> None: ...

    def createWidget(self, parent: QtWidgets.QWidget|None = ...) -> QgsOptionsPageWidget|None: ...
    def path(self) -> list[str]: ...
    def pagePositionHint(self) -> str: ...
    def setKey(self, key: str|None) -> None: ...
    def key(self) -> str: ...
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...


class QgsOrderByDialog(QtWidgets.QDialog):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def eventFilter(self, obj: QtCore.QObject|None, e: QtCore.QEvent|None) -> bool: ...
    def orderBy(self) -> _core.QgsFeatureRequest.OrderBy: ...
    def setOrderBy(self, orderBy: _core.QgsFeatureRequest.OrderBy) -> None: ...


class QgsOverlayWidgetLayout(QtWidgets.QLayout):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def verticalSpacing(self) -> int: ...
    def setVerticalSpacing(self, spacing: int) -> None: ...
    def horizontalSpacing(self) -> int: ...
    def setHorizontalSpacing(self, spacing: int) -> None: ...
    def addWidget(self, widget: QtWidgets.QWidget|None, edge: QtCore.Qt.Edge) -> None: ...
    def setGeometry(self, rect: QtCore.QRect) -> None: ...
    def minimumSize(self) -> QtCore.QSize: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def takeAt(self, index: int) -> QtWidgets.QLayoutItem|None: ...
    def itemAt(self, index: int) -> QtWidgets.QLayoutItem|None: ...
    def addItem(self, item: QtWidgets.QLayoutItem|None) -> None: ...
    def count(self) -> int: ...


class QgsOWSSourceSelect(QgsAbstractDataSourceWidget):

    class SupportedFormat(PyQt6.sip.wrapper):

        format = ... # type: str|None
        label = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsOWSSourceSelect.SupportedFormat') -> None: ...

    def __init__(self, service: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., widgetMode: _core.QgsProviderRegistry.WidgetMode = ...) -> None: ...

    def prepareExtent(self) -> None: ...
    def selectedCacheLoadControl(self) -> QtNetwork.QNetworkRequest.CacheLoadControl: ...
    def selectedTime(self) -> str: ...
    def selectedCrs(self) -> str: ...
    def selectedFormat(self) -> str: ...
    def enableLayersForCrs(self, item: QtWidgets.QTreeWidgetItem|None) -> None: ...
    def descriptionForAuthId(self, authId: str|None) -> str: ...
    def populateLayerList(self) -> None: ...
    def addDefaultServers(self) -> None: ...
    def setConnectionListPosition(self) -> None: ...
    def connectionInfo(self) -> str: ...
    def connName(self) -> str: ...
    def clearTimes(self) -> None: ...
    def populateTimes(self) -> None: ...
    def clearCrs(self) -> None: ...
    def populateCrs(self) -> None: ...
    def clearFormats(self) -> None: ...
    def populateFormats(self) -> None: ...
    def populateConnectionList(self) -> None: ...
    def selectedLayersTimes(self) -> list[str]: ...
    def selectedLayersCrses(self) -> list[str]: ...
    def selectedLayersFormats(self) -> list[str]: ...
    def providerFormats(self) -> list['QgsOWSSourceSelect.SupportedFormat']: ...
    def showStatusMessage(self, message: str|None) -> None: ...
    def showError(self, title: str|None, format: str|None, error: str|None) -> None: ...
    def setMapCanvas(self, mapCanvas: QgsMapCanvas|None) -> None: ...
    def reset(self) -> None: ...
    def refresh(self) -> None: ...


class QgsPanelWidgetWrapper(QgsPanelWidget):

    def __init__(self, widget: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def widget(self) -> QtWidgets.QWidget|None: ...


class QgsPanelWidgetStack(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def closePanel(self, panel: QgsPanelWidget|None) -> None: ...
    def showPanel(self, panel: QgsPanelWidget|None) -> None: ...
    def acceptAllPanels(self) -> None: ...
    def acceptCurrentPanel(self) -> None: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def currentPanel(self) -> QgsPanelWidget|None: ...
    def clear(self) -> None: ...
    def takeMainPanel(self) -> QgsPanelWidget|None: ...
    def mainPanel(self) -> QgsPanelWidget|None: ...
    def setMainPanel(self, panel: QgsPanelWidget|None) -> None: ...


class QgsPasswordLineEdit(QtWidgets.QLineEdit):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., passwordVisible: bool = ...) -> None: ...

    def setPasswordVisibility(self, visible: bool) -> None: ...
    def showLockIcon(self) -> bool: ...
    def setShowLockIcon(self, visible: bool) -> None: ...


class QgsPercentageWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setValue(self, value: float) -> None: ...
    def spinBox(self) -> 'QgsDoubleSpinBox|None': ...
    def value(self) -> float: ...


class QgsPixmapLabel(QtWidgets.QLabel):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def clear(self) -> None: ...
    def resizeEvent(self, a0: QtGui.QResizeEvent|None) -> None: ...
    def setPixmap(self, a0: QtGui.QPixmap) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def heightForWidth(self, width: int) -> int: ...


class QgsPlaybackControllerWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    operationTriggered: typing.ClassVar[QtCore.pyqtSignal]
    def togglePause(self) -> None: ...
    def setState(self, state: _core.Qgis.AnimationState) -> None: ...
    def button(self, operation: _core.Qgis.PlaybackOperation) -> QtWidgets.QPushButton|None: ...


class QgsPluginManagerInterface(QtCore.QObject):

    def __init__(self) -> None: ...

    def pushMessage(self, text: str|None, level: _core.Qgis.MessageLevel = ..., duration: int = ...) -> None: ...
    def showPluginManager(self, tabIndex: int = ...) -> None: ...
    def addToRepositoryList(self, repository: dict[str|None, str|None]) -> None: ...
    def clearRepositoryList(self) -> None: ...
    def pluginMetadata(self, key: str|None) -> dict[str, str]: ...
    def reloadModel(self) -> None: ...
    def addPluginMetadata(self, metadata: dict[str|None, str|None]) -> None: ...
    def clearPythonPluginMetadata(self) -> None: ...


class QgsPointCloudAttributeComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setAttribute(self, name: str|None) -> None: ...
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    attributeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def attributes(self) -> _core.QgsPointCloudAttributeCollection: ...
    def setAttributes(self, attributes: _core.QgsPointCloudAttributeCollection) -> None: ...
    def layer(self) -> _core.QgsPointCloudLayer|None: ...
    def currentAttribute(self) -> str: ...
    def allowEmptyAttributeName(self) -> bool: ...
    def setAllowEmptyAttributeName(self, allowEmpty: bool) -> None: ...
    def filters(self) -> _core.QgsPointCloudAttributeProxyModel.Filter: ...
    def setFilters(self, filters: _core.QgsPointCloudAttributeProxyModel.Filter) -> None: ...


class QgsSubsetStringEditorInterface(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def setSubsetString(self, subsetString: str|None) -> None: ...
    def subsetString(self) -> str: ...


class QgsPointCloudQueryBuilder(QgsSubsetStringEditorInterface):

    def __init__(self, layer: _core.QgsPointCloudLayer|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def reject(self) -> None: ...
    def accept(self) -> None: ...
    def setSubsetString(self, subsetString: str|None) -> None: ...
    def subsetString(self) -> str: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...


class QgsPresetColorRampWidget(QgsPanelWidget):

    def __init__(self, ramp: _core.QgsPresetSchemeColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setRamp(self, ramp: _core.QgsPresetSchemeColorRamp) -> None: ...
    def ramp(self) -> _core.QgsPresetSchemeColorRamp: ...


class QgsPresetColorRampDialog(QtWidgets.QDialog):

    def __init__(self, ramp: _core.QgsPresetSchemeColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def setRamp(self, ramp: _core.QgsPresetSchemeColorRamp) -> None: ...
    def ramp(self) -> _core.QgsPresetSchemeColorRamp: ...


class QgsPreviewEffect(QtWidgets.QGraphicsEffect):

    class PreviewMode(enum.IntEnum):
        PreviewGrayscale = ... # type: QgsPreviewEffect.PreviewMode
        PreviewMono = ... # type: QgsPreviewEffect.PreviewMode
        PreviewProtanope = ... # type: QgsPreviewEffect.PreviewMode
        PreviewDeuteranope = ... # type: QgsPreviewEffect.PreviewMode
        PreviewTritanope = ... # type: QgsPreviewEffect.PreviewMode

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    def draw(self, painter: QtGui.QPainter|None) -> None: ...
    def mode(self) -> 'QgsPreviewEffect.PreviewMode': ...
    def setMode(self, mode: 'QgsPreviewEffect.PreviewMode') -> None: ...


class QgsProjectStorageGuiProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProjectStorageGuiProvider') -> None: ...

    def showSaveGui(self) -> str: ...
    def showLoadGui(self) -> str: ...
    def visibleName(self) -> str: ...
    def type(self) -> str: ...


class QgsProjectStorageGuiRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def initializeFromProviderGuiRegistry(self, providerGuiRegistry: 'QgsProviderGuiRegistry|None') -> None: ...
    def unregisterProjectStorage(self, storage: QgsProjectStorageGuiProvider|None) -> None: ...
    def registerProjectStorage(self, storage: QgsProjectStorageGuiProvider|None) -> None: ...
    def projectStorages(self) -> list[QgsProjectStorageGuiProvider]: ...
    def projectStorageFromUri(self, uri: str|None) -> QgsProjectStorageGuiProvider|None: ...
    def projectStorageFromType(self, type: str|None) -> QgsProjectStorageGuiProvider|None: ...


class QgsProjectTrustDialog(QtWidgets.QDialog):

    def __init__(self, project: _core.QgsProject|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...


class QgsPropertyAssistantWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., definition: _core.QgsPropertyDefinition = ..., initialState: _core.QgsProperty = ..., layer: _core.QgsVectorLayer|None = ...) -> None: ...

    def setDockMode(self, dockMode: bool) -> None: ...
    def updateProperty(self, property: _core.QgsProperty) -> None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...


class QgsPropertyOverrideButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsVectorLayer|None = ...) -> None: ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    createAuxiliaryField: typing.ClassVar[QtCore.pyqtSignal]
    activated: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def menuActionTriggered(self, action: QtGui.QAction|None) -> None: ...
    def aboutToShowMenu(self) -> None: ...
    def setActive(self, active: bool) -> None: ...
    def updateFieldLists(self) -> None: ...
    def registerLinkedWidget(self, widget: QtWidgets.QWidget|None) -> None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def registerExpressionWidget(self, widget: QtWidgets.QWidget|None) -> None: ...
    def registerVisibleWidget(self, widget: QtWidgets.QWidget|None, natural: bool = ...) -> None: ...
    def registerEnabledWidget(self, widget: QtWidgets.QWidget|None, natural: bool = ...) -> None: ...
    def registerCheckedWidget(self, widget: QtWidgets.QWidget|None, natural: bool = ...) -> None: ...
    def vectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def setVectorLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def setUsageInfo(self, info: str|None) -> None: ...
    def usageInfo(self) -> str: ...
    def fullDescription(self) -> str: ...
    def validDataType(self) -> _core.QgsPropertyDefinition.DataType: ...
    def isActive(self) -> bool: ...
    def propertyKey(self) -> int: ...
    def setToProperty(self, property: _core.QgsProperty) -> None: ...
    def toProperty(self) -> _core.QgsProperty: ...
    @typing.overload
    def init(self, propertyKey: int, property: _core.QgsProperty, definitions: dict[int, _core.QgsPropertyDefinition], layer: _core.QgsVectorLayer|None = ..., auxiliaryStorageEnabled: bool = ...) -> None: ...
    @typing.overload
    def init(self, propertyKey: int, property: _core.QgsProperty, definition: _core.QgsPropertyDefinition, layer: _core.QgsVectorLayer|None = ..., auxiliaryStorageEnabled: bool = ...) -> None: ...
    @typing.overload
    def init(self, propertyKey: int, collection: _core.QgsAbstractPropertyCollection, definitions: dict[int, _core.QgsPropertyDefinition], layer: _core.QgsVectorLayer|None = ..., auxiliaryStorageEnabled: bool = ...) -> None: ...


class QgsProviderConnectionComboBox(QtWidgets.QComboBox):

    def __init__(self, provider: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    connectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setConnection(self, connection: str|None) -> None: ...
    def currentConnectionUri(self) -> str: ...
    def currentConnection(self) -> str: ...
    def allowEmptyConnection(self) -> bool: ...
    def setAllowEmptyConnection(self, allowEmpty: bool) -> None: ...
    def setProvider(self, provider: str|None) -> None: ...


class QgsProviderGuiMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, key: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProviderGuiMetadata') -> None: ...

    def key(self) -> str: ...
    def mapLayerConfigWidgetFactories(self) -> list[QgsMapLayerConfigWidgetFactory]: ...
    def sourceWidgetProviders(self) -> list['QgsProviderSourceWidgetProvider']: ...
    def subsetStringEditorProviders(self) -> list['QgsSubsetStringEditorProvider']: ...
    def sourceSelectProviders(self) -> list['QgsSourceSelectProvider']: ...
    def projectStorageGuiProviders(self) -> list[QgsProjectStorageGuiProvider]: ...
    def dataItemGuiProviders(self) -> list[QgsDataItemGuiProvider]: ...
    def registerGui(self, widget: QtWidgets.QMainWindow|None) -> None: ...


class QgsProviderGuiRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, pluginPath: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProviderGuiRegistry') -> None: ...

    def mapLayerConfigWidgetFactories(self, layer: _core.QgsMapLayer|None = ...) -> list[QgsMapLayerConfigWidgetFactory]: ...
    def sourceWidgetProviders(self, providerKey: str|None) -> list['QgsProviderSourceWidgetProvider']: ...
    def subsetStringEditorProviders(self, providerKey: str|None) -> list['QgsSubsetStringEditorProvider']: ...
    def projectStorageGuiProviders(self, providerKey: str|None) -> list[QgsProjectStorageGuiProvider]: ...
    def sourceSelectProviders(self, providerKey: str|None) -> list['QgsSourceSelectProvider']: ...
    def dataItemGuiProviders(self, providerKey: str|None) -> list[QgsDataItemGuiProvider]: ...
    def registerGuis(self, widget: QtWidgets.QMainWindow|None) -> None: ...
    def providerMetadata(self, providerKey: str|None) -> QgsProviderGuiMetadata|None: ...
    def providerList(self) -> list[str]: ...


class QgsProviderSourceWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    validChanged: typing.ClassVar[QtCore.pyqtSignal]
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def setMapCanvas(self, mapCanvas: QgsMapCanvas|None) -> None: ...
    def groupTitle(self) -> str: ...
    def sourceUri(self) -> str: ...
    def setSourceUri(self, uri: str|None) -> None: ...


class QgsProviderSourceWidgetProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProviderSourceWidgetProvider') -> None: ...

    def createWidget(self, layer: _core.QgsMapLayer|None, parent: QtWidgets.QWidget|None = ...) -> QgsProviderSourceWidget|None: ...
    def canHandleLayer(self, layer: _core.QgsMapLayer|None) -> bool: ...
    def name(self) -> str: ...
    def providerKey(self) -> str: ...


class QgsProviderSourceWidgetProviderRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def createWidget(self, layer: _core.QgsMapLayer|None, parent: QtWidgets.QWidget|None = ...) -> QgsProviderSourceWidget|None: ...
    def providersByKey(self, providerKey: str|None) -> list[QgsProviderSourceWidgetProvider]: ...
    def providerByName(self, name: str|None) -> QgsProviderSourceWidgetProvider|None: ...
    def initializeFromProviderGuiRegistry(self, providerGuiRegistry: QgsProviderGuiRegistry|None) -> None: ...
    def removeProvider(self, provider: QgsProviderSourceWidgetProvider|None) -> bool: ...
    def addProvider(self, provider: QgsProviderSourceWidgetProvider|None) -> None: ...
    def providers(self) -> list[QgsProviderSourceWidgetProvider]: ...


class QgsProviderSublayerDialogModel(_core.QgsProviderSublayerModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def setGeometryTypesResolved(self, resolved: bool) -> None: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...


class QgsProviderSublayersDialog(QtWidgets.QDialog):

    def __init__(self, uri: str|None, providerKey: str|None, filePath: str|None, initialDetails: collections.abc.Iterable[_core.QgsProviderSublayerDetails] = ..., acceptableTypes: collections.abc.Iterable[_core.Qgis.LayerType] = ..., parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    layersAdded: typing.ClassVar[QtCore.pyqtSignal]
    def setGroupName(self, groupNameIn: str|None) -> None: ...
    def groupName(self) -> str: ...
    def selectedNonLayerItems(self) -> list[_core.QgsProviderSublayerModel.NonLayerItem]: ...
    def selectedLayers(self) -> list[_core.QgsProviderSublayerDetails]: ...
    def setNonLayerItems(self, items: collections.abc.Iterable[_core.QgsProviderSublayerModel.NonLayerItem]) -> None: ...


class QgsProxyStyle(QtWidgets.QProxyStyle):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...


class QgsQueryBuilder(QgsSubsetStringEditorInterface):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def setDatasourceDescription(self, uri: str|None) -> None: ...
    def loadQuery(self) -> None: ...
    def saveQuery(self) -> None: ...
    def test(self) -> None: ...
    def clear(self) -> None: ...
    def reject(self) -> None: ...
    def accept(self) -> None: ...
    @staticmethod
    def loadQueryFromFile(subset: str|None) -> bool: ...
    @staticmethod
    def saveQueryToFile(subset: str|None) -> bool: ...
    def codeEditorWidget(self) -> 'QgsCodeEditor|None': ...
    def setSubsetString(self, subsetString: str|None) -> None: ...
    def subsetString(self) -> str: ...
    def setSql(self, sqlStatement: str|None) -> None: ...
    def sql(self) -> str: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...


class QgsQueryResultWidget(QtWidgets.QWidget):

    class QueryWidgetMode(enum.IntFlag):
        SqlQueryMode = ... # type: QgsQueryResultWidget.QueryWidgetMode
        QueryLayerUpdateMode = ... # type: QgsQueryResultWidget.QueryWidgetMode

    def __init__(self, parent: QtWidgets.QWidget|None = ..., connection: _core.QgsAbstractDatabaseProviderConnection|None = ...) -> None: ...

    firstResultBatchFetched: typing.ClassVar[QtCore.pyqtSignal]
    createSqlVectorLayer: typing.ClassVar[QtCore.pyqtSignal]
    @typing.overload
    def copyResults(self) -> None: ...
    @typing.overload
    def copyResults(self, fromRow: int, toRow: int, fromColumn: int, toColumn: int) -> None: ...
    @deprecated("""""")
    def tokensReady(self, tokens: collections.abc.Iterable[str|None]) -> None: ...
    def showError(self, title: str|None, message: str|None, isSqlError: bool = ...) -> None: ...
    def executeQuery(self) -> None: ...
    def notify(self, title: str|None, text: str|None, level: _core.Qgis.MessageLevel = ...) -> None: ...
    def setQuery(self, sql: str|None) -> None: ...
    def setConnection(self, connection: _core.QgsAbstractDatabaseProviderConnection|None) -> None: ...
    def setWidgetMode(self, widgetMode: 'QgsQueryResultWidget.QueryWidgetMode') -> None: ...
    def setSqlVectorLayerOptions(self, options: _core.QgsAbstractDatabaseProviderConnection.SqlVectorLayerOptions) -> None: ...


class QgsQueryResultDialog(QtWidgets.QDialog):

    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def closeEvent(self, event: QtGui.QCloseEvent|None) -> None: ...
    def resultWidget(self) -> QgsQueryResultWidget|None: ...


class QgsQueryResultMainWindow(QtWidgets.QMainWindow):

    def __init__(self, connection: _core.QgsAbstractDatabaseProviderConnection|None = ..., identifierName: str|None = ...) -> None: ...

    def closeEvent(self, event: QtGui.QCloseEvent|None) -> None: ...
    def resultWidget(self) -> QgsQueryResultWidget|None: ...


class QgsRangeSlider(QtWidgets.QWidget):

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, orientation: QtCore.Qt.Orientation, parent: QtWidgets.QWidget|None = ...) -> None: ...

    fixedRangeSizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    rangeLimitsChanged: typing.ClassVar[QtCore.pyqtSignal]
    rangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def event(self, event: QtCore.QEvent|None) -> bool: ...
    def setPageStep(self, step: int) -> None: ...
    def setSingleStep(self, step: int) -> None: ...
    def setRange(self, lower: int, upper: int) -> None: ...
    def setUpperValue(self, value: int) -> None: ...
    def setLowerValue(self, value: int) -> None: ...
    def setRangeLimits(self, minimum: int, maximum: int) -> None: ...
    def setMinimum(self, minimum: int) -> None: ...
    def setMaximum(self, maximum: int) -> None: ...
    def setFixedRangeSize(self, size: int) -> None: ...
    def fixedRangeSize(self) -> int: ...
    def pageStep(self) -> int: ...
    def singleStep(self) -> int: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def setFlippedDirection(self, flipped: bool) -> None: ...
    def flippedDirection(self) -> bool: ...
    def orientation(self) -> QtCore.Qt.Orientation: ...
    def setOrientation(self, orientation: QtCore.Qt.Orientation) -> None: ...
    def tickInterval(self) -> int: ...
    def setTickInterval(self, interval: int) -> None: ...
    def tickPosition(self) -> QtWidgets.QSlider.TickPosition: ...
    def setTickPosition(self, position: QtWidgets.QSlider.TickPosition) -> None: ...
    def upperValue(self) -> int: ...
    def lowerValue(self) -> int: ...
    def maximum(self) -> int: ...
    def minimum(self) -> int: ...


class QgsRasterFormatSaveOptionsWidget(QtWidgets.QWidget):

    class Type(enum.IntEnum):
        Default = ... # type: QgsRasterFormatSaveOptionsWidget.Type
        Full = ... # type: QgsRasterFormatSaveOptionsWidget.Type
        Table = ... # type: QgsRasterFormatSaveOptionsWidget.Type
        LineEdit = ... # type: QgsRasterFormatSaveOptionsWidget.Type
        ProfileLineEdit = ... # type: QgsRasterFormatSaveOptionsWidget.Type

    def __init__(self, parent: QtWidgets.QWidget|None = ..., format: str|None = ..., type: 'QgsRasterFormatSaveOptionsWidget.Type' = ..., provider: str|None = ...) -> None: ...

    optionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def updateProfiles(self) -> None: ...
    def validateOptions(self, gui: bool = ..., reportOk: bool = ...) -> str: ...
    def helpOptions(self) -> None: ...
    def apply(self) -> None: ...
    def setPyramidsFormat(self, format: _core.Qgis.RasterPyramidFormat) -> None: ...
    def setType(self, type: 'QgsRasterFormatSaveOptionsWidget.Type' = ...) -> None: ...
    def setOptions(self, options: str|None) -> None: ...
    def options(self) -> list[str]: ...
    def setRasterFileName(self, file: str|None) -> None: ...
    def setRasterLayer(self, rasterLayer: _core.QgsRasterLayer|None) -> None: ...
    def setProvider(self, provider: str|None) -> None: ...
    def setFormat(self, format: str|None) -> None: ...


class QgsRasterLayerSaveAsDialog(QtWidgets.QDialog):

    class ResolutionState(enum.IntEnum):
        OriginalResolution = ... # type: QgsRasterLayerSaveAsDialog.ResolutionState
        UserResolution = ... # type: QgsRasterLayerSaveAsDialog.ResolutionState

    class CrsState(enum.IntEnum):
        OriginalCrs = ... # type: QgsRasterLayerSaveAsDialog.CrsState
        CurrentCrs = ... # type: QgsRasterLayerSaveAsDialog.CrsState
        UserCrs = ... # type: QgsRasterLayerSaveAsDialog.CrsState

    class Mode(enum.IntEnum):
        RawDataMode = ... # type: QgsRasterLayerSaveAsDialog.Mode
        RenderedImageMode = ... # type: QgsRasterLayerSaveAsDialog.Mode

    def __init__(self, rasterLayer: _core.QgsRasterLayer|None, sourceProvider: _core.QgsRasterDataProvider|None, currentExtent: _core.QgsRectangle, layerCrs: _core.QgsCoordinateReferenceSystem, currentCrs: _core.QgsCoordinateReferenceSystem, parent: QtWidgets.QWidget|None = ..., f: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def hideOutput(self) -> None: ...
    def hideFormat(self) -> None: ...
    def pyramidsConfigOptions(self) -> list[str]: ...
    def pyramidsFormat(self) -> _core.Qgis.RasterPyramidFormat: ...
    def pyramidsResamplingMethod(self) -> str: ...
    def buildPyramidsFlag(self) -> _core.Qgis.RasterBuildPyramidOption: ...
    def pyramidsList(self) -> list[int]: ...
    def noData(self) -> list[_core.QgsRasterRange]: ...
    def outputRectangle(self) -> _core.QgsRectangle: ...
    def creationOptions(self) -> list[str]: ...
    def createOptions(self) -> list[str]: ...
    def outputCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def outputFormat(self) -> str: ...
    def outputLayerName(self) -> str: ...
    def outputFileName(self) -> str: ...
    def setAddToCanvas(self, checked: bool) -> None: ...
    def addToCanvas(self) -> bool: ...
    def tileMode(self) -> bool: ...
    def maximumTileSizeY(self) -> int: ...
    def maximumTileSizeX(self) -> int: ...
    def yResolution(self) -> float: ...
    def xResolution(self) -> float: ...
    def nRows(self) -> int: ...
    def nColumns(self) -> int: ...
    def mode(self) -> 'QgsRasterLayerSaveAsDialog.Mode': ...


class QgsRasterPyramidsOptionsWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., provider: str|None = ...) -> None: ...

    someValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    overviewListChanged: typing.ClassVar[QtCore.pyqtSignal]
    def checkAllLevels(self, checked: bool) -> None: ...
    def apply(self) -> None: ...
    def tuneForFormat(self, driverName: str|None) -> None: ...
    def setRasterFileName(self, file: str|None) -> None: ...
    def setRasterLayer(self, rasterLayer: _core.QgsRasterLayer|None) -> None: ...
    def resamplingMethod(self) -> str: ...
    def pyramidsFormat(self) -> _core.Qgis.RasterPyramidFormat: ...
    def overviewList(self) -> list[int]: ...
    def createOptionsWidget(self) -> QgsRasterFormatSaveOptionsWidget|None: ...
    def configOptions(self) -> list[str]: ...


class QgsRatioLockButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def changeEvent(self, e: QtCore.QEvent|None) -> None: ...
    lockChanged: typing.ClassVar[QtCore.pyqtSignal]
    def resetRatio(self) -> None: ...
    def setHeightSpinBox(self, widget: QtWidgets.QDoubleSpinBox|None) -> None: ...
    def setWidthSpinBox(self, widget: QtWidgets.QDoubleSpinBox|None) -> None: ...
    def locked(self) -> bool: ...
    def setLocked(self, locked: bool) -> None: ...


class QgsAbstractRelationEditorWidget(QtWidgets.QWidget):

    def __init__(self, config: dict[str|None, typing.Any], parent: QtWidgets.QWidget|None = ...) -> None: ...

    def afterSetRelations(self) -> None: ...
    def beforeSetRelations(self, newRelation: _core.QgsRelation, newNmRelation: _core.QgsRelation) -> None: ...
    def afterSetRelationFeature(self) -> None: ...
    def beforeSetRelationFeature(self, newRelation: _core.QgsRelation, newFeature: _core.QgsFeature) -> None: ...
    @deprecated("""""")
    def setTitle(self, title: str|None) -> None: ...
    def updateUi(self) -> None: ...
    def unlinkFeatures(self, fids: typing.Any) -> None: ...
    def deleteFeatures(self, fids: typing.Any) -> None: ...
    @deprecated("""""")
    def updateTitle(self) -> None: ...
    def showEvent(self, a0: QtGui.QShowEvent|None) -> None: ...
    def duplicateFeatures(self, fids: typing.Any) -> None: ...
    def duplicateFeature(self, fid: int) -> None: ...
    def unlinkFeature(self, fid: int = ...) -> None: ...
    def onLinkFeatureDlgAccepted(self) -> None: ...
    def linkFeature(self, filterExpression: str|None = ...) -> None: ...
    def deleteFeature(self, fid: int = ...) -> None: ...
    def addFeature(self, geometry: _core.QgsGeometry = ...) -> typing.Any: ...
    def saveEdits(self) -> None: ...
    def toggleEditing(self, state: bool) -> None: ...
    def parentFormValueChanged(self, attribute: str|None, newValue: typing.Any) -> None: ...
    relatedFeaturesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def multiEditModeActive(self) -> bool: ...
    def setConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    def config(self) -> dict[str, typing.Any]: ...
    def setForceSuppressFormPopup(self, forceSuppressFormPopup: bool) -> None: ...
    def forceSuppressFormPopup(self) -> bool: ...
    def features(self) -> list[_core.QgsFeature]: ...
    def feature(self) -> _core.QgsFeature: ...
    def setLabel(self, label: str|None = ...) -> None: ...
    @deprecated("""""")
    def label(self) -> str: ...
    def setNmRelationId(self, nmRelationId: typing.Any = ...) -> None: ...
    def nmRelationId(self) -> typing.Any: ...
    @deprecated("""""")
    def setShowLabel(self, showLabel: bool) -> None: ...
    @deprecated("""""")
    def showLabel(self) -> bool: ...
    def editorContext(self) -> QgsAttributeEditorContext: ...
    def setEditorContext(self, context: QgsAttributeEditorContext) -> None: ...
    def setMultiEditFeatureIds(self, fids: typing.Any) -> None: ...
    def setFeature(self, feature: _core.QgsFeature, update: bool = ...) -> None: ...
    def nmRelation(self) -> _core.QgsRelation: ...
    def relation(self) -> _core.QgsRelation: ...
    def setRelations(self, relation: _core.QgsRelation, nmrelation: _core.QgsRelation) -> None: ...
    def setRelationFeature(self, relation: _core.QgsRelation, feature: _core.QgsFeature) -> None: ...


class QgsRelationEditorWidget(QgsAbstractRelationEditorWidget):

    class Button(enum.IntEnum):
        NoButton = ... # type: QgsRelationEditorWidget.Button
        Link = ... # type: QgsRelationEditorWidget.Button
        Unlink = ... # type: QgsRelationEditorWidget.Button
        SaveChildEdits = ... # type: QgsRelationEditorWidget.Button
        AddChildFeature = ... # type: QgsRelationEditorWidget.Button
        DuplicateChildFeature = ... # type: QgsRelationEditorWidget.Button
        DeleteChildFeature = ... # type: QgsRelationEditorWidget.Button
        ZoomToChildFeature = ... # type: QgsRelationEditorWidget.Button
        AllButtons = ... # type: QgsRelationEditorWidget.Button

    def __init__(self, config: dict[str|None, typing.Any], parent: QtWidgets.QWidget|None = ...) -> None: ...

    def afterSetRelations(self) -> None: ...
    def beforeSetRelations(self, newRelation: _core.QgsRelation, newNmRelation: _core.QgsRelation) -> None: ...
    def afterSetRelationFeature(self) -> None: ...
    def beforeSetRelationFeature(self, newRelation: _core.QgsRelation, newFeature: _core.QgsFeature) -> None: ...
    def updateUi(self) -> None: ...
    def parentFormValueChanged(self, attribute: str|None, newValue: typing.Any) -> None: ...
    def setConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    def config(self) -> dict[str, typing.Any]: ...
    def zoomToSelectedFeatures(self) -> None: ...
    def deleteSelectedFeatures(self) -> None: ...
    def unlinkSelectedFeatures(self) -> None: ...
    def duplicateSelectedFeatures(self) -> None: ...
    @deprecated("""""")
    def duplicateFeature(self) -> None: ...
    def visibleButtons(self) -> 'QgsRelationEditorWidget.Button': ...
    def setVisibleButtons(self, buttons: 'QgsRelationEditorWidget.Button') -> None: ...
    def setEditorContext(self, context: QgsAttributeEditorContext) -> None: ...
    def featureSelectionManager(self) -> 'QgsIFeatureSelectionManager|None': ...
    def viewMode(self) -> 'QgsDualView.ViewMode': ...
    def setViewMode(self, mode: 'QgsDualView.ViewMode') -> None: ...


class QgsAbstractRelationEditorConfigWidget(QtWidgets.QWidget):

    def __init__(self, relation: _core.QgsRelation, parent: QtWidgets.QWidget|None) -> None: ...

    def nmRelation(self) -> _core.QgsRelation: ...
    def setNmRelation(self, nmRelation: _core.QgsRelation) -> None: ...
    def relation(self) -> _core.QgsRelation: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def setConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    def config(self) -> dict[str, typing.Any]: ...


class QgsRelationEditorConfigWidget(QgsAbstractRelationEditorConfigWidget):

    def __init__(self, relation: _core.QgsRelation, parent: QtWidgets.QWidget|None) -> None: ...

    def mEditExpression_clicked(self) -> None: ...
    def setConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    def config(self) -> dict[str, typing.Any]: ...


class QgsAbstractRelationEditorWidgetFactory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAbstractRelationEditorWidgetFactory') -> None: ...

    def configWidget(self, relation: _core.QgsRelation, parent: QtWidgets.QWidget|None) -> QgsAbstractRelationEditorConfigWidget|None: ...
    def create(self, config: dict[str|None, typing.Any], parent: QtWidgets.QWidget|None = ...) -> QgsAbstractRelationEditorWidget|None: ...
    def name(self) -> str: ...
    def type(self) -> str: ...


class QgsRelationWidgetRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsRelationWidgetRegistry') -> None: ...

    def defaultWidgetType(self) -> str: ...
    def setDefaultWidgetType(self, widgetType: str|None) -> None: ...
    def createConfigWidget(self, widgetType: str|None, relation: _core.QgsRelation, parent: QtWidgets.QWidget|None = ...) -> QgsAbstractRelationEditorConfigWidget|None: ...
    def create(self, widgetType: str|None, config: dict[str|None, typing.Any], parent: QtWidgets.QWidget|None = ...) -> QgsAbstractRelationEditorWidget|None: ...
    def factories(self) -> typing.Any: ...
    def relationWidgetNames(self) -> list[str]: ...
    def removeRelationWidget(self, widgetType: str|None) -> None: ...
    def addRelationWidget(self, widgetFactory: QgsAbstractRelationEditorWidgetFactory|None) -> None: ...


class QgsRichTextEditor(QtWidgets.QWidget):

    class Mode(enum.Enum):
        QTextDocument = ... # type: QgsRichTextEditor.Mode
        QgsTextRenderer = ... # type: QgsRichTextEditor.Mode
        PlainText = ... # type: QgsRichTextEditor.Mode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def focusInEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    textChanged: typing.ClassVar[QtCore.pyqtSignal]
    def clearSource(self) -> None: ...
    def setText(self, text: str|None) -> None: ...
    def setTextCursor(self, cursor: QtGui.QTextCursor) -> None: ...
    def textCursor(self) -> QtGui.QTextCursor: ...
    def document(self) -> QtGui.QTextDocument|None: ...
    def textEdit(self) -> QtWidgets.QTextEdit|None: ...
    def toHtml(self) -> str: ...
    def toPlainText(self) -> str: ...
    def setMode(self, mode: 'QgsRichTextEditor.Mode') -> None: ...
    def mode(self) -> 'QgsRichTextEditor.Mode': ...


class QgsRubberBand(QgsMapCanvasItem):

    class IconType(enum.IntEnum):
        ICON_NONE = ... # type: QgsRubberBand.IconType
        ICON_CROSS = ... # type: QgsRubberBand.IconType
        ICON_X = ... # type: QgsRubberBand.IconType
        ICON_BOX = ... # type: QgsRubberBand.IconType
        ICON_CIRCLE = ... # type: QgsRubberBand.IconType
        ICON_FULL_BOX = ... # type: QgsRubberBand.IconType
        ICON_DIAMOND = ... # type: QgsRubberBand.IconType
        ICON_FULL_DIAMOND = ... # type: QgsRubberBand.IconType
        ICON_SVG = ... # type: QgsRubberBand.IconType

    def __init__(self, mapCanvas: QgsMapCanvas|None, geometryType: _core.Qgis.GeometryType = ...) -> None: ...

    def updateRect(self) -> None: ...
    @typing.overload
    def drawShape(self, p: QtGui.QPainter|None, pts: collections.abc.Iterable[QtCore.QPointF]) -> None: ...
    @typing.overload
    def drawShape(self, p: QtGui.QPainter|None, rings: collections.abc.Iterable[QtGui.QPolygonF]) -> None: ...
    def paint(self, p: QtGui.QPainter|None) -> None: ...
    def setSymbol(self, symbol: _core.QgsSymbol|None) -> None: ...
    def symbol(self) -> _core.QgsSymbol|None: ...
    def updatePosition(self) -> None: ...
    def asGeometry(self) -> _core.QgsGeometry: ...
    def getPoint(self, i: int, j: int = ..., ringIndex: int = ...) -> _core.QgsPointXY|None: ...
    def numberOfVertices(self) -> int: ...
    def size(self) -> int: ...
    def setTranslationOffset(self, dx: float, dy: float) -> None: ...
    @typing.overload
    def addGeometry(self, geometry: _core.QgsGeometry, layer: _core.QgsMapLayer|None, doUpdate: bool = ...) -> None: ...
    @typing.overload
    def addGeometry(self, geometry: _core.QgsGeometry, crs: _core.QgsCoordinateReferenceSystem = ..., doUpdate: bool = ...) -> None: ...
    def copyPointsFrom(self, other: 'QgsRubberBand|None') -> None: ...
    def setToCanvasRectangle(self, rect: QtCore.QRect) -> None: ...
    @typing.overload
    def setToGeometry(self, geom: _core.QgsGeometry, layer: _core.QgsVectorLayer|None) -> None: ...
    @typing.overload
    def setToGeometry(self, geometry: _core.QgsGeometry, crs: _core.QgsCoordinateReferenceSystem = ...) -> None: ...
    def partSize(self, geometryIndex: int) -> int: ...
    @typing.overload
    def movePoint(self, p: _core.QgsPointXY, geometryIndex: int = ..., ringIndex: int = ...) -> None: ...
    @typing.overload
    def movePoint(self, index: int, p: _core.QgsPointXY, geometryIndex: int = ..., ringIndex: int = ...) -> None: ...
    def removeLastPoint(self, geometryIndex: int = ..., doUpdate: bool = ..., ringIndex: int = ...) -> None: ...
    def removePoint(self, index: int = ..., doUpdate: bool = ..., geometryIndex: int = ..., ringIndex: int = ...) -> None: ...
    def closePoints(self, doUpdate: bool = ..., geometryIndex: int = ..., ringIndex: int = ...) -> None: ...
    def addPoint(self, p: _core.QgsPointXY, doUpdate: bool = ..., geometryIndex: int = ..., ringIndex: int = ...) -> None: ...
    def reset(self, geometryType: _core.Qgis.GeometryType = ...) -> None: ...
    def setBrushStyle(self, brushStyle: QtCore.Qt.BrushStyle) -> None: ...
    def setLineStyle(self, penStyle: QtCore.Qt.PenStyle) -> None: ...
    def iconSize(self) -> float: ...
    def setIconSize(self, iconSize: float) -> None: ...
    def icon(self) -> 'QgsRubberBand.IconType': ...
    def setSvgIcon(self, path: str|None, drawOffset: QtCore.QPoint) -> None: ...
    def setIcon(self, icon: 'QgsRubberBand.IconType') -> None: ...
    def width(self) -> int: ...
    def setWidth(self, width: float) -> None: ...
    def secondaryStrokeColor(self) -> QtGui.QColor: ...
    def setSecondaryStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def strokeColor(self) -> QtGui.QColor: ...
    def setStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...


class QgsScaleComboBox(QtWidgets.QComboBox):

    class RatioMode(enum.IntEnum):
        ForceUnitNumerator = ... # type: QgsScaleComboBox.RatioMode
        Flexible = ... # type: QgsScaleComboBox.RatioMode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showPopup(self) -> None: ...
    def setRatioMode(self, mode: 'QgsScaleComboBox.RatioMode') -> None: ...
    def setNull(self) -> None: ...
    def setMinScale(self, scale: float) -> None: ...
    def setScale(self, scale: float) -> None: ...
    def updateScales(self, scales: collections.abc.Iterable[str|None] = ...) -> None: ...
    ratioModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def ratioMode(self) -> 'QgsScaleComboBox.RatioMode': ...
    def setPredefinedScales(self, scales: collections.abc.Iterable[float]) -> None: ...
    def allowNull(self) -> bool: ...
    def setAllowNull(self, allowNull: bool) -> None: ...
    @staticmethod
    def toDouble(string: str|None) -> typing.Tuple[float, bool]: ...
    @staticmethod
    def toString(scale: float, mode: 'QgsScaleComboBox.RatioMode' = ...) -> str: ...
    def minScale(self) -> float: ...
    def isNull(self) -> bool: ...
    def scale(self) -> float: ...
    def setScaleString(self, string: str|None) -> bool: ...
    def scaleString(self) -> str: ...


class QgsScaleMethodWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    methodChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setScaleMethod(self, method: _core.Qgis.ScaleCalculationMethod) -> None: ...
    def scaleMethod(self) -> _core.Qgis.ScaleCalculationMethod: ...


class QgsScaleRangeWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    rangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setScaleRange(self, min: float, max: float) -> None: ...
    def setMaximumScale(self, scale: float) -> None: ...
    def setMinimumScale(self, scale: float) -> None: ...
    def reloadProjectScales(self) -> None: ...
    def maximumScale(self) -> float: ...
    def minimumScale(self) -> float: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...


class QgsScaleVisibilityDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., title: str|None = ..., mapCanvas: QgsMapCanvas|None = ...) -> None: ...

    def setMaximumScale(self, scale: float) -> None: ...
    def setMinimumScale(self, scale: float) -> None: ...
    def setScaleVisibility(self, hasScaleVisibility: bool) -> None: ...
    @deprecated("""""")
    def setScaleVisiblity(self, hasScaleVisibility: bool) -> None: ...
    def maximumScale(self) -> float: ...
    def minimumScale(self) -> float: ...
    def hasScaleVisibility(self) -> bool: ...


class QgsScaleWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setNull(self) -> None: ...
    def setMinScale(self, scale: float) -> None: ...
    def setScaleFromCanvas(self) -> None: ...
    def updateScales(self, scales: collections.abc.Iterable[str|None] = ...) -> None: ...
    def setScale(self, scale: float) -> None: ...
    def setPredefinedScales(self, scales: collections.abc.Iterable[float]) -> None: ...
    def allowNull(self) -> bool: ...
    def setAllowNull(self, allowNull: bool) -> None: ...
    @staticmethod
    def toDouble(scaleString: str|None) -> typing.Tuple[float, bool]: ...
    @staticmethod
    def toString(scale: float) -> str: ...
    def minScale(self) -> float: ...
    def isNull(self) -> bool: ...
    def scale(self) -> float: ...
    def setScaleString(self, string: str|None) -> bool: ...
    def scaleString(self) -> str: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def showCurrentScaleButton(self) -> bool: ...
    def setShowCurrentScaleButton(self, showCurrentScaleButton: bool) -> None: ...


class QgsScreenHelper(QtCore.QObject):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    def eventFilter(self, watched: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    availableGeometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    screenDpiChanged: typing.ClassVar[QtCore.pyqtSignal]
    def availableGeometry(self) -> QtCore.QRect: ...
    def screenDpi(self) -> float: ...
    def windowHandle(self) -> QtGui.QWindow|None: ...
    def screen(self) -> QtGui.QScreen|None: ...


class QgsScrollArea(QtWidgets.QScrollArea):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def setVerticalOnly(self, verticalOnly: bool) -> None: ...
    def hasScrolled(self) -> bool: ...
    def scrollOccurred(self) -> None: ...


class QgsSearchQueryBuilder(QtWidgets.QDialog):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def loadQuery(self) -> None: ...
    def saveQuery(self) -> None: ...
    def setSearchString(self, searchString: str|None) -> None: ...
    def searchString(self) -> str: ...


class QgsSubsetStringEditorProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSubsetStringEditorProvider') -> None: ...

    def createDialog(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> QgsSubsetStringEditorInterface|None: ...
    def canHandleLayerStorageType(self, layer: _core.QgsVectorLayer|None) -> bool: ...
    def canHandleLayer(self, layer: _core.QgsVectorLayer|None) -> bool: ...
    def name(self) -> str: ...
    def providerKey(self) -> str: ...


class QgsSubsetStringEditorProviderRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def createDialog(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> QgsSubsetStringEditorInterface|None: ...
    def providersByKey(self, providerKey: str|None) -> list[QgsSubsetStringEditorProvider]: ...
    def providerByName(self, name: str|None) -> QgsSubsetStringEditorProvider|None: ...
    def initializeFromProviderGuiRegistry(self, providerGuiRegistry: QgsProviderGuiRegistry|None) -> None: ...
    def removeProvider(self, provider: QgsSubsetStringEditorProvider|None) -> bool: ...
    def addProvider(self, provider: QgsSubsetStringEditorProvider|None) -> None: ...
    def providers(self) -> list[QgsSubsetStringEditorProvider]: ...


class QgsShortcutsManager(QtCore.QObject):

    class CommonAction(enum.Enum):
        CodeToggleComment = ... # type: QgsShortcutsManager.CommonAction
        CodeReformat = ... # type: QgsShortcutsManager.CommonAction
        CodeRunScript = ... # type: QgsShortcutsManager.CommonAction
        CodeRunSelection = ... # type: QgsShortcutsManager.CommonAction

    def __init__(self, parent: QtCore.QObject|None = ..., settingsRoot: str|None = ...) -> None: ...

    def objectForSettingKey(self, name: str|None) -> QtCore.QObject|None: ...
    def objectSettingKey(self, object: QtCore.QObject|None) -> str: ...
    def settingsPath(self) -> str: ...
    def shortcutByName(self, name: str|None) -> QtGui.QShortcut|None: ...
    def actionByName(self, name: str|None) -> QtGui.QAction|None: ...
    def sequenceForCommonAction(self, action: 'QgsShortcutsManager.CommonAction') -> QtGui.QKeySequence: ...
    def shortcutForSequence(self, sequence: QtGui.QKeySequence|QtGui.QKeySequence.StandardKey|str|None|int) -> QtGui.QShortcut|None: ...
    def actionForSequence(self, sequence: QtGui.QKeySequence|QtGui.QKeySequence.StandardKey|str|None|int) -> QtGui.QAction|None: ...
    def objectForSequence(self, sequence: QtGui.QKeySequence|QtGui.QKeySequence.StandardKey|str|None|int) -> QtCore.QObject|None: ...
    def setObjectKeySequence(self, object: QtCore.QObject|None, sequence: str|None) -> bool: ...
    @typing.overload
    def setKeySequence(self, name: str|None, sequence: str|None) -> bool: ...
    @typing.overload
    def setKeySequence(self, action: QtGui.QAction|None, sequence: str|None) -> bool: ...
    @typing.overload
    def setKeySequence(self, shortcut: QtGui.QShortcut|None, sequence: str|None) -> bool: ...
    @typing.overload
    def defaultKeySequence(self, action: QtGui.QAction|None) -> str: ...
    @typing.overload
    def defaultKeySequence(self, shortcut: QtGui.QShortcut|None) -> str: ...
    def objectDefaultKeySequence(self, object: QtCore.QObject|None) -> str: ...
    def listAll(self) -> list[QtCore.QObject]: ...
    def listShortcuts(self) -> list[QtGui.QShortcut]: ...
    def listActions(self) -> list[QtGui.QAction]: ...
    def unregisterShortcut(self, shortcut: QtGui.QShortcut|None) -> bool: ...
    def unregisterAction(self, action: QtGui.QAction|None) -> bool: ...
    def registerShortcut(self, shortcut: QtGui.QShortcut|None, defaultSequence: str|None = ..., section: str|None = ...) -> bool: ...
    def initializeCommonAction(self, action: QtGui.QAction|None, commonAction: 'QgsShortcutsManager.CommonAction') -> None: ...
    def registerAction(self, action: QtGui.QAction|None, defaultShortcut: str|None = ..., section: str|None = ...) -> bool: ...
    def registerAllChildShortcuts(self, object: QtCore.QObject|None, recursive: bool = ..., section: str|None = ...) -> None: ...
    def registerAllChildActions(self, object: QtCore.QObject|None, recursive: bool = ..., section: str|None = ...) -> None: ...
    def registerAllChildren(self, object: QtCore.QObject|None, recursive: bool = ..., section: str|None = ...) -> None: ...


class QgsSlider(QtWidgets.QSlider):

    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, orientation: QtCore.Qt.Orientation, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def variantValue(self) -> typing.Any: ...
    def setValue(self, value: typing.Any) -> None: ...
    def singleStep(self) -> typing.Any: ...
    def setSingleStep(self, step: typing.Any) -> None: ...
    def maximum(self) -> typing.Any: ...
    def setMaximum(self, max: typing.Any) -> None: ...
    def minimum(self) -> typing.Any: ...
    def setMinimum(self, min: typing.Any) -> None: ...


class QgsSnapIndicator(PyQt6.sip.wrapper):

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    def isVisible(self) -> bool: ...
    def setVisible(self, visible: bool = ...) -> None: ...
    def match(self) -> _core.QgsPointLocator.Match: ...
    def setMatch(self, match: _core.QgsPointLocator.Match) -> None: ...


class QgsSnapToGridCanvasItem(QgsMapCanvasItem):

    def __init__(self, mapCanvas: QgsMapCanvas|None) -> None: ...

    def setEnabled(self, enabled: bool) -> None: ...
    def enabled(self) -> bool: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def setPrecision(self, precision: float) -> None: ...
    def precision(self) -> float: ...
    def setPoint(self, point: _core.QgsPointXY) -> None: ...
    def point(self) -> _core.QgsPointXY: ...
    def paint(self, painter: QtGui.QPainter|None) -> None: ...


class QgsSourceSelectProvider(PyQt6.sip.wrapper):

    class Capability(enum.IntFlag):
        NoCapabilities = ... # type: QgsSourceSelectProvider.Capability
        ConfigureFromUri = ... # type: QgsSourceSelectProvider.Capability

    class Ordering(enum.IntEnum):
        OrderLocalProvider = ... # type: QgsSourceSelectProvider.Ordering
        OrderDatabaseProvider = ... # type: QgsSourceSelectProvider.Ordering
        OrderRemoteProvider = ... # type: QgsSourceSelectProvider.Ordering
        OrderSearchProvider = ... # type: QgsSourceSelectProvider.Ordering
        OrderOtherProvider = ... # type: QgsSourceSelectProvider.Ordering

    staticMetaObject = ... # type: QtCore.QMetaObject

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSourceSelectProvider') -> None: ...

    def capabilities(self) -> 'QgsSourceSelectProvider.Capability': ...
    def createDataSourceWidget(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., widgetMode: _core.QgsProviderRegistry.WidgetMode = ...) -> QgsAbstractDataSourceWidget|None: ...
    def ordering(self) -> int: ...
    def icon(self) -> QtGui.QIcon: ...
    def toolTip(self) -> str: ...
    def text(self) -> str: ...
    def name(self) -> str: ...
    def providerKey(self) -> str: ...


class QgsSourceSelectProviderRegistry(QtCore.QObject):

    def __init__(self) -> None: ...

    providerRemoved: typing.ClassVar[QtCore.pyqtSignal]
    providerAdded: typing.ClassVar[QtCore.pyqtSignal]
    def createSelectionWidget(self, name: str|None, parent: QtWidgets.QWidget|None, fl: QtCore.Qt.WindowType, widgetMode: _core.QgsProviderRegistry.WidgetMode) -> QgsAbstractDataSourceWidget|None: ...
    def providersByKey(self, providerKey: str|None) -> list[QgsSourceSelectProvider]: ...
    def providerByName(self, name: str|None) -> QgsSourceSelectProvider|None: ...
    def initializeFromProviderGuiRegistry(self, providerGuiRegistry: QgsProviderGuiRegistry|None) -> None: ...
    def removeProvider(self, provider: QgsSourceSelectProvider|None) -> bool: ...
    def addProvider(self, provider: QgsSourceSelectProvider|None) -> None: ...
    def providers(self) -> list[QgsSourceSelectProvider]: ...


class QgsStatusBar(QtWidgets.QWidget):

    class Anchor(enum.IntEnum):
        AnchorLeft = ... # type: QgsStatusBar.Anchor
        AnchorRight = ... # type: QgsStatusBar.Anchor

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def changeEvent(self, event: QtCore.QEvent|None) -> None: ...
    def setParentStatusBar(self, statusBar: QtWidgets.QStatusBar|None) -> None: ...
    def clearMessage(self) -> None: ...
    def showMessage(self, message: str|None, timeout: int = ...) -> None: ...
    def currentMessage(self) -> str: ...
    def removeWidget(self, widget: QtWidgets.QWidget|None) -> None: ...
    def addPermanentWidget(self, widget: QtWidgets.QWidget|None, stretch: int = ..., anchor: 'QgsStatusBar.Anchor' = ...) -> None: ...


class QgsStoredQueryManager(QtCore.QObject):

    class QueryDetails(PyQt6.sip.wrapper):

        backend = ... # type: _core.Qgis.QueryStorageBackend
        definition = ... # type: str|None
        name = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsStoredQueryManager.QueryDetails') -> None: ...

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    queryRemoved: typing.ClassVar[QtCore.pyqtSignal]
    queryChanged: typing.ClassVar[QtCore.pyqtSignal]
    queryAdded: typing.ClassVar[QtCore.pyqtSignal]
    def allQueries(self) -> list['QgsStoredQueryManager.QueryDetails']: ...
    def query(self, name: str|None, backend: _core.Qgis.QueryStorageBackend = ...) -> str: ...
    def allQueryNames(self, backend: _core.Qgis.QueryStorageBackend = ...) -> list[str]: ...
    def removeQuery(self, name: str|None, backend: _core.Qgis.QueryStorageBackend = ...) -> None: ...
    def storeQuery(self, name: str|None, query: str|None, backend: _core.Qgis.QueryStorageBackend = ...) -> None: ...


class QgsStyleItemsListWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    saveEntity: typing.ClassVar[QtCore.pyqtSignal]
    selectionChangedWithStylePath: typing.ClassVar[QtCore.pyqtSignal]
    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def currentEntityType(self) -> _core.QgsStyle.StyleEntity: ...
    def currentItemName(self) -> str: ...
    def currentTagFilter(self) -> str: ...
    def setLayerType(self, type: _core.Qgis.GeometryType) -> None: ...
    def setSymbolType(self, type: _core.Qgis.SymbolType) -> None: ...
    def setEntityType(self, type: _core.QgsStyle.StyleEntity) -> None: ...
    def setStyle(self, style: _core.QgsStyle|None) -> None: ...


class QgsSublayersDialog(QtWidgets.QDialog):

    class ProviderType(enum.IntEnum):
        Ogr = ... # type: QgsSublayersDialog.ProviderType
        Gdal = ... # type: QgsSublayersDialog.ProviderType
        Vsifile = ... # type: QgsSublayersDialog.ProviderType
        Mdal = ... # type: QgsSublayersDialog.ProviderType

    class PromptMode(enum.IntEnum):
        PromptAlways = ... # type: QgsSublayersDialog.PromptMode
        PromptIfNeeded = ... # type: QgsSublayersDialog.PromptMode
        PromptNever = ... # type: QgsSublayersDialog.PromptMode
        PromptLoadAll = ... # type: QgsSublayersDialog.PromptMode

    class LayerDefinition(PyQt6.sip.wrapper):

        count = ... # type: int
        description = ... # type: str|None
        layerId = ... # type: int
        layerName = ... # type: str|None
        type = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsSublayersDialog.LayerDefinition') -> None: ...

    @deprecated("""""")
    def __init__(self, providerType: 'QgsSublayersDialog.ProviderType', name: str|None, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., dataSourceUri: str|None = ...) -> None: ...

    def exec(self) -> int: ...
    def countColumn(self) -> int: ...
    def addToGroupCheckbox(self) -> bool: ...
    def showAddToGroupCheckbox(self) -> bool: ...
    def setShowAddToGroupCheckbox(self, showAddToGroupCheckbox: bool) -> None: ...
    def selection(self) -> list['QgsSublayersDialog.LayerDefinition']: ...
    def populateLayerTable(self, list: collections.abc.Iterable['QgsSublayersDialog.LayerDefinition']) -> None: ...


class QgsSubstitutionListWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    substitutionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def substitutions(self) -> _core.QgsStringReplacementCollection: ...
    def setSubstitutions(self, substitutions: _core.QgsStringReplacementCollection) -> None: ...


class QgsSubstitutionListDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def substitutions(self) -> _core.QgsStringReplacementCollection: ...
    def setSubstitutions(self, substitutions: _core.QgsStringReplacementCollection) -> None: ...


class QgsSymbolButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., dialogTitle: str|None = ...) -> None: ...

    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def dropEvent(self, e: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, e: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def changeEvent(self, e: QtCore.QEvent|None) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setFixedSizeConstraints(self, fixedSizeConstraints: bool) -> None: ...
    def setToDefaultSymbol(self) -> None: ...
    def setToNull(self) -> None: ...
    def setShowNull(self, showNull: bool) -> None: ...
    def pasteColor(self) -> None: ...
    def copyColor(self) -> None: ...
    def pasteSymbol(self) -> None: ...
    def copySymbol(self) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setSymbol(self, symbol: _core.QgsSymbol|None) -> None: ...
    def fixedSizeConstraints(self) -> bool: ...
    def isNull(self) -> bool: ...
    def showNull(self) -> bool: ...
    def defaultSymbol(self) -> _core.QgsSymbol|None: ...
    def setDefaultSymbol(self, symbol: _core.QgsSymbol|None) -> None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def symbol(self) -> _core.QgsSymbol|None: ...
    def dialogTitle(self) -> str: ...
    def setDialogTitle(self, title: str|None) -> None: ...
    def symbolType(self) -> _core.Qgis.SymbolType: ...
    def setSymbolType(self, type: _core.Qgis.SymbolType) -> None: ...
    def sizeHint(self) -> QtCore.QSize: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsTableView(QtWidgets.QTableView):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...


class QgsTableWidgetItem(QtWidgets.QTableWidgetItem):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, text: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTableWidgetItem') -> None: ...

    def __ge__(self, other: QtWidgets.QTableWidgetItem) -> bool: ...
    def __lt__(self, other: QtWidgets.QTableWidgetItem) -> bool: ...
    def sortRole(self) -> int: ...
    def setSortRole(self, role: int) -> None: ...


class QgsTabWidget(QtWidgets.QTabWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setTabStyle(self, tabIndex: int, labelStyle: _core.QgsAttributeEditorElement.LabelStyle) -> None: ...
    def tabRemoved(self, index: int) -> None: ...
    def tabInserted(self, index: int) -> None: ...
    def realTabIndex(self, widget: QtWidgets.QWidget|None) -> int: ...
    def setTabVisible(self, tab: QtWidgets.QWidget|None, visible: bool) -> None: ...
    def showTab(self, tab: QtWidgets.QWidget|None) -> None: ...
    def hideTab(self, tab: QtWidgets.QWidget|None) -> None: ...


class QgsTaskManagerWidget(QtWidgets.QWidget):

    def __init__(self, manager: _core.QgsTaskManager|None, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsTemporalControllerWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def applySizeConstraintsToStack(self) -> bool: ...
    def temporalController(self) -> _core.QgsTemporalNavigationObject|None: ...


class QgsTextFormatWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    class Mode(enum.IntEnum):
        Text = ... # type: QgsTextFormatWidget.Mode
        Labeling = ... # type: QgsTextFormatWidget.Mode

    @typing.overload
    def __init__(self, format: _core.QgsTextFormat = ..., mapCanvas: QgsMapCanvas|None = ..., parent: QtWidgets.QWidget|None = ..., layer: _core.QgsMapLayer|None = ...) -> None: ...
    @typing.overload
    def __init__(self, mapCanvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None, mode: 'QgsTextFormatWidget.Mode', layer: _core.QgsMapLayer|None = ...) -> None: ...

    def updatePreview(self) -> None: ...
    def saveFormat(self) -> None: ...
    def setFormatFromStyle(self, name: str|None, type: _core.QgsStyle.StyleEntity, stylePath: str|None) -> None: ...
    def updatePlacementWidgets(self) -> None: ...
    def updateLinePlacementOptions(self) -> None: ...
    def setPropertyOverrideButtonsVisible(self, visible: bool) -> None: ...
    def labelGeometryType(self) -> _core.Qgis.GeometryType: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    @deprecated("""""")
    def enableDataDefinedAlignment(self, enable: bool) -> None: ...
    def setPreviewBackground(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def updateWidgetForFormat(self, format: _core.QgsTextFormat) -> None: ...
    auxiliaryFieldCreated: typing.ClassVar[QtCore.pyqtSignal]
    widgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDockMode(self, enabled: bool) -> None: ...
    def deactivateField(self, key: _core.QgsPalLayerSettings.Property) -> None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def setFormat(self, format: _core.QgsTextFormat) -> None: ...
    def format(self, includeDataDefinedProperties: bool = ...) -> _core.QgsTextFormat: ...


class QgsTextFormatDialog(QtWidgets.QDialog):

    def __init__(self, format: _core.QgsTextFormat, mapCanvas: QgsMapCanvas|None = ..., parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., layer: _core.QgsMapLayer|None = ...) -> None: ...

    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def format(self) -> _core.QgsTextFormat: ...


class QgsTextFormatPanelWidget(QgsPanelWidgetWrapper):

    def __init__(self, format: _core.QgsTextFormat, mapCanvas: QgsMapCanvas|None = ..., parent: QtWidgets.QWidget|None = ..., layer: _core.QgsMapLayer|None = ...) -> None: ...

    def setDockMode(self, dockMode: bool) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def setFormat(self, format: _core.QgsTextFormat) -> None: ...
    def format(self) -> _core.QgsTextFormat: ...


class QgsTextPreview(QtWidgets.QLabel):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def mapUnits(self) -> _core.Qgis.DistanceUnit: ...
    def setMapUnits(self, unit: _core.Qgis.DistanceUnit) -> None: ...
    def scale(self) -> float: ...
    def setScale(self, scale: float) -> None: ...
    def format(self) -> _core.QgsTextFormat: ...
    def setFormat(self, format: _core.QgsTextFormat) -> None: ...
    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...


class QgsToolTipComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def event(self, event: QtCore.QEvent|None) -> bool: ...


class QgsTreeWidgetItem(QtWidgets.QTreeWidgetItem):

    @typing.overload
    def __init__(self, view: QtWidgets.QTreeWidget|None, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, strings: collections.abc.Iterable[str|None], type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, view: QtWidgets.QTreeWidget|None, strings: collections.abc.Iterable[str|None], type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, view: QtWidgets.QTreeWidget|None, after: QtWidgets.QTreeWidgetItem|None, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtWidgets.QTreeWidgetItem|None, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtWidgets.QTreeWidgetItem|None, strings: collections.abc.Iterable[str|None], type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtWidgets.QTreeWidgetItem|None, after: QtWidgets.QTreeWidgetItem|None, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsTreeWidgetItem') -> None: ...

    def __ge__(self, other: QtWidgets.QTreeWidgetItem) -> bool: ...
    def __lt__(self, other: QtWidgets.QTreeWidgetItem) -> bool: ...
    def alwaysOnTopPriority(self) -> int: ...
    def setAlwaysOnTopPriority(self, priority: int) -> None: ...
    def sortData(self, column: int) -> typing.Any: ...
    def setSortData(self, column: int, value: typing.Any) -> None: ...


class QgsTreeWidgetItemObject(QtCore.QObject, QgsTreeWidgetItem):

    @typing.overload
    def __init__(self, type: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtWidgets.QTreeWidget|None, type: int = ...) -> None: ...

    itemEdited: typing.ClassVar[QtCore.pyqtSignal]
    def setData(self, column: int, role: int, value: typing.Any) -> None: ...


class QgsMapUnitScaleWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    mapUnitScaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def setMapUnitScale(self, scale: _core.QgsMapUnitScale) -> None: ...
    def mapUnitScale(self) -> _core.QgsMapUnitScale: ...


class QgsMapUnitScaleDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def setMapUnitScale(self, scale: _core.QgsMapUnitScale) -> None: ...
    def getMapUnitScale(self) -> _core.QgsMapUnitScale: ...


class QgsUnitSelectionWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setShowMapScaleButton(self, show: bool) -> None: ...
    def showMapScaleButton(self) -> bool: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def setMapUnitScale(self, scale: _core.QgsMapUnitScale) -> None: ...
    def getMapUnitScale(self) -> _core.QgsMapUnitScale: ...
    def setUnit(self, unit: _core.Qgis.RenderUnit) -> None: ...
    def setUnitIndex(self, unitIndex: int) -> None: ...
    def unit(self) -> _core.Qgis.RenderUnit: ...
    def getUnit(self) -> int: ...
    @typing.overload
    def setUnits(self, units: collections.abc.Iterable[str|None], mapUnitIdx: int) -> None: ...
    @typing.overload
    def setUnits(self, units: collections.abc.Iterable[_core.Qgis.RenderUnit]) -> None: ...


class QgsUserInputWidget(QgsFloatingWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def addUserInputWidget(self, widget: QtWidgets.QWidget|None) -> None: ...


class QgsValidityCheckResultsModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        Description = ... # type: QgsValidityCheckResultsModel.CustomRole

    def __init__(self, results: collections.abc.Iterable[_core.QgsValidityCheckResult], parent: QtCore.QObject|None = ...) -> None: ...

    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex) -> QtCore.QModelIndex: ...


class QgsValidityCheckResultsWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    @staticmethod
    def runChecks(type: int, context: _core.QgsValidityCheckContext|None, title: str|None, description: str|None, parent: QtWidgets.QWidget|None = ...) -> bool: ...
    def setResults(self, results: collections.abc.Iterable[_core.QgsValidityCheckResult]) -> None: ...
    def setDescription(self, description: str|None) -> None: ...


class QgsVariableEditorWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    scopeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def reloadContext(self) -> None: ...
    def variablesInActiveScope(self) -> dict[str, typing.Any]: ...
    def settingGroup(self) -> str: ...
    def setSettingGroup(self, group: str|None) -> None: ...
    def editableScope(self) -> _core.QgsExpressionContextScope|None: ...
    def setEditableScopeIndex(self, scopeIndex: int) -> None: ...
    def context(self) -> _core.QgsExpressionContext|None: ...
    def setContext(self, context: _core.QgsExpressionContext|None) -> None: ...


class QgsVectorLayerTemporalPropertiesWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsVectorLayer|None = ...) -> None: ...

    def syncToLayer(self) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def saveTemporalProperties(self) -> None: ...


class QgsVertexMarker(QgsMapCanvasItem):

    class IconType(enum.IntEnum):
        ICON_NONE = ... # type: QgsVertexMarker.IconType
        ICON_CROSS = ... # type: QgsVertexMarker.IconType
        ICON_X = ... # type: QgsVertexMarker.IconType
        ICON_BOX = ... # type: QgsVertexMarker.IconType
        ICON_CIRCLE = ... # type: QgsVertexMarker.IconType
        ICON_DOUBLE_TRIANGLE = ... # type: QgsVertexMarker.IconType
        ICON_TRIANGLE = ... # type: QgsVertexMarker.IconType
        ICON_RHOMBUS = ... # type: QgsVertexMarker.IconType
        ICON_INVERTED_TRIANGLE = ... # type: QgsVertexMarker.IconType

    def __init__(self, mapCanvas: QgsMapCanvas|None) -> None: ...

    def updatePosition(self) -> None: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def paint(self, p: QtGui.QPainter|None) -> None: ...
    def setPenWidth(self, width: int) -> None: ...
    def fillColor(self) -> QtGui.QColor: ...
    def setFillColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self) -> QtGui.QColor: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setIconSize(self, iconSize: int) -> None: ...
    def setIconType(self, iconType: int) -> None: ...
    def center(self) -> _core.QgsPointXY: ...
    def setCenter(self, point: _core.QgsPointXY) -> None: ...


class QgsVScrollArea(QgsScrollArea):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def eventFilter(self, o: QtCore.QObject|None, e: QtCore.QEvent|None) -> bool: ...


class QgsWindowManagerInterface(PyQt6.sip.wrapper):

    class StandardDialog(enum.IntEnum):
        DialogStyleManager = ... # type: QgsWindowManagerInterface.StandardDialog

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsWindowManagerInterface') -> None: ...

    def openStandardDialog(self, dialog: 'QgsWindowManagerInterface.StandardDialog') -> QtWidgets.QWidget|None: ...


class QgsActionMenu(QtWidgets.QMenu):

    class ActionData(PyQt6.sip.wrapper):

        actionData = ... # type: typing.Any
        actionType = ... # type: _core.Qgis.ActionType
        featureId = ... # type: int
        mapLayer = ... # type: _core.QgsMapLayer

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, action: _core.QgsAction, featureId: int, mapLayer: _core.QgsMapLayer|None) -> None: ...
        @typing.overload
        def __init__(self, action: 'QgsMapLayerAction|None', featureId: int, mapLayer: _core.QgsMapLayer|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsActionMenu.ActionData') -> None: ...

    @typing.overload
    def __init__(self, layer: _core.QgsVectorLayer|None, feature: _core.QgsFeature, actionScope: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, layer: _core.QgsVectorLayer|None, fid: int, actionScope: str|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    messageDiscarded: typing.ClassVar[QtCore.pyqtSignal]
    messageEmitted: typing.ClassVar[QtCore.pyqtSignal]
    reinit: typing.ClassVar[QtCore.pyqtSignal]
    def isEmpty(self) -> bool: ...
    def menuActions(self) -> list[_core.QgsAction]: ...
    def expressionContextScope(self) -> _core.QgsExpressionContextScope: ...
    def setExpressionContextScope(self, scope: _core.QgsExpressionContextScope) -> None: ...
    def setMode(self, mode: QgsAttributeEditorContext.Mode) -> None: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def setActionContextGenerator(self, generator: QgsMapLayerActionContextGenerator|None) -> None: ...


class QgsMapLayerAction(QtGui.QAction):

    @typing.overload
    def __init__(self, name: str|None, parent: QtCore.QObject|None, targets: _core.Qgis.MapLayerActionTarget = ..., icon: QtGui.QIcon = ..., flags: _core.Qgis.MapLayerActionFlag = ...) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, parent: QtCore.QObject|None, layer: _core.QgsMapLayer|None, targets: _core.Qgis.MapLayerActionTarget = ..., icon: QtGui.QIcon = ..., flags: _core.Qgis.MapLayerActionFlag = ...) -> None: ...
    @typing.overload
    def __init__(self, name: str|None, parent: QtCore.QObject|None, layerType: _core.Qgis.LayerType, targets: _core.Qgis.MapLayerActionTarget = ..., icon: QtGui.QIcon = ..., flags: _core.Qgis.MapLayerActionFlag = ...) -> None: ...

    triggeredForLayerV2: typing.ClassVar[QtCore.pyqtSignal]
    triggeredForFeatureV2: typing.ClassVar[QtCore.pyqtSignal]
    triggeredForFeaturesV2: typing.ClassVar[QtCore.pyqtSignal]
    triggeredForLayer: typing.ClassVar[QtCore.pyqtSignal]
    triggeredForFeature: typing.ClassVar[QtCore.pyqtSignal]
    triggeredForFeatures: typing.ClassVar[QtCore.pyqtSignal]
    def isEnabledOnlyWhenEditable(self) -> bool: ...
    def targets(self) -> _core.Qgis.MapLayerActionTarget: ...
    def setTargets(self, targets: _core.Qgis.MapLayerActionTarget) -> None: ...
    @typing.overload
    @deprecated("""""")
    def triggerForLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    @typing.overload
    def triggerForLayer(self, layer: _core.QgsMapLayer|None, context: 'QgsMapLayerActionContext') -> None: ...
    @typing.overload
    @deprecated("""""")
    def triggerForFeature(self, layer: _core.QgsMapLayer|None, feature: _core.QgsFeature) -> None: ...
    @typing.overload
    def triggerForFeature(self, layer: _core.QgsMapLayer|None, feature: _core.QgsFeature, context: 'QgsMapLayerActionContext') -> None: ...
    @typing.overload
    @deprecated("""""")
    def triggerForFeatures(self, layer: _core.QgsMapLayer|None, featureList: collections.abc.Iterable[_core.QgsFeature]) -> None: ...
    @typing.overload
    def triggerForFeatures(self, layer: _core.QgsMapLayer|None, featureList: collections.abc.Iterable[_core.QgsFeature], context: 'QgsMapLayerActionContext') -> None: ...
    @typing.overload
    @deprecated("""""")
    def canRunUsingLayer(self, layer: _core.QgsMapLayer|None) -> bool: ...
    @typing.overload
    def canRunUsingLayer(self, layer: _core.QgsMapLayer|None, context: 'QgsMapLayerActionContext') -> bool: ...
    def flags(self) -> _core.Qgis.MapLayerActionFlag: ...


class QgsMapLayerActionContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsMapLayerActionContext') -> None: ...

    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def setAttributeDialog(self, dialog: QgsAttributeDialog|None) -> None: ...
    def attributeDialog(self) -> QgsAttributeDialog|None: ...


class QgsMapLayerActionRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def defaultActionForLayer(self, layer: _core.QgsMapLayer|None) -> QgsMapLayerAction|None: ...
    def setDefaultActionForLayer(self, layer: _core.QgsMapLayer|None, action: QgsMapLayerAction|None) -> None: ...
    def removeMapLayerAction(self, action: QgsMapLayerAction|None) -> bool: ...
    def mapLayerActions(self, layer: _core.QgsMapLayer|None, targets: _core.Qgis.MapLayerActionTarget = ..., context: QgsMapLayerActionContext = ...) -> list[QgsMapLayerAction]: ...
    def addMapLayerAction(self, action: QgsMapLayerAction|None) -> None: ...


class QgsAnnotationItemCommonPropertiesWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    itemChanged: typing.ClassVar[QtCore.pyqtSignal]
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def updateItem(self, item: _core.QgsAnnotationItem|None) -> None: ...
    def setItem(self, item: _core.QgsAnnotationItem|None) -> None: ...


class QgsAnnotationItemAbstractGuiMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, visibleName: str|None, groupId: str|None = ..., flags: _core.Qgis.AnnotationItemGuiFlag = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemAbstractGuiMetadata') -> None: ...

    def newItemAddedToLayer(self, item: _core.QgsAnnotationItem|None, layer: _core.QgsAnnotationLayer|None) -> None: ...
    def createItem(self) -> _core.QgsAnnotationItem|None: ...
    def createMapTool(self, canvas: QgsMapCanvas|None, cadDockWidget: QgsAdvancedDigitizingDockWidget|None) -> 'QgsCreateAnnotationItemMapToolInterface|None': ...
    def createItemWidget(self, item: _core.QgsAnnotationItem|None) -> 'QgsAnnotationItemBaseWidget|None': ...
    def creationIcon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def groupId(self) -> str: ...
    def flags(self) -> _core.Qgis.AnnotationItemGuiFlag: ...
    def type(self) -> str: ...


class QgsAnnotationItemGuiGroup(PyQt6.sip.wrapper):

    icon = ... # type: QtGui.QIcon
    id = ... # type: str|None
    name = ... # type: str|None

    @typing.overload
    def __init__(self, id: str|None = ..., name: str|None = ..., icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsAnnotationItemGuiGroup') -> None: ...


class QgsAnnotationItemGuiRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    typeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def addDefaultItems(self) -> None: ...
    def itemMetadataIds(self) -> list[int]: ...
    def createItemWidget(self, item: _core.QgsAnnotationItem|None) -> 'QgsAnnotationItemBaseWidget|None': ...
    def newItemAddedToLayer(self, metadataId: int, item: _core.QgsAnnotationItem|None, layer: _core.QgsAnnotationLayer|None) -> None: ...
    def createItem(self, metadataId: int) -> _core.QgsAnnotationItem|None: ...
    def itemGroup(self, id: str|None) -> QgsAnnotationItemGuiGroup: ...
    def addItemGroup(self, group: QgsAnnotationItemGuiGroup) -> bool: ...
    def addAnnotationItemGuiMetadata(self, metadata: QgsAnnotationItemAbstractGuiMetadata|None) -> bool: ...
    def metadataIdForItemType(self, type: str|None) -> int: ...
    def itemMetadata(self, metadataId: int) -> QgsAnnotationItemAbstractGuiMetadata|None: ...


class QgsAnnotationItemBaseWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    def renderedItemDetails(self) -> _core.QgsRenderedAnnotationItemDetails|None: ...
    def setNewItem(self, item: _core.QgsAnnotationItem|None) -> bool: ...
    itemChanged: typing.ClassVar[QtCore.pyqtSignal]
    def focusDefaultWidget(self) -> None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def itemId(self) -> str: ...
    def setItemId(self, id: str|None) -> None: ...
    def layer(self) -> _core.QgsAnnotationLayer|None: ...
    def setLayer(self, layer: _core.QgsAnnotationLayer|None) -> None: ...
    def setItem(self, item: _core.QgsAnnotationItem|None) -> bool: ...
    def updateItem(self, item: _core.QgsAnnotationItem|None) -> None: ...
    def createItem(self) -> _core.QgsAnnotationItem|None: ...


class QgsCreateAnnotationItemMapToolHandler(QtCore.QObject):

    def __init__(self, canvas: QgsMapCanvas|None, cadDockWidget: QgsAdvancedDigitizingDockWidget|None, parent: QtCore.QObject|None = ...) -> None: ...

    itemCreated: typing.ClassVar[QtCore.pyqtSignal]
    def pushCreatedItem(self, item: _core.QgsAnnotationItem|None) -> None: ...
    def targetLayer(self) -> _core.QgsAnnotationLayer|None: ...
    def takeCreatedItem(self) -> _core.QgsAnnotationItem|None: ...


class QgsCreateAnnotationItemMapToolInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCreateAnnotationItemMapToolInterface') -> None: ...

    def mapTool(self) -> 'QgsMapTool|None': ...
    def handler(self) -> QgsCreateAnnotationItemMapToolHandler|None: ...


class QgsAttributeTableDelegate(QtWidgets.QItemDelegate):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    actionColumnItemPainted: typing.ClassVar[QtCore.pyqtSignal]
    def setFeatureSelectionModel(self, featureSelectionModel: 'QgsFeatureSelectionModel|None') -> None: ...
    def setEditorData(self, editor: QtWidgets.QWidget|None, index: QtCore.QModelIndex) -> None: ...
    def setModelData(self, editor: QtWidgets.QWidget|None, model: QtCore.QAbstractItemModel|None, index: QtCore.QModelIndex) -> None: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> None: ...
    def createEditor(self, parent: QtWidgets.QWidget|None, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> QtWidgets.QWidget|None: ...


class QgsFeatureModel(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsFeatureModel') -> None: ...

    def fidToIndex(self, fid: int) -> QtCore.QModelIndex: ...


class QgsAttributeTableFilterModel(QtCore.QSortFilterProxyModel, QgsFeatureModel):

    class CustomRole(enum.IntEnum):
        Type = ... # type: QgsAttributeTableFilterModel.CustomRole

    class ColumnType(enum.IntEnum):
        ColumnTypeField = ... # type: QgsAttributeTableFilterModel.ColumnType
        ColumnTypeActionButton = ... # type: QgsAttributeTableFilterModel.ColumnType

    class FilterMode(enum.IntEnum):
        ShowAll = ... # type: QgsAttributeTableFilterModel.FilterMode
        ShowSelected = ... # type: QgsAttributeTableFilterModel.FilterMode
        ShowVisible = ... # type: QgsAttributeTableFilterModel.FilterMode
        ShowFilteredList = ... # type: QgsAttributeTableFilterModel.FilterMode
        ShowEdited = ... # type: QgsAttributeTableFilterModel.FilterMode
        ShowInvalid = ... # type: QgsAttributeTableFilterModel.FilterMode

    def __init__(self, canvas: QgsMapCanvas|None, sourceModel: 'QgsAttributeTableModel|None', parent: QtCore.QObject|None = ...) -> None: ...

    def filterFeatures(self) -> None: ...
    def extentsChanged(self) -> None: ...
    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def generateListOfVisibleFeatures(self) -> None: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    filterError: typing.ClassVar[QtCore.pyqtSignal]
    visibleReloaded: typing.ClassVar[QtCore.pyqtSignal]
    featuresFiltered: typing.ClassVar[QtCore.pyqtSignal]
    sortColumnChanged: typing.ClassVar[QtCore.pyqtSignal]
    def filterExpression(self) -> str: ...
    def setFilterExpression(self, expression: _core.QgsExpression, context: _core.QgsExpressionContext) -> None: ...
    def setAttributeTableConfig(self, config: _core.QgsAttributeTableConfig) -> None: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def actionColumnIndex(self) -> int: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def sortExpression(self) -> str: ...
    @typing.overload
    def sort(self, column: int, order: QtCore.Qt.SortOrder = ...) -> None: ...
    @typing.overload
    def sort(self, expression: str|None, order: QtCore.Qt.SortOrder = ...) -> None: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def mapFromSource(self, sourceIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapToSource(self, proxyIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapFromMaster(self, sourceIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapToMaster(self, proxyIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def fidToIndexList(self, fid: int) -> list[QtCore.QModelIndex]: ...
    def fidToIndex(self, fid: int) -> QtCore.QModelIndex: ...
    def rowToId(self, row: QtCore.QModelIndex) -> int: ...
    def masterModel(self) -> 'QgsAttributeTableModel|None': ...
    def layerCache(self) -> _core.QgsVectorLayerCache|None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def filterMode(self) -> 'QgsAttributeTableFilterModel.FilterMode': ...
    def connectFilterModeConnections(self, filterMode: 'QgsAttributeTableFilterModel.FilterMode') -> None: ...
    def disconnectFilterModeConnections(self) -> None: ...
    def setFilterMode(self, filterMode: 'QgsAttributeTableFilterModel.FilterMode') -> None: ...
    def filteredFeatures(self) -> typing.Any: ...
    def setFilteredFeatures(self, ids: typing.Any) -> None: ...
    def selectedOnTop(self) -> bool: ...
    def setSelectedOnTop(self, selectedOnTop: bool) -> None: ...
    def setSourceModel(self, sourceModel: 'QgsAttributeTableModel|None') -> None: ...


class QgsAttributeTableModel(QtCore.QAbstractTableModel):

    class CustomRole(enum.IntEnum):
        FeatureId = ... # type: QgsAttributeTableModel.CustomRole
        FieldIndex = ... # type: QgsAttributeTableModel.CustomRole
        User = ... # type: QgsAttributeTableModel.CustomRole
        Sort = ... # type: QgsAttributeTableModel.CustomRole

    def __init__(self, layerCache: _core.QgsVectorLayerCache|None, parent: QtCore.QObject|None = ...) -> None: ...

    finished: typing.ClassVar[QtCore.pyqtSignal]
    modelChanged: typing.ClassVar[QtCore.pyqtSignal]
    def fieldConditionalStyleChanged(self, fieldName: str|None) -> None: ...
    def loadLayer(self) -> None: ...
    def setShowValidityState(self, show: bool) -> None: ...
    def showValidityState(self) -> bool: ...
    def setExtraColumns(self, extraColumns: int) -> None: ...
    def extraColumns(self) -> int: ...
    def editorContext(self) -> QgsAttributeEditorContext: ...
    def setEditorContext(self, context: QgsAttributeEditorContext) -> None: ...
    def request(self) -> _core.QgsFeatureRequest: ...
    def setRequest(self, request: _core.QgsFeatureRequest) -> None: ...
    def sortCacheExpression(self, cacheIndex: int = ...) -> str: ...
    def prefetchSortData(self, expression: str|None, cacheIndex: int = ...) -> None: ...
    def prefetchColumnData(self, column: int) -> None: ...
    def feature(self, idx: QtCore.QModelIndex) -> _core.QgsFeature: ...
    def executeMapLayerAction(self, action: QgsMapLayerAction|None, idx: QtCore.QModelIndex, context: QgsMapLayerActionContext = ...) -> None: ...
    def executeAction(self, action: QtCore.QUuid, idx: QtCore.QModelIndex) -> None: ...
    def layerCache(self) -> _core.QgsVectorLayerCache|None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def swapRows(self, a: int, b: int) -> None: ...
    def rowToId(self, row: int) -> int: ...
    def fieldCol(self, idx: int) -> int: ...
    def fieldIdx(self, col: int) -> int: ...
    def idToIndexList(self, id: int) -> list[QtCore.QModelIndex]: ...
    def idToIndex(self, id: int) -> QtCore.QModelIndex: ...
    def idToRow(self, id: int) -> int: ...
    def resetModel(self) -> None: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def reload(self, index1: QtCore.QModelIndex, index2: QtCore.QModelIndex) -> None: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...


class QgsAttributeTableView(QgsTableView):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def _q_selectRow(self, row: int) -> None: ...
    def selectRow(self, row: int) -> None: ...
    def selectAll(self) -> None: ...
    @typing.overload
    def repaintRequested(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> None: ...
    @typing.overload
    def repaintRequested(self) -> None: ...
    rowHeaderDoubleClicked: typing.ClassVar[QtCore.pyqtSignal]
    finished: typing.ClassVar[QtCore.pyqtSignal]
    columnResized: typing.ClassVar[QtCore.pyqtSignal]
    willShowContextMenu: typing.ClassVar[QtCore.pyqtSignal]
    def closeEvent(self, event: QtGui.QCloseEvent|None) -> None: ...
    def contextMenuEvent(self, event: QtGui.QContextMenuEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def closeCurrentEditor(self) -> None: ...
    def scrollToFeature(self, fid: int, column: int = ...) -> None: ...
    def selectedFeaturesIds(self) -> list[int]: ...
    def setAttributeTableConfig(self, config: _core.QgsAttributeTableConfig) -> None: ...
    def eventFilter(self, object: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def setFeatureSelectionManager(self, featureSelectionManager: 'QgsIFeatureSelectionManager|None') -> None: ...
    def setModel(self, filterModel: QgsAttributeTableFilterModel|None) -> None: ...


class QgsDualView(QtWidgets.QStackedWidget):

    class FeatureListBrowsingAction(enum.IntEnum):
        NoAction = ... # type: QgsDualView.FeatureListBrowsingAction
        PanToFeature = ... # type: QgsDualView.FeatureListBrowsingAction
        ZoomToFeature = ... # type: QgsDualView.FeatureListBrowsingAction

    class ViewMode(enum.IntEnum):
        AttributeTable = ... # type: QgsDualView.ViewMode
        AttributeEditor = ... # type: QgsDualView.ViewMode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def hideEvent(self, event: QtGui.QHideEvent|None) -> None: ...
    showContextMenuExternally: typing.ClassVar[QtCore.pyqtSignal]
    formModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    filterExpressionSet: typing.ClassVar[QtCore.pyqtSignal]
    filterChanged: typing.ClassVar[QtCore.pyqtSignal]
    displayExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def parentFormValueChanged(self, attribute: str|None, value: typing.Any) -> None: ...
    def cancelProgress(self) -> None: ...
    def copyCellContent(self) -> None: ...
    def toggleSearchMode(self, enabled: bool) -> None: ...
    def setMultiEditEnabled(self, enabled: bool) -> None: ...
    def openConditionalStyles(self) -> None: ...
    def saveEditChanges(self) -> bool: ...
    def setCurrentEditSelection(self, fids: typing.Any) -> None: ...
    @staticmethod
    def requiredAttributes(layer: _core.QgsVectorLayer|None) -> list[int]: ...
    def attributeTableConfig(self) -> _core.QgsAttributeTableConfig: ...
    def sortExpression(self) -> str: ...
    def setSortExpression(self, sortExpression: str|None, sortOrder: QtCore.Qt.SortOrder = ...) -> None: ...
    def setAttributeTableConfig(self, config: _core.QgsAttributeTableConfig) -> None: ...
    def tableView(self) -> QgsAttributeTableView|None: ...
    def setFeatureSelectionManager(self, featureSelectionManager: 'QgsIFeatureSelectionManager|None') -> None: ...
    def setRequest(self, request: _core.QgsFeatureRequest) -> None: ...
    def masterModel(self) -> QgsAttributeTableModel|None: ...
    def filteredFeatures(self) -> typing.Any: ...
    def filterFeatures(self, filterExpression: _core.QgsExpression, context: _core.QgsExpressionContext) -> None: ...
    def setFilteredFeatures(self, filteredFeatures: typing.Any) -> None: ...
    def filteredFeatureCount(self) -> int: ...
    def featureCount(self) -> int: ...
    def setSelectedOnTop(self, selectedOnTop: bool) -> None: ...
    def filterMode(self) -> QgsAttributeTableFilterModel.FilterMode: ...
    def setFilterMode(self, filterMode: QgsAttributeTableFilterModel.FilterMode) -> None: ...
    def view(self) -> 'QgsDualView.ViewMode': ...
    def setView(self, view: 'QgsDualView.ViewMode') -> None: ...
    def init(self, layer: _core.QgsVectorLayer|None, mapCanvas: QgsMapCanvas|None, request: _core.QgsFeatureRequest = ..., context: QgsAttributeEditorContext = ..., loadFeatures: bool = ..., showFirstFeature: bool = ...) -> None: ...


class QgsAttributeTableAction(QtGui.QAction):

    def __init__(self, name: str|None, dualView: QgsDualView|None, action: QtCore.QUuid, fieldIdx: QtCore.QModelIndex) -> None: ...

    def featureForm(self) -> None: ...
    def execute(self) -> None: ...


class QgsAttributeTableMapLayerAction(QtGui.QAction):

    def __init__(self, name: str|None, dualView: QgsDualView|None, action: QgsMapLayerAction|None, fieldIdx: QtCore.QModelIndex) -> None: ...

    def execute(self) -> None: ...


class QgsFeatureListModel(QtCore.QSortFilterProxyModel, QgsFeatureModel):

    class Role(enum.IntEnum):
        FeatureInfoRole = ... # type: QgsFeatureListModel.Role
        FeatureRole = ... # type: QgsFeatureListModel.Role
        FeatureWithGeometryRole = ... # type: QgsFeatureListModel.Role

    class FeatureInfo(PyQt6.sip.wrapper):

        isEdited = ... # type: bool
        isNew = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsFeatureListModel.FeatureInfo') -> None: ...

    def __init__(self, sourceModel: QgsAttributeTableFilterModel|None, parent: QtCore.QObject|None = ...) -> None: ...

    def onEndInsertRows(self, parent: QtCore.QModelIndex, first: int, last: int) -> None: ...
    def onBeginInsertRows(self, parent: QtCore.QModelIndex, first: int, last: int) -> None: ...
    def onEndRemoveRows(self, parent: QtCore.QModelIndex, first: int, last: int) -> None: ...
    def onBeginRemoveRows(self, parent: QtCore.QModelIndex, first: int, last: int) -> None: ...
    def setSortByDisplayExpression(self, sortByDisplayExpression: bool, order: QtCore.Qt.SortOrder = ...) -> None: ...
    def sortByDisplayExpression(self) -> bool: ...
    def fidToIndexList(self, fid: int) -> list[QtCore.QModelIndex]: ...
    def fidToIndex(self, fid: int) -> QtCore.QModelIndex: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapSelectionToMaster(self, selection: QtCore.QItemSelection) -> QtCore.QItemSelection: ...
    def mapSelectionFromMaster(self, selection: QtCore.QItemSelection) -> QtCore.QItemSelection: ...
    def mapFromMaster(self, sourceIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapToMaster(self, proxyIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapFromSource(self, sourceIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def mapToSource(self, proxyIndex: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def fidToIdx(self, fid: int) -> QtCore.QModelIndex: ...
    def idxToFid(self, index: QtCore.QModelIndex) -> int: ...
    def featureByIndex(self, index: QtCore.QModelIndex, feat: _core.QgsFeature) -> bool: ...
    def displayExpression(self) -> str: ...
    def parserErrorString(self) -> str: ...
    def setDisplayExpression(self, expression: str|None) -> bool: ...
    def masterModel(self) -> QgsAttributeTableModel|None: ...
    def injectNull(self) -> bool: ...
    def setInjectNull(self, injectNull: bool) -> None: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def layerCache(self) -> _core.QgsVectorLayerCache|None: ...
    def setSourceModel(self, sourceModel: QgsAttributeTableFilterModel|None) -> None: ...


class QgsFeatureListView(QtWidgets.QListView):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def editLastFeature(self) -> None: ...
    def editPreviousFeature(self) -> None: ...
    def editNextFeature(self) -> None: ...
    def editFirstFeature(self) -> None: ...
    @typing.overload
    def repaintRequested(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> None: ...
    @typing.overload
    def repaintRequested(self) -> None: ...
    def selectAll(self) -> None: ...
    @typing.overload
    def setEditSelection(self, fids: typing.Any) -> None: ...
    @typing.overload
    def setEditSelection(self, index: QtCore.QModelIndex, command: QtCore.QItemSelectionModel.SelectionFlag) -> None: ...
    willShowContextMenu: typing.ClassVar[QtCore.pyqtSignal]
    displayExpressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    currentEditSelectionProgressChanged: typing.ClassVar[QtCore.pyqtSignal]
    currentEditSelectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def contextMenuEvent(self, event: QtGui.QContextMenuEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def setFeatureSelectionManager(self, featureSelectionManager: 'QgsIFeatureSelectionManager|None') -> None: ...
    def setCurrentFeatureEdited(self, state: bool) -> None: ...
    def currentEditSelection(self) -> typing.Any: ...
    def parserErrorString(self) -> str: ...
    def displayExpression(self) -> str: ...
    def setDisplayExpression(self, displayExpression: str|None) -> bool: ...
    def featureListModel(self) -> QgsFeatureListModel|None: ...
    def setModel(self, featureListModel: QgsFeatureListModel|None) -> None: ...
    def layerCache(self) -> _core.QgsVectorLayerCache|None: ...


class QgsFeatureListViewDelegate(QtWidgets.QItemDelegate):

    class Element(enum.IntEnum):
        EditElement = ... # type: QgsFeatureListViewDelegate.Element
        SelectionElement = ... # type: QgsFeatureListViewDelegate.Element

    ICON_SIZE = ... # type: int

    def __init__(self, listModel: QgsFeatureListModel|None, parent: QtCore.QObject|None = ...) -> None: ...

    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> None: ...
    def sizeHint(self, option: QtWidgets.QStyleOptionViewItem, index: QtCore.QModelIndex) -> QtCore.QSize: ...
    editButtonClicked: typing.ClassVar[QtCore.pyqtSignal]
    def setCurrentFeatureEdited(self, state: bool) -> None: ...
    def setFeatureSelectionModel(self, featureSelectionModel: 'QgsFeatureSelectionModel|None') -> None: ...
    def positionToElement(self, pos: QtCore.QPoint) -> 'QgsFeatureListViewDelegate.Element': ...
    def setEditSelectionModel(self, editSelectionModel: QtCore.QItemSelectionModel|None) -> None: ...


class QgsFeatureSelectionModel(QtCore.QItemSelectionModel):

    def __init__(self, model: QtCore.QAbstractItemModel|None, featureModel: QgsFeatureModel|None, featureSelectionHandler: 'QgsIFeatureSelectionManager|None', parent: QtCore.QObject|None) -> None: ...

    def setFeatureSelectionManager(self, featureSelectionManager: 'QgsIFeatureSelectionManager|None') -> None: ...
    def selectFeatures(self, selection: QtCore.QItemSelection, command: QtCore.QItemSelectionModel.SelectionFlag) -> None: ...
    @typing.overload
    def select(self, index: QtCore.QModelIndex, command: QtCore.QItemSelectionModel.SelectionFlag) -> None: ...
    @typing.overload
    def select(self, selection: QtCore.QItemSelection, command: QtCore.QItemSelectionModel.SelectionFlag) -> None: ...
    requestRepaint: typing.ClassVar[QtCore.pyqtSignal]
    @typing.overload
    def isSelected(self, fid: int) -> bool: ...
    @typing.overload
    def isSelected(self, index: QtCore.QModelIndex) -> bool: ...
    def enableSync(self, enable: bool) -> None: ...


class QgsFieldConditionalFormatWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    rulesUpdated: typing.ClassVar[QtCore.pyqtSignal]
    @staticmethod
    def defaultPresets() -> list[_core.QgsConditionalStyle]: ...
    def setPresets(self, styles: collections.abc.Iterable[_core.QgsConditionalStyle]) -> None: ...
    @deprecated("""""")
    def reset(self) -> None: ...
    @deprecated("""""")
    def loadStyle(self, style: _core.QgsConditionalStyle) -> None: ...
    def editStyle(self, index: int, style: _core.QgsConditionalStyle) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    @deprecated("""""")
    def viewRules(self) -> None: ...


class QgsEditConditionalFormatRuleWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    canceled: typing.ClassVar[QtCore.pyqtSignal]
    ruleDeleted: typing.ClassVar[QtCore.pyqtSignal]
    ruleSaved: typing.ClassVar[QtCore.pyqtSignal]
    def setRule(self, rule: str|None) -> None: ...
    def currentStyle(self) -> _core.QgsConditionalStyle: ...
    def loadStyle(self, style: _core.QgsConditionalStyle) -> None: ...
    def setPresets(self, styles: collections.abc.Iterable[_core.QgsConditionalStyle]) -> None: ...
    def setLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...


class QgsIFeatureSelectionManager(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...

    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def selectedFeatureIds(self) -> typing.Any: ...
    def setSelectedFeatures(self, ids: typing.Any) -> None: ...
    def deselect(self, ids: typing.Any) -> None: ...
    def select(self, ids: typing.Any) -> None: ...
    def selectedFeatureCount(self) -> int: ...


class QgsOrganizeTableColumnsDialog(QtWidgets.QDialog):

    @typing.overload
    def __init__(self, vl: _core.QgsVectorLayer|None, config: _core.QgsAttributeTableConfig, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...
    @typing.overload
    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def toggleSelection(self) -> None: ...
    def hideAll(self) -> None: ...
    def showAll(self) -> None: ...
    def config(self) -> _core.QgsAttributeTableConfig: ...


class QgsAuthAuthoritiesEditor(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...


class QgsAuthCertInfo(QtWidgets.QWidget):

    def __init__(self, cert: QtNetwork.QSslCertificate, manageCertTrust: bool = ..., parent: QtWidgets.QWidget|None = ..., connectionCAs: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> None: ...

    def trustCacheRebuilt(self) -> bool: ...


class QgsAuthCertInfoDialog(QtWidgets.QDialog):

    def __init__(self, cert: QtNetwork.QSslCertificate, manageCertTrust: bool, parent: QtWidgets.QWidget|None = ..., connectionCAs: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> None: ...

    def trustCacheRebuilt(self) -> bool: ...
    def certInfoWidget(self) -> QgsAuthCertInfo|None: ...


class QgsAuthCertEditors(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsAuthCertManager(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def certEditorsWidget(self) -> QgsAuthCertEditors|None: ...


class QgsAuthCertTrustPolicyComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., policy: _core.QgsAuthCertUtils.CertTrustPolicy = ..., defaultpolicy: _core.QgsAuthCertUtils.CertTrustPolicy = ...) -> None: ...

    def setDefaultTrustPolicy(self, defaultpolicy: _core.QgsAuthCertUtils.CertTrustPolicy) -> None: ...
    def setTrustPolicy(self, policy: _core.QgsAuthCertUtils.CertTrustPolicy) -> None: ...
    def trustPolicyForIndex(self, indx: int) -> _core.QgsAuthCertUtils.CertTrustPolicy: ...
    def trustPolicy(self) -> _core.QgsAuthCertUtils.CertTrustPolicy: ...


class QgsAuthConfigEditor(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., showUtilities: bool = ..., relayMessages: bool = ...) -> None: ...

    def setRelayMessages(self, relay: bool = ...) -> None: ...
    def setShowUtilitiesButton(self, show: bool = ...) -> None: ...
    def selectedAuthenticationConfigIds(self) -> list[str]: ...
    def toggleTitleVisibility(self, visible: bool) -> None: ...


class QgsAuthConfigSelect(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., dataprovider: str|None = ...) -> None: ...

    def clearMessage(self) -> None: ...
    def showMessage(self, msg: str|None) -> None: ...
    selectedConfigIdRemoved: typing.ClassVar[QtCore.pyqtSignal]
    selectedConfigIdChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDataProviderKey(self, key: str|None) -> None: ...
    def configId(self) -> str: ...
    def setConfigId(self, authcfg: str|None) -> None: ...


class QgsAuthConfigUriEdit(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., datauri: str|None = ..., dataprovider: str|None = ...) -> None: ...

    @staticmethod
    def hasConfigId(txt: str|None) -> bool: ...
    def dataSourceUri(self) -> str: ...
    def setDataSourceUri(self, datauri: str|None) -> None: ...


class QgsAuthMethodPlugins(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsAuthEditorWidgets(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsAuthIdentitiesEditor(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...


class QgsAuthImportCertDialog(QtWidgets.QDialog):

    class CertInput(enum.IntEnum):
        AllInputs = ... # type: QgsAuthImportCertDialog.CertInput
        FileInput = ... # type: QgsAuthImportCertDialog.CertInput
        TextInput = ... # type: QgsAuthImportCertDialog.CertInput

    class CertFilter(enum.IntEnum):
        NoFilter = ... # type: QgsAuthImportCertDialog.CertFilter
        CaFilter = ... # type: QgsAuthImportCertDialog.CertFilter

    def __init__(self, parent: QtWidgets.QWidget|None = ..., filter: 'QgsAuthImportCertDialog.CertFilter' = ..., input: 'QgsAuthImportCertDialog.CertInput' = ...) -> None: ...

    def certTrustPolicy(self) -> _core.QgsAuthCertUtils.CertTrustPolicy: ...
    def allowInvalidCerts(self) -> bool: ...
    def certTextToImport(self) -> str: ...
    def certFileToImport(self) -> str: ...
    def certificatesToImport(self) -> list[QtNetwork.QSslCertificate]: ...


class QgsAuthImportIdentityDialog(QtWidgets.QDialog):

    class Validity(enum.IntEnum):
        Valid = ... # type: QgsAuthImportIdentityDialog.Validity
        Invalid = ... # type: QgsAuthImportIdentityDialog.Validity
        Unknown = ... # type: QgsAuthImportIdentityDialog.Validity

    class BundleTypes(enum.IntEnum):
        PkiPaths = ... # type: QgsAuthImportIdentityDialog.BundleTypes
        PkiPkcs12 = ... # type: QgsAuthImportIdentityDialog.BundleTypes

    class IdentityType(enum.IntEnum):
        CertIdentity = ... # type: QgsAuthImportIdentityDialog.IdentityType

    def __init__(self, identitytype: 'QgsAuthImportIdentityDialog.IdentityType', parent: QtWidgets.QWidget|None = ...) -> None: ...

    def pkiBundleToImport(self) -> _core.QgsPkiBundle: ...
    def identityType(self) -> 'QgsAuthImportIdentityDialog.IdentityType': ...


class QgsAuthMethodEdit(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def clearConfig(self) -> None: ...
    def resetConfig(self) -> None: ...
    def loadConfig(self, configmap: dict[str|None, str|None]) -> None: ...
    validityChanged: typing.ClassVar[QtCore.pyqtSignal]
    def configMap(self) -> dict[str, str]: ...
    def validateConfig(self) -> bool: ...


class QgsAuthServersEditor(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...


class QgsAuthSettingsWidget(QtWidgets.QWidget):

    class WarningType(enum.IntEnum):
        ProjectFile = ... # type: QgsAuthSettingsWidget.WarningType
        UserSettings = ... # type: QgsAuthSettingsWidget.WarningType

    def __init__(self, parent: QtWidgets.QWidget|None = ..., configId: str|None = ..., username: str|None = ..., password: str|None = ..., dataprovider: str|None = ...) -> None: ...

    configIdChanged: typing.ClassVar[QtCore.pyqtSignal]
    passwordChanged: typing.ClassVar[QtCore.pyqtSignal]
    usernameChanged: typing.ClassVar[QtCore.pyqtSignal]
    def convertToEncrypted(self) -> bool: ...
    def configurationTabIsSelected(self) -> bool: ...
    def storeUsernameIsChecked(self) -> bool: ...
    def storePasswordIsChecked(self) -> bool: ...
    def setStorePasswordChecked(self, checked: bool) -> None: ...
    def setStoreUsernameChecked(self, checked: bool) -> None: ...
    def showStoreCheckboxes(self, enabled: bool) -> None: ...
    def btnConvertToEncryptedIsEnabled(self) -> bool: ...
    @staticmethod
    def formattedWarning(warning: 'QgsAuthSettingsWidget.WarningType') -> str: ...
    def dataprovider(self) -> str: ...
    def setDataprovider(self, dataprovider: str|None) -> None: ...
    def setConfigId(self, configId: str|None) -> None: ...
    def configId(self) -> str: ...
    def setPassword(self, password: str|None) -> None: ...
    def password(self) -> str: ...
    def setUsername(self, username: str|None) -> None: ...
    def username(self) -> str: ...
    def setBasicText(self, basicText: str|None) -> None: ...
    def setWarningText(self, warningText: str|None) -> None: ...
    def removeBasicSettings(self) -> None: ...


class QgsAuthSslConfigWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., cert: QtNetwork.QSslCertificate = ..., hostport: str|None = ..., connectionCAs: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> None: ...

    readyToSaveChanged: typing.ClassVar[QtCore.pyqtSignal]
    hostPortValidityChanged: typing.ClassVar[QtCore.pyqtSignal]
    certFoundInAuthDatabase: typing.ClassVar[QtCore.pyqtSignal]
    configEnabledChanged: typing.ClassVar[QtCore.pyqtSignal]
    def readyToSave(self) -> bool: ...
    def validateHostPortText(self, txt: str|None) -> None: ...
    def setConfigCheckable(self, checkable: bool) -> None: ...
    def setSslHost(self, host: str|None) -> None: ...
    def resetSslPeerVerify(self) -> None: ...
    def setSslPeerVerify(self, mode: QtNetwork.QSslSocket.PeerVerifyMode, modedepth: int) -> None: ...
    def resetSslIgnoreErrors(self) -> None: ...
    def setSslIgnoreErrors(self, errors: collections.abc.Iterable[QtNetwork.QSslError]) -> None: ...
    def setSslIgnoreErrorEnums(self, errorenums: collections.abc.Iterable[QtNetwork.QSslError.SslError]) -> None: ...
    def appendSslIgnoreErrors(self, errors: collections.abc.Iterable[QtNetwork.QSslError]) -> None: ...
    def resetSslProtocol(self) -> None: ...
    def setSslProtocol(self, protocol: QtNetwork.QSsl.SslProtocol) -> None: ...
    def resetSslCertConfig(self) -> None: ...
    def saveSslCertConfig(self) -> None: ...
    def loadSslCustomConfig(self, config: _core.QgsAuthConfigSslServer = ...) -> None: ...
    def setSslCertificate(self, cert: QtNetwork.QSslCertificate, hostport: str|None = ...) -> None: ...
    def enableSslCustomOptions(self, enable: bool) -> None: ...
    def sslPeerVerifyDepth(self) -> int: ...
    def sslPeerVerifyMode(self) -> QtNetwork.QSslSocket.PeerVerifyMode: ...
    def sslIgnoreErrorEnums(self) -> list[QtNetwork.QSslError.SslError]: ...
    def sslProtocol(self) -> QtNetwork.QSsl.SslProtocol: ...
    def sslHost(self) -> str: ...
    def sslCertificate(self) -> QtNetwork.QSslCertificate: ...
    def sslCustomConfig(self) -> _core.QgsAuthConfigSslServer: ...
    def sslConfigGroupBox(self) -> QtWidgets.QGroupBox|None: ...
    def certificateGroupBox(self) -> QtWidgets.QGroupBox|None: ...


class QgsAuthSslConfigDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., cert: QtNetwork.QSslCertificate = ..., hostport: str|None = ...) -> None: ...

    def accept(self) -> None: ...
    def sslCustomConfigWidget(self) -> QgsAuthSslConfigWidget|None: ...


class QgsAuthSslErrorsDialog(QtWidgets.QDialog):

    def __init__(self, reply: QtNetwork.QNetworkReply|None, sslErrors: collections.abc.Iterable[QtNetwork.QSslError], parent: QtWidgets.QWidget|None = ..., digest: str|None = ..., hostport: str|None = ...) -> None: ...


class QgsAuthSslImportDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def accept(self) -> None: ...


class QgsAuthTrustedCAsDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., trustedCAs: collections.abc.Iterable[QtNetwork.QSslCertificate] = ...) -> None: ...

    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...


class QgsCalloutPanelWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsMapLayer|None = ...) -> None: ...

    calloutChanged: typing.ClassVar[QtCore.pyqtSignal]
    def callout(self) -> _core.QgsCallout|None: ...
    def setCallout(self, callout: _core.QgsCallout|None) -> None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def geometryType(self) -> _core.Qgis.GeometryType: ...
    def setGeometryType(self, type: _core.Qgis.GeometryType) -> None: ...


class QgsCalloutWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None, vl: _core.QgsMapLayer|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def registerDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsCallout.Property) -> None: ...
    def setGeometryType(self, type: _core.Qgis.GeometryType) -> None: ...
    def layer(self) -> _core.QgsMapLayer|None: ...
    @deprecated("""""")
    def vectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def callout(self) -> _core.QgsCallout|None: ...
    def setCallout(self, callout: _core.QgsCallout|None) -> None: ...


class QgsCodeInterpreter(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCodeInterpreter') -> None: ...

    def execCommandImpl(self, command: str|None) -> int: ...
    def promptForState(self, state: int) -> str: ...
    def currentState(self) -> int: ...
    def exec(self, command: str|None) -> int: ...


class QgsCodeEditor(Qsci.QsciScintilla):

    class Flag(enum.IntFlag):
        CodeFolding = ... # type: QgsCodeEditor.Flag
        ImmediatelyUpdateHistory = ... # type: QgsCodeEditor.Flag

    class MarginRole(enum.IntEnum):
        LineNumbers = ... # type: QgsCodeEditor.MarginRole
        ErrorIndicators = ... # type: QgsCodeEditor.MarginRole
        FoldingControls = ... # type: QgsCodeEditor.MarginRole

    class Mode(enum.Enum):
        ScriptEditor = ... # type: QgsCodeEditor.Mode
        OutputDisplay = ... # type: QgsCodeEditor.Mode
        CommandInput = ... # type: QgsCodeEditor.Mode

    SEARCH_RESULT_INDICATOR = ... # type: int

    def __init__(self, parent: QtWidgets.QWidget|None = ..., title: str|None = ..., folding: bool = ..., margin: bool = ..., flags: 'QgsCodeEditor.Flag' = ..., mode: 'QgsCodeEditor.Mode' = ...) -> None: ...

    def toggleLineComments(self, commentPrefix: str|None) -> None: ...
    def showMessage(self, title: str|None, message: str|None, level: _core.Qgis.MessageLevel) -> None: ...
    def reformatCodeString(self, string: str|None) -> str: ...
    def populateContextMenu(self, menu: QtWidgets.QMenu|None) -> None: ...
    def updatePrompt(self) -> None: ...
    def updateSoftHistory(self) -> None: ...
    def runPostLexerConfigurationTasks(self) -> None: ...
    def lexerFont(self) -> QtGui.QFont: ...
    def lexerColor(self, role: 'QgsCodeEditorColorScheme.ColorRole') -> QtGui.QColor: ...
    def initializeLexer(self) -> None: ...
    def eventFilter(self, watched: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def event(self, event: QtCore.QEvent|None) -> bool: ...
    def contextMenuEvent(self, event: QtGui.QContextMenuEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    @staticmethod
    def isFixedPitch(font: QtGui.QFont) -> bool: ...
    editingTimeout: typing.ClassVar[QtCore.pyqtSignal]
    helpRequested: typing.ClassVar[QtCore.pyqtSignal]
    persistentHistoryCleared: typing.ClassVar[QtCore.pyqtSignal]
    sessionHistoryCleared: typing.ClassVar[QtCore.pyqtSignal]
    def setEditingTimeoutInterval(self, timeout: int) -> None: ...
    def setText(self, text: str|None) -> None: ...
    def adjustScrollWidth(self) -> None: ...
    def toggleComment(self) -> None: ...
    def checkSyntax(self) -> bool: ...
    def reformatCode(self) -> None: ...
    def writeHistoryFile(self) -> bool: ...
    def clearPersistentHistory(self) -> None: ...
    def clearSessionHistory(self) -> None: ...
    def removeHistoryCommand(self, index: int) -> None: ...
    def showHistory(self) -> None: ...
    def showNextCommand(self) -> None: ...
    def showPreviousCommand(self) -> None: ...
    def moveCursorToEnd(self) -> None: ...
    def moveCursorToStart(self) -> None: ...
    def runCommand(self, command: str|None, skipHistory: bool = ...) -> None: ...
    def editingTimeoutInterval(self) -> int: ...
    def wrapPosition(self, line: int = ...) -> int: ...
    def callTip(self) -> None: ...
    def setLinearSelection(self, start: int, end: int) -> None: ...
    def selectionEnd(self) -> int: ...
    def selectionStart(self) -> int: ...
    def setLinearPosition(self, position: int) -> None: ...
    def linearPosition(self) -> int: ...
    def setInterpreter(self, newInterpreter: QgsCodeInterpreter|None) -> None: ...
    def interpreter(self) -> QgsCodeInterpreter|None: ...
    def history(self) -> list[str]: ...
    def setHistoryFilePath(self, path: str|None) -> None: ...
    def isCursorOnLastLine(self) -> bool: ...
    def mode(self) -> 'QgsCodeEditor.Mode': ...
    def clearWarnings(self) -> None: ...
    def addWarning(self, lineNumber: int, warning: str|None) -> None: ...
    @staticmethod
    def getMonospaceFont() -> QtGui.QFont: ...
    @staticmethod
    def setColor(role: 'QgsCodeEditorColorScheme.ColorRole', color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @staticmethod
    def color(role: 'QgsCodeEditorColorScheme.ColorRole') -> QtGui.QColor: ...
    @staticmethod
    def defaultColor(role: 'QgsCodeEditorColorScheme.ColorRole', theme: str|None = ...) -> QtGui.QColor: ...
    def insertText(self, text: str|None) -> None: ...
    def foldingVisible(self) -> bool: ...
    def setFoldingVisible(self, folding: bool) -> None: ...
    def lineNumbersVisible(self) -> bool: ...
    def setLineNumbersVisible(self, visible: bool) -> None: ...
    @deprecated("""""")
    def marginVisible(self) -> bool: ...
    @deprecated("""""")
    def setMarginVisible(self, margin: bool) -> None: ...
    @staticmethod
    def languageToString(language: _core.Qgis.ScriptLanguage) -> str: ...
    def languageCapabilities(self) -> _core.Qgis.ScriptLanguageCapability: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...
    def setTitle(self, title: str|None) -> None: ...


class QgsCodeEditorColorScheme(PyQt6.sip.wrapper):

    class ColorRole(enum.Enum):
        Default = ... # type: QgsCodeEditorColorScheme.ColorRole
        Keyword = ... # type: QgsCodeEditorColorScheme.ColorRole
        Class = ... # type: QgsCodeEditorColorScheme.ColorRole
        Method = ... # type: QgsCodeEditorColorScheme.ColorRole
        Decoration = ... # type: QgsCodeEditorColorScheme.ColorRole
        Number = ... # type: QgsCodeEditorColorScheme.ColorRole
        Comment = ... # type: QgsCodeEditorColorScheme.ColorRole
        CommentLine = ... # type: QgsCodeEditorColorScheme.ColorRole
        CommentBlock = ... # type: QgsCodeEditorColorScheme.ColorRole
        Background = ... # type: QgsCodeEditorColorScheme.ColorRole
        Cursor = ... # type: QgsCodeEditorColorScheme.ColorRole
        CaretLine = ... # type: QgsCodeEditorColorScheme.ColorRole
        SingleQuote = ... # type: QgsCodeEditorColorScheme.ColorRole
        DoubleQuote = ... # type: QgsCodeEditorColorScheme.ColorRole
        TripleSingleQuote = ... # type: QgsCodeEditorColorScheme.ColorRole
        TripleDoubleQuote = ... # type: QgsCodeEditorColorScheme.ColorRole
        Operator = ... # type: QgsCodeEditorColorScheme.ColorRole
        QuotedOperator = ... # type: QgsCodeEditorColorScheme.ColorRole
        Identifier = ... # type: QgsCodeEditorColorScheme.ColorRole
        QuotedIdentifier = ... # type: QgsCodeEditorColorScheme.ColorRole
        Tag = ... # type: QgsCodeEditorColorScheme.ColorRole
        UnknownTag = ... # type: QgsCodeEditorColorScheme.ColorRole
        MarginBackground = ... # type: QgsCodeEditorColorScheme.ColorRole
        MarginForeground = ... # type: QgsCodeEditorColorScheme.ColorRole
        SelectionBackground = ... # type: QgsCodeEditorColorScheme.ColorRole
        SelectionForeground = ... # type: QgsCodeEditorColorScheme.ColorRole
        MatchedBraceBackground = ... # type: QgsCodeEditorColorScheme.ColorRole
        MatchedBraceForeground = ... # type: QgsCodeEditorColorScheme.ColorRole
        Edge = ... # type: QgsCodeEditorColorScheme.ColorRole
        Fold = ... # type: QgsCodeEditorColorScheme.ColorRole
        Error = ... # type: QgsCodeEditorColorScheme.ColorRole
        ErrorBackground = ... # type: QgsCodeEditorColorScheme.ColorRole
        FoldIconForeground = ... # type: QgsCodeEditorColorScheme.ColorRole
        FoldIconHalo = ... # type: QgsCodeEditorColorScheme.ColorRole
        IndentationGuide = ... # type: QgsCodeEditorColorScheme.ColorRole
        SearchMatchBackground = ... # type: QgsCodeEditorColorScheme.ColorRole

    @typing.overload
    def __init__(self, id: str|None = ..., name: str|None = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCodeEditorColorScheme') -> None: ...

    def setColor(self, role: 'QgsCodeEditorColorScheme.ColorRole', color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def color(self, role: 'QgsCodeEditorColorScheme.ColorRole') -> QtGui.QColor: ...
    def name(self) -> str: ...
    def id(self) -> str: ...


class QgsCodeEditorColorSchemeRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsCodeEditorColorSchemeRegistry') -> None: ...

    def scheme(self, id: str|None) -> QgsCodeEditorColorScheme: ...
    def schemes(self) -> list[str]: ...
    def removeColorScheme(self, id: str|None) -> bool: ...
    def addColorScheme(self, scheme: QgsCodeEditorColorScheme) -> bool: ...


class QgsCodeEditorCSS(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorDockWidget(QtWidgets.QWidget):

    def __init__(self, dockId: str|None = ..., usePersistentWidget: bool = ...) -> None: ...

    visibilityChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setUserVisible(self, visible: bool) -> None: ...
    def isUserVisible(self) -> bool: ...
    def setDockObjectName(self, name: str|None) -> None: ...
    def dockToggleButton(self) -> QtWidgets.QToolButton|None: ...
    def setTitle(self, title: str|None) -> None: ...


class QgsCodeEditorExpression(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def toggleComment(self) -> None: ...
    def setFields(self, fields: _core.QgsFields) -> None: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext) -> None: ...
    def languageCapabilities(self) -> _core.Qgis.ScriptLanguageCapability: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorHTML(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def reformatCodeString(self, string: str|None) -> str: ...
    def initializeLexer(self) -> None: ...
    def toggleComment(self) -> None: ...
    def languageCapabilities(self) -> _core.Qgis.ScriptLanguageCapability: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorJavascript(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorJson(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorPython(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., filenames: collections.abc.Iterable[str|None] = ..., mode: QgsCodeEditor.Mode = ..., flags: QgsCodeEditor.Flag = ...) -> None: ...

    def autoComplete(self) -> None: ...
    def populateContextMenu(self, menu: QtWidgets.QMenu|None) -> None: ...
    def reformatCodeString(self, string: str|None) -> str: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def initializeLexer(self) -> None: ...
    def toggleComment(self) -> None: ...
    def showApiDocumentation(self, item: str|None) -> None: ...
    def searchSelectedTextInPyQGISDocs(self) -> None: ...
    def checkSyntax(self) -> bool: ...
    def updateCapabilities(self) -> None: ...
    def characterAfterCursor(self) -> str: ...
    def characterBeforeCursor(self) -> str: ...
    def isCursorInsideStringLiteralOrComment(self) -> bool: ...
    def loadScript(self, script: str|None) -> bool: ...
    def loadAPIs(self, filenames: collections.abc.Iterable[str|None]) -> None: ...
    def languageCapabilities(self) -> _core.Qgis.ScriptLanguageCapability: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorR(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., mode: QgsCodeEditor.Mode = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorShell(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., mode: QgsCodeEditor.Mode = ..., language: _core.Qgis.ScriptLanguage = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorSQL(QgsCodeEditor):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def initializeLexer(self) -> None: ...
    def extraKeywords(self) -> list[str]: ...
    def setExtraKeywords(self, extraKeywords: collections.abc.Iterable[str|None]) -> None: ...
    def fieldNames(self) -> list[str]: ...
    def setFieldNames(self, fieldNames: collections.abc.Iterable[str|None]) -> None: ...
    def setFields(self, fields: _core.QgsFields) -> None: ...
    def language(self) -> _core.Qgis.ScriptLanguage: ...


class QgsCodeEditorWidget(QgsPanelWidget):

    def __init__(self, editor: QgsCodeEditor|None, messageBar: QgsMessageBar|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    loadedExternalChanges: typing.ClassVar[QtCore.pyqtSignal]
    filePathChanged: typing.ClassVar[QtCore.pyqtSignal]
    searchBarToggled: typing.ClassVar[QtCore.pyqtSignal]
    def shareOnGist(self, isPublic: bool) -> bool: ...
    def openInExternalEditor(self, line: int = ..., column: int = ...) -> bool: ...
    def setFilePath(self, path: str|None) -> None: ...
    def loadFile(self, path: str|None) -> bool: ...
    def triggerFind(self) -> None: ...
    def setReplaceBarVisible(self, visible: bool) -> None: ...
    def setSearchBarVisible(self, visible: bool) -> None: ...
    def hideSearchBar(self) -> None: ...
    def showSearchBar(self) -> None: ...
    def save(self, path: str|None = ...) -> bool: ...
    def filePath(self) -> str: ...
    def clearWarnings(self) -> None: ...
    def addWarning(self, lineNumber: int, warning: str|None) -> None: ...
    def scrollbarHighlightController(self) -> QgsScrollBarHighlightController|None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def isSearchBarVisible(self) -> bool: ...
    def editor(self) -> QgsCodeEditor|None: ...
    def eventFilter(self, obj: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...


class QgsDevToolWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsDevToolWidgetFactory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, title: str|None = ..., icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsDevToolWidgetFactory') -> None: ...

    def createWidget(self, parent: QtWidgets.QWidget|None = ...) -> QgsDevToolWidget|None: ...
    def setTitle(self, title: str|None) -> None: ...
    def title(self) -> str: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...


class QgsEditorConfigWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None) -> None: ...

    def updateDataDefinedButton(self, button: QgsPropertyOverrideButton|None) -> None: ...
    def updateDataDefinedButtons(self) -> None: ...
    def initializeDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: 'QgsWidgetWrapper.Property') -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def field(self) -> int: ...
    def setConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    def config(self) -> dict[str, typing.Any]: ...


class QgsEditorWidgetAutoConfPlugin(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEditorWidgetAutoConfPlugin') -> None: ...

    def editorWidgetSetup(self, vl: _core.QgsVectorLayer|None, fieldName: str|None) -> typing.Tuple[_core.QgsEditorWidgetSetup, int]: ...


class QgsEditorWidgetFactory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, name: str|None, icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsEditorWidgetFactory') -> None: ...

    def fieldScore(self, vl: _core.QgsVectorLayer|None, fieldIdx: int) -> int: ...
    def supportsField(self, vl: _core.QgsVectorLayer|None, fieldIdx: int) -> bool: ...
    def configWidget(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None) -> QgsEditorConfigWidget|None: ...
    def isReadOnly(self) -> bool: ...
    def icon(self) -> QtGui.QIcon: ...
    def name(self) -> str: ...
    def createSearchWidget(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None) -> 'QgsSearchWidgetWrapper|None': ...
    def create(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None) -> 'QgsEditorWidgetWrapper|None': ...


class QgsEditorWidgetRegistry(QtCore.QObject):

    def __init__(self) -> None: ...

    def registerAutoConfPlugin(self, plugin: QgsEditorWidgetAutoConfPlugin|None) -> None: ...
    def registerWidget(self, widgetId: str|None, widgetFactory: QgsEditorWidgetFactory|None) -> bool: ...
    def factory(self, widgetId: str|None) -> QgsEditorWidgetFactory|None: ...
    def factories(self) -> typing.Any: ...
    def isReadOnly(self, widgetId: str|None) -> bool: ...
    def icon(self, widgetId: str|None) -> QtGui.QIcon: ...
    def name(self, widgetId: str|None) -> str: ...
    def createConfigWidget(self, widgetId: str|None, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None) -> QgsEditorConfigWidget|None: ...
    def createSearchWidget(self, widgetId: str|None, vl: _core.QgsVectorLayer|None, fieldIdx: int, config: dict[str|None, typing.Any], parent: QtWidgets.QWidget|None) -> 'QgsSearchWidgetWrapper|None': ...
    @typing.overload
    def create(self, widgetId: str|None, vl: _core.QgsVectorLayer|None, fieldIdx: int, config: dict[str|None, typing.Any], editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None) -> 'QgsEditorWidgetWrapper|None': ...
    @typing.overload
    def create(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None) -> 'QgsEditorWidgetWrapper|None': ...
    def findBest(self, vl: _core.QgsVectorLayer|None, fieldName: str|None) -> _core.QgsEditorWidgetSetup: ...
    def initEditors(self, mapCanvas: QgsMapCanvas|None = ..., messageBar: QgsMessageBar|None = ...) -> None: ...


class QgsWidgetWrapper(QtCore.QObject):

    class Property(enum.IntEnum):
        RootPath = ... # type: QgsWidgetWrapper.Property
        DocumentViewerContent = ... # type: QgsWidgetWrapper.Property
        StorageUrl = ... # type: QgsWidgetWrapper.Property

    def __init__(self, vl: _core.QgsVectorLayer|None, editor: QtWidgets.QWidget|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setEnabled(self, enabled: bool) -> None: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    contextChanged: typing.ClassVar[QtCore.pyqtSignal]
    def notifyAboutToSave(self) -> None: ...
    def setDataDefinedProperties(self, collection: _core.QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> _core.QgsPropertyCollection: ...
    def valid(self) -> bool: ...
    @staticmethod
    def fromWidget(widget: QtWidgets.QWidget|None) -> 'QgsWidgetWrapper|None': ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def context(self) -> QgsAttributeEditorContext: ...
    @typing.overload
    def config(self, key: str|None, defaultVal: typing.Any = ...) -> typing.Any: ...
    @typing.overload
    def config(self) -> dict[str, typing.Any]: ...
    def setContext(self, context: QgsAttributeEditorContext) -> None: ...
    def setConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    def widget(self) -> QtWidgets.QWidget|None: ...
    @staticmethod
    def propertyDefinitions() -> dict[int, _core.QgsPropertyDefinition]: ...


class QgsEditorWidgetWrapper(QgsWidgetWrapper):

    class ConstraintResult(enum.IntEnum):
        ConstraintResultPass = ... # type: QgsEditorWidgetWrapper.ConstraintResult
        ConstraintResultFailHard = ... # type: QgsEditorWidgetWrapper.ConstraintResult
        ConstraintResultFailSoft = ... # type: QgsEditorWidgetWrapper.ConstraintResult

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, editor: QtWidgets.QWidget|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setFormFeatureAttribute(self, attributeName: str|None, attributeValue: typing.Any) -> bool: ...
    def setFormFeature(self, feature: _core.QgsFeature) -> None: ...
    def formFeature(self) -> _core.QgsFeature: ...
    def updateConstraintWidgetStatus(self) -> None: ...
    def parentFormValueChanged(self, attribute: str|None, value: typing.Any) -> None: ...
    def emitValueChanged(self) -> None: ...
    def setValues(self, value: typing.Any, additionalValues: collections.abc.Iterable[typing.Any]) -> None: ...
    @deprecated("""""")
    def setValue(self, value: typing.Any) -> None: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    constraintResultVisibleChanged: typing.ClassVar[QtCore.pyqtSignal]
    constraintStatusChanged: typing.ClassVar[QtCore.pyqtSignal]
    valuesChanged: typing.ClassVar[QtCore.pyqtSignal]
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setConstraintResultVisible(self, constraintResultVisible: bool) -> None: ...
    def constraintResultVisible(self) -> bool: ...
    def constraintResult(self) -> 'QgsEditorWidgetWrapper.ConstraintResult': ...
    def setHint(self, hintText: str|None) -> None: ...
    def constraintFailureReason(self) -> str: ...
    def isBlockingCommit(self) -> bool: ...
    def isValidConstraint(self) -> bool: ...
    @typing.overload
    def updateConstraint(self, featureContext: _core.QgsFeature, constraintOrigin: _core.QgsFieldConstraints.ConstraintOrigin = ...) -> None: ...
    @typing.overload
    def updateConstraint(self, layer: _core.QgsVectorLayer|None, index: int, feature: _core.QgsFeature, constraintOrigin: _core.QgsFieldConstraints.ConstraintOrigin = ...) -> None: ...
    @typing.overload
    def updateConstraint(self, constraintResult: 'QgsEditorWidgetWrapper.ConstraintResult', constraintFailureReason: str|None) -> None: ...
    def showIndeterminateState(self) -> None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    @staticmethod
    def isInTable(parent: QtWidgets.QWidget|None) -> bool: ...
    @staticmethod
    def fromWidget(widget: QtWidgets.QWidget|None) -> 'QgsEditorWidgetWrapper|None': ...
    def defaultValue(self) -> typing.Any: ...
    def field(self) -> _core.QgsField: ...
    def fieldIdx(self) -> int: ...
    def additionalFieldValues(self) -> list[typing.Any]: ...
    def additionalFields(self) -> list[str]: ...
    def value(self) -> typing.Any: ...


class QgsSearchWidgetWrapper(QgsWidgetWrapper):

    class FilterFlag(enum.IntEnum):
        EqualTo = ... # type: QgsSearchWidgetWrapper.FilterFlag
        NotEqualTo = ... # type: QgsSearchWidgetWrapper.FilterFlag
        GreaterThan = ... # type: QgsSearchWidgetWrapper.FilterFlag
        LessThan = ... # type: QgsSearchWidgetWrapper.FilterFlag
        GreaterThanOrEqualTo = ... # type: QgsSearchWidgetWrapper.FilterFlag
        LessThanOrEqualTo = ... # type: QgsSearchWidgetWrapper.FilterFlag
        Between = ... # type: QgsSearchWidgetWrapper.FilterFlag
        CaseInsensitive = ... # type: QgsSearchWidgetWrapper.FilterFlag
        Contains = ... # type: QgsSearchWidgetWrapper.FilterFlag
        DoesNotContain = ... # type: QgsSearchWidgetWrapper.FilterFlag
        IsNull = ... # type: QgsSearchWidgetWrapper.FilterFlag
        IsNotBetween = ... # type: QgsSearchWidgetWrapper.FilterFlag
        IsNotNull = ... # type: QgsSearchWidgetWrapper.FilterFlag
        StartsWith = ... # type: QgsSearchWidgetWrapper.FilterFlag
        EndsWith = ... # type: QgsSearchWidgetWrapper.FilterFlag

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def clearExpression(self) -> None: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def setExpression(self, expression: str|None) -> None: ...
    valueCleared: typing.ClassVar[QtCore.pyqtSignal]
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    expressionChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def fieldIndex(self) -> int: ...
    def setAggregate(self, aggregate: str|None) -> None: ...
    def aggregate(self) -> str: ...
    def createFieldIdentifier(self) -> str: ...
    def createExpression(self, flags: 'QgsSearchWidgetWrapper.FilterFlag') -> str: ...
    def applyDirectly(self) -> bool: ...
    def expression(self) -> str: ...
    def defaultFlags(self) -> 'QgsSearchWidgetWrapper.FilterFlag': ...
    def supportedFlags(self) -> 'QgsSearchWidgetWrapper.FilterFlag': ...
    @staticmethod
    def toString(flag: 'QgsSearchWidgetWrapper.FilterFlag') -> str: ...
    @staticmethod
    def nonExclusiveFilterFlags() -> list['QgsSearchWidgetWrapper.FilterFlag']: ...
    @staticmethod
    def exclusiveFilterFlags() -> list['QgsSearchWidgetWrapper.FilterFlag']: ...


class QgsActionWidgetWrapper(QgsWidgetWrapper):

    def __init__(self, layer: _core.QgsVectorLayer|None, editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None, messageBar: QgsMessageBar|None = ...) -> None: ...

    def setEnabled(self, enabled: bool) -> None: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def valid(self) -> bool: ...
    def setAction(self, action: _core.QgsAction) -> None: ...


class QgsCheckboxSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setExpression(self, expression: str|None) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def createExpression(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> str: ...
    def defaultFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def supportedFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def valid(self) -> bool: ...
    def expression(self) -> str: ...
    def applyDirectly(self) -> bool: ...
    def value(self) -> typing.Any: ...


class QgsDateTimeEdit(QtWidgets.QDateTimeEdit):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def isNull(self) -> bool: ...
    def emitValueChanged(self, value: typing.Any) -> None: ...
    def displayNull(self, updateCalendar: bool = ...) -> None: ...
    def showEvent(self, event: QtGui.QShowEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def focusInEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def event(self, event: QtCore.QEvent|None) -> bool: ...
    def setNullRepresentation(self, null: str|None) -> None: ...
    def nullRepresentation(self) -> str: ...
    def setEmpty(self) -> None: ...
    def clear(self) -> None: ...
    def date(self) -> QtCore.QDate: ...
    def time(self) -> QtCore.QTime: ...
    def dateTime(self) -> QtCore.QDateTime: ...
    def setDateTime(self, dateTime: QtCore.QDateTime|datetime.datetime) -> None: ...
    def allowNull(self) -> bool: ...
    def setAllowNull(self, allowNull: bool) -> None: ...


class QgsTimeEdit(QgsDateTimeEdit):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def emitValueChanged(self, value: typing.Any) -> None: ...
    timeValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setTime(self, time: QtCore.QTime|datetime.time) -> None: ...


class QgsDateEdit(QgsDateTimeEdit):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def emitValueChanged(self, value: typing.Any) -> None: ...
    dateValueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDate(self, date: QtCore.QDate|datetime.date) -> None: ...


class QgsDateTimeSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setExpression(self, exp: str|None) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def createExpression(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> str: ...
    def defaultFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def supportedFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def valid(self) -> bool: ...
    def expression(self) -> str: ...
    def applyDirectly(self) -> bool: ...
    def value(self) -> typing.Any: ...


class QgsDefaultSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def caseSensitiveCheckBox(self) -> QtWidgets.QCheckBox|None: ...
    def lineEdit(self) -> QgsFilterLineEdit|None: ...
    def valid(self) -> bool: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setExpression(self, exp: str|None) -> None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def createExpression(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> str: ...
    def defaultFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def supportedFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def applyDirectly(self) -> bool: ...
    def expression(self) -> str: ...


class QgsDoubleSpinBox(QtWidgets.QDoubleSpinBox):

    class ClearValueMode(enum.IntEnum):
        MinimumValue = ... # type: QgsDoubleSpinBox.ClearValueMode
        MaximumValue = ... # type: QgsDoubleSpinBox.ClearValueMode
        CustomValue = ... # type: QgsDoubleSpinBox.ClearValueMode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def timerEvent(self, event: QtCore.QTimerEvent|None) -> None: ...
    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def changeEvent(self, event: QtCore.QEvent|None) -> None: ...
    editingTimeout: typing.ClassVar[QtCore.pyqtSignal]
    textEdited: typing.ClassVar[QtCore.pyqtSignal]
    returnPressed: typing.ClassVar[QtCore.pyqtSignal]
    def setEditingTimeoutInterval(self, timeout: int) -> None: ...
    def editingTimeoutInterval(self) -> int: ...
    def stepBy(self, steps: int) -> None: ...
    def paintEvent(self, e: QtGui.QPaintEvent|None) -> None: ...
    def validate(self, input: str|None) -> typing.Tuple[QtGui.QValidator.State, int]: ...
    def valueFromText(self, text: str|None) -> float: ...
    def setSpecialValueText(self, txt: str|None) -> None: ...
    def setLineEditAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def isCleared(self) -> bool: ...
    def clearValue(self) -> float: ...
    def setClearValueMode(self, mode: 'QgsDoubleSpinBox.ClearValueMode', clearValueText: str|None = ...) -> None: ...
    def setClearValue(self, customValue: float, clearValueText: str|None = ...) -> None: ...
    def clear(self) -> None: ...
    def expressionsEnabled(self) -> bool: ...
    def setExpressionsEnabled(self, enabled: bool) -> None: ...
    def showClearButton(self) -> bool: ...
    def setShowClearButton(self, showClearButton: bool) -> None: ...


class QgsHtmlWidgetWrapper(QgsWidgetWrapper):

    def __init__(self, layer: _core.QgsVectorLayer|None, editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None) -> None: ...

    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def needsGeometry(self) -> bool: ...
    def setHtmlCode(self, htmlCode: str|None) -> None: ...
    def reinitWidget(self) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def valid(self) -> bool: ...


class QgsJsonEditWidget(QtWidgets.QWidget):

    class FormatJson(enum.IntEnum):
        Indented = ... # type: QgsJsonEditWidget.FormatJson
        Compact = ... # type: QgsJsonEditWidget.FormatJson
        Disabled = ... # type: QgsJsonEditWidget.FormatJson

    class View(enum.IntEnum):
        Text = ... # type: QgsJsonEditWidget.View
        Tree = ... # type: QgsJsonEditWidget.View

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setControlsVisible(self, visible: bool) -> None: ...
    def setFormatJsonMode(self, formatJson: 'QgsJsonEditWidget.FormatJson') -> None: ...
    def setView(self, view: 'QgsJsonEditWidget.View') -> None: ...
    def jsonText(self) -> str: ...
    def setJsonText(self, jsonText: str|None) -> None: ...
    def jsonEditor(self) -> QgsCodeEditorJson|None: ...


class QgsMultiEditToolButton(QtWidgets.QToolButton):

    class State(enum.IntEnum):
        Default = ... # type: QgsMultiEditToolButton.State
        MixedValues = ... # type: QgsMultiEditToolButton.State
        Changed = ... # type: QgsMultiEditToolButton.State

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    resetFieldValueTriggered: typing.ClassVar[QtCore.pyqtSignal]
    setFieldValueTriggered: typing.ClassVar[QtCore.pyqtSignal]
    def changesCommitted(self) -> None: ...
    def resetChanges(self) -> None: ...
    def setIsChanged(self, changed: bool) -> None: ...
    def setIsMixed(self, mixed: bool) -> None: ...
    def setField(self, field: _core.QgsField) -> None: ...
    def state(self) -> 'QgsMultiEditToolButton.State': ...


class QgsQmlWidgetWrapper(QgsWidgetWrapper):

    def __init__(self, layer: _core.QgsVectorLayer|None, editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None) -> None: ...

    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def setQmlCode(self, qmlCode: str|None) -> None: ...
    def reinitWidget(self) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def valid(self) -> bool: ...


class QgsRelationAggregateSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, layer: _core.QgsVectorLayer|None, wrapper: 'QgsRelationWidgetWrapper|None', parent: QtWidgets.QWidget|None = ...) -> None: ...

    def eventFilter(self, watched: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def setExpression(self, value: str|None) -> None: ...
    def applyDirectly(self) -> bool: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def valid(self) -> bool: ...
    def expression(self) -> str: ...


class QgsRelationReferenceSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setExpression(self, exp: str|None) -> None: ...
    @deprecated("""""")
    def onValueChanged(self, value: typing.Any) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def createExpression(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> str: ...
    def defaultFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def supportedFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def valid(self) -> bool: ...
    def expression(self) -> str: ...
    def applyDirectly(self) -> bool: ...
    def value(self) -> typing.Any: ...


class QgsRelationReferenceWidget(QtWidgets.QWidget):

    class CanvasExtent(enum.IntEnum):
        Fixed = ... # type: QgsRelationReferenceWidget.CanvasExtent
        Pan = ... # type: QgsRelationReferenceWidget.CanvasExtent
        Scale = ... # type: QgsRelationReferenceWidget.CanvasExtent

    def __init__(self, parent: QtWidgets.QWidget|None) -> None: ...

    foreignKeysChanged: typing.ClassVar[QtCore.pyqtSignal]
    foreignKeyChanged: typing.ClassVar[QtCore.pyqtSignal]
    def init(self) -> None: ...
    def showEvent(self, e: QtGui.QShowEvent|None) -> None: ...
    def saveReferencedAttributeForm(self) -> bool: ...
    def deleteForeignKeys(self) -> None: ...
    def mapIdentification(self) -> None: ...
    def openForm(self) -> None: ...
    def setSortOrder(self, sortOrder: QtCore.Qt.SortOrder) -> None: ...
    def sortOrder(self) -> QtCore.Qt.SortOrder: ...
    def setOrderExpression(self, orderExpression: str|None) -> None: ...
    def orderExpression(self) -> str: ...
    def setFetchLimit(self, fetchLimit: int) -> None: ...
    def fetchLimit(self) -> int: ...
    def setReferencedLayerName(self, referencedLayerName: str|None) -> None: ...
    def referencedLayerName(self) -> str: ...
    def setReferencedLayerId(self, referencedLayerId: str|None) -> None: ...
    def referencedLayerId(self) -> str: ...
    def setReferencedLayerProviderKey(self, referencedLayerProviderKey: str|None) -> None: ...
    def referencedLayerProviderKey(self) -> str: ...
    def setReferencedLayerDataSource(self, referencedLayerDataSource: str|None) -> None: ...
    def referencedLayerDataSource(self) -> str: ...
    def setParentFormFeature(self, parentFormFeature: _core.QgsFeature) -> None: ...
    def setFormFeature(self, formFeature: _core.QgsFeature) -> None: ...
    def relation(self) -> _core.QgsRelation: ...
    def setAllowAddFeatures(self, allowAddFeatures: bool) -> None: ...
    def allowAddFeatures(self) -> bool: ...
    def showIndeterminateState(self) -> None: ...
    def referencedFeature(self) -> _core.QgsFeature: ...
    def setFilterExpression(self, filterExpression: str|None) -> None: ...
    def filterExpression(self) -> str: ...
    def setChainFilters(self, chainFilters: bool) -> None: ...
    def chainFilters(self) -> bool: ...
    def setOpenFormButtonVisible(self, openFormButtonVisible: bool) -> None: ...
    def openFormButtonVisible(self) -> bool: ...
    def setFilterFields(self, filterFields: collections.abc.Iterable[str|None]) -> None: ...
    def setAllowMapIdentification(self, allowMapIdentification: bool) -> None: ...
    def allowMapIdentification(self) -> bool: ...
    def setReadOnlySelector(self, readOnly: bool) -> None: ...
    def readOnlySelector(self) -> bool: ...
    def setEmbedForm(self, display: bool) -> None: ...
    def embedForm(self) -> bool: ...
    def setEditorContext(self, context: QgsAttributeEditorContext, canvas: QgsMapCanvas|None, messageBar: QgsMessageBar|None) -> None: ...
    def foreignKeys(self) -> list[typing.Any]: ...
    @deprecated("""""")
    def foreignKey(self) -> typing.Any: ...
    def setForeignKeys(self, values: collections.abc.Iterable[typing.Any]) -> None: ...
    @deprecated("""""")
    def setForeignKey(self, value: typing.Any) -> None: ...
    def setRelationEditable(self, editable: bool) -> None: ...
    def setRelation(self, relation: _core.QgsRelation, allowNullValue: bool) -> None: ...


class QgsRelationReferenceWidgetWrapper(QgsEditorWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, editor: QtWidgets.QWidget|None, canvas: QgsMapCanvas|None, messageBar: QgsMessageBar|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def widgetValueChanged(self, attribute: str|None, newValue: typing.Any, attributeChanged: bool) -> None: ...
    def updateConstraintWidgetStatus(self) -> None: ...
    def parentFormValueChanged(self, attribute: str|None, value: typing.Any) -> None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def additionalFields(self) -> list[str]: ...
    def additionalFieldValues(self) -> list[typing.Any]: ...
    def showIndeterminateState(self) -> None: ...
    def valid(self) -> bool: ...
    def value(self) -> typing.Any: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...


class QgsRelationWidgetWrapper(QgsWidgetWrapper):

    @typing.overload
    def __init__(self, vl: _core.QgsVectorLayer|None, relation: _core.QgsRelation, editor: QtWidgets.QWidget|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, relationEditorName: str|None, vl: _core.QgsVectorLayer|None, relation: _core.QgsRelation, editor: QtWidgets.QWidget|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setVisible(self, visible: bool) -> None: ...
    def setMultiEditFeatureIds(self, fids: typing.Any) -> None: ...
    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    relatedFeaturesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def valid(self) -> bool: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def widgetValueChanged(self, attribute: str|None, newValue: typing.Any, attributeChanged: bool) -> None: ...
    def relation(self) -> _core.QgsRelation: ...
    @deprecated("""""")
    def setLabel(self, label: str|None = ...) -> None: ...
    @deprecated("""""")
    def label(self) -> str: ...
    def setNmRelationId(self, nmRelationId: typing.Any = ...) -> None: ...
    def nmRelationId(self) -> typing.Any: ...
    def setForceSuppressFormPopup(self, forceSuppressFormPopup: bool) -> None: ...
    def forceSuppressFormPopup(self) -> bool: ...
    def widgetConfig(self) -> dict[str, typing.Any]: ...
    def setWidgetConfig(self, config: dict[str|None, typing.Any]) -> None: ...
    @deprecated("""""")
    def visibleButtons(self) -> _core.QgsAttributeEditorRelation.Button: ...
    @deprecated("""""")
    def setVisibleButtons(self, buttons: _core.QgsAttributeEditorRelation.Button) -> None: ...
    @deprecated("""""")
    def showSaveChildEditsButton(self) -> bool: ...
    @deprecated("""""")
    def setShowSaveChildEditsButton(self, showChildEdits: bool) -> None: ...
    @deprecated("""""")
    def setShowUnlinkButton(self, showUnlinkButton: bool) -> None: ...
    @deprecated("""""")
    def showUnlinkButton(self) -> bool: ...
    @deprecated("""""")
    def setShowLinkButton(self, showLinkButton: bool) -> None: ...
    @deprecated("""""")
    def showLinkButton(self) -> bool: ...
    @deprecated("""""")
    def setShowLabel(self, showLabel: bool) -> None: ...
    @deprecated("""""")
    def showLabel(self) -> bool: ...


class QgsSearchWidgetToolButton(QtWidgets.QToolButton):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    activeFlagsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setActive(self) -> None: ...
    def setInactive(self) -> None: ...
    def isActive(self) -> bool: ...
    def activeFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def toggleFlag(self, flag: QgsSearchWidgetWrapper.FilterFlag) -> None: ...
    def setActiveFlags(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> None: ...
    def availableFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def setDefaultFlags(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> None: ...
    def setAvailableFlags(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> None: ...


class QgsSpacerWidgetWrapper(QgsWidgetWrapper):

    def __init__(self, layer: _core.QgsVectorLayer|None, editor: QtWidgets.QWidget|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setDrawLine(self, drawLine: bool) -> None: ...
    def drawLine(self) -> bool: ...
    def valid(self) -> bool: ...


class QgsSpinBox(QtWidgets.QSpinBox):

    class ClearValueMode(enum.IntEnum):
        MinimumValue = ... # type: QgsSpinBox.ClearValueMode
        MaximumValue = ... # type: QgsSpinBox.ClearValueMode
        CustomValue = ... # type: QgsSpinBox.ClearValueMode

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def focusOutEvent(self, event: QtGui.QFocusEvent|None) -> None: ...
    def timerEvent(self, event: QtCore.QTimerEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def changeEvent(self, event: QtCore.QEvent|None) -> None: ...
    editingTimeout: typing.ClassVar[QtCore.pyqtSignal]
    textEdited: typing.ClassVar[QtCore.pyqtSignal]
    returnPressed: typing.ClassVar[QtCore.pyqtSignal]
    def setEditingTimeoutInterval(self, timeout: int) -> None: ...
    def editingTimeoutInterval(self) -> int: ...
    def stepBy(self, steps: int) -> None: ...
    def validate(self, input: str|None) -> typing.Tuple[QtGui.QValidator.State, int]: ...
    def valueFromText(self, text: str|None) -> int: ...
    def setSpecialValueText(self, txt: str|None) -> None: ...
    def setLineEditAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def clearValue(self) -> int: ...
    def setClearValueMode(self, mode: 'QgsSpinBox.ClearValueMode', clearValueText: str|None = ...) -> None: ...
    def setClearValue(self, customValue: int, clearValueText: str|None = ...) -> None: ...
    def clear(self) -> None: ...
    def expressionsEnabled(self) -> bool: ...
    def setExpressionsEnabled(self, enabled: bool) -> None: ...
    def showClearButton(self) -> bool: ...
    def setShowClearButton(self, showClearButton: bool) -> None: ...


class QgsTextWidgetWrapper(QgsWidgetWrapper):

    def __init__(self, layer: _core.QgsVectorLayer|None, editor: QtWidgets.QWidget|None, parent: QtWidgets.QWidget|None) -> None: ...

    def setFeature(self, feature: _core.QgsFeature) -> None: ...
    def needsGeometry(self) -> bool: ...
    def setText(self, text: str|None) -> None: ...
    def reinitWidget(self) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def valid(self) -> bool: ...


class QgsValueMapSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setExpression(self, exp: str|None) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def createExpression(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> str: ...
    def defaultFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def supportedFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def valid(self) -> bool: ...
    def expression(self) -> str: ...
    def applyDirectly(self) -> bool: ...


class QgsValueRelationSearchWidgetWrapper(QgsSearchWidgetWrapper):

    def __init__(self, vl: _core.QgsVectorLayer|None, fieldIdx: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setExpression(self, exp: str|None) -> None: ...
    def onValueChanged(self) -> None: ...
    def initWidget(self, editor: QtWidgets.QWidget|None) -> None: ...
    def createWidget(self, parent: QtWidgets.QWidget|None) -> QtWidgets.QWidget|None: ...
    def setEnabled(self, enabled: bool) -> None: ...
    def clearWidget(self) -> None: ...
    def createExpression(self, flags: QgsSearchWidgetWrapper.FilterFlag) -> str: ...
    def defaultFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def supportedFlags(self) -> QgsSearchWidgetWrapper.FilterFlag: ...
    def value(self) -> typing.Any: ...
    def valid(self) -> bool: ...
    def expression(self) -> str: ...
    def applyDirectly(self) -> bool: ...


class QgsEffectDrawModeComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setDrawMode(self, drawMode: _core.QgsPaintEffect.DrawMode) -> None: ...
    def drawMode(self) -> _core.QgsPaintEffect.DrawMode: ...


class QgsEffectStackPropertiesWidget(QgsPanelWidget):

    def __init__(self, stack: _core.QgsEffectStack|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setWidget(self, widget: QtWidgets.QWidget|None) -> None: ...
    def moveEffectByOffset(self, offset: int) -> None: ...
    def updateUi(self) -> None: ...
    @typing.overload
    def loadStack(self) -> None: ...
    @typing.overload
    def loadStack(self, stack: _core.QgsEffectStack|None) -> None: ...
    def changeEffect(self, newEffect: _core.QgsPaintEffect|None) -> None: ...
    def updatePreview(self) -> None: ...
    def effectChanged(self) -> None: ...
    def removeEffect(self) -> None: ...
    def addEffect(self) -> None: ...
    def moveEffectUp(self) -> None: ...
    def moveEffectDown(self) -> None: ...
    def setPreviewPicture(self, picture: QtGui.QPicture) -> None: ...
    def stack(self) -> _core.QgsEffectStack|None: ...


class QgsEffectStackPropertiesDialog(QgsDialog):

    def __init__(self, stack: _core.QgsEffectStack|None, parent: QtWidgets.QWidget|None = ..., f: QtCore.Qt.WindowType = ...) -> None: ...

    def setPreviewPicture(self, picture: QtGui.QPicture) -> None: ...
    def stack(self) -> _core.QgsEffectStack|None: ...


class QgsEffectStackCompactWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., effect: _core.QgsPaintEffect|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setPreviewPicture(self, picture: QtGui.QPicture) -> None: ...
    def paintEffect(self) -> _core.QgsPaintEffect|None: ...
    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...


class QgsPaintEffectPropertiesWidget(QtWidgets.QWidget):

    def __init__(self, effect: _core.QgsPaintEffect|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changeEffect: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def emitSignalChanged(self) -> None: ...
    def effectTypeChanged(self) -> None: ...


class QgsPaintEffectWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...


class QgsDrawSourceWidget(QgsPaintEffectWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...
    @staticmethod
    def create() -> QgsPaintEffectWidget|None: ...


class QgsBlurWidget(QgsPaintEffectWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...
    @staticmethod
    def create() -> QgsPaintEffectWidget|None: ...


class QgsShadowEffectWidget(QgsPaintEffectWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...
    @staticmethod
    def create() -> QgsPaintEffectWidget|None: ...


class QgsGlowWidget(QgsPaintEffectWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...
    @staticmethod
    def create() -> QgsPaintEffectWidget|None: ...


class QgsTransformWidget(QgsPaintEffectWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...
    @staticmethod
    def create() -> QgsPaintEffectWidget|None: ...


class QgsColorEffectWidget(QgsPaintEffectWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPaintEffect(self, effect: _core.QgsPaintEffect|None) -> None: ...
    @staticmethod
    def create() -> QgsPaintEffectWidget|None: ...


class QgsElevationControllerSettingsAction(QtWidgets.QWidgetAction):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def sizeSpin(self) -> QgsDoubleSpinBox|None: ...


class QgsElevationControllerWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    invertedChanged: typing.ClassVar[QtCore.pyqtSignal]
    fixedRangeSizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    rangeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSignificantElevations(self, elevations: collections.abc.Iterable[float]) -> None: ...
    def setInverted(self, inverted: bool) -> None: ...
    def setFixedRangeSize(self, size: float) -> None: ...
    def setRangeLimits(self, limits: _core.QgsDoubleRange) -> None: ...
    def setRange(self, range: _core.QgsDoubleRange) -> None: ...
    def fixedRangeSize(self) -> float: ...
    def menu(self) -> QtWidgets.QMenu|None: ...
    def slider(self) -> QgsRangeSlider|None: ...
    def rangeLimits(self) -> _core.QgsDoubleRange: ...
    def range(self) -> _core.QgsDoubleRange: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...


class QgsPlotCanvas(QtWidgets.QGraphicsView):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def wheelZoom(self, event: QtGui.QWheelEvent|None) -> None: ...
    def viewportEvent(self, event: QtCore.QEvent|None) -> bool: ...
    def resizeEvent(self, e: QtGui.QResizeEvent|None) -> None: ...
    def wheelEvent(self, e: QtGui.QWheelEvent|None) -> None: ...
    def mouseReleaseEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def mouseDoubleClickEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def keyReleaseEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...
    willBeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    contextMenuAboutToShow: typing.ClassVar[QtCore.pyqtSignal]
    plotAreaChanged: typing.ClassVar[QtCore.pyqtSignal]
    toolChanged: typing.ClassVar[QtCore.pyqtSignal]
    def refresh(self) -> None: ...
    def snapToPlot(self, point: QtCore.QPoint) -> _core.QgsPointXY: ...
    def zoomToRect(self, rect: QtCore.QRectF) -> None: ...
    def scalePlot(self, factor: float) -> None: ...
    def centerPlotOn(self, x: float, y: float) -> None: ...
    def panContentsBy(self, dx: float, dy: float) -> None: ...
    def toCanvasCoordinates(self, point: _core.QgsPoint) -> _core.QgsPointXY: ...
    def toMapCoordinates(self, point: _core.QgsPointXY) -> _core.QgsPoint: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def tool(self) -> 'QgsPlotTool|None': ...
    def unsetTool(self, tool: 'QgsPlotTool|None') -> None: ...
    def setTool(self, tool: 'QgsPlotTool|None') -> None: ...


class QgsElevationProfileCanvas(QgsPlotCanvas):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setSnappingEnabled(self, enabled: bool) -> None: ...
    def clear(self) -> None: ...
    def zoomFull(self) -> None: ...
    scaleChanged: typing.ClassVar[QtCore.pyqtSignal]
    canvasPointHovered: typing.ClassVar[QtCore.pyqtSignal]
    activeJobCountChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSubsectionsSymbol(self, symbol: _core.QgsLineSymbol|None) -> None: ...
    def subsectionsSymbol(self) -> _core.QgsLineSymbol|None: ...
    def setBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setDistanceUnit(self, unit: _core.Qgis.DistanceUnit) -> None: ...
    def distanceUnit(self) -> _core.Qgis.DistanceUnit: ...
    def setAxisScaleRatio(self, scale: float) -> None: ...
    def axisScaleRatio(self) -> float: ...
    def setLockAxisScales(self, lock: bool) -> None: ...
    def lockAxisScales(self) -> bool: ...
    def plotPointToCanvasPoint(self, point: _core.QgsProfilePoint) -> _core.QgsPointXY: ...
    def canvasPointToPlotPoint(self, point: QtCore.QPointF) -> _core.QgsProfilePoint: ...
    @typing.overload
    def identify(self, point: QtCore.QPointF) -> list[_core.QgsProfileIdentifyResults]: ...
    @typing.overload
    def identify(self, rect: QtCore.QRectF) -> list[_core.QgsProfileIdentifyResults]: ...
    def render(self, context: _core.QgsRenderContext, width: float, height: float, plotSettings: _core.Qgs2DXyPlot) -> None: ...
    def visibleElevationRange(self) -> _core.QgsDoubleRange: ...
    def visibleDistanceRange(self) -> _core.QgsDoubleRange: ...
    def setVisiblePlotRange(self, minimumDistance: float, maximumDistance: float, minimumElevation: float, maximumElevation: float) -> None: ...
    def tolerance(self) -> float: ...
    def setTolerance(self, tolerance: float) -> None: ...
    def profileCurve(self) -> _core.QgsCurve|None: ...
    def setProfileCurve(self, curve: _core.QgsCurve|None) -> None: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def sources(self) -> list[_core.QgsAbstractProfileSource]: ...
    def setSources(self, sources: collections.abc.Iterable[_core.QgsAbstractProfileSource]) -> None: ...
    def layers(self) -> list[_core.QgsMapLayer]: ...
    def setLayers(self, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def invalidateCurrentPlotExtent(self) -> None: ...
    def refresh(self) -> None: ...
    def plotArea(self) -> QtCore.QRectF: ...
    def mouseMoveEvent(self, e: QtGui.QMouseEvent|None) -> None: ...
    def wheelZoom(self, event: QtGui.QWheelEvent|None) -> None: ...
    def zoomToRect(self, rect: QtCore.QRectF) -> None: ...
    def snapToPlot(self, point: QtCore.QPoint) -> _core.QgsPointXY: ...
    @typing.overload
    def scalePlot(self, factor: float) -> None: ...
    @typing.overload
    def scalePlot(self, xFactor: float, yFactor: float) -> None: ...
    def centerPlotOn(self, x: float, y: float) -> None: ...
    def panContentsBy(self, dx: float, dy: float) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def toCanvasCoordinates(self, point: _core.QgsPoint) -> _core.QgsPointXY: ...
    def toMapCoordinates(self, point: _core.QgsPointXY) -> _core.QgsPoint: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsHistoryEntry(PyQt6.sip.wrapper):

    entry = ... # type: dict[str|None, typing.Any]
    id = ... # type: int
    providerId = ... # type: str|None
    timestamp = ... # type: QtCore.QDateTime|datetime.datetime

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, providerId: str|None, timestamp: QtCore.QDateTime|datetime.datetime, entry: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, entry: dict[str|None, typing.Any]) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHistoryEntry') -> None: ...

    def __repr__(self) -> typing.Any: ...
    def isValid(self) -> bool: ...


class QgsHistoryEntryModel(QtCore.QAbstractItemModel):

    def __init__(self, providerId: str|None = ..., backends: _core.Qgis.HistoryProviderBackend = ..., registry: 'QgsHistoryProviderRegistry|None' = ..., context: 'QgsHistoryWidgetContext' = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def index2node(self, index: QtCore.QModelIndex) -> 'QgsHistoryEntryNode|None': ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...


class QgsHistoryEntryNode(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def matchesString(self, searchString: str|None) -> bool: ...
    def populateContextMenu(self, menu: QtWidgets.QMenu|None, context: 'QgsHistoryWidgetContext') -> None: ...
    def doubleClicked(self, context: 'QgsHistoryWidgetContext') -> bool: ...
    def createWidget(self, context: 'QgsHistoryWidgetContext') -> QtWidgets.QWidget|None: ...
    def html(self, context: 'QgsHistoryWidgetContext') -> str: ...
    def childCount(self) -> int: ...
    def data(self, role: int = ...) -> typing.Any: ...
    def parent(self) -> 'QgsHistoryEntryGroup|None': ...


class QgsHistoryEntryGroup(QgsHistoryEntryNode):

    def __init__(self) -> None: ...

    def childCount(self) -> int: ...
    def clear(self) -> None: ...
    def removeChildAt(self, index: int) -> None: ...
    def childAt(self, index: int) -> QgsHistoryEntryNode|None: ...
    def indexOf(self, child: QgsHistoryEntryNode|None) -> int: ...
    def insertChild(self, index: int, child: QgsHistoryEntryNode|None) -> None: ...
    def addChild(self, child: QgsHistoryEntryNode|None) -> None: ...


class QgsAbstractHistoryProvider(QtCore.QObject):

    def __init__(self) -> None: ...

    def updateNodeForEntry(self, node: QgsHistoryEntryNode|None, entry: QgsHistoryEntry, context: 'QgsHistoryWidgetContext') -> None: ...
    def createNodeForEntry(self, entry: QgsHistoryEntry, context: 'QgsHistoryWidgetContext') -> QgsHistoryEntryNode|None: ...
    def id(self) -> str: ...


class QgsHistoryProviderRegistry(QtCore.QObject):

    class HistoryEntryOptions(PyQt6.sip.wrapper):

        storageBackends = ... # type: _core.Qgis.HistoryProviderBackend

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsHistoryProviderRegistry.HistoryEntryOptions') -> None: ...

    def __init__(self, parent: QtCore.QObject|None = ..., useMemoryDatabase: bool = ...) -> None: ...

    historyCleared: typing.ClassVar[QtCore.pyqtSignal]
    entryUpdated: typing.ClassVar[QtCore.pyqtSignal]
    entryAdded: typing.ClassVar[QtCore.pyqtSignal]
    def clearHistory(self, backend: _core.Qgis.HistoryProviderBackend, providerId: str|None = ...) -> bool: ...
    @staticmethod
    def userHistoryDbPath() -> str: ...
    def queryEntries(self, start: QtCore.QDateTime|datetime.datetime = ..., end: QtCore.QDateTime|datetime.datetime = ..., providerId: str|None = ..., backends: _core.Qgis.HistoryProviderBackend = ...) -> list[QgsHistoryEntry]: ...
    def updateEntry(self, id: int, entry: dict[str|None, typing.Any], backend: _core.Qgis.HistoryProviderBackend = ...) -> bool: ...
    def entry(self, id: int, backend: _core.Qgis.HistoryProviderBackend = ...) -> typing.Tuple[QgsHistoryEntry, bool]: ...
    def addEntries(self, entries: collections.abc.Iterable[QgsHistoryEntry], options: 'QgsHistoryProviderRegistry.HistoryEntryOptions' = ...) -> bool: ...
    @typing.overload
    def addEntry(self, providerId: str|None, entry: dict[str|None, typing.Any], options: 'QgsHistoryProviderRegistry.HistoryEntryOptions' = ...) -> typing.Tuple[int, bool]: ...
    @typing.overload
    def addEntry(self, entry: QgsHistoryEntry, options: 'QgsHistoryProviderRegistry.HistoryEntryOptions' = ...) -> typing.Tuple[int, bool]: ...
    def providerIds(self) -> list[str]: ...
    def removeProvider(self, id: str|None) -> bool: ...
    def providerById(self, id: str|None) -> QgsAbstractHistoryProvider|None: ...
    def addProvider(self, provider: QgsAbstractHistoryProvider|None) -> bool: ...


class QgsHistoryWidget(QgsPanelWidget):

    def __init__(self, providerId: str|None = ..., backends: _core.Qgis.HistoryProviderBackend = ..., registry: QgsHistoryProviderRegistry|None = ..., context: 'QgsHistoryWidgetContext' = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsHistoryWidgetContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsHistoryWidgetContext') -> None: ...

    def historyWidget(self) -> QgsHistoryWidget|None: ...
    def setHistoryWidget(self, widget: QgsHistoryWidget|None) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...


class QgsAbstractInputController(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def type(self) -> _core.Qgis.InputControllerType: ...
    def deviceId(self) -> str: ...
    def clone(self) -> 'QgsAbstractInputController|None': ...


class QgsAbstract2DMapController(QgsAbstractInputController):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def type(self) -> _core.Qgis.InputControllerType: ...


class QgsAbstract3DMapController(QgsAbstractInputController):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def type(self) -> _core.Qgis.InputControllerType: ...


class QgsInputControllerManager(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def register3DMapController(self, controller: QgsAbstract3DMapController|None) -> bool: ...
    def create3DMapController(self, deviceId: str|None) -> QgsAbstract3DMapController|None: ...
    def available3DMapControllers(self) -> list[str]: ...
    def register2DMapController(self, controller: QgsAbstract2DMapController|None) -> bool: ...
    def create2DMapController(self, deviceId: str|None) -> QgsAbstract2DMapController|None: ...
    def available2DMapControllers(self) -> list[str]: ...


class QgsLabelingEngineRuleWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def rule(self) -> _core.QgsAbstractLabelingEngineRule|None: ...
    def setRule(self, rule: _core.QgsAbstractLabelingEngineRule|None) -> None: ...


class QgsLabelingEngineRulesWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def rules(self) -> list[_core.QgsAbstractLabelingEngineRule]: ...
    def setRules(self, rules: collections.abc.Iterable[_core.QgsAbstractLabelingEngineRule]) -> None: ...


class QgsLabelingEngineRulesDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def rules(self) -> list[_core.QgsAbstractLabelingEngineRule]: ...
    def setRules(self, rules: collections.abc.Iterable[_core.QgsAbstractLabelingEngineRule]) -> None: ...


class QgsLabelSettingsWidgetBase(QgsPanelWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., vl: _core.QgsMapLayer|None = ...) -> None: ...

    def registerDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsPalLayerSettings.Property) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    auxiliaryFieldCreated: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def updateDataDefinedProperties(self, properties: _core.QgsPropertyCollection) -> None: ...
    def setDataDefinedProperties(self, dataDefinedProperties: _core.QgsPropertyCollection) -> None: ...
    def dataDefinedProperties(self) -> _core.QgsPropertyCollection: ...
    def setGeometryType(self, type: _core.Qgis.GeometryType) -> None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...


class QgsLabelLineAnchorWidget(QgsLabelSettingsWidgetBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., vl: _core.QgsVectorLayer|None = ...) -> None: ...

    def updateDataDefinedProperties(self, properties: _core.QgsPropertyCollection) -> None: ...
    def settings(self) -> _core.QgsLabelLineSettings: ...
    def setSettings(self, settings: _core.QgsLabelLineSettings) -> None: ...


class QgsLabelObstacleSettingsWidget(QgsLabelSettingsWidgetBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., vl: _core.QgsVectorLayer|None = ...) -> None: ...

    def updateDataDefinedProperties(self, properties: _core.QgsPropertyCollection) -> None: ...
    def setGeometryType(self, type: _core.Qgis.GeometryType) -> None: ...
    def settings(self) -> _core.QgsLabelObstacleSettings: ...
    def setSettings(self, settings: _core.QgsLabelObstacleSettings) -> None: ...


class QgsLabelSettingsWidgetDialog(QtWidgets.QDialog):

    def __init__(self, widget: QgsLabelSettingsWidgetBase|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...


class QgsLabelRemoveDuplicatesSettingsWidget(QgsLabelSettingsWidgetBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsMapLayer|None = ...) -> None: ...

    def updateDataDefinedProperties(self, properties: _core.QgsPropertyCollection) -> None: ...
    def setGeometryType(self, type: _core.Qgis.GeometryType) -> None: ...
    def settings(self) -> _core.QgsLabelThinningSettings: ...
    def setSettings(self, settings: _core.QgsLabelThinningSettings) -> None: ...


class QgsTabPositionWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    positionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setUnit(self, unit: _core.Qgis.RenderUnit) -> None: ...
    def positions(self) -> list[_core.QgsTextFormat.Tab]: ...
    def setPositions(self, positions: collections.abc.Iterable[_core.QgsTextFormat.Tab]) -> None: ...


class QgsTabPositionDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., f: QtCore.Qt.WindowType = ...) -> None: ...

    def setUnit(self, unit: _core.Qgis.RenderUnit) -> None: ...
    def positions(self) -> list[_core.QgsTextFormat.Tab]: ...
    def setPositions(self, positions: collections.abc.Iterable[_core.QgsTextFormat.Tab]) -> None: ...


class QgsCustomLayerOrderWidget(QtWidgets.QWidget):

    def __init__(self, bridge: 'QgsLayerTreeMapCanvasBridge|None', parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsLayerTreeEmbeddedConfigWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def applyToLayer(self) -> None: ...
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...


class QgsLayerTreeEmbeddedWidgetProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerTreeEmbeddedWidgetProvider') -> None: ...

    def supportsLayer(self, layer: _core.QgsMapLayer|None) -> bool: ...
    def createWidget(self, layer: _core.QgsMapLayer|None, widgetIndex: int) -> QtWidgets.QWidget|None: ...
    def name(self) -> str: ...
    def id(self) -> str: ...


class QgsLayerTreeEmbeddedWidgetRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def removeProvider(self, providerId: str|None) -> bool: ...
    def addProvider(self, provider: QgsLayerTreeEmbeddedWidgetProvider|None) -> bool: ...
    def provider(self, providerId: str|None) -> QgsLayerTreeEmbeddedWidgetProvider|None: ...
    def providers(self) -> list[str]: ...


class QgsLayerTreeMapCanvasBridge(QtCore.QObject):

    def __init__(self, root: _core.QgsLayerTree|None, canvas: QgsMapCanvas|None, parent: QtCore.QObject|None = ...) -> None: ...

    canvasLayersChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCanvasLayers(self) -> None: ...
    def autoSetupOnFirstLayer(self) -> bool: ...
    def setAutoSetupOnFirstLayer(self, enabled: bool) -> None: ...
    def overviewCanvas(self) -> QgsMapOverviewCanvas|None: ...
    @deprecated("""""")
    def setOvervewCanvas(self, overviewCanvas: QgsMapOverviewCanvas|None) -> None: ...
    def setOverviewCanvas(self, overviewCanvas: QgsMapOverviewCanvas|None) -> None: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def rootGroup(self) -> _core.QgsLayerTree|None: ...


class QgsLayerTreeProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, treeModel: _core.QgsLayerTreeModel|None, parent: QtCore.QObject|None) -> None: ...

    def nodeShown(self, node: _core.QgsLayerTreeNode|None) -> bool: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def setHideValidLayers(self, hideValid: bool) -> None: ...
    def hideValidLayers(self) -> bool: ...
    def setShowPrivateLayers(self, showPrivate: bool) -> None: ...
    def showPrivateLayers(self) -> bool: ...
    def setFilterText(self, filterText: str|None = ...) -> None: ...


class QgsLayerTreeViewBase(QtWidgets.QTreeView):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def onModelReset(self) -> None: ...
    def onExpandedChanged(self, node: _core.QgsLayerTreeNode|None, expanded: bool) -> None: ...
    def updateExpandedStateToNode(self, index: QtCore.QModelIndex) -> None: ...
    def layerTreeModelIndexToViewIndex(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def viewIndexToLayerTreeModelIndex(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def updateExpandedStateFromNode(self, node: _core.QgsLayerTreeNode|None) -> None: ...
    def collapseAllNodes(self) -> None: ...
    def expandAllNodes(self) -> None: ...
    def defaultActions(self) -> 'QgsLayerTreeViewDefaultActions|None': ...
    def selectedLayersRecursive(self) -> list[_core.QgsMapLayer]: ...
    def selectedLegendNodes(self) -> list[_core.QgsLayerTreeModelLegendNode]: ...
    def currentLegendNode(self) -> _core.QgsLayerTreeModelLegendNode|None: ...
    def setCurrentLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def setCurrentNode(self, node: _core.QgsLayerTreeNode|None) -> None: ...
    def legendNode2sourceIndex(self, legendNode: _core.QgsLayerTreeModelLegendNode|None) -> QtCore.QModelIndex: ...
    def legendNode2index(self, legendNode: _core.QgsLayerTreeModelLegendNode|None) -> QtCore.QModelIndex: ...
    def selectedLayers(self) -> list[_core.QgsMapLayer]: ...
    def selectedLayerNodes(self) -> list[_core.QgsLayerTreeLayer]: ...
    def currentGroupNode(self) -> _core.QgsLayerTreeGroup|None: ...
    def layerForIndex(self, index: QtCore.QModelIndex) -> _core.QgsMapLayer|None: ...
    def currentLayer(self) -> _core.QgsMapLayer|None: ...
    def selectedNodes(self, skipInternal: bool = ...) -> list[_core.QgsLayerTreeNode]: ...
    def currentNode(self) -> _core.QgsLayerTreeNode|None: ...
    def index2legendNode(self, index: QtCore.QModelIndex) -> _core.QgsLayerTreeModelLegendNode|None: ...
    def node2sourceIndex(self, node: _core.QgsLayerTreeNode|None) -> QtCore.QModelIndex: ...
    def node2index(self, node: _core.QgsLayerTreeNode|None) -> QtCore.QModelIndex: ...
    def index2node(self, index: QtCore.QModelIndex) -> _core.QgsLayerTreeNode|None: ...
    def layerTreeModel(self) -> _core.QgsLayerTreeModel|None: ...
    def setLayerTreeModel(self, model: _core.QgsLayerTreeModel|None) -> None: ...
    def mouseDoubleClickEvent(self, event: QtGui.QMouseEvent|None) -> None: ...


class QgsLayerTreeView(QgsLayerTreeViewBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def onCurrentChanged(self) -> None: ...
    def modelRowsRemoved(self) -> None: ...
    def modelRowsInserted(self, index: QtCore.QModelIndex, start: int, end: int) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragMoveEvent(self, event: QtGui.QDragMoveEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def contextMenuEvent(self, event: QtGui.QContextMenuEvent|None) -> None: ...
    contextMenuAboutToShow: typing.ClassVar[QtCore.pyqtSignal]
    datasetsDropped: typing.ClassVar[QtCore.pyqtSignal]
    currentLayerChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setHideValidLayers(self, hideValid: bool) -> None: ...
    def setShowPrivateLayers(self, showPrivate: bool) -> None: ...
    def setMessageBar(self, messageBar: QgsMessageBar|None) -> None: ...
    def setLayerMarkWidth(self, width: int) -> None: ...
    def refreshLayerSymbology(self, layerId: str|None) -> None: ...
    def hideValidLayers(self) -> bool: ...
    def showPrivateLayers(self) -> bool: ...
    def layerMarkWidth(self) -> int: ...
    def indicators(self, node: _core.QgsLayerTreeNode|None) -> list['QgsLayerTreeViewIndicator']: ...
    def removeIndicator(self, node: _core.QgsLayerTreeNode|None, indicator: 'QgsLayerTreeViewIndicator|None') -> None: ...
    def addIndicator(self, node: _core.QgsLayerTreeNode|None, indicator: 'QgsLayerTreeViewIndicator|None') -> None: ...
    def setLayerVisible(self, layer: _core.QgsMapLayer|None, visible: bool) -> None: ...
    def menuProvider(self) -> 'QgsLayerTreeViewMenuProvider|None': ...
    def setMenuProvider(self, menuProvider: 'QgsLayerTreeViewMenuProvider|None') -> None: ...
    def proxyModel(self) -> QgsLayerTreeProxyModel|None: ...
    @typing.overload
    def setModel(self, model: QtCore.QAbstractItemModel|None) -> None: ...
    @typing.overload
    def setModel(self, model: _core.QgsLayerTreeModel|None, proxyModel: QgsLayerTreeProxyModel|None) -> None: ...


class QgsLayerTreeViewMenuProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayerTreeViewMenuProvider') -> None: ...

    def createContextMenu(self) -> QtWidgets.QMenu|None: ...


class QgsLayerTreeViewDefaultActions(QtCore.QObject):

    def __init__(self, view: QgsLayerTreeViewBase|None) -> None: ...

    def uniqueGroupName(self, parentGroup: _core.QgsLayerTreeGroup|None) -> str: ...
    def mutuallyExclusiveGroup(self) -> None: ...
    def groupSelected(self) -> None: ...
    def moveToBottom(self) -> None: ...
    def moveToTop(self) -> None: ...
    def moveOutOfGroup(self) -> None: ...
    @deprecated("""""")
    def makeTopLevel(self) -> None: ...
    def showFeatureCount(self) -> None: ...
    def renameGroupOrLayer(self) -> None: ...
    def removeGroupPromoteLayers(self) -> None: ...
    def removeGroupOrLayer(self) -> None: ...
    def addGroup(self) -> None: ...
    def showInOverview(self) -> None: ...
    @typing.overload
    def zoomToGroup(self, canvas: QgsMapCanvas|None) -> None: ...
    @typing.overload
    def zoomToGroup(self) -> None: ...
    @typing.overload
    def zoomToSelection(self, canvas: QgsMapCanvas|None) -> None: ...
    @typing.overload
    def zoomToSelection(self) -> None: ...
    @typing.overload
    def zoomToLayers(self, canvas: QgsMapCanvas|None) -> None: ...
    @typing.overload
    def zoomToLayers(self) -> None: ...
    @typing.overload
    def zoomToLayers(self, canvas: QgsMapCanvas|None, layers: collections.abc.Iterable[_core.QgsMapLayer]) -> None: ...
    @typing.overload
    @deprecated("""""")
    def zoomToLayer(self, canvas: QgsMapCanvas|None) -> None: ...
    @typing.overload
    @deprecated("""""")
    def zoomToLayer(self) -> None: ...
    def actionMutuallyExclusiveGroup(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionGroupSelected(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionMoveToBottom(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionMoveToTop(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionMoveOutOfGroup(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionMakeTopLevel(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionZoomToGroup(self, canvas: QgsMapCanvas|None, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionZoomToSelection(self, canvas: QgsMapCanvas|None, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionZoomToLayers(self, canvas: QgsMapCanvas|None, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    @deprecated("""""")
    def actionZoomToLayer(self, canvas: QgsMapCanvas|None, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionCheckAndAllParents(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionUncheckAndAllChildren(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionCheckAndAllChildren(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionShowFeatureCount(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionRenameGroupOrLayer(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionShowInOverview(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionRemoveGroupPromoteLayers(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionRemoveGroupOrLayer(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...
    def actionAddGroup(self, parent: QtCore.QObject|None = ...) -> QtGui.QAction|None: ...


class QgsLayerTreeViewIndicator(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    clicked: typing.ClassVar[QtCore.pyqtSignal]
    def setToolTip(self, tip: str|None) -> None: ...
    def toolTip(self) -> str: ...
    def setIcon(self, icon: QtGui.QIcon) -> None: ...
    def icon(self) -> QtGui.QIcon: ...


class QgsLayoutComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., manager: _core.QgsLayoutManager|None = ...) -> None: ...

    layoutChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCurrentLayout(self, layout: _core.QgsMasterLayoutInterface|None) -> None: ...
    def layout(self, index: int) -> _core.QgsMasterLayoutInterface|None: ...
    def currentLayout(self) -> _core.QgsMasterLayoutInterface|None: ...
    def allowEmptyLayout(self) -> bool: ...
    def setAllowEmptyLayout(self, allowEmpty: bool) -> None: ...
    def setFilters(self, filters: _core.QgsLayoutManagerProxyModel.Filter) -> None: ...
    def filters(self) -> _core.QgsLayoutManagerProxyModel.Filter: ...
    def setLayoutManager(self, manager: _core.QgsLayoutManager|None) -> None: ...


class QgsLayoutCustomDropHandler(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def handlePaste(self, iface: 'QgsLayoutDesignerInterface|None', pastePoint: QtCore.QPointF, data: QtCore.QMimeData|None) -> typing.Tuple[bool, list[_core.QgsLayoutItem]]: ...
    @typing.overload
    @deprecated("""""")
    def handleFileDrop(self, iface: 'QgsLayoutDesignerInterface|None', file: str|None) -> bool: ...
    @typing.overload
    def handleFileDrop(self, iface: 'QgsLayoutDesignerInterface|None', dropPoint: QtCore.QPointF, file: str|None) -> bool: ...


class QgsLayoutDesignerInterface(QtCore.QObject):

    class StandardTool(enum.IntEnum):
        ToolMoveItemContent = ... # type: QgsLayoutDesignerInterface.StandardTool
        ToolMoveItemNodes = ... # type: QgsLayoutDesignerInterface.StandardTool

    class ExportResults(PyQt6.sip.wrapper):

        labelingResults = ... # type: typing.Any
        result = ... # type: _core.QgsLayoutExporter.ExportResult

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsLayoutDesignerInterface.ExportResults') -> None: ...

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    mapPreviewRefreshed: typing.ClassVar[QtCore.pyqtSignal]
    layoutExported: typing.ClassVar[QtCore.pyqtSignal]
    def showRulers(self, visible: bool) -> None: ...
    def close(self) -> None: ...
    def lastExportResults(self) -> 'QgsLayoutDesignerInterface.ExportResults|None': ...
    def activateTool(self, tool: 'QgsLayoutDesignerInterface.StandardTool') -> None: ...
    def removeDockWidget(self, dock: QtWidgets.QDockWidget|None) -> None: ...
    def addDockWidget(self, area: QtCore.Qt.DockWidgetArea, dock: QtWidgets.QDockWidget|None) -> None: ...
    def atlasToolbar(self) -> QtWidgets.QToolBar|None: ...
    def actionsToolbar(self) -> QtWidgets.QToolBar|None: ...
    def navigationToolbar(self) -> QtWidgets.QToolBar|None: ...
    def layoutToolbar(self) -> QtWidgets.QToolBar|None: ...
    def settingsMenu(self) -> QtWidgets.QMenu|None: ...
    def reportMenu(self) -> QtWidgets.QMenu|None: ...
    def atlasMenu(self) -> QtWidgets.QMenu|None: ...
    def itemsMenu(self) -> QtWidgets.QMenu|None: ...
    def viewMenu(self) -> QtWidgets.QMenu|None: ...
    def editMenu(self) -> QtWidgets.QMenu|None: ...
    def layoutMenu(self) -> QtWidgets.QMenu|None: ...
    def showItemOptions(self, item: _core.QgsLayoutItem|None, bringPanelToFront: bool = ...) -> None: ...
    def setAtlasFeature(self, feature: _core.QgsFeature) -> None: ...
    def atlasPreviewEnabled(self) -> bool: ...
    def setAtlasPreviewEnabled(self, enabled: bool) -> None: ...
    def selectItems(self, items: collections.abc.Iterable[_core.QgsLayoutItem]) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def view(self) -> 'QgsLayoutView|None': ...
    def window(self) -> QtWidgets.QWidget|None: ...
    def masterLayout(self) -> _core.QgsMasterLayoutInterface|None: ...
    def layout(self) -> _core.QgsLayout|None: ...


class QgsLayoutItemComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layout: _core.QgsLayout|None = ...) -> None: ...

    itemChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setItem(self, item: _core.QgsLayoutItem|None) -> None: ...
    def currentItem(self) -> _core.QgsLayoutItem|None: ...
    def item(self, index: int) -> _core.QgsLayoutItem|None: ...
    def itemFlags(self) -> _core.QgsLayoutItem.Flag: ...
    def setItemFlags(self, flags: _core.QgsLayoutItem.Flag) -> None: ...
    def allowEmptyItem(self) -> bool: ...
    def setAllowEmptyItem(self, allowEmpty: bool) -> None: ...
    def exceptedItemList(self) -> list[_core.QgsLayoutItem]: ...
    def setExceptedItemList(self, exceptList: collections.abc.Iterable[_core.QgsLayoutItem]) -> None: ...
    def itemType(self) -> _core.QgsLayoutItemRegistry.ItemType: ...
    def setItemType(self, itemType: _core.QgsLayoutItemRegistry.ItemType) -> None: ...
    def currentLayout(self) -> _core.QgsLayout|None: ...
    def setCurrentLayout(self, layout: _core.QgsLayout|None) -> None: ...


class QgsLayoutItemAbstractGuiMetadata(PyQt6.sip.wrapper):

    class Flag(enum.IntEnum):
        FlagNoCreationTools = ... # type: QgsLayoutItemAbstractGuiMetadata.Flag

    @typing.overload
    def __init__(self, type: int, visibleName: str|None, groupId: str|None = ..., isNodeBased: bool = ..., flags: 'QgsLayoutItemAbstractGuiMetadata.Flag' = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutItemAbstractGuiMetadata') -> None: ...

    def handleDoubleClick(self, item: _core.QgsLayoutItem|None, action: _core.Qgis.MouseHandlesAction) -> None: ...
    def newItemAddedToLayout(self, item: _core.QgsLayoutItem|None) -> None: ...
    def createItem(self, layout: _core.QgsLayout|None) -> _core.QgsLayoutItem|None: ...
    def createNodeRubberBand(self, view: 'QgsLayoutView|None') -> QtWidgets.QGraphicsItem|None: ...
    def createRubberBand(self, view: 'QgsLayoutView|None') -> 'QgsLayoutViewRubberBand|None': ...
    def createItemWidget(self, item: _core.QgsLayoutItem|None) -> 'QgsLayoutItemBaseWidget|None': ...
    def creationIcon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def isNodeBased(self) -> bool: ...
    def groupId(self) -> str: ...
    def flags(self) -> 'QgsLayoutItemAbstractGuiMetadata.Flag': ...
    def type(self) -> int: ...


class QgsLayoutItemGuiGroup(PyQt6.sip.wrapper):

    icon = ... # type: QtGui.QIcon
    id = ... # type: str|None
    name = ... # type: str|None

    @typing.overload
    def __init__(self, id: str|None = ..., name: str|None = ..., icon: QtGui.QIcon = ...) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutItemGuiGroup') -> None: ...


class QgsLayoutItemGuiRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    groupRemoved: typing.ClassVar[QtCore.pyqtSignal]
    typeRemoved: typing.ClassVar[QtCore.pyqtSignal]
    typeAdded: typing.ClassVar[QtCore.pyqtSignal]
    def itemMetadataIds(self) -> list[int]: ...
    def createItemWidget(self, item: _core.QgsLayoutItem|None) -> 'QgsLayoutItemBaseWidget|None': ...
    def newItemAddedToLayout(self, metadataId: int, item: _core.QgsLayoutItem|None, properties: dict[str|None, typing.Any] = ...) -> None: ...
    def createItem(self, metadataId: int, layout: _core.QgsLayout|None) -> _core.QgsLayoutItem|None: ...
    def itemGroup(self, id: str|None) -> QgsLayoutItemGuiGroup: ...
    def removeItemGroup(self, id: str|None) -> bool: ...
    def addItemGroup(self, group: QgsLayoutItemGuiGroup) -> bool: ...
    @typing.overload
    def removeLayoutItemGuiMetadata(self, type: int) -> bool: ...
    @typing.overload
    def removeLayoutItemGuiMetadata(self, metadata: QgsLayoutItemAbstractGuiMetadata|None) -> bool: ...
    def addLayoutItemGuiMetadata(self, metadata: QgsLayoutItemAbstractGuiMetadata|None) -> bool: ...
    def metadataIdForItemType(self, type: int) -> int: ...
    def itemMetadata(self, metadataId: int) -> QgsLayoutItemAbstractGuiMetadata|None: ...


class QgsLayoutConfigObject(QtCore.QObject):

    def __init__(self, parent: QtWidgets.QWidget|None, layoutObject: _core.QgsLayoutObject|None) -> None: ...

    def layoutAtlas(self) -> _core.QgsLayoutAtlas|None: ...
    def coverageLayer(self) -> _core.QgsVectorLayer|None: ...
    def updateDataDefinedButton(self, button: QgsPropertyOverrideButton|None) -> None: ...
    def initializeDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsLayoutObject.DataDefinedProperty) -> None: ...


class QgsLayoutItemBaseWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None, layoutObject: _core.QgsLayoutObject|None) -> None: ...

    def layoutAtlas(self) -> _core.QgsLayoutAtlas|None: ...
    def setNewItem(self, item: _core.QgsLayoutItem|None) -> bool: ...
    def coverageLayer(self) -> _core.QgsVectorLayer|None: ...
    def updateDataDefinedButton(self, button: QgsPropertyOverrideButton|None) -> None: ...
    def registerDataDefinedButton(self, button: QgsPropertyOverrideButton|None, property: _core.QgsLayoutObject.DataDefinedProperty) -> None: ...
    def setMasterLayout(self, masterLayout: _core.QgsMasterLayoutInterface|None) -> None: ...
    def setDesignerInterface(self, iface: QgsLayoutDesignerInterface|None) -> None: ...
    def setReportTypeString(self, string: str|None) -> None: ...
    def setItem(self, item: _core.QgsLayoutItem|None) -> bool: ...
    def layoutObject(self) -> _core.QgsLayoutObject|None: ...


class QgsLayoutItemPropertiesWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None, item: _core.QgsLayoutItem|None) -> None: ...

    def populateDataDefinedButtons(self) -> None: ...
    def initializeDataDefinedButtons(self) -> None: ...
    def updateVariables(self) -> None: ...
    def setMasterLayout(self, masterLayout: _core.QgsMasterLayoutInterface|None) -> None: ...
    def setItem(self, item: _core.QgsLayoutItem|None) -> None: ...
    def showFrameGroup(self, showGroup: bool) -> None: ...
    def showBackgroundGroup(self, showGroup: bool) -> None: ...
    def positionMode(self) -> _core.QgsLayoutItem.ReferencePoint: ...


class QgsLayoutItemPropertiesDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def setLayout(self, layout: _core.QgsLayout|None) -> None: ...
    def setReferencePoint(self, point: _core.QgsLayoutItem.ReferencePoint) -> None: ...
    def referencePoint(self) -> _core.QgsLayoutItem.ReferencePoint: ...
    def itemSize(self) -> _core.QgsLayoutSize: ...
    def setItemSize(self, size: _core.QgsLayoutSize) -> None: ...
    def page(self) -> int: ...
    def itemPosition(self) -> _core.QgsLayoutPoint: ...
    def setItemPosition(self, position: _core.QgsLayoutPoint) -> None: ...


class QgsLayoutRuler(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., orientation: QtCore.Qt.Orientation = ...) -> None: ...

    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    cursorPosChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCursorPosition(self, position: QtCore.QPointF) -> None: ...
    def setContextMenu(self, menu: QtWidgets.QMenu|None) -> None: ...
    def rulerSize(self) -> int: ...
    def setLayoutView(self, view: 'QgsLayoutView|None') -> None: ...
    def layoutView(self) -> 'QgsLayoutView|None': ...
    def setSceneTransform(self, transform: QtGui.QTransform) -> None: ...
    def minimumSizeHint(self) -> QtCore.QSize: ...


class QgsLayoutUnitsComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setConverter(self, converter: _core.QgsLayoutMeasurementConverter|None) -> None: ...
    def converter(self) -> _core.QgsLayoutMeasurementConverter|None: ...
    def linkToWidget(self, widget: QtWidgets.QDoubleSpinBox|None) -> None: ...
    def setUnit(self, unit: _core.Qgis.LayoutUnit) -> None: ...
    def unit(self) -> _core.Qgis.LayoutUnit: ...


class QgsLayoutView(QtWidgets.QGraphicsView):

    class PasteMode(enum.IntEnum):
        PasteModeCursor = ... # type: QgsLayoutView.PasteMode
        PasteModeCenter = ... # type: QgsLayoutView.PasteMode
        PasteModeInPlace = ... # type: QgsLayoutView.PasteMode

    class ClipboardOperation(enum.IntEnum):
        ClipboardCut = ... # type: QgsLayoutView.ClipboardOperation
        ClipboardCopy = ... # type: QgsLayoutView.ClipboardOperation

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def dragEnterEvent(self, e: QtGui.QDragEnterEvent|None) -> None: ...
    def scrollContentsBy(self, dx: int, dy: int) -> None: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def mouseDoubleClickEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    willBeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    itemFocused: typing.ClassVar[QtCore.pyqtSignal]
    statusMessage: typing.ClassVar[QtCore.pyqtSignal]
    pageChanged: typing.ClassVar[QtCore.pyqtSignal]
    cursorPosChanged: typing.ClassVar[QtCore.pyqtSignal]
    zoomLevelChanged: typing.ClassVar[QtCore.pyqtSignal]
    toolSet: typing.ClassVar[QtCore.pyqtSignal]
    layoutSet: typing.ClassVar[QtCore.pyqtSignal]
    def pushStatusMessage(self, message: str|None) -> None: ...
    def viewChanged(self) -> None: ...
    def ungroupSelectedItems(self) -> None: ...
    def groupSelectedItems(self) -> None: ...
    def deleteItems(self, items: collections.abc.Iterable[_core.QgsLayoutItem]) -> None: ...
    def deleteSelectedItems(self) -> None: ...
    def unlockAllItems(self) -> None: ...
    def lockSelectedItems(self) -> None: ...
    def moveSelectedItemsToBottom(self) -> None: ...
    def moveSelectedItemsToTop(self) -> None: ...
    def lowerSelectedItems(self) -> None: ...
    def raiseSelectedItems(self) -> None: ...
    def selectNextItemBelow(self) -> None: ...
    def selectNextItemAbove(self) -> None: ...
    def invertSelection(self) -> None: ...
    def deselectAll(self) -> None: ...
    def selectAll(self) -> None: ...
    def emitZoomLevelChanged(self) -> None: ...
    def zoomActual(self) -> None: ...
    def zoomOut(self) -> None: ...
    def zoomIn(self) -> None: ...
    def zoomWidth(self) -> None: ...
    def zoomFull(self) -> None: ...
    def setSectionLabel(self, label: str|None) -> None: ...
    def deltaForKeyEvent(self, event: QtGui.QKeyEvent|None) -> QtCore.QPointF: ...
    def hasItemsInClipboard(self) -> bool: ...
    @typing.overload
    def pasteItems(self, mode: 'QgsLayoutView.PasteMode') -> list[_core.QgsLayoutItem]: ...
    @typing.overload
    def pasteItems(self, layoutPoint: QtCore.QPointF) -> list[_core.QgsLayoutItem]: ...
    def copyItems(self, items: collections.abc.Iterable[_core.QgsLayoutItem], operation: 'QgsLayoutView.ClipboardOperation') -> None: ...
    def copySelectedItems(self, operation: 'QgsLayoutView.ClipboardOperation') -> None: ...
    def resizeSelectedItems(self, resize: _core.QgsLayoutAligner.Resize) -> None: ...
    def distributeSelectedItems(self, distribution: _core.QgsLayoutAligner.Distribution) -> None: ...
    def alignSelectedItems(self, alignment: _core.QgsLayoutAligner.Alignment) -> None: ...
    def visiblePageNumbers(self) -> list[int]: ...
    def visiblePages(self) -> list[_core.QgsLayoutItemPage]: ...
    def currentPage(self) -> int: ...
    def menuProvider(self) -> 'QgsLayoutViewMenuProvider|None': ...
    def setMenuProvider(self, provider: 'QgsLayoutViewMenuProvider|None') -> None: ...
    def setVerticalRuler(self, ruler: QgsLayoutRuler|None) -> None: ...
    def setHorizontalRuler(self, ruler: QgsLayoutRuler|None) -> None: ...
    def setZoomLevel(self, level: float) -> None: ...
    def scaleSafe(self, scale: float) -> None: ...
    def previewMode(self) -> QgsPreviewEffect.PreviewMode: ...
    def setPreviewMode(self, mode: QgsPreviewEffect.PreviewMode) -> None: ...
    def previewModeEnabled(self) -> bool: ...
    def setPreviewModeEnabled(self, enabled: bool) -> None: ...
    def unsetTool(self, tool: 'QgsLayoutViewTool|None') -> None: ...
    def setTool(self, tool: 'QgsLayoutViewTool|None') -> None: ...
    def tool(self) -> 'QgsLayoutViewTool|None': ...
    def setCurrentLayout(self, layout: _core.QgsLayout|None) -> None: ...
    def currentLayout(self) -> _core.QgsLayout|None: ...


class QgsLayoutViewMenuProvider(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsLayoutViewMenuProvider') -> None: ...

    def createContextMenu(self, parent: QtWidgets.QWidget|None, layout: _core.QgsLayout|None, layoutPoint: QtCore.QPointF) -> QtWidgets.QMenu|None: ...


class QgsLayoutViewMouseEvent(QtGui.QMouseEvent):

    def __init__(self, view: QgsLayoutView|None, event: QtGui.QMouseEvent|None, snap: bool = ...) -> None: ...

    def isSnapped(self) -> bool: ...
    def snappedPoint(self) -> QtCore.QPointF: ...
    def layoutPoint(self) -> QtCore.QPointF: ...
    def snapPoint(self, horizontalSnapLine: QtWidgets.QGraphicsLineItem|None = ..., verticalSnapLine: QtWidgets.QGraphicsLineItem|None = ..., ignoreItems: collections.abc.Iterable[_core.QgsLayoutItem] = ...) -> None: ...


class QgsLayoutViewRubberBand(QtCore.QObject):

    def __init__(self, view: QgsLayoutView|None = ...) -> None: ...

    def updateRect(self, start: QtCore.QPointF, position: QtCore.QPointF, constrainSquare: bool, fromCenter: bool) -> QtCore.QRectF: ...
    sizeChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setPen(self, pen: QtGui.QPen|QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def pen(self) -> QtGui.QPen: ...
    def setBrush(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    def brush(self) -> QtGui.QBrush: ...
    def layout(self) -> _core.QgsLayout|None: ...
    def view(self) -> QgsLayoutView|None: ...
    def finish(self, position: QtCore.QPointF = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> QtCore.QRectF: ...
    def update(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def start(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def create(self, view: QgsLayoutView|None) -> 'QgsLayoutViewRubberBand|None': ...


class QgsLayoutViewRectangularRubberBand(QgsLayoutViewRubberBand):

    def __init__(self, view: QgsLayoutView|None = ...) -> None: ...

    def finish(self, position: QtCore.QPointF = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> QtCore.QRectF: ...
    def update(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def start(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def create(self, view: QgsLayoutView|None) -> 'QgsLayoutViewRectangularRubberBand|None': ...


class QgsLayoutViewEllipticalRubberBand(QgsLayoutViewRubberBand):

    def __init__(self, view: QgsLayoutView|None = ...) -> None: ...

    def finish(self, position: QtCore.QPointF = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> QtCore.QRectF: ...
    def update(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def start(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def create(self, view: QgsLayoutView|None) -> 'QgsLayoutViewEllipticalRubberBand|None': ...


class QgsLayoutViewTriangleRubberBand(QgsLayoutViewRubberBand):

    def __init__(self, view: QgsLayoutView|None = ...) -> None: ...

    def finish(self, position: QtCore.QPointF = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> QtCore.QRectF: ...
    def update(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def start(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def create(self, view: QgsLayoutView|None) -> 'QgsLayoutViewTriangleRubberBand|None': ...


class QgsLayoutViewTool(QtCore.QObject):

    class Flag(enum.IntEnum):
        FlagSnaps = ... # type: QgsLayoutViewTool.Flag

    def __init__(self, view: QgsLayoutView|None, name: str|None) -> None: ...

    def isClickAndDrag(self, startViewPoint: QtCore.QPoint, endViewPoint: QtCore.QPoint) -> bool: ...
    def setFlags(self, flags: 'QgsLayoutViewTool.Flag') -> None: ...
    itemFocused: typing.ClassVar[QtCore.pyqtSignal]
    deactivated: typing.ClassVar[QtCore.pyqtSignal]
    activated: typing.ClassVar[QtCore.pyqtSignal]
    def ignoredSnapItems(self) -> list[_core.QgsLayoutItem]: ...
    def layout(self) -> _core.QgsLayout|None: ...
    def view(self) -> QgsLayoutView|None: ...
    def toolName(self) -> str: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def setCursor(self, cursor: QtGui.QCursor|QtCore.Qt.CursorShape) -> None: ...
    def action(self) -> QtGui.QAction|None: ...
    def setAction(self, action: QtGui.QAction|None) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutDoubleClickEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def flags(self) -> 'QgsLayoutViewTool.Flag': ...


class QgsLayoutViewToolAddItem(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    createdItem: typing.ClassVar[QtCore.pyqtSignal]
    def setCustomProperties(self, properties: dict[str|None, typing.Any]) -> None: ...
    def customProperties(self) -> dict[str, typing.Any]: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def setItemMetadataId(self, metadataId: int) -> None: ...
    def itemMetadataId(self) -> int: ...


class QgsLayoutViewToolAddNodeItem(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    createdItem: typing.ClassVar[QtCore.pyqtSignal]
    def deactivate(self) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def setItemMetadataId(self, metadataId: int) -> None: ...
    def itemMetadataId(self) -> int: ...


class QgsLayoutViewToolEditNodes(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def ignoredSnapItems(self) -> list[_core.QgsLayoutItem]: ...
    def deactivate(self) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def layoutDoubleClickEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def activate(self) -> None: ...
    def deleteSelectedNode(self) -> None: ...


class QgsLayoutViewToolMoveItemContent(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLayoutViewToolPan(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def deactivate(self) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLayoutViewToolSelect(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def searchToleranceInLayoutUnits(self) -> float: ...
    def setLayout(self, layout: _core.QgsLayout|None) -> None: ...
    def deactivate(self) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLayoutViewToolTemporaryKeyPan(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def activate(self) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLayoutViewToolZoom(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def deactivate(self) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutPressEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLayoutViewToolTemporaryKeyZoom(QgsLayoutViewToolZoom):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def activate(self) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLayoutViewToolTemporaryMousePan(QgsLayoutViewTool):

    def __init__(self, view: QgsLayoutView|None) -> None: ...

    def activate(self) -> None: ...
    def layoutReleaseEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...
    def layoutMoveEvent(self, event: QgsLayoutViewMouseEvent|None) -> None: ...


class QgsLocatorWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def eventFilter(self, obj: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    configTriggered: typing.ClassVar[QtCore.pyqtSignal]
    def invalidateResults(self) -> None: ...
    def search(self, string: str|None) -> None: ...
    def setResultContainerAnchors(self, anchorPoint: QgsFloatingWidget.AnchorPoint, anchorWidgetPoint: QgsFloatingWidget.AnchorPoint) -> None: ...
    def setPlaceholderText(self, text: str|None) -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def locator(self) -> _core.QgsLocator|None: ...


class QgsMapTool(QtCore.QObject):

    class Flag(enum.IntEnum):
        Transient = ... # type: QgsMapTool.Flag
        EditTool = ... # type: QgsMapTool.Flag
        AllowZoomRect = ... # type: QgsMapTool.Flag
        ShowContextMenu = ... # type: QgsMapTool.Flag

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    def setToolName(self, name: str|None) -> None: ...
    def layer(self, id: str|None) -> _core.QgsMapLayer|None: ...
    def toCanvasCoordinates(self, point: _core.QgsPointXY) -> QtCore.QPoint: ...
    def toMapCoordinatesV2(self, layer: _core.QgsMapLayer|None, point: _core.QgsPoint) -> _core.QgsPoint: ...
    @typing.overload
    def toLayerCoordinates(self, layer: _core.QgsMapLayer|None, point: QtCore.QPoint) -> _core.QgsPointXY: ...
    @typing.overload
    def toLayerCoordinates(self, layer: _core.QgsMapLayer|None, point: _core.QgsPointXY) -> _core.QgsPointXY: ...
    @typing.overload
    def toLayerCoordinates(self, layer: _core.QgsMapLayer|None, rect: _core.QgsRectangle) -> _core.QgsRectangle: ...
    def toLayerCoordinatesV2(self, layer: _core.QgsMapLayer|None, point: _core.QgsPoint) -> _core.QgsPoint: ...
    reactivated: typing.ClassVar[QtCore.pyqtSignal]
    deactivated: typing.ClassVar[QtCore.pyqtSignal]
    activated: typing.ClassVar[QtCore.pyqtSignal]
    messageDiscarded: typing.ClassVar[QtCore.pyqtSignal]
    messageEmitted: typing.ClassVar[QtCore.pyqtSignal]
    @typing.overload
    def toMapCoordinates(self, point: QtCore.QPoint) -> _core.QgsPointXY: ...
    @typing.overload
    def toMapCoordinates(self, layer: _core.QgsMapLayer|None, point: _core.QgsPointXY) -> _core.QgsPointXY: ...
    def populateContextMenuWithEvent(self, menu: QtWidgets.QMenu|None, event: QgsMapMouseEvent|None) -> bool: ...
    def populateContextMenu(self, menu: QtWidgets.QMenu|None) -> None: ...
    @typing.overload
    @staticmethod
    def searchRadiusMU(context: _core.QgsRenderContext) -> float: ...
    @typing.overload
    @staticmethod
    def searchRadiusMU(canvas: QgsMapCanvas|None) -> float: ...
    @staticmethod
    def searchRadiusMM() -> float: ...
    def toolName(self) -> str: ...
    def canvas(self) -> QgsMapCanvas|None: ...
    def clean(self) -> None: ...
    def reactivate(self) -> None: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def setCursor(self, cursor: QtGui.QCursor|QtCore.Qt.CursorShape) -> None: ...
    def button(self) -> QtWidgets.QAbstractButton|None: ...
    def setButton(self, button: QtWidgets.QAbstractButton|None) -> None: ...
    def isActive(self) -> bool: ...
    def action(self) -> QtGui.QAction|None: ...
    def setAction(self, action: QtGui.QAction|None) -> None: ...
    def shortcutEvent(self, e: QtGui.QKeyEvent|None) -> bool: ...
    def canvasToolTipEvent(self, e: QtGui.QHelpEvent|None) -> bool: ...
    def gestureEvent(self, e: QtWidgets.QGestureEvent|None) -> bool: ...
    def keyReleaseEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def wheelEvent(self, e: QtGui.QWheelEvent|None) -> None: ...
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasDoubleClickEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def flags(self) -> 'QgsMapTool.Flag': ...


class QgsMapToolEdit(QgsMapTool):

    class TopologicalResult(enum.IntEnum):
        Success = ... # type: QgsMapToolEdit.TopologicalResult
        InvalidCanvas = ... # type: QgsMapToolEdit.TopologicalResult
        InvalidLayer = ... # type: QgsMapToolEdit.TopologicalResult

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    def notifyNotEditableLayer(self) -> None: ...
    def notifyNotVectorLayer(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def addTopologicalPoints(self, vertices: collections.abc.Iterable[_core.QgsPointXY]) -> 'QgsMapToolEdit.TopologicalResult': ...
    @typing.overload
    def addTopologicalPoints(self, vertices: collections.abc.Iterable[_core.QgsPoint]) -> 'QgsMapToolEdit.TopologicalResult': ...
    def currentVectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def createRubberBand(self, geometryType: _core.Qgis.GeometryType = ..., alternativeBand: bool = ...) -> QgsRubberBand|None: ...
    @staticmethod
    def digitizingFillColor() -> QtGui.QColor: ...
    @staticmethod
    def digitizingStrokeWidth() -> int: ...
    @staticmethod
    def digitizingStrokeColor() -> QtGui.QColor: ...
    def createGeometryRubberBand(self, geometryType: _core.Qgis.GeometryType = ..., alternativeBand: bool = ...) -> QgsGeometryRubberBand|None: ...
    @staticmethod
    def defaultMValue() -> float: ...
    @staticmethod
    def defaultZValue() -> float: ...
    def flags(self) -> QgsMapTool.Flag: ...


class QgsMapToolAdvancedDigitizing(QgsMapToolEdit):

    def __init__(self, canvas: QgsMapCanvas|None, cadDockWidget: QgsAdvancedDigitizingDockWidget|None) -> None: ...

    transientGeometryChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setSnapToLayerGridEnabled(self, snapToLayerGridEnabled: bool) -> None: ...
    def snapToLayerGridEnabled(self) -> bool: ...
    def cadCanvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def cadCanvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def cadCanvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def setUseSnappingIndicator(self, enabled: bool) -> None: ...
    def setAutoSnapEnabled(self, enabled: bool) -> None: ...
    def setAdvancedDigitizingAllowed(self, allowed: bool) -> None: ...
    def useSnappingIndicator(self) -> bool: ...
    def isAutoSnapEnabled(self) -> bool: ...
    def isAdvancedDigitizingAllowed(self) -> bool: ...
    def layer(self) -> _core.QgsMapLayer|None: ...
    def cadDockWidget(self) -> QgsAdvancedDigitizingDockWidget|None: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...


class QgsMapToolCapture(QgsMapToolAdvancedDigitizing):

    class Capability(enum.IntEnum):
        NoCapabilities = ... # type: QgsMapToolCapture.Capability
        SupportsCurves = ... # type: QgsMapToolCapture.Capability
        ValidateGeometries = ... # type: QgsMapToolCapture.Capability

    class CaptureMode(enum.IntEnum):
        CaptureNone = ... # type: QgsMapToolCapture.CaptureMode
        CapturePoint = ... # type: QgsMapToolCapture.CaptureMode
        CaptureLine = ... # type: QgsMapToolCapture.CaptureMode
        CapturePolygon = ... # type: QgsMapToolCapture.CaptureMode

    def __init__(self, canvas: QgsMapCanvas|None, cadDockWidget: QgsAdvancedDigitizingDockWidget|None, mode: 'QgsMapToolCapture.CaptureMode') -> None: ...

    def stopCapturing(self) -> None: ...
    def polygonCaptured(self, polygon: _core.QgsCurvePolygon|None) -> None: ...
    def lineCaptured(self, line: _core.QgsCurve|None) -> None: ...
    def pointCaptured(self, point: _core.QgsPoint) -> None: ...
    def geometryCaptured(self, geometry: _core.QgsGeometry) -> None: ...
    def closePolygon(self) -> None: ...
    @typing.overload
    @deprecated("""""")
    def setPoints(self, pointList: collections.abc.Iterable[_core.QgsPointXY]) -> None: ...
    @typing.overload
    def setPoints(self, pointList: collections.abc.Iterable[_core.QgsPoint]) -> None: ...
    def pointsZM(self) -> list[_core.QgsPoint]: ...
    @deprecated("""""")
    def points(self) -> list[_core.QgsPointXY]: ...
    def size(self) -> int: ...
    def isCapturing(self) -> bool: ...
    def startCapturing(self) -> None: ...
    def undo(self, isAutoRepeat: bool = ...) -> None: ...
    @typing.overload
    def addVertex(self, point: _core.QgsPointXY) -> int: ...
    @typing.overload
    def addVertex(self, mapPoint: _core.QgsPointXY, match: _core.QgsPointLocator.Match) -> int: ...
    def fetchLayerPoint(self, match: _core.QgsPointLocator.Match, layerPoint: _core.QgsPoint) -> int: ...
    @typing.overload
    def nextPoint(self, mapPoint: _core.QgsPoint, layerPoint: _core.QgsPoint) -> int: ...
    @typing.overload
    def nextPoint(self, p: QtCore.QPoint, layerPoint: _core.QgsPoint, mapPoint: _core.QgsPoint) -> int: ...
    @deprecated("""""")
    def setStreamDigitizingEnabled(self, enable: bool) -> None: ...
    @deprecated("""""")
    def setCircularDigitizingEnabled(self, enable: bool) -> None: ...
    @typing.overload
    def mapPoint(self, e: QgsMapMouseEvent) -> _core.QgsPoint: ...
    @typing.overload
    def mapPoint(self, point: _core.QgsPointXY) -> _core.QgsPoint: ...
    def takeRubberBand(self) -> QgsRubberBand|None: ...
    def clean(self) -> None: ...
    def deleteTempRubberBand(self) -> None: ...
    def wheelEvent(self, e: QtGui.QWheelEvent|None) -> None: ...
    def keyReleaseEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def cadCanvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def cadCanvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def cadCanvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def snappingMatches(self) -> list[_core.QgsPointLocator.Match]: ...
    def captureCurve(self) -> _core.QgsCompoundCurve|None: ...
    def clearCurve(self) -> None: ...
    def addCurve(self, c: _core.QgsCurve|None) -> int: ...
    def mode(self) -> 'QgsMapToolCapture.CaptureMode': ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def currentCaptureTechnique(self) -> _core.Qgis.CaptureTechnique: ...
    def setCurrentCaptureTechnique(self, technique: _core.Qgis.CaptureTechnique) -> None: ...
    def supportsTechnique(self, technique: _core.Qgis.CaptureTechnique) -> bool: ...
    def capabilities(self) -> 'QgsMapToolCapture.Capability': ...


class QgsMapToolCaptureLayerGeometry(QgsMapToolCapture):

    def __init__(self, canvas: QgsMapCanvas|None, cadDockWidget: QgsAdvancedDigitizingDockWidget|None, mode: QgsMapToolCapture.CaptureMode) -> None: ...

    def geometryCaptured(self, geometry: _core.QgsGeometry) -> None: ...
    def layerPolygonCaptured(self, polygon: _core.QgsCurvePolygon|None) -> None: ...
    def layerLineCaptured(self, line: _core.QgsCurve|None) -> None: ...
    def layerPointCaptured(self, point: _core.QgsPoint) -> None: ...
    def layerGeometryCaptured(self, geometry: _core.QgsGeometry) -> None: ...


class QgsMapToolDigitizeFeature(QgsMapToolCaptureLayerGeometry):

    def __init__(self, canvas: QgsMapCanvas|None, cadDockWidget: QgsAdvancedDigitizingDockWidget|None, mode: QgsMapToolCapture.CaptureMode = ...) -> None: ...

    def featureDigitized(self, feature: _core.QgsFeature) -> None: ...
    def layerGeometryCaptured(self, geometry: _core.QgsGeometry) -> None: ...
    def setCheckGeometryType(self, checkGeometryType: bool) -> None: ...
    def checkGeometryType(self) -> bool: ...
    digitizingCanceled: typing.ClassVar[QtCore.pyqtSignal]
    digitizingFinished: typing.ClassVar[QtCore.pyqtSignal]
    digitizingCompleted: typing.ClassVar[QtCore.pyqtSignal]
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def reactivate(self) -> None: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def setLayer(self, vl: _core.QgsMapLayer|None) -> None: ...
    def cadCanvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def supportsTechnique(self, technique: _core.Qgis.CaptureTechnique) -> bool: ...
    def capabilities(self) -> QgsMapToolCapture.Capability: ...


class QgsMapToolEmitPoint(QgsMapTool):

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    canvasClicked: typing.ClassVar[QtCore.pyqtSignal]
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def flags(self) -> QgsMapTool.Flag: ...


class QgsMapToolExtent(QgsMapTool):

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    extentChanged: typing.ClassVar[QtCore.pyqtSignal]
    def clearRubberBand(self) -> None: ...
    def extent(self) -> _core.QgsRectangle: ...
    def ratio(self) -> QtCore.QSize: ...
    def setRatio(self, ratio: QtCore.QSize) -> None: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def flags(self) -> QgsMapTool.Flag: ...


class QgsMapToolIdentify(QgsMapTool):

    class Type(enum.IntEnum):
        VectorLayer = ... # type: QgsMapToolIdentify.Type
        RasterLayer = ... # type: QgsMapToolIdentify.Type
        MeshLayer = ... # type: QgsMapToolIdentify.Type
        VectorTileLayer = ... # type: QgsMapToolIdentify.Type
        PointCloudLayer = ... # type: QgsMapToolIdentify.Type
        AllLayers = ... # type: QgsMapToolIdentify.Type

    class IdentifyMode(enum.IntEnum):
        DefaultQgsSetting = ... # type: QgsMapToolIdentify.IdentifyMode
        ActiveLayer = ... # type: QgsMapToolIdentify.IdentifyMode
        TopDownStopAtFirst = ... # type: QgsMapToolIdentify.IdentifyMode
        TopDownAll = ... # type: QgsMapToolIdentify.IdentifyMode
        LayerSelection = ... # type: QgsMapToolIdentify.IdentifyMode

    class IdentifyResult(PyQt6.sip.wrapper):

        mAttributes = ... # type: dict[str|None, str|None]
        mDerivedAttributes = ... # type: dict[str|None, str|None]
        mFeature = ... # type: _core.QgsFeature
        mFields = ... # type: _core.QgsFields
        mLabel = ... # type: str|None
        mLayer = ... # type: _core.QgsMapLayer
        mParams = ... # type: dict[str|None, typing.Any]

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, layer: _core.QgsMapLayer|None, feature: _core.QgsFeature, derivedAttributes: dict[str|None, str|None]) -> None: ...
        @typing.overload
        def __init__(self, layer: _core.QgsMapLayer|None, label: str|None, attributes: dict[str|None, str|None], derivedAttributes: dict[str|None, str|None]) -> None: ...
        @typing.overload
        def __init__(self, layer: _core.QgsMapLayer|None, label: str|None, fields: _core.QgsFields, feature: _core.QgsFeature, derivedAttributes: dict[str|None, str|None]) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMapToolIdentify.IdentifyResult') -> None: ...

    class IdentifyProperties(PyQt6.sip.wrapper):

        searchRadiusMapUnits = ... # type: float
        skip3DLayers = ... # type: bool

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsMapToolIdentify.IdentifyProperties') -> None: ...

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    def restorePropertiesOverrides(self) -> None: ...
    def setPropertiesOverrides(self, overrides: 'QgsMapToolIdentify.IdentifyProperties') -> None: ...
    @deprecated("""""")
    def restoreCanvasPropertiesOverrides(self) -> None: ...
    @deprecated("""""")
    def setCanvasPropertiesOverrides(self, searchRadiusMapUnits: float) -> None: ...
    def derivedAttributesForPoint(self, point: _core.QgsPoint) -> dict[str, str]: ...
    def identifyMeshLayer(self, results: collections.abc.Iterable['QgsMapToolIdentify.IdentifyResult'], layer: _core.QgsMeshLayer|None, point: _core.QgsPointXY, identifyContext: _core.QgsIdentifyContext = ...) -> bool: ...
    def identifyVectorLayer(self, results: collections.abc.Iterable['QgsMapToolIdentify.IdentifyResult'], layer: _core.QgsVectorLayer|None, point: _core.QgsPointXY, identifyContext: _core.QgsIdentifyContext = ...) -> bool: ...
    def identifyRasterLayer(self, results: collections.abc.Iterable['QgsMapToolIdentify.IdentifyResult'], layer: _core.QgsRasterLayer|None, point: _core.QgsPointXY, viewExtent: _core.QgsRectangle, mapUnitsPerPixel: float, identifyContext: _core.QgsIdentifyContext = ...) -> bool: ...
    def identifyLayer(self, results: collections.abc.Iterable['QgsMapToolIdentify.IdentifyResult'], layer: _core.QgsMapLayer|None, point: _core.QgsPointXY, viewExtent: _core.QgsRectangle, mapUnitsPerPixel: float, layerType: 'QgsMapToolIdentify.Type' = ..., identifyContext: _core.QgsIdentifyContext = ...) -> bool: ...
    changedRasterResults: typing.ClassVar[QtCore.pyqtSignal]
    identifyMessage: typing.ClassVar[QtCore.pyqtSignal]
    identifyProgress: typing.ClassVar[QtCore.pyqtSignal]
    def formatChanged(self, layer: _core.QgsRasterLayer|None) -> None: ...
    def identifyMenu(self) -> QgsIdentifyMenu|None: ...
    @typing.overload
    def identify(self, x: int, y: int, layerList: collections.abc.Iterable[_core.QgsMapLayer] = ..., mode: 'QgsMapToolIdentify.IdentifyMode' = ..., identifyContext: _core.QgsIdentifyContext = ...) -> list['QgsMapToolIdentify.IdentifyResult']: ...
    @typing.overload
    def identify(self, x: int, y: int, mode: 'QgsMapToolIdentify.IdentifyMode', layerType: 'QgsMapToolIdentify.Type' = ..., identifyContext: _core.QgsIdentifyContext = ...) -> list['QgsMapToolIdentify.IdentifyResult']: ...
    @typing.overload
    def identify(self, geometry: _core.QgsGeometry, mode: 'QgsMapToolIdentify.IdentifyMode', layerType: 'QgsMapToolIdentify.Type', identifyContext: _core.QgsIdentifyContext = ...) -> list['QgsMapToolIdentify.IdentifyResult']: ...
    @typing.overload
    def identify(self, geometry: _core.QgsGeometry, mode: 'QgsMapToolIdentify.IdentifyMode', layerList: collections.abc.Iterable[_core.QgsMapLayer], layerType: 'QgsMapToolIdentify.Type', identifyContext: _core.QgsIdentifyContext = ...) -> list['QgsMapToolIdentify.IdentifyResult']: ...
    @typing.overload
    def identify(self, x: int, y: int, mode: 'QgsMapToolIdentify.IdentifyMode', layerList: collections.abc.Iterable[_core.QgsMapLayer], layerType: 'QgsMapToolIdentify.Type' = ..., identifyContext: _core.QgsIdentifyContext = ...) -> list['QgsMapToolIdentify.IdentifyResult']: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def flags(self) -> QgsMapTool.Flag: ...


class QgsMapToolIdentifyFeature(QgsMapToolIdentify):

    def __init__(self, canvas: QgsMapCanvas|None, vl: _core.QgsVectorLayer|None = ...) -> None: ...

    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    featureIdentified: typing.ClassVar[QtCore.pyqtSignal]
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def setLayer(self, vl: _core.QgsVectorLayer|None) -> None: ...


class QgsMapToolPan(QgsMapTool):

    def __init__(self, canvas: QgsMapCanvas|None) -> None: ...

    panDistanceBearingChanged: typing.ClassVar[QtCore.pyqtSignal]
    def isPinching(self) -> bool: ...
    def isDragging(self) -> bool: ...
    def gestureEvent(self, e: QtWidgets.QGestureEvent|None) -> bool: ...
    def canvasDoubleClickEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def flags(self) -> QgsMapTool.Flag: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...


class QgsMapToolZoom(QgsMapTool):

    def __init__(self, canvas: QgsMapCanvas|None, zoomOut: bool) -> None: ...

    def deactivate(self) -> None: ...
    def keyReleaseEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def canvasReleaseEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasPressEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def canvasMoveEvent(self, e: QgsMapMouseEvent|None) -> None: ...
    def flags(self) -> QgsMapTool.Flag: ...


class QgsMeshLayerProperties(QgsLayerPropertiesDialog):

    def __init__(self, lyr: _core.QgsMapLayer|None, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ..., a3: QtCore.Qt.WindowType = ...) -> None: ...

    def rollback(self) -> None: ...
    def apply(self) -> None: ...
    def syncToLayer(self) -> None: ...
    @deprecated("""""")
    def saveStyleAs(self) -> None: ...
    @deprecated("""""")
    def loadStyle(self) -> None: ...
    @deprecated("""""")
    def saveDefaultStyle(self) -> None: ...


class QgsNumericFormatSelectorWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsNumericFormatSelectorDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsNumericFormatWidget(QgsPanelWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsBasicNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsBearingNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsBearingNumericFormatDialog(QtWidgets.QDialog):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsBearingNumericFormat|None: ...


class QgsGeographicCoordinateNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, hidePrecisionControl: bool = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsGeographicCoordinateNumericFormatDialog(QtWidgets.QDialog):

    def __init__(self, format: _core.QgsNumericFormat|None, hidePrecisionControl: bool = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsGeographicCoordinateNumericFormat|None: ...


class QgsCurrencyNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsPercentageNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsScientificNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsFractionNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...


class QgsExpressionBasedNumericFormatWidget(QgsNumericFormatWidget):

    def __init__(self, format: _core.QgsNumericFormat|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def format(self) -> _core.QgsNumericFormat|None: ...
    def setFormat(self, format: _core.QgsNumericFormat|None) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...


class QgsNumericFormatConfigurationWidgetFactory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNumericFormatConfigurationWidgetFactory') -> None: ...

    def create(self, format: _core.QgsNumericFormat|None) -> QgsNumericFormatWidget|None: ...


class QgsNumericFormatGuiRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsNumericFormatGuiRegistry') -> None: ...

    def formatConfigurationWidget(self, format: _core.QgsNumericFormat|None) -> QgsNumericFormatWidget|None: ...
    def removeFormatConfigurationWidgetFactory(self, id: str|None) -> None: ...
    def addFormatConfigurationWidgetFactory(self, id: str|None, factory: QgsNumericFormatConfigurationWidgetFactory|None) -> None: ...


class QgsVectorLayerSaveAsDialog(QtWidgets.QDialog):

    class Option(enum.IntFlag):
        Symbology = ... # type: QgsVectorLayerSaveAsDialog.Option
        DestinationCrs = ... # type: QgsVectorLayerSaveAsDialog.Option
        Fields = ... # type: QgsVectorLayerSaveAsDialog.Option
        AddToCanvas = ... # type: QgsVectorLayerSaveAsDialog.Option
        SelectedOnly = ... # type: QgsVectorLayerSaveAsDialog.Option
        GeometryType = ... # type: QgsVectorLayerSaveAsDialog.Option
        Extent = ... # type: QgsVectorLayerSaveAsDialog.Option
        Metadata = ... # type: QgsVectorLayerSaveAsDialog.Option
        AllOptions = ... # type: QgsVectorLayerSaveAsDialog.Option

    def __init__(self, layer: _core.QgsVectorLayer|None, options: 'QgsVectorLayerSaveAsDialog.Option' = ..., parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def accept(self) -> None: ...
    def creationActionOnExistingFile(self) -> _core.QgsVectorFileWriter.ActionOnExistingFile: ...
    def setIncludeZ(self, checked: bool) -> None: ...
    def includeZ(self) -> bool: ...
    def setForceMulti(self, checked: bool) -> None: ...
    def forceMulti(self) -> bool: ...
    def automaticGeometryType(self) -> bool: ...
    def geometryType(self) -> _core.Qgis.WkbType: ...
    def persistMetadata(self) -> bool: ...
    def onlySelected(self) -> bool: ...
    def setOnlySelected(self, onlySelected: bool) -> None: ...
    def filterExtent(self) -> _core.QgsRectangle: ...
    def hasFilterExtent(self) -> bool: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def scale(self) -> float: ...
    def symbologyExport(self) -> _core.Qgis.FeatureSymbologyExport: ...
    def setAddToCanvas(self, checked: bool) -> None: ...
    def addToCanvas(self) -> bool: ...
    def attributesExportNames(self) -> list[str]: ...
    def attributesAsDisplayedValues(self) -> list[int]: ...
    def selectedAttributes(self) -> list[int]: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def layerOptions(self) -> list[str]: ...
    def datasourceOptions(self) -> list[str]: ...
    def layerName(self) -> str: ...
    def fileName(self) -> str: ...
    def encoding(self) -> str: ...
    def format(self) -> str: ...


class QgsPlotCanvasItem(QtWidgets.QGraphicsItem):

    def __init__(self, canvas: QgsPlotCanvas|None) -> None: ...

    @typing.overload
    def paint(self, painter: QtGui.QPainter|None) -> None: ...
    @typing.overload
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...


class QgsPlotMouseEvent(QtGui.QMouseEvent):

    @typing.overload
    def __init__(self, canvas: QgsPlotCanvas|None, event: QtGui.QMouseEvent|None) -> None: ...
    @typing.overload
    def __init__(self, canvas: QgsPlotCanvas|None, type: QtCore.QEvent.Type, pos: QtCore.QPoint, button: QtCore.Qt.MouseButton = ..., buttons: QtCore.Qt.MouseButton = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> None: ...

    def isSnapped(self) -> bool: ...
    def snappedPoint(self) -> _core.QgsPointXY: ...
    def mapPoint(self) -> _core.QgsPoint: ...


class QgsPlotRubberBand(QtCore.QObject):

    def __init__(self, canvas: QgsPlotCanvas|None = ...) -> None: ...

    def updateRect(self, start: QtCore.QPointF, position: QtCore.QPointF, constrainSquare: bool, fromCenter: bool) -> QtCore.QRectF: ...
    def setPen(self, pen: QtGui.QPen|QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def pen(self) -> QtGui.QPen: ...
    def setBrush(self, brush: QtGui.QBrush|QtGui.QColor|QtCore.Qt.GlobalColor|int|QtGui.QGradient) -> None: ...
    def brush(self) -> QtGui.QBrush: ...
    def canvas(self) -> QgsPlotCanvas|None: ...
    def finish(self, position: QtCore.QPointF = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> QtCore.QRectF: ...
    def update(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def start(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...


class QgsPlotRectangularRubberBand(QgsPlotRubberBand):

    def __init__(self, canvas: QgsPlotCanvas|None = ...) -> None: ...

    def finish(self, position: QtCore.QPointF = ..., modifiers: QtCore.Qt.KeyboardModifier = ...) -> QtCore.QRectF: ...
    def update(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...
    def start(self, position: QtCore.QPointF, modifiers: QtCore.Qt.KeyboardModifier) -> None: ...


class QgsPlotTool(QtCore.QObject):

    def __init__(self, canvas: QgsPlotCanvas|None, name: str|None) -> None: ...

    @staticmethod
    def constrainPointToRect(point: QtCore.QPointF, rect: QtCore.QRectF) -> QtCore.QPointF: ...
    def isClickAndDrag(self, startViewPoint: QtCore.QPoint, endViewPoint: QtCore.QPoint) -> bool: ...
    def toCanvasCoordinates(self, point: _core.QgsPoint) -> _core.QgsPointXY: ...
    def toMapCoordinates(self, point: _core.QgsPointXY) -> _core.QgsPoint: ...
    deactivated: typing.ClassVar[QtCore.pyqtSignal]
    activated: typing.ClassVar[QtCore.pyqtSignal]
    def populateContextMenuWithEvent(self, menu: QtWidgets.QMenu|None, event: QgsPlotMouseEvent|None) -> bool: ...
    def setCursor(self, cursor: QtGui.QCursor|QtCore.Qt.CursorShape) -> None: ...
    def action(self) -> QtGui.QAction|None: ...
    def setAction(self, action: QtGui.QAction|None) -> None: ...
    def canvas(self) -> QgsPlotCanvas|None: ...
    def deactivate(self) -> None: ...
    def activate(self) -> None: ...
    def isActive(self) -> bool: ...
    def canvasToolTipEvent(self, event: QtGui.QHelpEvent|None) -> bool: ...
    def gestureEvent(self, event: QtWidgets.QGestureEvent|None) -> bool: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def plotReleaseEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotPressEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotDoubleClickEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotMoveEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def toolName(self) -> str: ...
    def flags(self) -> _core.Qgis.PlotToolFlag: ...


class QgsPlotToolPan(QgsPlotTool):

    def __init__(self, canvas: QgsPlotCanvas|None) -> None: ...

    def deactivate(self) -> None: ...
    def plotReleaseEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotPressEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotMoveEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def flags(self) -> _core.Qgis.PlotToolFlag: ...


class QgsPlotToolZoom(QgsPlotTool):

    def __init__(self, canvas: QgsPlotCanvas|None) -> None: ...

    def deactivate(self) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def plotReleaseEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotMoveEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotPressEvent(self, event: QgsPlotMouseEvent|None) -> None: ...


class QgsPlotToolTemporaryKeyPan(QgsPlotTool):

    def __init__(self, canvas: QgsPlotCanvas|None) -> None: ...

    def activate(self) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def plotMoveEvent(self, event: QgsPlotMouseEvent|None) -> None: ...


class QgsPlotToolTemporaryMousePan(QgsPlotTool):

    def __init__(self, canvas: QgsPlotCanvas|None) -> None: ...

    def activate(self) -> None: ...
    def plotReleaseEvent(self, event: QgsPlotMouseEvent|None) -> None: ...
    def plotMoveEvent(self, event: QgsPlotMouseEvent|None) -> None: ...


class QgsPlotToolTemporaryKeyZoom(QgsPlotToolZoom):

    def __init__(self, canvas: QgsPlotCanvas|None) -> None: ...

    def activate(self) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def plotReleaseEvent(self, event: QgsPlotMouseEvent|None) -> None: ...


class QgsPlotWidget(QgsPanelWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def updateDataDefinedButton(self, button: QgsPropertyOverrideButton|None) -> None: ...
    def initializeDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsPlot.DataDefinedProperty) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def createPlot(self) -> _core.QgsPlot|None: ...
    def setPlot(self, plot: _core.QgsPlot|None) -> None: ...


class QgsBarChartPlotWidget(QgsPlotWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @staticmethod
    def create(parent: QtWidgets.QWidget|None) -> QgsPlotWidget|None: ...
    def createPlot(self) -> _core.QgsPlot|None: ...
    def setPlot(self, plot: _core.QgsPlot|None) -> None: ...


class QgsLineChartPlotWidget(QgsPlotWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @staticmethod
    def create(parent: QtWidgets.QWidget|None) -> QgsPlotWidget|None: ...
    def createPlot(self) -> _core.QgsPlot|None: ...
    def setPlot(self, plot: _core.QgsPlot|None) -> None: ...


class QgsPieChartPlotWidget(QgsPlotWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @staticmethod
    def create(parent: QtWidgets.QWidget|None) -> QgsPlotWidget|None: ...
    def createPlot(self) -> _core.QgsPlot|None: ...
    def setPlot(self, plot: _core.QgsPlot|None) -> None: ...


class QgsPointCloudRendererWidget(QgsPanelWidget):

    def __init__(self, layer: _core.QgsPointCloudLayer|None, style: _core.QgsStyle|None) -> None: ...

    def layer(self) -> _core.QgsPointCloudLayer|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsPointCloudRenderer|None: ...


class QgsPointCloudRendererPropertiesWidget(QgsMapLayerConfigWidget):

    def __init__(self, layer: _core.QgsPointCloudLayer|None, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def apply(self) -> None: ...
    def setDockMode(self, dockMode: bool) -> None: ...
    def syncToLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...


class QgsAggregateMappingModel(QtCore.QAbstractTableModel):

    class ColumnDataIndex(enum.IntEnum):
        SourceExpression = ... # type: QgsAggregateMappingModel.ColumnDataIndex
        Aggregate = ... # type: QgsAggregateMappingModel.ColumnDataIndex
        Delimiter = ... # type: QgsAggregateMappingModel.ColumnDataIndex
        DestinationName = ... # type: QgsAggregateMappingModel.ColumnDataIndex
        DestinationType = ... # type: QgsAggregateMappingModel.ColumnDataIndex
        DestinationLength = ... # type: QgsAggregateMappingModel.ColumnDataIndex
        DestinationPrecision = ... # type: QgsAggregateMappingModel.ColumnDataIndex

    class Aggregate(PyQt6.sip.wrapper):

        aggregate = ... # type: str|None
        delimiter = ... # type: str|None
        field = ... # type: _core.QgsField
        source = ... # type: str|None

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsAggregateMappingModel.Aggregate') -> None: ...

    def __init__(self, sourceFields: _core.QgsFields = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def setBaseExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def contextGenerator(self) -> _core.QgsExpressionContextGenerator|None: ...
    def setSourceFields(self, sourceFields: _core.QgsFields) -> None: ...
    def moveDown(self, index: QtCore.QModelIndex) -> bool: ...
    def moveUp(self, index: QtCore.QModelIndex) -> bool: ...
    def removeField(self, index: QtCore.QModelIndex) -> bool: ...
    def appendField(self, field: _core.QgsField, source: str|None = ..., aggregate: str|None = ...) -> None: ...
    def setMapping(self, mapping: collections.abc.Iterable['QgsAggregateMappingModel.Aggregate']) -> None: ...
    def mapping(self) -> list['QgsAggregateMappingModel.Aggregate']: ...
    def sourceFields(self) -> _core.QgsFields: ...


class QgsAggregateMappingWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., sourceFields: _core.QgsFields = ...) -> None: ...

    def moveSelectedFieldsDown(self) -> bool: ...
    def moveSelectedFieldsUp(self) -> bool: ...
    def removeSelectedFields(self) -> bool: ...
    def appendField(self, field: _core.QgsField, source: str|None = ..., aggregate: str|None = ...) -> None: ...
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def scrollTo(self, index: QtCore.QModelIndex) -> None: ...
    def sourceLayer(self) -> _core.QgsVectorLayer|None: ...
    def setSourceLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def setSourceFields(self, sourceFields: _core.QgsFields) -> None: ...
    def selectionModel(self) -> QtCore.QItemSelectionModel|None: ...
    def setMapping(self, mapping: collections.abc.Iterable[QgsAggregateMappingModel.Aggregate]) -> None: ...
    def mapping(self) -> list[QgsAggregateMappingModel.Aggregate]: ...
    def model(self) -> QgsAggregateMappingModel|None: ...


class QgsProcessingAlgorithmConfigurationWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def registerProcessingContextGenerator(self, generator: 'QgsProcessingContextGenerator|None') -> None: ...
    def algorithm(self) -> _core.QgsProcessingAlgorithm|None: ...
    def setAlgorithm(self, algorithm: _core.QgsProcessingAlgorithm|None) -> None: ...
    def widgetContext(self) -> 'QgsProcessingParameterWidgetContext': ...
    def setWidgetContext(self, context: 'QgsProcessingParameterWidgetContext') -> None: ...
    def setConfiguration(self, configuration: dict[str|None, typing.Any]) -> None: ...
    def configuration(self) -> dict[str, typing.Any]: ...


class QgsProcessingAlgorithmConfigurationWidgetFactory(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingAlgorithmConfigurationWidgetFactory') -> None: ...

    def canCreateFor(self, algorithm: _core.QgsProcessingAlgorithm|None) -> bool: ...
    def create(self, algorithm: _core.QgsProcessingAlgorithm|None) -> QgsProcessingAlgorithmConfigurationWidget|None: ...


class QgsProcessingParametersGenerator(PyQt6.sip.wrapper):

    class Flag(enum.IntFlag):
        SkipDefaultValueParameters = ... # type: QgsProcessingParametersGenerator.Flag
        SkipValidation = ... # type: QgsProcessingParametersGenerator.Flag

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParametersGenerator') -> None: ...

    def createProcessingParameters(self, flags: 'QgsProcessingParametersGenerator.Flag' = ...) -> dict[str, typing.Any]: ...


class QgsProcessingContextGenerator(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingContextGenerator') -> None: ...

    def processingContext(self) -> _core.QgsProcessingContext|None: ...


class QgsProcessingAlgorithmDialogBase(QtWidgets.QDialog, QgsProcessingParametersGenerator, QgsProcessingContextGenerator):

    class DialogMode(enum.IntEnum):
        Single = ... # type: QgsProcessingAlgorithmDialogBase.DialogMode
        Batch = ... # type: QgsProcessingAlgorithmDialogBase.DialogMode

    class LogFormat(enum.IntEnum):
        FormatPlainText = ... # type: QgsProcessingAlgorithmDialogBase.LogFormat
        FormatHtml = ... # type: QgsProcessingAlgorithmDialogBase.LogFormat

    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ..., mode: 'QgsProcessingAlgorithmDialogBase.DialogMode' = ...) -> None: ...

    def algExecuted(self, successful: bool, results: dict[str|None, typing.Any]) -> None: ...
    def runAlgorithm(self) -> None: ...
    def finished(self, successful: bool, result: dict[str|None, typing.Any], context: _core.QgsProcessingContext, feedback: _core.QgsProcessingFeedback|None) -> None: ...
    algorithmFinished: typing.ClassVar[QtCore.pyqtSignal]
    algorithmAboutToRun: typing.ClassVar[QtCore.pyqtSignal]
    def applyContextOverrides(self, context: _core.QgsProcessingContext|None) -> None: ...
    def isFinalized(self) -> bool: ...
    @staticmethod
    def formatStringForLog(string: str|None) -> str: ...
    def setCurrentTask(self, task: _core.QgsProcessingAlgRunnerTask|None) -> None: ...
    def hideShortHelp(self) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def blockAdditionalControlsWhileRunning(self) -> None: ...
    def blockControlsWhileRunning(self) -> None: ...
    def updateRunButtonVisibility(self) -> None: ...
    def resetAdditionalGui(self) -> None: ...
    def resetGui(self) -> None: ...
    def setInfo(self, message: str|None, isError: bool = ..., escapeHtml: bool = ..., isWarning: bool = ...) -> None: ...
    def setResults(self, results: dict[str|None, typing.Any]) -> None: ...
    def setExecutedAnyResult(self, executedAnyResult: bool) -> None: ...
    def setExecuted(self, executed: bool) -> None: ...
    def clearProgress(self) -> None: ...
    def tabWidget(self) -> QtWidgets.QTabWidget|None: ...
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def changeParametersButton(self) -> QtWidgets.QPushButton|None: ...
    def cancelButton(self) -> QtWidgets.QPushButton|None: ...
    def runButton(self) -> QtWidgets.QPushButton|None: ...
    def closeEvent(self, e: QtGui.QCloseEvent|None) -> None: ...
    def reject(self) -> None: ...
    def showParameters(self) -> None: ...
    def copyLogToClipboard(self) -> None: ...
    def saveLog(self) -> None: ...
    def clearLog(self) -> None: ...
    def createProgressDialog(self) -> QtWidgets.QDialog|None: ...
    def pushConsoleInfo(self, info: str|None) -> None: ...
    def setProgressText(self, text: str|None) -> None: ...
    def setPercentage(self, percent: float) -> None: ...
    def pushCommandInfo(self, info: str|None) -> None: ...
    def pushDebugInfo(self, message: str|None) -> None: ...
    def pushFormattedMessage(self, html: str|None) -> None: ...
    def pushInfo(self, info: str|None) -> None: ...
    def pushWarning(self, warning: str|None) -> None: ...
    def reportError(self, error: str|None, fatalError: bool) -> None: ...
    def setParameters(self, values: dict[str|None, typing.Any]) -> None: ...
    def setLogLevel(self, level: _core.Qgis.ProcessingLogLevel) -> None: ...
    def logLevel(self) -> _core.Qgis.ProcessingLogLevel: ...
    def saveLogToFile(self, path: str|None, format: 'QgsProcessingAlgorithmDialogBase.LogFormat' = ...) -> None: ...
    def createFeedback(self) -> _core.QgsProcessingFeedback|None: ...
    def results(self) -> dict[str, typing.Any]: ...
    def wasExecuted(self) -> bool: ...
    def showLog(self) -> None: ...
    def mainWidget(self) -> QgsPanelWidget|None: ...
    def setMainWidget(self, widget: QgsPanelWidget|None) -> None: ...
    def algorithm(self) -> _core.QgsProcessingAlgorithm|None: ...
    def setAlgorithm(self, algorithm: _core.QgsProcessingAlgorithm|None) -> None: ...


class QgsProcessingBatchAlgorithmDialogBase(QgsProcessingAlgorithmDialogBase):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def createSummaryTable(self, results: collections.abc.Iterable[dict[str, typing.Any]], errors: collections.abc.Iterable[dict[str, typing.Any]]) -> None: ...
    def loadHtmlResults(self, results: dict[str|None, typing.Any], index: int) -> None: ...
    def handleAlgorithmResults(self, algorithm: _core.QgsProcessingAlgorithm|None, context: _core.QgsProcessingContext, feedback: _core.QgsProcessingFeedback|None, parameters: dict[str|None, typing.Any]) -> None: ...
    def createContext(self, feedback: _core.QgsProcessingFeedback|None) -> _core.QgsProcessingContext|None: ...
    def execute(self, parameters: collections.abc.Iterable[dict[str, typing.Any]]) -> None: ...
    def isFinalized(self) -> bool: ...
    def algExecuted(self, successful: bool, results: dict[str|None, typing.Any]) -> None: ...
    def runAsSingle(self) -> None: ...
    def blockAdditionalControlsWhileRunning(self) -> None: ...
    def resetAdditionalGui(self) -> None: ...


class QgsProcessingFavoriteAlgorithmManager(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def isFavorite(self, id: str|None) -> bool: ...
    def clear(self) -> None: ...
    def remove(self, id: str|None) -> None: ...
    def add(self, id: str|None) -> None: ...
    def favoriteAlgorithmIds(self) -> list[str]: ...


class QgsProcessingGui(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingGui') -> None: ...


class QgsProcessingGuiRegistry(PyQt6.sip.wrapper):

    def __init__(self) -> None: ...

    def createModelConfigWidgetForComponent(self, component: _core.QgsProcessingModelComponent|None, context: _core.QgsProcessingContext, widgetContext: 'QgsProcessingParameterWidgetContext') -> 'QgsProcessingModelConfigWidget|None': ...
    def createParameterDefinitionWidget(self, type: str|None, context: _core.QgsProcessingContext, widgetContext: 'QgsProcessingParameterWidgetContext', definition: _core.QgsProcessingParameterDefinition|None = ..., algorithm: _core.QgsProcessingAlgorithm|None = ...) -> 'QgsProcessingAbstractParameterDefinitionWidget|None': ...
    def createModelerParameterWidget(self, model: _core.QgsProcessingModelAlgorithm|None, childId: str|None, parameter: _core.QgsProcessingParameterDefinition|None, context: _core.QgsProcessingContext) -> 'QgsProcessingModelerParameterWidget|None': ...
    def createParameterWidgetWrapper(self, parameter: _core.QgsProcessingParameterDefinition|None, type: _core.Qgis.ProcessingMode) -> 'QgsAbstractProcessingParameterWidgetWrapper|None': ...
    def unregisterModelConfigWidgetFactory(self, factory: 'QgsProcessingModelConfigWidgetFactory|None') -> None: ...
    def registerModelConfigWidgetFactory(self, factory: 'QgsProcessingModelConfigWidgetFactory|None') -> None: ...
    def removeParameterWidgetFactory(self, factory: 'QgsProcessingParameterWidgetFactoryInterface|None') -> None: ...
    def addParameterWidgetFactory(self, factory: 'QgsProcessingParameterWidgetFactoryInterface|None') -> bool: ...
    def algorithmConfigurationWidget(self, algorithm: _core.QgsProcessingAlgorithm|None) -> QgsProcessingAlgorithmConfigurationWidget|None: ...
    def removeAlgorithmConfigurationWidgetFactory(self, factory: QgsProcessingAlgorithmConfigurationWidgetFactory|None) -> None: ...
    def addAlgorithmConfigurationWidgetFactory(self, factory: QgsProcessingAlgorithmConfigurationWidgetFactory|None) -> None: ...


class QgsProcessingGuiUtils(PyQt6.sip.wrapper):

    class ResultLayerDetails(PyQt6.sip.wrapper):

        destinationProject = ... # type: _core.QgsProject
        layer = ... # type: _core.QgsMapLayer
        sortKey = ... # type: int
        targetLayerTreeGroup = ... # type: _core.QgsLayerTreeGroup

        @typing.overload
        def __init__(self, layer: _core.QgsMapLayer|None) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsProcessingGuiUtils.ResultLayerDetails') -> None: ...

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingGuiUtils') -> None: ...

    @staticmethod
    def addResultLayers(layers: collections.abc.Iterable['QgsProcessingGuiUtils.ResultLayerDetails'], context: _core.QgsProcessingContext, view: QgsLayerTreeView|None = ...) -> None: ...
    @staticmethod
    def layerTreeResultsGroup(layerDetails: _core.QgsProcessingContext.LayerDetails, context: _core.QgsProcessingContext) -> _core.QgsLayerTreeGroup|None: ...
    @staticmethod
    def configureResultLayerTreeLayer(layerTreeLayer: _core.QgsLayerTreeLayer|None) -> None: ...


class QgsProcessingHistoryProvider(QgsAbstractHistoryProvider):

    def __init__(self) -> None: ...

    showMessage: typing.ClassVar[QtCore.pyqtSignal]
    createTest: typing.ClassVar[QtCore.pyqtSignal]
    executePython: typing.ClassVar[QtCore.pyqtSignal]
    def updateNodeForEntry(self, node: QgsHistoryEntryNode|None, entry: QgsHistoryEntry, context: QgsHistoryWidgetContext) -> None: ...
    def createNodeForEntry(self, entry: QgsHistoryEntry, context: QgsHistoryWidgetContext) -> QgsHistoryEntryNode|None: ...
    def portOldLog(self) -> None: ...
    def id(self) -> str: ...


class QgsProcessingHistoryWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def saveLog(self) -> None: ...
    def openHelp(self) -> None: ...
    def clearHistory(self) -> None: ...


class QgsProcessingHistoryDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...


class QgsProcessingMapLayerComboBox(QtWidgets.QWidget):

    def __init__(self, parameter: _core.QgsProcessingParameterDefinition|None, type: _core.Qgis.ProcessingMode = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, event: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    valueChanged: typing.ClassVar[QtCore.pyqtSignal]
    def isEditable(self) -> bool: ...
    def setEditable(self, editable: bool) -> None: ...
    def setWidgetContext(self, context: 'QgsProcessingParameterWidgetContext') -> None: ...
    def value(self) -> typing.Any: ...
    def setValue(self, value: typing.Any, context: _core.QgsProcessingContext) -> None: ...
    def currentText(self) -> str: ...
    def currentLayer(self) -> _core.QgsMapLayer|None: ...
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...


class QgsProcessingModelerParameterWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, model: _core.QgsProcessingModelAlgorithm|None, childId: str|None, parameter: _core.QgsProcessingParameterDefinition|None, context: _core.QgsProcessingContext, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setSourceType(self, type: _core.Qgis.ProcessingModelChildParameterSource) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setDialog(self, dialog: QtWidgets.QDialog|None) -> None: ...
    def value(self) -> typing.Any: ...
    def modelOutputName(self) -> str: ...
    def isModelOutput(self) -> bool: ...
    def setToModelOutput(self, value: str|None) -> None: ...
    @typing.overload
    def setWidgetValue(self, value: _core.QgsProcessingModelChildParameterSource) -> None: ...
    @typing.overload
    def setWidgetValue(self, values: collections.abc.Iterable[_core.QgsProcessingModelChildParameterSource]) -> None: ...
    def createLabel(self) -> QtWidgets.QLabel|None: ...
    def parameterDefinition(self) -> _core.QgsProcessingParameterDefinition|None: ...
    def setExpressionHelpText(self, text: str|None) -> None: ...
    def populateSources(self, compatibleParameterTypes: collections.abc.Iterable[str|None], compatibleOutputTypes: collections.abc.Iterable[str|None], compatibleDataTypes: collections.abc.Iterable[int]) -> None: ...
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def setWidgetContext(self, context: 'QgsProcessingParameterWidgetContext') -> None: ...


class QgsProcessingMultipleSelectionPanelWidget(QgsPanelWidget):

    def __init__(self, availableOptions: collections.abc.Iterable[typing.Any] = ..., selectedOptions: collections.abc.Iterable[typing.Any] = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    def listView(self) -> QtWidgets.QListView|None: ...
    def addOption(self, value: typing.Any, title: str|None, selected: bool, updateExistingTitle: bool = ..., optionalIconDecoration: QtGui.QIcon = ...) -> None: ...
    selectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    acceptClicked: typing.ClassVar[QtCore.pyqtSignal]
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def selectedOptions(self) -> list[typing.Any]: ...
    def setValueFormatter(self, a0: typing.Callable[..., None]) -> None: ...


class QgsProcessingMultipleSelectionDialog(QtWidgets.QDialog):

    def __init__(self, availableOptions: collections.abc.Iterable[typing.Any] = ..., selectedOptions: collections.abc.Iterable[typing.Any] = ..., parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def selectedOptions(self) -> list[typing.Any]: ...
    def setValueFormatter(self, a0: typing.Callable[..., None]) -> None: ...


class QgsProcessingMultipleInputPanelWidget(QgsProcessingMultipleSelectionPanelWidget):

    def __init__(self, parameter: _core.QgsProcessingParameterMultipleLayers|None, selectedOptions: collections.abc.Iterable[typing.Any], modelSources: collections.abc.Iterable[_core.QgsProcessingModelChildParameterSource], model: _core.QgsProcessingModelAlgorithm|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...


class QgsProcessingMultipleInputDialog(QtWidgets.QDialog):

    def __init__(self, parameter: _core.QgsProcessingParameterMultipleLayers|None, selectedOptions: collections.abc.Iterable[typing.Any], modelSources: collections.abc.Iterable[_core.QgsProcessingModelChildParameterSource], model: _core.QgsProcessingModelAlgorithm|None = ..., parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def selectedOptions(self) -> list[typing.Any]: ...


class QgsProcessingLayerOutputDestinationWidget(QtWidgets.QWidget):

    def __init__(self, parameter: _core.QgsProcessingDestinationParameter|None, defaultSelection: bool, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, event: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    destinationChanged: typing.ClassVar[QtCore.pyqtSignal]
    skipOutputChanged: typing.ClassVar[QtCore.pyqtSignal]
    def openAfterRunning(self) -> bool: ...
    def addOpenAfterRunningOption(self) -> None: ...
    def registerProcessingParametersGenerator(self, generator: QgsProcessingParametersGenerator|None) -> None: ...
    def setContext(self, context: _core.QgsProcessingContext|None) -> None: ...
    def setWidgetContext(self, context: 'QgsProcessingParameterWidgetContext') -> None: ...
    def value(self) -> typing.Any: ...
    def setValue(self, value: typing.Any) -> None: ...
    def outputIsSkipped(self) -> bool: ...


class QgsProcessingAbstractParameterDefinitionWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, context: _core.QgsProcessingContext, widgetContext: 'QgsProcessingParameterWidgetContext', definition: _core.QgsProcessingParameterDefinition|None = ..., algorithm: _core.QgsProcessingAlgorithm|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def widgetContext(self) -> 'QgsProcessingParameterWidgetContext': ...
    def setWidgetContext(self, context: 'QgsProcessingParameterWidgetContext') -> None: ...
    def createParameter(self, name: str|None, description: str|None, flags: _core.Qgis.ProcessingParameterFlag) -> _core.QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterDefinitionWidget(QtWidgets.QWidget):

    def __init__(self, type: str|None, context: _core.QgsProcessingContext, widgetContext: 'QgsProcessingParameterWidgetContext', definition: _core.QgsProcessingParameterDefinition|None = ..., algorithm: _core.QgsProcessingAlgorithm|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def createParameter(self, name: str|None = ...) -> _core.QgsProcessingParameterDefinition|None: ...


class QgsProcessingModelConfigWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def apply(self) -> None: ...


class QgsProcessingParameterDefinitionPanelWidget(QgsProcessingModelConfigWidget):

    def __init__(self, type: str|None, context: _core.QgsProcessingContext, widgetContext: 'QgsProcessingParameterWidgetContext', definition: _core.QgsProcessingParameterDefinition|None = ..., algorithm: _core.QgsProcessingAlgorithm|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def switchToCommentTab(self) -> None: ...
    def commentColor(self) -> QtGui.QColor: ...
    def setCommentColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def comments(self) -> str: ...
    def setComments(self, comments: str|None) -> None: ...
    def createParameter(self, name: str|None = ...) -> _core.QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterDefinitionDialog(QtWidgets.QDialog):

    def __init__(self, type: str|None, context: _core.QgsProcessingContext, widgetContext: 'QgsProcessingParameterWidgetContext', definition: _core.QgsProcessingParameterDefinition|None = ..., algorithm: _core.QgsProcessingAlgorithm|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def accept(self) -> None: ...
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def switchToCommentTab(self) -> None: ...
    def commentColor(self) -> QtGui.QColor: ...
    def setCommentColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def comments(self) -> str: ...
    def setComments(self, comments: str|None) -> None: ...
    def createParameter(self, name: str|None = ...) -> _core.QgsProcessingParameterDefinition|None: ...


class QgsProcessingParametersWidget(QgsPanelWidget, QgsProcessingParametersGenerator):

    def __init__(self, algorithm: _core.QgsProcessingAlgorithm|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def addExtraWidget(self, widget: QtWidgets.QWidget|None) -> None: ...
    def addOutputWidget(self, widget: QtWidgets.QWidget|None, stretch: int = ...) -> None: ...
    def addOutputLabel(self, label: QtWidgets.QWidget|None) -> None: ...
    def addParameterLabel(self, parameter: _core.QgsProcessingParameterDefinition|None, label: QtWidgets.QWidget|None) -> None: ...
    def addParameterWidget(self, parameter: _core.QgsProcessingParameterDefinition|None, widget: QtWidgets.QWidget|None, stretch: int = ...) -> None: ...
    def initWidgets(self) -> None: ...
    def algorithm(self) -> _core.QgsProcessingAlgorithm|None: ...


class QgsProcessingRecentAlgorithmLog(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def push(self, id: str|None) -> None: ...
    def recentAlgorithmIds(self) -> list[str]: ...


class QgsProcessingToolboxModelNode(QtCore.QObject):

    class NodeType(enum.IntEnum):
        Provider = ... # type: QgsProcessingToolboxModelNode.NodeType
        Group = ... # type: QgsProcessingToolboxModelNode.NodeType
        Algorithm = ... # type: QgsProcessingToolboxModelNode.NodeType
        Recent = ... # type: QgsProcessingToolboxModelNode.NodeType
        Parameter = ... # type: QgsProcessingToolboxModelNode.NodeType
        ParameterGroup = ... # type: QgsProcessingToolboxModelNode.NodeType
        Favorite = ... # type: QgsProcessingToolboxModelNode.NodeType

    def __init__(self) -> None: ...

    def deleteChildren(self) -> None: ...
    def addChildNode(self, node: 'QgsProcessingToolboxModelNode|None') -> None: ...
    def getChildGroupNode(self, id: str|None) -> 'QgsProcessingToolboxModelGroupNode|None': ...
    def takeChild(self, node: 'QgsProcessingToolboxModelNode|None') -> 'QgsProcessingToolboxModelNode|None': ...
    def children(self) -> list['QgsProcessingToolboxModelNode']: ...
    def parent(self) -> 'QgsProcessingToolboxModelNode|None': ...
    def nodeType(self) -> 'QgsProcessingToolboxModelNode.NodeType': ...


class QgsProcessingToolboxModelRecentNode(QgsProcessingToolboxModelNode):

    def __init__(self) -> None: ...

    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModelFavoriteNode(QgsProcessingToolboxModelNode):

    def __init__(self) -> None: ...

    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModelParameterGroupNode(QgsProcessingToolboxModelNode):

    def __init__(self) -> None: ...

    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModelProviderNode(QgsProcessingToolboxModelNode):

    def __init__(self, provider: _core.QgsProcessingProvider|None) -> None: ...

    def providerId(self) -> str: ...
    def provider(self) -> _core.QgsProcessingProvider|None: ...
    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModelGroupNode(QgsProcessingToolboxModelNode):

    def __init__(self, id: str|None, name: str|None) -> None: ...

    def name(self) -> str: ...
    def id(self) -> str: ...
    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModelAlgorithmNode(QgsProcessingToolboxModelNode):

    def __init__(self, algorithm: _core.QgsProcessingAlgorithm|None) -> None: ...

    def algorithm(self) -> _core.QgsProcessingAlgorithm|None: ...
    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModelParameterNode(QgsProcessingToolboxModelNode):

    def __init__(self, paramType: _core.QgsProcessingParameterType|None) -> None: ...

    def parameterType(self) -> _core.QgsProcessingParameterType|None: ...
    def nodeType(self) -> QgsProcessingToolboxModelNode.NodeType: ...


class QgsProcessingToolboxModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        NodeType = ... # type: QgsProcessingToolboxModel.CustomRole
        AlgorithmFlags = ... # type: QgsProcessingToolboxModel.CustomRole
        AlgorithmId = ... # type: QgsProcessingToolboxModel.CustomRole
        AlgorithmName = ... # type: QgsProcessingToolboxModel.CustomRole
        AlgorithmShortDescription = ... # type: QgsProcessingToolboxModel.CustomRole
        AlgorithmTags = ... # type: QgsProcessingToolboxModel.CustomRole
        ProviderFlags = ... # type: QgsProcessingToolboxModel.CustomRole
        ParameterTypeId = ... # type: QgsProcessingToolboxModel.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ..., registry: _core.QgsProcessingRegistry|None = ..., recentLog: QgsProcessingRecentAlgorithmLog|None = ..., favoriteManager: QgsProcessingFavoriteAlgorithmManager|None = ...) -> None: ...

    favoriteAlgorithmAdded: typing.ClassVar[QtCore.pyqtSignal]
    recentAlgorithmAdded: typing.ClassVar[QtCore.pyqtSignal]
    def indexOfParentTreeNode(self, parentNode: QgsProcessingToolboxModelNode|None) -> QtCore.QModelIndex: ...
    def indexForProvider(self, providerId: str|None) -> QtCore.QModelIndex: ...
    def isParameter(self, index: QtCore.QModelIndex) -> bool: ...
    def parameterTypeForIndex(self, index: QtCore.QModelIndex) -> _core.QgsProcessingParameterType|None: ...
    def isAlgorithm(self, index: QtCore.QModelIndex) -> bool: ...
    def algorithmForIndex(self, index: QtCore.QModelIndex) -> _core.QgsProcessingAlgorithm|None: ...
    def providerIdForIndex(self, index: QtCore.QModelIndex) -> str: ...
    def providerForIndex(self, index: QtCore.QModelIndex) -> _core.QgsProcessingProvider|None: ...
    def node2index(self, node: QgsProcessingToolboxModelNode|None) -> QtCore.QModelIndex: ...
    def index2node(self, index: QtCore.QModelIndex) -> QgsProcessingToolboxModelNode|None: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, a0: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsProcessingToolboxProxyModel(QtCore.QSortFilterProxyModel):

    class Filter(enum.IntFlag):
        Toolbox = ... # type: QgsProcessingToolboxProxyModel.Filter
        Modeler = ... # type: QgsProcessingToolboxProxyModel.Filter
        InPlace = ... # type: QgsProcessingToolboxProxyModel.Filter
        ShowKnownIssues = ... # type: QgsProcessingToolboxProxyModel.Filter

    def __init__(self, parent: QtCore.QObject|None = ..., registry: _core.QgsProcessingRegistry|None = ..., recentLog: QgsProcessingRecentAlgorithmLog|None = ..., favoriteManager: QgsProcessingFavoriteAlgorithmManager|None = ...) -> None: ...

    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def filterString(self) -> str: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def setInPlaceLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def filters(self) -> 'QgsProcessingToolboxProxyModel.Filter': ...
    def setFilters(self, filters: 'QgsProcessingToolboxProxyModel.Filter') -> None: ...
    def toolboxModel(self) -> QgsProcessingToolboxModel|None: ...


class QgsProcessingToolboxTreeView(QtWidgets.QTreeView):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., registry: _core.QgsProcessingRegistry|None = ..., recentLog: QgsProcessingRecentAlgorithmLog|None = ..., favoriteManager: QgsProcessingFavoriteAlgorithmManager|None = ...) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def reset(self) -> None: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def setInPlaceLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def filters(self) -> QgsProcessingToolboxProxyModel.Filter: ...
    def setFilters(self, filters: QgsProcessingToolboxProxyModel.Filter) -> None: ...
    def selectedParameterType(self) -> _core.QgsProcessingParameterType|None: ...
    def parameterTypeForIndex(self, index: QtCore.QModelIndex) -> _core.QgsProcessingParameterType|None: ...
    def selectedAlgorithm(self) -> _core.QgsProcessingAlgorithm|None: ...
    def algorithmForIndex(self, index: QtCore.QModelIndex) -> _core.QgsProcessingAlgorithm|None: ...
    def setToolboxProxyModel(self, model: QgsProcessingToolboxProxyModel|None) -> None: ...
    def setRegistry(self, registry: _core.QgsProcessingRegistry|None, recentLog: QgsProcessingRecentAlgorithmLog|None = ..., favoriteManager: QgsProcessingFavoriteAlgorithmManager|None = ...) -> None: ...


class QgsProcessingParameterWidgetContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterWidgetContext') -> None: ...

    def setModelDesignerDialog(self, dialog: 'QgsModelDesignerDialog|None') -> None: ...
    def modelDesignerDialog(self) -> 'QgsModelDesignerDialog|None': ...
    def processingContextGenerator(self) -> QgsProcessingContextGenerator|None: ...
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def setActiveLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def activeLayer(self) -> _core.QgsMapLayer|None: ...
    def setModelChildAlgorithmId(self, id: str|None) -> None: ...
    def modelChildAlgorithmId(self) -> str: ...
    def setModel(self, model: _core.QgsProcessingModelAlgorithm|None) -> None: ...
    def model(self) -> _core.QgsProcessingModelAlgorithm|None: ...
    def project(self) -> _core.QgsProject|None: ...
    def setProject(self, project: _core.QgsProject|None) -> None: ...
    def browserModel(self) -> QgsBrowserGuiModel|None: ...
    def setBrowserModel(self, model: QgsBrowserGuiModel|None) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...


class QgsAbstractProcessingParameterWidgetWrapper(QtCore.QObject, _core.QgsExpressionContextGenerator):

    def __init__(self, parameter: _core.QgsProcessingParameterDefinition|None = ..., type: _core.Qgis.ProcessingMode = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def linkedVectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def widgetValue(self) -> typing.Any: ...
    def setWidgetValue(self, value: typing.Any, context: _core.QgsProcessingContext) -> None: ...
    def createLabel(self) -> QtWidgets.QLabel|None: ...
    def createWidget(self) -> QtWidgets.QWidget|None: ...
    widgetValueHasChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDialog(self, dialog: QtWidgets.QDialog|None) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def stretch(self) -> int: ...
    def postInitialize(self, wrappers: collections.abc.Iterable['QgsAbstractProcessingParameterWidgetWrapper']) -> None: ...
    def registerProcessingParametersGenerator(self, generator: QgsProcessingParametersGenerator|None) -> None: ...
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def customProperties(self) -> dict[str, typing.Any]: ...
    def parameterValue(self) -> typing.Any: ...
    def setParameterValue(self, value: typing.Any, context: _core.QgsProcessingContext) -> None: ...
    def parameterDefinition(self) -> _core.QgsProcessingParameterDefinition|None: ...
    def wrappedLabel(self) -> QtWidgets.QLabel|None: ...
    def wrappedWidget(self) -> QtWidgets.QWidget|None: ...
    def createWrappedLabel(self) -> QtWidgets.QLabel|None: ...
    def createWrappedWidget(self, context: _core.QgsProcessingContext) -> QtWidgets.QWidget|None: ...
    def widgetContext(self) -> QgsProcessingParameterWidgetContext: ...
    def setWidgetContext(self, context: QgsProcessingParameterWidgetContext) -> None: ...
    def type(self) -> _core.Qgis.ProcessingMode: ...
    @property
    def param(self) -> _core.QgsProcessingParameterDefinition|None: ...


class QgsProcessingParameterWidgetFactoryInterface(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsProcessingParameterWidgetFactoryInterface') -> None: ...

    def defaultModelSource(self, parameter: _core.QgsProcessingParameterDefinition|None) -> _core.Qgis.ProcessingModelChildParameterSource: ...
    def modelerExpressionFormatString(self) -> str: ...
    def compatibleDataTypes(self, parameter: _core.QgsProcessingParameterDefinition|None) -> list[int]: ...
    def compatibleOutputTypes(self) -> list[str]: ...
    def compatibleParameterTypes(self) -> list[str]: ...
    def createParameterDefinitionWidget(self, context: _core.QgsProcessingContext, widgetContext: QgsProcessingParameterWidgetContext, definition: _core.QgsProcessingParameterDefinition|None = ..., algorithm: _core.QgsProcessingAlgorithm|None = ...) -> QgsProcessingAbstractParameterDefinitionWidget|None: ...
    def createModelerWidgetWrapper(self, model: _core.QgsProcessingModelAlgorithm|None, childId: str|None, parameter: _core.QgsProcessingParameterDefinition|None, context: _core.QgsProcessingContext) -> QgsProcessingModelerParameterWidget|None: ...
    def createWidgetWrapper(self, parameter: _core.QgsProcessingParameterDefinition|None, type: _core.Qgis.ProcessingMode) -> QgsAbstractProcessingParameterWidgetWrapper|None: ...
    def parameterType(self) -> str: ...


class QgsProcessingHiddenWidgetWrapper(QgsAbstractProcessingParameterWidgetWrapper):

    def __init__(self, parameter: _core.QgsProcessingParameterDefinition|None = ..., type: _core.Qgis.ProcessingMode = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def createLabel(self) -> QtWidgets.QLabel|None: ...
    def createWidget(self) -> QtWidgets.QWidget|None: ...
    def setLinkedVectorLayer(self, layer: _core.QgsVectorLayer|None) -> None: ...
    def linkedVectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def widgetValue(self) -> typing.Any: ...
    def setWidgetValue(self, value: typing.Any, context: _core.QgsProcessingContext) -> None: ...


class QgsModelArrowItem(QtCore.QObject, QtWidgets.QGraphicsPathItem):

    class Marker(enum.IntEnum):
        Circle = ... # type: QgsModelArrowItem.Marker
        ArrowHead = ... # type: QgsModelArrowItem.Marker
        NoMarker = ... # type: QgsModelArrowItem.Marker

    @typing.overload
    def __init__(self, startItem: 'QgsModelComponentGraphicItem|None', startEdge: QtCore.Qt.Edge, startIndex: int, startIsOutgoing: bool, startMarker: 'QgsModelArrowItem.Marker', endItem: 'QgsModelComponentGraphicItem|None', endEdge: QtCore.Qt.Edge, endIndex: int, endIsIncoming: bool, endMarker: 'QgsModelArrowItem.Marker') -> None: ...
    @typing.overload
    def __init__(self, startItem: 'QgsModelComponentGraphicItem|None', startEdge: QtCore.Qt.Edge, startIndex: int, startMarker: 'QgsModelArrowItem.Marker', endItem: 'QgsModelComponentGraphicItem|None', endMarker: 'QgsModelArrowItem.Marker') -> None: ...
    @typing.overload
    def __init__(self, startItem: 'QgsModelComponentGraphicItem|None', startMarker: 'QgsModelArrowItem.Marker', endItem: 'QgsModelComponentGraphicItem|None', endEdge: QtCore.Qt.Edge, endIndex: int, endMarker: 'QgsModelArrowItem.Marker') -> None: ...
    @typing.overload
    def __init__(self, startItem: 'QgsModelComponentGraphicItem|None', startMarker: 'QgsModelArrowItem.Marker', endItem: 'QgsModelComponentGraphicItem|None', endMarker: 'QgsModelArrowItem.Marker') -> None: ...

    def updatePath(self) -> None: ...
    painterPathUpdated: typing.ClassVar[QtCore.pyqtSignal]
    def setPenStyle(self, style: QtCore.Qt.PenStyle) -> None: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...


class QgsModelComponentGraphicItem(QtWidgets.QGraphicsObject):

    class Flag(enum.IntEnum):
        Unused = ... # type: QgsModelComponentGraphicItem.Flag

    class State(enum.IntEnum):
        Normal = ... # type: QgsModelComponentGraphicItem.State
        Selected = ... # type: QgsModelComponentGraphicItem.State
        Hover = ... # type: QgsModelComponentGraphicItem.State

    def __init__(self, component: _core.QgsProcessingModelComponent|None, model: _core.QgsProcessingModelAlgorithm|None, parent: QtWidgets.QGraphicsItem|None) -> None: ...

    def updateButtonPositions(self) -> None: ...
    def updateStoredComponentPosition(self, pos: QtCore.QPointF, size: QtCore.QSizeF) -> None: ...
    def iconPixmap(self) -> QtGui.QPixmap: ...
    def iconPicture(self) -> QtGui.QPicture: ...
    def titleAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def strokeStyle(self, state: 'QgsModelComponentGraphicItem.State') -> QtCore.Qt.PenStyle: ...
    def textColor(self, state: 'QgsModelComponentGraphicItem.State') -> QtGui.QColor: ...
    def strokeColor(self, state: 'QgsModelComponentGraphicItem.State') -> QtGui.QColor: ...
    def fillColor(self, state: 'QgsModelComponentGraphicItem.State') -> QtGui.QColor: ...
    def truncatedTextForItem(self, text: str|None) -> str: ...
    def editComponent(self) -> None: ...
    sizePositionChanged: typing.ClassVar[QtCore.pyqtSignal]
    updateArrowPaths: typing.ClassVar[QtCore.pyqtSignal]
    repaintArrows: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    aboutToChange: typing.ClassVar[QtCore.pyqtSignal]
    requestModelRepaint: typing.ClassVar[QtCore.pyqtSignal]
    def deleteComponent(self) -> None: ...
    def canDeleteComponent(self) -> bool: ...
    def editComment(self) -> None: ...
    def outSocketAt(self, index: int) -> 'QgsModelDesignerSocketGraphicItem|None': ...
    @typing.overload
    def calculateAutomaticLinkPoint(self, other: 'QgsModelComponentGraphicItem|None') -> typing.Tuple[QtCore.QPointF, QtCore.Qt.Edge]: ...
    @typing.overload
    def calculateAutomaticLinkPoint(self, point: QtCore.QPointF) -> typing.Tuple[QtCore.QPointF, QtCore.Qt.Edge]: ...
    def linkPoint(self, edge: QtCore.Qt.Edge, index: int, incoming: bool) -> QtCore.QPointF: ...
    def linkPointText(self, edge: QtCore.Qt.Edge, index: int) -> str: ...
    def linkPointCount(self, edge: QtCore.Qt.Edge) -> int: ...
    def state(self) -> 'QgsModelComponentGraphicItem.State': ...
    def setLabel(self, label: str|None) -> None: ...
    def label(self) -> str: ...
    def itemRect(self, storedRect: bool = ...) -> QtCore.QRectF: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...
    def contains(self, point: QtCore.QPointF) -> bool: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def itemChange(self, change: QtWidgets.QGraphicsItem.GraphicsItemChange, value: typing.Any) -> typing.Any: ...
    def hoverLeaveEvent(self, event: QtWidgets.QGraphicsSceneHoverEvent|None) -> None: ...
    def hoverMoveEvent(self, event: QtWidgets.QGraphicsSceneHoverEvent|None) -> None: ...
    def hoverEnterEvent(self, event: QtWidgets.QGraphicsSceneHoverEvent|None) -> None: ...
    def mouseDoubleClickEvent(self, event: QtWidgets.QGraphicsSceneMouseEvent|None) -> None: ...
    def setItemRect(self, rect: QtCore.QRectF) -> None: ...
    def previewItemMove(self, dx: float, dy: float) -> None: ...
    def moveComponentBy(self, dx: float, dy: float) -> None: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def font(self) -> QtGui.QFont: ...
    def view(self) -> 'QgsModelGraphicsView|None': ...
    def model(self) -> _core.QgsProcessingModelAlgorithm|None: ...
    def component(self) -> _core.QgsProcessingModelComponent|None: ...
    def flags(self) -> 'QgsModelComponentGraphicItem.Flag': ...


class QgsModelParameterGraphicItem(QgsModelComponentGraphicItem):

    def __init__(self, parameter: _core.QgsProcessingModelParameter|None, model: _core.QgsProcessingModelAlgorithm|None, parent: QtWidgets.QGraphicsItem|None) -> None: ...

    def deleteComponent(self) -> None: ...
    def updateStoredComponentPosition(self, pos: QtCore.QPointF, size: QtCore.QSizeF) -> None: ...
    def linkPointText(self, edge: QtCore.Qt.Edge, index: int) -> str: ...
    def linkPointCount(self, edge: QtCore.Qt.Edge) -> int: ...
    def iconPicture(self) -> QtGui.QPicture: ...
    def textColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def strokeColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def fillColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def linkColor(self, edge: QtCore.Qt.Edge, index: int) -> QtGui.QColor: ...
    def canDeleteComponent(self) -> bool: ...
    def contextMenuEvent(self, event: QtWidgets.QGraphicsSceneContextMenuEvent|None) -> None: ...


class QgsModelChildAlgorithmGraphicItem(QgsModelComponentGraphicItem):

    def __init__(self, child: _core.QgsProcessingModelChildAlgorithm|None, model: _core.QgsProcessingModelAlgorithm|None, parent: QtWidgets.QGraphicsItem|None) -> None: ...

    def deleteComponent(self) -> None: ...
    def updateStoredComponentPosition(self, pos: QtCore.QPointF, size: QtCore.QSizeF) -> None: ...
    def linkPointText(self, edge: QtCore.Qt.Edge, index: int) -> str: ...
    def linkPointCount(self, edge: QtCore.Qt.Edge) -> int: ...
    def iconPicture(self) -> QtGui.QPicture: ...
    def iconPixmap(self) -> QtGui.QPixmap: ...
    def textColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def strokeColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def fillColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    showLog: typing.ClassVar[QtCore.pyqtSignal]
    showPreviousResults: typing.ClassVar[QtCore.pyqtSignal]
    runSelected: typing.ClassVar[QtCore.pyqtSignal]
    runFromHere: typing.ClassVar[QtCore.pyqtSignal]
    def results(self) -> _core.QgsProcessingModelChildAlgorithmResult: ...
    def setResults(self, results: _core.QgsProcessingModelChildAlgorithmResult) -> None: ...
    def canDeleteComponent(self) -> bool: ...
    def contextMenuEvent(self, event: QtWidgets.QGraphicsSceneContextMenuEvent|None) -> None: ...


class QgsModelOutputGraphicItem(QgsModelComponentGraphicItem):

    def __init__(self, output: _core.QgsProcessingModelOutput|None, model: _core.QgsProcessingModelAlgorithm|None, parent: QtWidgets.QGraphicsItem|None) -> None: ...

    def deleteComponent(self) -> None: ...
    def updateStoredComponentPosition(self, pos: QtCore.QPointF, size: QtCore.QSizeF) -> None: ...
    def iconPicture(self) -> QtGui.QPicture: ...
    def textColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def strokeColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def fillColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def canDeleteComponent(self) -> bool: ...


class QgsModelCommentGraphicItem(QgsModelComponentGraphicItem):

    def __init__(self, comment: _core.QgsProcessingModelComment|None, parentItem: QgsModelComponentGraphicItem|None, model: _core.QgsProcessingModelAlgorithm|None, parent: QtWidgets.QGraphicsItem|None) -> None: ...

    def editComponent(self) -> None: ...
    def deleteComponent(self) -> None: ...
    def updateStoredComponentPosition(self, pos: QtCore.QPointF, size: QtCore.QSizeF) -> None: ...
    def strokeStyle(self, state: QgsModelComponentGraphicItem.State) -> QtCore.Qt.PenStyle: ...
    def textColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def strokeColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def fillColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def parentComponentItem(self) -> QgsModelComponentGraphicItem|None: ...
    def canDeleteComponent(self) -> bool: ...
    def contextMenuEvent(self, event: QtWidgets.QGraphicsSceneContextMenuEvent|None) -> None: ...


class QgsModelGroupBoxGraphicItem(QgsModelComponentGraphicItem):

    def __init__(self, box: _core.QgsProcessingModelGroupBox|None, model: _core.QgsProcessingModelAlgorithm|None, parent: QtWidgets.QGraphicsItem|None) -> None: ...

    def editComponent(self) -> None: ...
    def deleteComponent(self) -> None: ...
    def updateStoredComponentPosition(self, pos: QtCore.QPointF, size: QtCore.QSizeF) -> None: ...
    def titleAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def strokeStyle(self, state: QgsModelComponentGraphicItem.State) -> QtCore.Qt.PenStyle: ...
    def textColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def strokeColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def fillColor(self, state: QgsModelComponentGraphicItem.State) -> QtGui.QColor: ...
    def applyEdit(self, groupBox: _core.QgsProcessingModelGroupBox) -> None: ...
    def canDeleteComponent(self) -> bool: ...
    def contextMenuEvent(self, event: QtWidgets.QGraphicsSceneContextMenuEvent|None) -> None: ...


class QgsProcessingModelConfigWidgetFactory(QtCore.QObject):

    def __init__(self) -> None: ...

    def createWidget(self, component: _core.QgsProcessingModelComponent|None, context: _core.QgsProcessingContext, widgetContext: QgsProcessingParameterWidgetContext) -> QgsProcessingModelConfigWidget|None: ...
    def supportsComponent(self, component: _core.QgsProcessingModelComponent|None) -> bool: ...


class QgsModelDesignerDialog(QtWidgets.QMainWindow):

    class SaveAction(enum.Enum):
        SaveAsFile = ... # type: QgsModelDesignerDialog.SaveAction
        SaveInProject = ... # type: QgsModelDesignerDialog.SaveAction

    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def setModelName(self, name: str|None) -> None: ...
    def setLastRunResult(self, result: _core.QgsProcessingModelResult) -> None: ...
    def checkForUnsavedChanges(self) -> bool: ...
    def validateSave(self, action: 'QgsModelDesignerDialog.SaveAction') -> bool: ...
    def setDirty(self, dirty: bool) -> None: ...
    def view(self) -> 'QgsModelGraphicsView|None': ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def actionRun(self) -> QtGui.QAction|None: ...
    def actionSaveInProject(self) -> QtGui.QAction|None: ...
    def actionOpen(self) -> QtGui.QAction|None: ...
    def toolbar(self) -> QtWidgets.QToolBar|None: ...
    def registerProcessingContextGenerator(self, generator: QgsProcessingContextGenerator|None) -> None: ...
    def createWidgetContext(self) -> QgsProcessingParameterWidgetContext: ...
    def createExecutionDialog(self) -> QgsProcessingAlgorithmDialogBase|None: ...
    def saveModel(self, saveAs: bool = ...) -> bool: ...
    def exportAsScriptAlgorithm(self) -> None: ...
    def addInput(self, inputId: str|None, pos: QtCore.QPointF) -> None: ...
    def addAlgorithm(self, algorithmId: str|None, pos: QtCore.QPointF) -> None: ...
    def repaintModel(self, showControls: bool = ...) -> None: ...
    def activate(self) -> None: ...
    def modelScene(self) -> 'QgsModelGraphicsScene|None': ...
    def setModelScene(self, scene: 'QgsModelGraphicsScene|None') -> None: ...
    def loadModel(self, path: str|None) -> None: ...
    def setModel(self, model: _core.QgsProcessingModelAlgorithm|None) -> None: ...
    def model(self) -> _core.QgsProcessingModelAlgorithm|None: ...
    def abortUndoCommand(self) -> None: ...
    def endUndoCommand(self) -> None: ...
    def beginUndoCommand(self, text: str|None, id: str|None = ...) -> None: ...
    def closeEvent(self, event: QtGui.QCloseEvent|None) -> None: ...


class QgsModelChildDependenciesWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None, model: _core.QgsProcessingModelAlgorithm|None, childId: str|None) -> None: ...

    def setValue(self, value: collections.abc.Iterable[_core.QgsProcessingModelChildDependency]) -> None: ...
    def value(self) -> list[_core.QgsProcessingModelChildDependency]: ...


class QgsModelDesignerFlatButtonGraphicItem(QtWidgets.QGraphicsObject):

    def __init__(self, parent: QtWidgets.QGraphicsItem|None, picture: QtGui.QPicture, position: QtCore.QPointF, size: QtCore.QSizeF = ...) -> None: ...

    def setPicture(self, picture: QtGui.QPicture) -> None: ...
    clicked: typing.ClassVar[QtCore.pyqtSignal]
    def view(self) -> 'QgsModelGraphicsView|None': ...
    def setPosition(self, position: QtCore.QPointF) -> None: ...
    def position(self) -> QtCore.QPointF: ...
    def mousePressEvent(self, event: QtWidgets.QGraphicsSceneMouseEvent|None) -> None: ...
    def hoverLeaveEvent(self, event: QtWidgets.QGraphicsSceneHoverEvent|None) -> None: ...
    def hoverEnterEvent(self, event: QtWidgets.QGraphicsSceneHoverEvent|None) -> None: ...
    def boundingRect(self) -> QtCore.QRectF: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...


class QgsModelDesignerFoldButtonGraphicItem(QgsModelDesignerFlatButtonGraphicItem):

    def __init__(self, parent: QtWidgets.QGraphicsItem|None, folded: bool, position: QtCore.QPointF, size: QtCore.QSizeF = ...) -> None: ...

    folded: typing.ClassVar[QtCore.pyqtSignal]
    def mousePressEvent(self, event: QtWidgets.QGraphicsSceneMouseEvent|None) -> None: ...


class QgsModelDesignerSocketGraphicItem(QgsModelDesignerFlatButtonGraphicItem):

    def __init__(self, parent: QgsModelComponentGraphicItem|None, component: _core.QgsProcessingModelComponent|None, index: int, position: QtCore.QPointF, edge: QtCore.Qt.Edge, size: QtCore.QSizeF = ...) -> None: ...

    def isDefaultParameterValue(self) -> bool: ...
    def socketColor(self) -> QtGui.QColor: ...
    def componentItem(self) -> QgsModelComponentGraphicItem|None: ...
    def component(self) -> _core.QgsProcessingModelComponent|None: ...
    def isInput(self) -> bool: ...
    def edge(self) -> QtCore.Qt.Edge: ...
    def index(self) -> int: ...
    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...


class QgsModelGraphicsScene(QtWidgets.QGraphicsScene):

    class Flag(enum.IntEnum):
        FlagHideControls = ... # type: QgsModelGraphicsScene.Flag
        FlagHideComments = ... # type: QgsModelGraphicsScene.Flag
        FlagHideFeatureCount = ... # type: QgsModelGraphicsScene.Flag

    class ZValues(enum.IntEnum):
        GroupBox = ... # type: QgsModelGraphicsScene.ZValues
        ArrowLink = ... # type: QgsModelGraphicsScene.ZValues
        ArrowDecoration = ... # type: QgsModelGraphicsScene.ZValues
        ModelComponent = ... # type: QgsModelGraphicsScene.ZValues
        MouseHandles = ... # type: QgsModelGraphicsScene.ZValues
        RubberBand = ... # type: QgsModelGraphicsScene.ZValues
        ZSnapIndicator = ... # type: QgsModelGraphicsScene.ZValues

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def createGroupBoxGraphicItem(self, model: _core.QgsProcessingModelAlgorithm|None, box: _core.QgsProcessingModelGroupBox|None) -> QgsModelComponentGraphicItem|None: ...
    def createCommentGraphicItem(self, model: _core.QgsProcessingModelAlgorithm|None, comment: _core.QgsProcessingModelComment|None, parentItem: QgsModelComponentGraphicItem|None) -> QgsModelComponentGraphicItem|None: ...
    def createOutputGraphicItem(self, model: _core.QgsProcessingModelAlgorithm|None, output: _core.QgsProcessingModelOutput|None) -> QgsModelComponentGraphicItem|None: ...
    def createChildAlgGraphicItem(self, model: _core.QgsProcessingModelAlgorithm|None, child: _core.QgsProcessingModelChildAlgorithm|None) -> QgsModelChildAlgorithmGraphicItem|None: ...
    def createParameterGraphicItem(self, model: _core.QgsProcessingModelAlgorithm|None, param: _core.QgsProcessingModelParameter|None) -> QgsModelComponentGraphicItem|None: ...
    showChildAlgorithmLog: typing.ClassVar[QtCore.pyqtSignal]
    showChildAlgorithmOutputs: typing.ClassVar[QtCore.pyqtSignal]
    runFromChild: typing.ClassVar[QtCore.pyqtSignal]
    runSelected: typing.ClassVar[QtCore.pyqtSignal]
    selectedItemChanged: typing.ClassVar[QtCore.pyqtSignal]
    componentChanged: typing.ClassVar[QtCore.pyqtSignal]
    componentAboutToChange: typing.ClassVar[QtCore.pyqtSignal]
    rebuildRequired: typing.ClassVar[QtCore.pyqtSignal]
    def updateBounds(self) -> None: ...
    def requestRebuildRequired(self) -> None: ...
    def showWarning(self, shortMessage: str|None, title: str|None, longMessage: str|None, level: _core.Qgis.MessageLevel = ...) -> None: ...
    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def setLastRunResult(self, result: _core.QgsProcessingModelResult, context: _core.QgsProcessingContext) -> None: ...
    def setSelectedItem(self, item: QgsModelComponentGraphicItem|None) -> None: ...
    def deselectAll(self) -> None: ...
    def selectAll(self) -> None: ...
    def outputItem(self, childId: str|None, childOutputName: str|None) -> QgsModelComponentGraphicItem|None: ...
    def parameterItem(self, name: str|None) -> QgsModelComponentGraphicItem|None: ...
    def childAlgorithmItem(self, childId: str|None) -> QgsModelChildAlgorithmGraphicItem|None: ...
    def groupBoxItem(self, uuid: str|None) -> QgsModelComponentGraphicItem|None: ...
    def componentItemAt(self, position: QtCore.QPointF) -> QgsModelComponentGraphicItem|None: ...
    def selectedComponentItems(self) -> list[QgsModelComponentGraphicItem]: ...
    def createItems(self, model: _core.QgsProcessingModelAlgorithm|None, context: _core.QgsProcessingContext) -> None: ...
    def mousePressEvent(self, event: QtWidgets.QGraphicsSceneMouseEvent|None) -> None: ...
    def flags(self) -> 'QgsModelGraphicsScene.Flag': ...
    def setFlag(self, flag: 'QgsModelGraphicsScene.Flag', on: bool = ...) -> None: ...
    def setFlags(self, flags: 'QgsModelGraphicsScene.Flag') -> None: ...
    def setModel(self, model: _core.QgsProcessingModelAlgorithm|None) -> None: ...
    def model(self) -> _core.QgsProcessingModelAlgorithm|None: ...


class QgsModelGraphicsView(QtWidgets.QGraphicsView):

    class PasteMode(enum.IntEnum):
        PasteModeCursor = ... # type: QgsModelGraphicsView.PasteMode
        PasteModeCenter = ... # type: QgsModelGraphicsView.PasteMode
        PasteModeInPlace = ... # type: QgsModelGraphicsView.PasteMode

    class ClipboardOperation(enum.IntEnum):
        ClipboardCut = ... # type: QgsModelGraphicsView.ClipboardOperation
        ClipboardCopy = ... # type: QgsModelGraphicsView.ClipboardOperation

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    deleteSelectedItems: typing.ClassVar[QtCore.pyqtSignal]
    commandAborted: typing.ClassVar[QtCore.pyqtSignal]
    commandEnded: typing.ClassVar[QtCore.pyqtSignal]
    commandBegun: typing.ClassVar[QtCore.pyqtSignal]
    macroCommandEnded: typing.ClassVar[QtCore.pyqtSignal]
    macroCommandStarted: typing.ClassVar[QtCore.pyqtSignal]
    willBeDeleted: typing.ClassVar[QtCore.pyqtSignal]
    itemFocused: typing.ClassVar[QtCore.pyqtSignal]
    inputDropped: typing.ClassVar[QtCore.pyqtSignal]
    algorithmDropped: typing.ClassVar[QtCore.pyqtSignal]
    def snapSelected(self) -> None: ...
    def pasteItems(self, mode: 'QgsModelGraphicsView.PasteMode') -> None: ...
    def copyItems(self, items: collections.abc.Iterable[QgsModelComponentGraphicItem], operation: 'QgsModelGraphicsView.ClipboardOperation') -> None: ...
    def copySelectedItems(self, operation: 'QgsModelGraphicsView.ClipboardOperation') -> None: ...
    def abortCommand(self) -> None: ...
    def endCommand(self) -> None: ...
    def beginCommand(self, text: str|None) -> None: ...
    def endMacroCommand(self) -> None: ...
    def startMacroCommand(self, text: str|None) -> None: ...
    def modelScene(self) -> QgsModelGraphicsScene|None: ...
    def setModelScene(self, scene: QgsModelGraphicsScene|None) -> None: ...
    def keyReleaseEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def mouseDoubleClickEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseReleaseEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def wheelEvent(self, event: QtGui.QWheelEvent|None) -> None: ...
    def dragMoveEvent(self, event: QtGui.QDragMoveEvent|None) -> None: ...
    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...


class QgsModelViewSnapMarker(QtWidgets.QGraphicsRectItem):

    def __init__(self) -> None: ...

    def paint(self, painter: QtGui.QPainter|None, option: QtWidgets.QStyleOptionGraphicsItem|None, widget: QtWidgets.QWidget|None = ...) -> None: ...


class QgsCoordinateBoundsPreviewMapWidget(QgsMapCanvas):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPreviewRect(self, rect: _core.QgsRectangle) -> None: ...
    def canvasRect(self) -> _core.QgsRectangle: ...
    def setCanvasRect(self, rect: _core.QgsRectangle) -> None: ...


class QgsCoordinateOperationWidget(QtWidgets.QWidget):

    class OperationDetails(PyQt6.sip.wrapper):

        allowFallback = ... # type: bool
        destinationTransformId = ... # type: int
        isAvailable = ... # type: bool
        proj = ... # type: str|None
        sourceTransformId = ... # type: int

        @typing.overload
        def __init__(self) -> None: ...
        @typing.overload
        def __init__(self, a0: 'QgsCoordinateOperationWidget.OperationDetails') -> None: ...

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    operationDoubleClicked: typing.ClassVar[QtCore.pyqtSignal]
    operationChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setShowFallbackOption(self, visible: bool) -> None: ...
    def setSelectedOperationUsingContext(self, context: _core.QgsCoordinateTransformContext) -> None: ...
    def setSelectedOperation(self, operation: 'QgsCoordinateOperationWidget.OperationDetails') -> None: ...
    def selectedOperation(self) -> 'QgsCoordinateOperationWidget.OperationDetails': ...
    def defaultOperation(self) -> 'QgsCoordinateOperationWidget.OperationDetails': ...
    def availableOperations(self) -> list['QgsCoordinateOperationWidget.OperationDetails']: ...
    def hasSelection(self) -> bool: ...
    def makeDefaultSelected(self) -> bool: ...
    def setShowMakeDefault(self, show: bool) -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def setDestinationCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setSourceCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def destinationCrs(self) -> _core.QgsCoordinateReferenceSystem: ...
    def sourceCrs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsCoordinateReferenceSystemModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        NodeType = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Name = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        AuthId = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Deprecated = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Type = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        GroupId = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Wkt = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Proj = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Group = ... # type: QgsCoordinateReferenceSystemModel.CustomRole
        Projection = ... # type: QgsCoordinateReferenceSystemModel.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def authIdToIndex(self, authId: str|None) -> QtCore.QModelIndex: ...
    def addCustomCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> QtCore.QModelIndex: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, a0: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsCoordinateReferenceSystemProxyModel(QtCore.QSortFilterProxyModel):

    class Filter(enum.IntEnum):
        FilterHorizontal = ... # type: QgsCoordinateReferenceSystemProxyModel.Filter
        FilterVertical = ... # type: QgsCoordinateReferenceSystemProxyModel.Filter
        FilterCompound = ... # type: QgsCoordinateReferenceSystemProxyModel.Filter

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def lessThan(self, left: QtCore.QModelIndex, right: QtCore.QModelIndex) -> bool: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def filterDeprecated(self) -> bool: ...
    def setFilterDeprecated(self, filter: bool) -> None: ...
    def filterAuthIds(self) -> set[str]: ...
    def setFilterAuthIds(self, filter: collections.abc.Iterable[str|None]) -> None: ...
    def filterString(self) -> str: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def filters(self) -> 'QgsCoordinateReferenceSystemProxyModel.Filter': ...
    def setFilters(self, filters: 'QgsCoordinateReferenceSystemProxyModel.Filter') -> None: ...
    def coordinateReferenceSystemModel(self) -> QgsCoordinateReferenceSystemModel|None: ...


class QgsCrsDefinitionWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDefinitionString(self, definition: str|None) -> None: ...
    def definitionString(self) -> str: ...
    def setFormat(self, format: _core.Qgis.CrsDefinitionFormat) -> None: ...
    def format(self) -> _core.Qgis.CrsDefinitionFormat: ...
    @typing.overload
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    @typing.overload
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem, nativeFormat: _core.Qgis.CrsDefinitionFormat) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsCrsSelectionWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., filters: QgsCoordinateReferenceSystemProxyModel.Filter = ...) -> None: ...

    hasValidSelectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    crsDoubleClicked: typing.ClassVar[QtCore.pyqtSignal]
    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setOgcWmsCrsFilter(self, crsFilter: collections.abc.Iterable[str|None]) -> None: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setFilters(self, filters: QgsCoordinateReferenceSystemProxyModel.Filter) -> None: ...
    def filters(self) -> QgsCoordinateReferenceSystemProxyModel.Filter: ...
    def hasValidSelection(self) -> bool: ...
    def setNotSetText(self, text: str|None, description: str|None = ...) -> None: ...
    def showNoCrs(self) -> bool: ...
    def setShowNoCrs(self, show: bool) -> None: ...
    def setMessage(self, message: str|None) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsProjectionSelectionDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., filters: QgsCoordinateReferenceSystemProxyModel.Filter = ...) -> None: ...

    def setOgcWmsCrsFilter(self, crsFilter: collections.abc.Iterable[str|None]) -> None: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setFilters(self, filters: QgsCoordinateReferenceSystemProxyModel.Filter) -> None: ...
    def filters(self) -> QgsCoordinateReferenceSystemProxyModel.Filter: ...
    def hasValidSelection(self) -> bool: ...
    def setRequireValidSelection(self) -> None: ...
    def setNotSetText(self, text: str|None, description: str|None = ...) -> None: ...
    def showNoProjection(self) -> bool: ...
    def setShowNoProjection(self, show: bool) -> None: ...
    def showNoCrsForLayerMessage(self) -> None: ...
    def setMessage(self, message: str|None) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsProjectionSelectionTreeWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., filters: QgsCoordinateReferenceSystemProxyModel.Filter = ...) -> None: ...

    def eventFilter(self, obj: QtCore.QObject|None, ev: QtCore.QEvent|None) -> bool: ...
    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    hasValidSelectionChanged: typing.ClassVar[QtCore.pyqtSignal]
    projectionDoubleClicked: typing.ClassVar[QtCore.pyqtSignal]
    initialized: typing.ClassVar[QtCore.pyqtSignal]
    crsSelected: typing.ClassVar[QtCore.pyqtSignal]
    def clearRecentCrs(self) -> None: ...
    @deprecated("""""")
    def pushProjectionToFront(self) -> None: ...
    def setOgcWmsCrsFilter(self, crsFilter: collections.abc.Iterable[str|None]) -> None: ...
    def setPreviewRect(self, rect: _core.QgsRectangle) -> None: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setFilters(self, filters: QgsCoordinateReferenceSystemProxyModel.Filter) -> None: ...
    def filters(self) -> QgsCoordinateReferenceSystemProxyModel.Filter: ...
    def previewRect(self) -> _core.QgsRectangle: ...
    def hasValidSelection(self) -> bool: ...
    def showBoundsMap(self) -> bool: ...
    def setNotSetText(self, text: str|None) -> None: ...
    def showNoProjection(self) -> bool: ...
    def setShowBoundsMap(self, show: bool) -> None: ...
    def setShowNoProjection(self, show: bool) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsProjectionSelectionWidget(QtWidgets.QWidget):

    class CrsOption(enum.IntEnum):
        Invalid = ... # type: QgsProjectionSelectionWidget.CrsOption
        LayerCrs = ... # type: QgsProjectionSelectionWidget.CrsOption
        ProjectCrs = ... # type: QgsProjectionSelectionWidget.CrsOption
        CurrentCrs = ... # type: QgsProjectionSelectionWidget.CrsOption
        DefaultCrs = ... # type: QgsProjectionSelectionWidget.CrsOption
        RecentCrs = ... # type: QgsProjectionSelectionWidget.CrsOption
        CrsNotSet = ... # type: QgsProjectionSelectionWidget.CrsOption

    def __init__(self, parent: QtWidgets.QWidget|None = ..., filters: QgsCoordinateReferenceSystemProxyModel.Filter = ...) -> None: ...

    def dropEvent(self, event: QtGui.QDropEvent|None) -> None: ...
    def dragLeaveEvent(self, event: QtGui.QDragLeaveEvent|None) -> None: ...
    def dragEnterEvent(self, event: QtGui.QDragEnterEvent|None) -> None: ...
    def selectCrs(self) -> None: ...
    def setLayerCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    def setCrs(self, crs: _core.QgsCoordinateReferenceSystem) -> None: ...
    cleared: typing.ClassVar[QtCore.pyqtSignal]
    crsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setFilters(self, filters: QgsCoordinateReferenceSystemProxyModel.Filter) -> None: ...
    def filters(self) -> QgsCoordinateReferenceSystemProxyModel.Filter: ...
    def setFilter(self, crses: collections.abc.Iterable[_core.QgsCoordinateReferenceSystem]) -> None: ...
    def dialogTitle(self) -> str: ...
    def setDialogTitle(self, title: str|None) -> None: ...
    def sourceEnsemble(self) -> str: ...
    def setSourceEnsemble(self, ensemble: str|None) -> None: ...
    def setShowAccuracyWarnings(self, show: bool) -> None: ...
    def showAccuracyWarnings(self) -> bool: ...
    def setMessage(self, text: str|None) -> None: ...
    def setNotSetText(self, text: str|None) -> None: ...
    def optionVisible(self, option: 'QgsProjectionSelectionWidget.CrsOption') -> bool: ...
    def setOptionVisible(self, option: 'QgsProjectionSelectionWidget.CrsOption', visible: bool) -> None: ...
    def crs(self) -> _core.QgsCoordinateReferenceSystem: ...


class QgsRecentCoordinateReferenceSystemsModel(QtCore.QAbstractItemModel):

    class CustomRole(enum.IntEnum):
        Crs = ... # type: QgsRecentCoordinateReferenceSystemsModel.CustomRole
        AuthId = ... # type: QgsRecentCoordinateReferenceSystemsModel.CustomRole

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def crs(self, index: QtCore.QModelIndex) -> _core.QgsCoordinateReferenceSystem: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, a0: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsRecentCoordinateReferenceSystemsProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def crs(self, index: QtCore.QModelIndex) -> _core.QgsCoordinateReferenceSystem: ...
    def filterAcceptsRow(self, sourceRow: int, sourceParent: QtCore.QModelIndex) -> bool: ...
    def filters(self) -> QgsCoordinateReferenceSystemProxyModel.Filter: ...
    def setFilterString(self, filter: str|None) -> None: ...
    def setFilterDeprecated(self, filter: bool) -> None: ...
    def setFilters(self, filters: QgsCoordinateReferenceSystemProxyModel.Filter) -> None: ...
    def recentCoordinateReferenceSystemsModel(self) -> QgsRecentCoordinateReferenceSystemsModel|None: ...


class QgsAbstractDbSourceSelect(QgsAbstractDataSourceWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., widgetMode: _core.QgsProviderRegistry.WidgetMode = ...) -> None: ...

    def treeviewDoubleClicked(self, index: QtCore.QModelIndex) -> None: ...
    def treeviewClicked(self, index: QtCore.QModelIndex) -> None: ...
    def setSql(self, index: QtCore.QModelIndex) -> None: ...
    def storeSettings(self) -> None: ...
    def proxyModel(self) -> QtCore.QSortFilterProxyModel|None: ...
    def init(self, model: _core.QgsAbstractDbTableModel|None, delegate: QtWidgets.QItemDelegate|None = ...) -> None: ...
    def settingPath(self) -> str: ...


class QgsGdalCredentialOptionsWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    optionsChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCredentialOptions(self, options: dict[str|None, typing.Any]) -> None: ...
    def credentialOptions(self) -> dict[str, typing.Any]: ...
    def setHandler(self, handler: str|None) -> None: ...


class QgsRasterAttributeTableWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., rasterLayer: _core.QgsRasterLayer|None = ..., bandNumber: int = ...) -> None: ...

    def setDockMode(self, dockMode: bool) -> None: ...
    def setEditable(self, editable: bool, allowCancel: bool = ...) -> bool: ...
    def saveChanges(self) -> None: ...
    rendererChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...
    def isDirty(self) -> bool: ...
    def setRasterLayer(self, rasterLayer: _core.QgsRasterLayer|None, bandNumber: int = ...) -> None: ...


class QgsRasterAttributeTableDialog(QtWidgets.QDialog):

    def __init__(self, rasterLayer: _core.QgsRasterLayer|None, bandNumber: int = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def reject(self) -> None: ...


class QgsColorRampShaderWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def populateColormapTreeWidget(self, colorRampItems: collections.abc.Iterable[_core.QgsColorRampShader.ColorRampItem]) -> None: ...
    def loadMinimumMaximumFromTree(self) -> None: ...
    def classify(self) -> None: ...
    classificationModeChanged: typing.ClassVar[QtCore.pyqtSignal]
    widgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    minimumMaximumChangedFromTree: typing.ClassVar[QtCore.pyqtSignal]
    def setFromShader(self, colorRampShader: _core.QgsColorRampShader) -> None: ...
    def shader(self) -> _core.QgsColorRampShader: ...
    def maximum(self) -> float: ...
    def minimum(self) -> float: ...
    def setMinimumMaximum(self, minimum: float, maximum: float) -> None: ...
    def setMinimumMaximumAndClassify(self, minimum: float, maximum: float) -> None: ...
    def setExtent(self, extent: _core.QgsRectangle) -> None: ...
    def setRasterBand(self, band: int) -> None: ...
    def setRasterDataProvider(self, dp: _core.QgsRasterDataProvider|None) -> None: ...
    def initializeForUseWithRasterLayer(self) -> None: ...


class QgsRasterRendererWidget(QtWidgets.QWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> None: ...

    widgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setContrastEnhancementAlgorithm(self, algorithm: _core.QgsContrastEnhancement.ContrastEnhancementAlgorithm) -> None: ...
    def contrastEnhancementAlgorithm(self) -> _core.QgsContrastEnhancement.ContrastEnhancementAlgorithm: ...
    def minMaxWidget(self) -> 'QgsRasterMinMaxWidget|None': ...
    def doComputations(self) -> None: ...
    def selectedBand(self, index: int = ...) -> int: ...
    def setStdDev(self, value: str|None) -> None: ...
    def stdDev(self) -> str: ...
    def setMax(self, value: str|None, index: int = ...) -> None: ...
    def setMin(self, value: str|None, index: int = ...) -> None: ...
    def max(self, index: int = ...) -> str: ...
    def min(self, index: int = ...) -> str: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def rasterLayer(self) -> _core.QgsRasterLayer|None: ...
    def setRasterLayer(self, layer: _core.QgsRasterLayer|None) -> None: ...
    def renderer(self) -> _core.QgsRasterRenderer|None: ...


class QgsHillshadeRendererWidget(QgsRasterRendererWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle = ...) -> None: ...

    def setMultiDirectional(self, isMultiDirectional: bool) -> None: ...
    def setZFactor(self, zfactor: float) -> None: ...
    def setAzimuth(self, azimuth: float) -> None: ...
    def setAltitude(self, altitude: float) -> None: ...
    def multiDirectional(self) -> bool: ...
    def zFactor(self) -> float: ...
    def altitude(self) -> float: ...
    def azimuth(self) -> float: ...
    def setFromRenderer(self, renderer: _core.QgsRasterRenderer|None) -> None: ...
    def renderer(self) -> _core.QgsRasterRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> QgsRasterRendererWidget|None: ...


class QgsMultiBandColorRendererWidget(QgsRasterRendererWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle = ...) -> None: ...

    def loadMinMax(self, bandNo: int, min: float, max: float) -> None: ...
    def minMaxWidget(self) -> 'QgsRasterMinMaxWidget|None': ...
    def doComputations(self) -> None: ...
    def setContrastEnhancementAlgorithm(self, algorithm: _core.QgsContrastEnhancement.ContrastEnhancementAlgorithm) -> None: ...
    def contrastEnhancementAlgorithm(self) -> _core.QgsContrastEnhancement.ContrastEnhancementAlgorithm: ...
    def selectedBand(self, index: int = ...) -> int: ...
    def setMax(self, value: str|None, index: int = ...) -> None: ...
    def setMin(self, value: str|None, index: int = ...) -> None: ...
    def max(self, index: int = ...) -> str: ...
    def min(self, index: int = ...) -> str: ...
    def setFromRenderer(self, r: _core.QgsRasterRenderer|None) -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def renderer(self) -> _core.QgsRasterRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> QgsRasterRendererWidget|None: ...


class QgsPalettedRendererWidget(QgsRasterRendererWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle = ...) -> None: ...

    def setFromRenderer(self, r: _core.QgsRasterRenderer|None) -> None: ...
    def renderer(self) -> _core.QgsRasterRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> QgsRasterRendererWidget|None: ...


class QgsRasterAttributeTableModel(QtCore.QAbstractTableModel):

    def __init__(self, rat: _core.QgsRasterAttributeTable|None, parent: QtCore.QObject|None = ...) -> None: ...

    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...
    def removeRow(self, position: int) -> typing.Tuple[bool, str]: ...
    def insertRamp(self, position: int) -> typing.Tuple[bool, str]: ...
    def insertColor(self, position: int) -> typing.Tuple[bool, str]: ...
    def insertRow(self, position: int, rowData: collections.abc.Iterable[typing.Any]) -> typing.Tuple[bool, str]: ...
    def removeColorOrRamp(self) -> typing.Tuple[bool, str]: ...
    def removeField(self, position: int) -> typing.Tuple[bool, str]: ...
    @typing.overload
    def insertField(self, position: int, name: str|None, usage: _core.Qgis.RasterAttributeTableFieldUsage, type: QtCore.QMetaType.Type) -> typing.Tuple[bool, str]: ...
    @typing.overload
    @deprecated("""""")
    def insertField(self, position: int, name: str|None, usage: _core.Qgis.RasterAttributeTableFieldUsage, type: typing.Any) -> typing.Tuple[bool, str]: ...
    def isDirty(self) -> bool: ...
    def isValid(self) -> typing.Tuple[bool, str]: ...
    def headerTooltip(self, section: int) -> str: ...
    def headerNames(self) -> list[str]: ...
    def hasRamp(self) -> bool: ...
    def hasColor(self) -> bool: ...
    def setEditable(self, editable: bool) -> None: ...
    def editable(self) -> bool: ...


class QgsRasterBandComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    bandChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setBand(self, band: int) -> None: ...
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    @staticmethod
    def displayBandName(provider: _core.QgsRasterDataProvider|None, band: int) -> str: ...
    def setShowNotSetOption(self, show: bool, string: str|None = ...) -> None: ...
    def isShowingNotSetOption(self) -> bool: ...
    def currentBand(self) -> int: ...
    def layer(self) -> _core.QgsRasterLayer|None: ...


class QgsRasterContourRendererWidget(QgsRasterRendererWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle = ...) -> None: ...

    def renderer(self) -> _core.QgsRasterRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> QgsRasterRendererWidget|None: ...


class QgsRasterHistogramWidget(QgsMapLayerConfigWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def apply(self) -> None: ...
    def refreshHistogram(self) -> None: ...
    def setSelectedBand(self, index: int) -> None: ...
    def histoAction(self, actionName: str|None, actionFlag: bool = ...) -> None: ...
    def computeHistogram(self, forceComputeFlag: bool) -> bool: ...
    def setActive(self, activeFlag: bool) -> None: ...
    def setRendererWidget(self, name: str|None, rendererWidget: QgsRasterRendererWidget|None = ...) -> None: ...
    def histoSaveAsImage(self, filename: str|None, width: int = ..., height: int = ..., quality: int = ...) -> bool: ...


class QgsRasterMinMaxWidget(QtWidgets.QWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    load: typing.ClassVar[QtCore.pyqtSignal]
    widgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setCollapsed(self, b: bool) -> None: ...
    def isCollapsed(self) -> bool: ...
    def userHasSetManualMinMaxValues(self) -> None: ...
    def doComputations(self) -> None: ...
    def hideUpdatedExtent(self) -> None: ...
    def minMaxOrigin(self) -> _core.QgsRasterMinMaxOrigin: ...
    def setFromMinMaxOrigin(self, a0: _core.QgsRasterMinMaxOrigin) -> None: ...
    def sampleSize(self) -> int: ...
    def extent(self) -> _core.QgsRectangle: ...
    def setBands(self, bands: collections.abc.Iterable[int]) -> None: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def setExtent(self, extent: _core.QgsRectangle) -> None: ...


class QgsRasterTransparencyWidget(QgsMapLayerConfigWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def apply(self) -> None: ...
    def syncToLayer(self) -> None: ...
    def pixelSelectorTool(self) -> QgsMapToolEmitPoint|None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...


class QgsRendererRasterPropertiesWidget(QgsMapLayerConfigWidget):

    def __init__(self, layer: _core.QgsMapLayer|None, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def syncToLayer(self, layer: _core.QgsRasterLayer|None) -> None: ...
    def apply(self) -> None: ...
    def rendererChanged(self) -> None: ...
    def currentRenderWidget(self) -> QgsRasterRendererWidget|None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...


class QgsSingleBandGrayRendererWidget(QgsRasterRendererWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle = ...) -> None: ...

    def loadMinMax(self, bandNo: int, min: float, max: float) -> None: ...
    def minMaxWidget(self) -> QgsRasterMinMaxWidget|None: ...
    def doComputations(self) -> None: ...
    def setContrastEnhancementAlgorithm(self, algorithm: _core.QgsContrastEnhancement.ContrastEnhancementAlgorithm) -> None: ...
    def contrastEnhancementAlgorithm(self) -> _core.QgsContrastEnhancement.ContrastEnhancementAlgorithm: ...
    def selectedBand(self, index: int = ...) -> int: ...
    def setMax(self, value: str|None, index: int = ...) -> None: ...
    def setMin(self, value: str|None, index: int = ...) -> None: ...
    def max(self, index: int = ...) -> str: ...
    def min(self, index: int = ...) -> str: ...
    def setFromRenderer(self, r: _core.QgsRasterRenderer|None) -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def renderer(self) -> _core.QgsRasterRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> QgsRasterRendererWidget|None: ...


class QgsSingleBandPseudoColorRendererWidget(QgsRasterRendererWidget):

    def __init__(self, layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle = ...) -> None: ...

    def loadMinMaxFromTree(self, min: float, max: float) -> None: ...
    def loadMinMax(self, bandNo: int, min: float, max: float) -> None: ...
    def selectedBand(self, index: int = ...) -> int: ...
    def setMax(self, value: str|None, index: int = ...) -> None: ...
    def setMin(self, value: str|None, index: int = ...) -> None: ...
    def max(self, index: int = ...) -> str: ...
    def min(self, index: int = ...) -> str: ...
    def setFromRenderer(self, r: _core.QgsRasterRenderer|None) -> None: ...
    def minMaxWidget(self) -> QgsRasterMinMaxWidget|None: ...
    def doComputations(self) -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...
    def renderer(self) -> _core.QgsRasterRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsRasterLayer|None, extent: _core.QgsRectangle) -> QgsRasterRendererWidget|None: ...


class QgsRasterLayerProperties(QgsLayerPropertiesDialog):

    def __init__(self, lyr: _core.QgsMapLayer|None, canvas: QgsMapCanvas|None, parent: QtWidgets.QWidget|None = ..., a3: QtCore.Qt.WindowType = ...) -> None: ...

    def rollback(self) -> None: ...
    def apply(self) -> None: ...
    def optionsStackedWidget_CurrentChanged(self, index: int) -> None: ...
    @deprecated("""""")
    def saveDefaultStyle(self) -> None: ...
    def eventFilter(self, obj: QtCore.QObject|None, ev: QtCore.QEvent|None) -> bool: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def addPropertiesPageFactory(self, factory: QgsMapLayerConfigWidgetFactory|None) -> None: ...


class QgsRasterLayerTemporalPropertiesWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., layer: _core.QgsRasterLayer|None = ...) -> None: ...

    def addWidget(self, widget: QgsMapLayerConfigWidget|None) -> None: ...
    def syncToLayer(self) -> None: ...
    def saveTemporalProperties(self) -> None: ...


class QgsFieldCalculator(QtWidgets.QDialog):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def accept(self) -> None: ...
    def changedAttributeId(self) -> int: ...


class QgsVectorLayerProperties(QgsLayerPropertiesDialog):

    def __init__(self, canvas: QgsMapCanvas|None, messageBar: QgsMessageBar|None, lyr: _core.QgsVectorLayer|None = ..., parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ...) -> None: ...

    def rollback(self) -> None: ...
    def apply(self) -> None: ...
    def syncToLayer(self) -> None: ...
    def optionsStackedWidget_CurrentChanged(self, index: int) -> None: ...
    def eventFilter(self, obj: QtCore.QObject|None, ev: QtCore.QEvent|None) -> bool: ...


class CharacterWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def paintEvent(self, event: QtGui.QPaintEvent|None) -> None: ...
    def mousePressEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def mouseMoveEvent(self, event: QtGui.QMouseEvent|None) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    characterSelected: typing.ClassVar[QtCore.pyqtSignal]
    def clearCharacter(self) -> None: ...
    def setCharacter(self, character: str) -> None: ...
    def setColumns(self, columns: int) -> None: ...
    def updateFontMerging(self, enable: bool) -> None: ...
    def setFontStyle(self, fontStyle: str|None) -> None: ...
    def setFontSize(self, fontSize: float) -> None: ...
    def setFont(self, font: QtGui.QFont) -> None: ...
    def font(self) -> QtGui.QFont: ...
    def character(self) -> str: ...
    def squareSize(self) -> int: ...
    def columns(self) -> int: ...
    def sizeHint(self) -> QtCore.QSize: ...


class QgsRendererWidget(QgsPanelWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None) -> None: ...

    def pasteSymbolToSelection(self) -> None: ...
    def paste(self) -> None: ...
    def copy(self) -> None: ...
    def changeSymbolAngle(self) -> None: ...
    def changeSymbolSize(self) -> None: ...
    def changeSymbolWidth(self) -> None: ...
    def changeSymbolUnit(self) -> None: ...
    def changeSymbolOpacity(self) -> None: ...
    def changeSymbolColor(self) -> None: ...
    def contextMenuViewCategories(self, p: QtCore.QPoint) -> None: ...
    def registerDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsFeatureRenderer.Property) -> None: ...
    def setSymbolLevels(self, levels: collections.abc.Iterable[_core.QgsLegendSymbolItem], enabled: bool) -> None: ...
    def createDataDefinedSizeLegendWidget(self, symbol: _core.QgsMarkerSymbol|None, ddsLegend: _core.QgsDataDefinedSizeLegend|None) -> 'QgsDataDefinedSizeLegendWidget|None': ...
    def refreshSymbolView(self) -> None: ...
    def selectedSymbols(self) -> list[_core.QgsSymbol]: ...
    symbolLevelsChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerVariablesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDockMode(self, dockMode: bool) -> None: ...
    def applyChanges(self) -> None: ...
    def vectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def showSymbolLevelsDialog(self, r: _core.QgsFeatureRenderer|None) -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...


class Qgs25DRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsSymbolLayerWidget(QtWidgets.QWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, parent: QtWidgets.QWidget|None, vl: _core.QgsVectorLayer|None = ...) -> None: ...

    def updateDataDefinedProperty(self) -> None: ...
    symbolChanged: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def registerDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsSymbolLayer.Property) -> None: ...
    def vectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...


class QgsArrowSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsBrushStyleComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def iconForBrush(self, style: QtCore.Qt.BrushStyle) -> QtGui.QIcon: ...
    def setBrushStyle(self, style: QtCore.Qt.BrushStyle) -> None: ...
    def brushStyle(self) -> QtCore.Qt.BrushStyle: ...


class QgsCategorizedSymbolRendererWidget(QgsRendererWidget):

    class CustomRole(enum.IntEnum):
        Value = ... # type: QgsCategorizedSymbolRendererWidget.CustomRole

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def refreshSymbolView(self) -> None: ...
    def selectedCategoryList(self) -> list[_core.QgsRendererCategory]: ...
    def selectedSymbols(self) -> list[_core.QgsSymbol]: ...
    @deprecated("""""")
    def layerUniqueValues(self, attrName: str|None) -> list[typing.Any]: ...
    def applyChangeToSymbol(self) -> None: ...
    def changeCategorySymbol(self) -> None: ...
    def changeSelectedSymbols(self) -> None: ...
    def selectedCategories(self) -> list[int]: ...
    def currentCategoryRow(self) -> int: ...
    def populateCategories(self) -> None: ...
    def updateUiFromRenderer(self) -> None: ...
    def pasteSymbolToSelection(self) -> None: ...
    def setSymbolLevels(self, levels: collections.abc.Iterable[_core.QgsLegendSymbolItem], enabled: bool) -> None: ...
    def matchToSymbolsFromXml(self) -> None: ...
    def matchToSymbolsFromLibrary(self) -> None: ...
    def rowsMoved(self) -> None: ...
    def showSymbolLevels(self) -> None: ...
    def deleteUnusedCategories(self) -> None: ...
    def deleteAllCategories(self) -> None: ...
    def deleteCategories(self) -> None: ...
    def applyColorRamp(self) -> None: ...
    def addCategories(self) -> None: ...
    def addCategory(self) -> None: ...
    def categoriesDoubleClicked(self, idx: QtCore.QModelIndex) -> None: ...
    def categoryColumnChanged(self, field: str|None) -> None: ...
    def changeCategorizedSymbol(self) -> None: ...
    def matchToSymbols(self, style: _core.QgsStyle|None) -> int: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsCptCityColorRampDialog(QtWidgets.QDialog):

    def __init__(self, ramp: _core.QgsCptCityColorRamp, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def eventFilter(self, obj: QtCore.QObject|None, event: QtCore.QEvent|None) -> bool: ...
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def saveAsGradientRamp(self) -> bool: ...
    def selectedName(self) -> str: ...
    def setRamp(self, ramp: _core.QgsCptCityColorRamp) -> None: ...
    def ramp(self) -> _core.QgsCptCityColorRamp: ...


class QgsDashSpaceWidget(QgsPanelWidget):

    def __init__(self, vectorPattern: collections.abc.Iterable[float], parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setUnit(self, unit: _core.Qgis.RenderUnit) -> None: ...
    def dashDotVector(self) -> list[float]: ...


class QgsDashSpaceDialog(QtWidgets.QDialog):

    def __init__(self, v: collections.abc.Iterable[float], parent: QtWidgets.QWidget|None = ..., f: QtCore.Qt.WindowType = ...) -> None: ...

    def setUnit(self, unit: _core.Qgis.RenderUnit) -> None: ...
    def dashDotVector(self) -> list[float]: ...


class QgsDataDefinedSizeLegendWidget(QgsPanelWidget):

    def __init__(self, ddsLegend: _core.QgsDataDefinedSizeLegend|None, ddSize: _core.QgsProperty, overrideSymbol: _core.QgsMarkerSymbol|None, canvas: QgsMapCanvas|None = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def dataDefinedSizeLegend(self) -> _core.QgsDataDefinedSizeLegend|None: ...


class QgsEllipseSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsEmbeddedSymbolRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsGraduatedHistogramWidget(QgsHistogramWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def drawHistogram(self) -> None: ...
    rangesModified: typing.ClassVar[QtCore.pyqtSignal]
    def setRenderer(self, renderer: _core.QgsGraduatedSymbolRenderer|None) -> None: ...


class QgsGraduatedSymbolRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def refreshSymbolView(self) -> None: ...
    def findSymbolForRange(self, lowerBound: float, upperBound: float, ranges: collections.abc.Iterable[_core.QgsRendererRange]) -> _core.QgsSymbol|None: ...
    def selectedSymbols(self) -> list[_core.QgsSymbol]: ...
    def applyChangeToSymbol(self) -> None: ...
    def changeSelectedSymbols(self) -> None: ...
    def changeRange(self, rangeIdx: int) -> None: ...
    def changeRangeSymbol(self, rangeIdx: int) -> None: ...
    def selectedRanges(self) -> list[_core.QgsRendererRange]: ...
    def selectedClasses(self) -> list[int]: ...
    def rowsOrdered(self) -> bool: ...
    def disconnectUpdateHandlers(self) -> None: ...
    def connectUpdateHandlers(self) -> None: ...
    def updateUiFromRenderer(self, updateCount: bool = ...) -> None: ...
    def pasteSymbolToSelection(self) -> None: ...
    def setSymbolLevels(self, levels: collections.abc.Iterable[_core.QgsLegendSymbolItem], enabled: bool) -> None: ...
    def refreshRanges(self, reset: bool) -> None: ...
    def modelDataChanged(self) -> None: ...
    def rowsMoved(self) -> None: ...
    def showSymbolLevels(self) -> None: ...
    def labelFormatChanged(self) -> None: ...
    def toggleBoundariesLink(self, linked: bool) -> None: ...
    def deleteAllClasses(self) -> None: ...
    def deleteClasses(self) -> None: ...
    def addClass(self) -> None: ...
    def changeCurrentValue(self, item: QtGui.QStandardItem|None) -> None: ...
    def rangesClicked(self, idx: QtCore.QModelIndex) -> None: ...
    def rangesDoubleClicked(self, idx: QtCore.QModelIndex) -> None: ...
    def reapplySizes(self) -> None: ...
    def reapplyColorRamp(self) -> None: ...
    def classifyGraduated(self) -> None: ...
    def graduatedColumnChanged(self, field: str|None) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsHeatmapRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsInterpolatedLineSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsInvertedPolygonRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def setDockMode(self, dockMode: bool) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsLayerPropertiesWidget(QgsPanelWidget, _core.QgsExpressionContextGenerator):

    def __init__(self, layer: _core.QgsSymbolLayer|None, symbol: _core.QgsSymbol|None, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def registerDataDefinedButton(self, button: QgsPropertyOverrideButton|None, key: _core.QgsSymbolLayer.Property) -> None: ...
    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def updateSymbolLayerWidget(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    def populateLayerTypes(self) -> None: ...
    changeLayer: typing.ClassVar[QtCore.pyqtSignal]
    changed: typing.ClassVar[QtCore.pyqtSignal]
    def emitSignalChanged(self) -> None: ...
    def layerTypeChanged(self) -> None: ...
    def setDockMode(self, dockMode: bool) -> None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...


class QgsMergedFeatureRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def setDockMode(self, dockMode: bool) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsNullSymbolRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsMaskMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsPenStyleComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def iconForPen(self, style: QtCore.Qt.PenStyle) -> QtGui.QIcon: ...
    def setPenStyle(self, style: QtCore.Qt.PenStyle) -> None: ...
    def penStyle(self) -> QtCore.Qt.PenStyle: ...


class QgsPenJoinStyleComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPenJoinStyle(self, style: QtCore.Qt.PenJoinStyle) -> None: ...
    def penJoinStyle(self) -> QtCore.Qt.PenJoinStyle: ...


class QgsPenCapStyleComboBox(QtWidgets.QComboBox):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setPenCapStyle(self, style: QtCore.Qt.PenCapStyle) -> None: ...
    def penCapStyle(self) -> QtCore.Qt.PenCapStyle: ...


class QgsPointClusterRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsPointDisplacementRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def createExpressionContext(self) -> _core.QgsExpressionContext: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsRendererPropertiesDialog(QtWidgets.QDialog):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, embedded: bool = ..., parent: QtWidgets.QWidget|None = ...) -> None: ...

    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def connectValueChanged(self, widgets: collections.abc.Iterable[QtWidgets.QWidget]) -> None: ...
    def openPanel(self, panel: QgsPanelWidget|None) -> None: ...
    def onOK(self) -> None: ...
    def apply(self) -> None: ...
    def rendererChanged(self) -> None: ...
    showPanel: typing.ClassVar[QtCore.pyqtSignal]
    widgetChanged: typing.ClassVar[QtCore.pyqtSignal]
    layerVariablesChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setDockMode(self, dockMode: bool) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...


class QgsDataDefinedValueDialog(QtWidgets.QDialog):

    def __init__(self, symbolList: collections.abc.Iterable[_core.QgsSymbol], layer: _core.QgsVectorLayer|None, label: str|None) -> None: ...

    def init(self, propertyKey: int) -> None: ...
    def dataDefinedChanged(self) -> None: ...
    def vectorLayer(self) -> _core.QgsVectorLayer|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...


class QgsDataDefinedSizeDialog(QgsDataDefinedValueDialog):

    def __init__(self, symbolList: collections.abc.Iterable[_core.QgsSymbol], layer: _core.QgsVectorLayer|None) -> None: ...

    def setDataDefined(self, symbol: _core.QgsSymbol|None, dd: _core.QgsProperty) -> None: ...
    def value(self, symbol: _core.QgsSymbol|None) -> float: ...
    def symbolDataDefined(self, symbol: _core.QgsSymbol|None) -> _core.QgsProperty: ...


class QgsDataDefinedRotationDialog(QgsDataDefinedValueDialog):

    def __init__(self, symbolList: collections.abc.Iterable[_core.QgsSymbol], layer: _core.QgsVectorLayer|None) -> None: ...

    def setDataDefined(self, symbol: _core.QgsSymbol|None, dd: _core.QgsProperty) -> None: ...
    def value(self, symbol: _core.QgsSymbol|None) -> float: ...
    def symbolDataDefined(self, symbol: _core.QgsSymbol|None) -> _core.QgsProperty: ...


class QgsDataDefinedWidthDialog(QgsDataDefinedValueDialog):

    def __init__(self, symbolList: collections.abc.Iterable[_core.QgsSymbol], layer: _core.QgsVectorLayer|None) -> None: ...

    def setDataDefined(self, symbol: _core.QgsSymbol|None, dd: _core.QgsProperty) -> None: ...
    def value(self, symbol: _core.QgsSymbol|None) -> float: ...
    def symbolDataDefined(self, symbol: _core.QgsSymbol|None) -> _core.QgsProperty: ...


class QgsRuleBasedRendererModel(QtCore.QAbstractItemModel):

    def __init__(self, renderer: _core.QgsRuleBasedRenderer|None, parent: QtCore.QObject|None, screen: QtGui.QScreen|None = ...) -> None: ...

    def clearFeatureCounts(self) -> None: ...
    def finishedAddingRules(self) -> None: ...
    def willAddRules(self, parent: QtCore.QModelIndex, count: int) -> None: ...
    def setSymbol(self, index: QtCore.QModelIndex, symbol: _core.QgsSymbol|None) -> None: ...
    def removeRule(self, index: QtCore.QModelIndex) -> None: ...
    @typing.overload
    def updateRule(self, parent: QtCore.QModelIndex, row: int) -> None: ...
    @typing.overload
    def updateRule(self, index: QtCore.QModelIndex) -> None: ...
    def insertRule(self, parent: QtCore.QModelIndex, before: int, newrule: _core.QgsRuleBasedRenderer.Rule|None) -> None: ...
    def ruleForIndex(self, index: QtCore.QModelIndex) -> _core.QgsRuleBasedRenderer.Rule|None: ...
    def removeRows(self, row: int, count: int, parent: QtCore.QModelIndex = ...) -> bool: ...
    def dropMimeData(self, data: QtCore.QMimeData|None, action: QtCore.Qt.DropAction, row: int, column: int, parent: QtCore.QModelIndex) -> bool: ...
    def mimeData(self, indexes: collections.abc.Iterable[QtCore.QModelIndex]) -> QtCore.QMimeData|None: ...
    def mimeTypes(self) -> list[str]: ...
    def supportedDropActions(self) -> QtCore.Qt.DropAction: ...
    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int = ...) -> bool: ...
    def parent(self, index: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex = ...) -> QtCore.QModelIndex: ...
    def columnCount(self, a0: QtCore.QModelIndex = ...) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int = ...) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...


class QgsRuleBasedRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def pasteSymbolToSelection(self) -> None: ...
    def paste(self) -> None: ...
    def copy(self) -> None: ...
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def refreshSymbolView(self) -> None: ...
    def selectedRules(self) -> list[_core.QgsRuleBasedRenderer.Rule]: ...
    def selectedSymbols(self) -> list[_core.QgsSymbol]: ...
    def currentRule(self) -> _core.QgsRuleBasedRenderer.Rule|None: ...
    def setSymbolLevels(self, levels: collections.abc.Iterable[_core.QgsLegendSymbolItem], enabled: bool) -> None: ...
    def refineRuleScalesGui(self, index: collections.abc.Iterable[QtCore.QModelIndex]) -> None: ...
    def refineRuleRangesGui(self) -> None: ...
    def refineRuleCategoriesGui(self) -> None: ...
    def refineRule(self, type: int) -> None: ...
    def restoreSectionWidths(self) -> None: ...
    def saveSectionWidth(self, section: int, oldSize: int, newSize: int) -> None: ...
    def selectedRulesChanged(self) -> None: ...
    def currentRuleChanged(self, current: QtCore.QModelIndex = ..., previous: QtCore.QModelIndex = ...) -> None: ...
    def setRenderingOrder(self) -> None: ...
    def refineRuleRanges(self) -> None: ...
    def refineRuleCategories(self) -> None: ...
    def refineRuleScales(self) -> None: ...
    def clearFeatureCounts(self) -> None: ...
    def countFeatures(self) -> None: ...
    def removeRule(self) -> None: ...
    @typing.overload
    def editRule(self) -> None: ...
    @typing.overload
    def editRule(self, index: QtCore.QModelIndex) -> None: ...
    def addRule(self) -> None: ...
    def setDockMode(self, dockMode: bool) -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsRendererRulePropsWidget(QgsPanelWidget):

    def __init__(self, rule: _core.QgsRuleBasedRenderer.Rule|None, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ..., context: 'QgsSymbolWidgetContext' = ...) -> None: ...

    def setDockMode(self, dockMode: bool) -> None: ...
    def apply(self) -> None: ...
    def buildExpression(self) -> None: ...
    def testFilter(self) -> None: ...
    def rule(self) -> _core.QgsRuleBasedRenderer.Rule|None: ...


class QgsRendererRulePropsDialog(QtWidgets.QDialog):

    def __init__(self, rule: _core.QgsRuleBasedRenderer.Rule|None, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ..., context: 'QgsSymbolWidgetContext' = ...) -> None: ...

    def accept(self) -> None: ...
    def buildExpression(self) -> None: ...
    def testFilter(self) -> None: ...
    def rule(self) -> _core.QgsRuleBasedRenderer.Rule|None: ...


class QgsSingleSymbolRendererWidget(QgsRendererWidget):

    def __init__(self, layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> None: ...

    def setSymbolLevels(self, levels: collections.abc.Iterable[_core.QgsLegendSymbolItem], enabled: bool) -> None: ...
    def setDockMode(self, dockMode: bool) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def renderer(self) -> _core.QgsFeatureRenderer|None: ...
    @staticmethod
    def create(layer: _core.QgsVectorLayer|None, style: _core.QgsStyle|None, renderer: _core.QgsFeatureRenderer|None) -> QgsRendererWidget|None: ...


class QgsSmartGroupCondition(QtWidgets.QWidget):

    def __init__(self, id: int, parent: QtWidgets.QWidget|None = ...) -> None: ...

    removed: typing.ClassVar[QtCore.pyqtSignal]
    def destruct(self) -> None: ...
    def hideRemoveButton(self, hide: bool) -> None: ...
    def setParameter(self, param: str|None) -> None: ...
    def setConstraint(self, constraint: str|None) -> None: ...
    def parameter(self) -> str: ...
    def constraint(self) -> str: ...


class QgsSmartGroupEditorDialog(QtWidgets.QDialog):

    def __init__(self, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def removeCondition(self, a0: int) -> None: ...
    def addCondition(self) -> None: ...
    def setSmartgroupName(self, a0: str|None) -> None: ...
    def setOperator(self, a0: str|None) -> None: ...
    def conditionOperator(self) -> str: ...
    def smartgroupName(self) -> str: ...


class QgsStyleExportImportDialog(QtWidgets.QDialog):

    class Mode(enum.IntEnum):
        Export = ... # type: QgsStyleExportImportDialog.Mode
        Import = ... # type: QgsStyleExportImportDialog.Mode

    def __init__(self, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ..., mode: 'QgsStyleExportImportDialog.Mode' = ...) -> None: ...

    def importTypeChanged(self, a0: int) -> None: ...
    def deselectSmartgroup(self, groupName: str|None) -> None: ...
    def selectSmartgroup(self, groupName: str|None) -> None: ...
    def deselectTag(self, tagName: str|None) -> None: ...
    def selectTag(self, tagName: str|None) -> None: ...
    def deselectFavorites(self) -> None: ...
    def selectFavorites(self) -> None: ...
    def clearSelection(self) -> None: ...
    def selectAll(self) -> None: ...
    def selectByGroup(self) -> None: ...
    def doExportImport(self) -> None: ...
    def deselectSymbols(self, symbolNames: collections.abc.Iterable[str|None]) -> None: ...
    def selectSymbols(self, symbolNames: collections.abc.Iterable[str|None]) -> None: ...
    def setImportFilePath(self, path: str|None) -> None: ...


class QgsStyleGroupSelectionDialog(QtWidgets.QDialog):

    def __init__(self, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    favoritesSelected: typing.ClassVar[QtCore.pyqtSignal]
    favoritesDeselected: typing.ClassVar[QtCore.pyqtSignal]
    allSelected: typing.ClassVar[QtCore.pyqtSignal]
    allDeselected: typing.ClassVar[QtCore.pyqtSignal]
    smartgroupDeselected: typing.ClassVar[QtCore.pyqtSignal]
    smartgroupSelected: typing.ClassVar[QtCore.pyqtSignal]
    tagDeselected: typing.ClassVar[QtCore.pyqtSignal]
    tagSelected: typing.ClassVar[QtCore.pyqtSignal]
    def setBold(self, item: QtGui.QStandardItem|None) -> None: ...


class QgsStyleManagerDialog(QtWidgets.QDialog):

    @typing.overload
    def __init__(self, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ..., readOnly: bool = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtWidgets.QWidget|None = ..., flags: QtCore.Qt.WindowType = ...) -> None: ...

    def setBold(self, a0: QtGui.QStandardItem|None) -> None: ...
    def enableItemsForGroupingMode(self, a0: bool) -> None: ...
    def enableGroupInputs(self, a0: bool) -> None: ...
    def enableSymbolInputs(self, a0: bool) -> None: ...
    @deprecated("""""")
    def removeColorRamp(self) -> bool: ...
    @deprecated("""""")
    def removeSymbol(self) -> bool: ...
    def editColorRamp(self) -> bool: ...
    def editSymbol(self) -> bool: ...
    def addSymbol(self, symbolType: int = ...) -> bool: ...
    def currentItemName(self) -> str: ...
    def currentItemType(self) -> int: ...
    @deprecated("""""")
    def populateColorRamps(self, colorRamps: collections.abc.Iterable[str|None], checkable: bool = ...) -> None: ...
    @deprecated("""""")
    def populateSymbols(self, symbolNames: collections.abc.Iterable[str|None], checkable: bool = ...) -> None: ...
    @deprecated("""""")
    def setSymbolsChecked(self, a0: collections.abc.Iterable[str|None]) -> None: ...
    def populateGroups(self) -> None: ...
    @deprecated("""""")
    def populateTypes(self) -> None: ...
    def detagSelectedSymbols(self) -> None: ...
    def tagSelectedSymbols(self, newTag: bool = ...) -> None: ...
    def removeFavoriteSelectedSymbols(self) -> None: ...
    def addFavoriteSelectedSymbols(self) -> None: ...
    def addColorRamp(self, type: str|None = ...) -> bool: ...
    def listitemsContextMenu(self, a0: QtCore.QPoint) -> None: ...
    def grouptreeContextMenu(self, a0: QtCore.QPoint) -> None: ...
    def selectedSymbolsChanged(self, selected: QtCore.QItemSelection, deselected: QtCore.QItemSelection) -> None: ...
    def symbolSelected(self, a0: QtCore.QModelIndex) -> None: ...
    def filterSymbols(self, filter: str|None) -> None: ...
    @deprecated("""""")
    def regrouped(self, a0: QtGui.QStandardItem|None) -> None: ...
    def editSmartgroupAction(self) -> None: ...
    def tagSymbolsAction(self) -> None: ...
    def removeGroup(self) -> None: ...
    def addSmartgroup(self) -> int: ...
    def addTag(self) -> int: ...
    def groupRenamed(self, item: QtGui.QStandardItem|None) -> None: ...
    def groupChanged(self, a0: QtCore.QModelIndex) -> None: ...
    @deprecated("""""")
    def itemChanged(self, item: QtGui.QStandardItem|None) -> None: ...
    def showHelp(self) -> None: ...
    def onClose(self) -> None: ...
    def onFinished(self) -> None: ...
    def populateList(self) -> None: ...
    def importItems(self) -> None: ...
    def exportItems(self) -> None: ...
    def exportSelectedItemsImages(self, dir: str|None, format: str|None, size: QtCore.QSize) -> None: ...
    def exportItemsPNG(self) -> None: ...
    def exportItemsSVG(self) -> None: ...
    def removeItem(self) -> None: ...
    def editItem(self) -> None: ...
    def addItem(self) -> None: ...
    def activate(self) -> None: ...
    def setBaseStyleName(self, name: str|None) -> None: ...
    def setSmartGroupsVisible(self, show: bool) -> None: ...
    def setFavoritesGroupVisible(self, show: bool) -> None: ...
    @staticmethod
    def addColorRampStatic(parent: QtWidgets.QWidget|None, style: _core.QgsStyle|None, RampType: str|None = ...) -> str: ...


class QgsStyleSaveDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., type: _core.QgsStyle.StyleEntity = ...) -> None: ...

    def destinationStyle(self) -> _core.QgsStyle|None: ...
    def selectedType(self) -> _core.QgsStyle.StyleEntity: ...
    def isFavorite(self) -> bool: ...
    def tags(self) -> str: ...
    def setDefaultTags(self, tags: str|None) -> None: ...
    def name(self) -> str: ...


class QgsSvgSelectorFilterModel(QtCore.QSortFilterProxyModel):

    def __init__(self, parent: QtCore.QObject|None, path: str|None = ..., iconSize: int = ...) -> None: ...


class QgsSvgSelectorListModel(QtCore.QAbstractListModel):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None, iconSize: int = ...) -> None: ...
    @typing.overload
    def __init__(self, parent: QtCore.QObject|None, path: str|None, iconSize: int = ...) -> None: ...

    def data(self, index: QtCore.QModelIndex, role: int = ...) -> typing.Any: ...
    def rowCount(self, parent: QtCore.QModelIndex = ...) -> int: ...


class QgsSvgSelectorGroupsModel(QtGui.QStandardItemModel):

    def __init__(self, parent: QtCore.QObject|None) -> None: ...


class QgsSvgSelectorWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def populateList(self) -> None: ...
    svgParametersChanged: typing.ClassVar[QtCore.pyqtSignal]
    svgSelected: typing.ClassVar[QtCore.pyqtSignal]
    def setSvgParameters(self, parameters: dict[str|None, _core.QgsProperty]) -> None: ...
    def setSvgPath(self, svgPath: str|None) -> None: ...
    def propertyOverrideToolButton(self) -> QgsPropertyOverrideButton|None: ...
    def browserVisible(self) -> bool: ...
    def setBrowserVisible(self, visible: bool) -> None: ...
    def allowParameters(self) -> bool: ...
    @deprecated("""""")
    def allowParamerters(self) -> bool: ...
    def setAllowParameters(self, allow: bool) -> None: ...
    def sourceLineEdit(self) -> QgsPictureSourceLineEditBase|None: ...
    def currentSvgPath(self) -> str: ...
    def initParametersModel(self, generator: _core.QgsExpressionContextGenerator|None, layer: _core.QgsVectorLayer|None = ...) -> None: ...


class QgsSvgSelectorDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., fl: QtCore.Qt.WindowType = ..., buttons: QtWidgets.QDialogButtonBox.StandardButton = ..., orientation: QtCore.Qt.Orientation = ...) -> None: ...

    def svgSelector(self) -> QgsSvgSelectorWidget|None: ...


class QgsSymbolAnimationSettingsWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def animationSettings(self) -> _core.QgsSymbolAnimationSettings: ...
    def setAnimationSettings(self, settings: _core.QgsSymbolAnimationSettings) -> None: ...


class QgsSymbolAnimationSettingsDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., f: QtCore.Qt.WindowType = ...) -> None: ...

    def animationSettings(self) -> _core.QgsSymbolAnimationSettings: ...
    def setAnimationSettings(self, settings: _core.QgsSymbolAnimationSettings) -> None: ...


class QgsSymbolBufferSettingsWidget(QgsPanelWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def bufferSettings(self) -> _core.QgsSymbolBufferSettings: ...
    def setBufferSettings(self, settings: _core.QgsSymbolBufferSettings) -> None: ...


class QgsSymbolBufferSettingsDialog(QtWidgets.QDialog):

    def __init__(self, parent: QtWidgets.QWidget|None = ..., f: QtCore.Qt.WindowType = ...) -> None: ...

    def bufferSettings(self) -> _core.QgsSymbolBufferSettings: ...
    def setBufferSettings(self, settings: _core.QgsSymbolBufferSettings) -> None: ...


class QgsSimpleLineSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def resizeEvent(self, event: QtGui.QResizeEvent|None) -> None: ...
    def updatePatternIcon(self) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsSimpleMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setColorFill(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColorStroke(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsSimpleFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setStrokeColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsFilledMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsGradientFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setGradientSpread(self, index: int) -> None: ...
    def setCoordinateMode(self, index: int) -> None: ...
    def setGradientType(self, index: int) -> None: ...
    def applyColorRamp(self) -> None: ...
    def setColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsShapeburstFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setColor2(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsTemplatedLineSymbolLayerWidget(QgsSymbolLayerWidget):

    class TemplatedSymbolType(enum.Enum):
        Hash = ... # type: QgsTemplatedLineSymbolLayerWidget.TemplatedSymbolType
        Marker = ... # type: QgsTemplatedLineSymbolLayerWidget.TemplatedSymbolType

    def __init__(self, symbolType: 'QgsTemplatedLineSymbolLayerWidget.TemplatedSymbolType', vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setOffsetAlongLine(self, val: float) -> None: ...
    def setInterval(self, val: float) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    def event(self, e: QtCore.QEvent|None) -> bool: ...


class QgsMarkerLineSymbolLayerWidget(QgsTemplatedLineSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsHashedLineSymbolLayerWidget(QgsTemplatedLineSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsSvgMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setGuiForSvg(self, layer: _core.QgsSvgMarkerSymbolLayer|None, skipDefaultColors: bool = ...) -> None: ...
    @deprecated("""""")
    def populateList(self) -> None: ...
    def setSvgParameters(self, parameters: dict[str|None, _core.QgsProperty]) -> None: ...
    def setSvgPath(self, name: str|None) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsRasterMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsAnimatedMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsRasterFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsRasterLineSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsLineburstSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsFilledLineSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsSVGFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def updateParamGui(self, resetValues: bool = ...) -> None: ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsLinePatternFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsPointPatternFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsRandomMarkerFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsFontMarkerSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setCharacterFromText(self, text: str|None) -> None: ...
    def setCharacter(self, chr: str) -> None: ...
    def setAngle(self, angle: float) -> None: ...
    def setSize(self, size: float) -> None: ...
    def setColorStroke(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def setFontFamily(self, font: QtGui.QFont) -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsCentroidFillSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsLinearReferencingSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsGeometryGeneratorSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsSymbolLevelsWidget(QgsPanelWidget):

    @typing.overload
    def __init__(self, renderer: _core.QgsFeatureRenderer|None, usingSymbolLevels: bool, parent: QtWidgets.QWidget|None = ...) -> None: ...
    @typing.overload
    def __init__(self, symbols: collections.abc.Iterable[_core.QgsLegendSymbolItem], usingSymbolLevels: bool, parent: QtWidgets.QWidget|None = ...) -> None: ...

    @deprecated("""""")
    def apply(self) -> None: ...
    def setForceOrderingEnabled(self, enabled: bool) -> None: ...
    def symbolLevels(self) -> list[_core.QgsLegendSymbolItem]: ...
    def usingLevels(self) -> bool: ...


class QgsSymbolLevelsDialog(QtWidgets.QDialog):

    def __init__(self, renderer: _core.QgsFeatureRenderer|None, usingSymbolLevels: bool, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLevels(self) -> list[_core.QgsLegendSymbolItem]: ...
    def usingLevels(self) -> bool: ...
    def setForceOrderingEnabled(self, enabled: bool) -> None: ...


class QgsSymbolSelectorWidget(QgsPanelWidget):

    def __init__(self, symbol: _core.QgsSymbol|None, style: _core.QgsStyle|None, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    symbolModified: typing.ClassVar[QtCore.pyqtSignal]
    def changeLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    def symbolChanged(self) -> None: ...
    def updatePreview(self) -> None: ...
    def updateLayerPreview(self) -> None: ...
    def layerChanged(self) -> None: ...
    def duplicateLayer(self) -> None: ...
    def lockLayer(self) -> None: ...
    def removeLayer(self) -> None: ...
    def addLayer(self) -> None: ...
    def moveLayerUp(self) -> None: ...
    def moveLayerDown(self) -> None: ...
    def symbol(self) -> _core.QgsSymbol|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def advancedMenu(self) -> QtWidgets.QMenu|None: ...


class QgsSymbolSelectorDialog(QtWidgets.QDialog):

    def __init__(self, symbol: _core.QgsSymbol|None, style: _core.QgsStyle|None, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ..., embedded: bool = ...) -> None: ...

    symbolModified: typing.ClassVar[QtCore.pyqtSignal]
    def keyPressEvent(self, e: QtGui.QKeyEvent|None) -> None: ...
    def changeLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    def symbolChanged(self) -> None: ...
    def updatePreview(self) -> None: ...
    def updateLayerPreview(self) -> None: ...
    def layerChanged(self) -> None: ...
    def duplicateLayer(self) -> None: ...
    def lockLayer(self) -> None: ...
    def removeLayer(self) -> None: ...
    def addLayer(self) -> None: ...
    def moveLayerUp(self) -> None: ...
    def moveLayerDown(self) -> None: ...
    def buttonBox(self) -> QtWidgets.QDialogButtonBox|None: ...
    def symbol(self) -> _core.QgsSymbol|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...
    def advancedMenu(self) -> QtWidgets.QMenu|None: ...


class QgsSymbolsListWidget(QtWidgets.QWidget):

    def __init__(self, symbol: _core.QgsSymbol|None, style: _core.QgsStyle|None, menu: QtWidgets.QMenu|None, parent: QtWidgets.QWidget|None, layer: _core.QgsVectorLayer|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def updateDataDefinedLineWidth(self) -> None: ...
    def updateDataDefinedMarkerAngle(self) -> None: ...
    def updateDataDefinedMarkerSize(self) -> None: ...
    def clipFeaturesToggled(self, checked: bool) -> None: ...
    def setLineWidth(self, width: float) -> None: ...
    def setMarkerSize(self, size: float) -> None: ...
    def setMarkerAngle(self, angle: float) -> None: ...
    def setSymbolColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def layer(self) -> _core.QgsVectorLayer|None: ...
    def context(self) -> 'QgsSymbolWidgetContext': ...
    def setContext(self, context: 'QgsSymbolWidgetContext') -> None: ...


class QgsSymbolWidgetContext(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, other: 'QgsSymbolWidgetContext') -> None: ...

    def setSymbolType(self, type: _core.Qgis.SymbolType) -> None: ...
    def symbolType(self) -> _core.Qgis.SymbolType: ...
    def globalProjectAtlasMapLayerScopes(self, layer: _core.QgsMapLayer|None) -> list[_core.QgsExpressionContextScope]: ...
    def additionalExpressionContextScopes(self) -> list[_core.QgsExpressionContextScope]: ...
    def setAdditionalExpressionContextScopes(self, scopes: collections.abc.Iterable[_core.QgsExpressionContextScope]) -> None: ...
    def expressionContext(self) -> _core.QgsExpressionContext|None: ...
    def setExpressionContext(self, context: _core.QgsExpressionContext|None) -> None: ...
    def messageBar(self) -> QgsMessageBar|None: ...
    def setMessageBar(self, bar: QgsMessageBar|None) -> None: ...
    def mapCanvas(self) -> QgsMapCanvas|None: ...
    def setMapCanvas(self, canvas: QgsMapCanvas|None) -> None: ...


class QgsVectorFieldSymbolLayerWidget(QgsSymbolLayerWidget):

    def __init__(self, vl: _core.QgsVectorLayer|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def symbolLayer(self) -> _core.QgsSymbolLayer|None: ...
    def setSymbolLayer(self, layer: _core.QgsSymbolLayer|None) -> None: ...
    @staticmethod
    def create(vl: _core.QgsVectorLayer|None) -> QgsSymbolLayerWidget|None: ...


class QgsSensorAbstractGuiMetadata(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self, type: str|None, visibleName: str|None) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSensorAbstractGuiMetadata') -> None: ...

    def createSensor(self, parent: QtCore.QObject|None) -> _core.QgsAbstractSensor|None: ...
    def createSensorWidget(self, sensor: _core.QgsAbstractSensor|None) -> 'QgsAbstractSensorWidget|None': ...
    def creationIcon(self) -> QtGui.QIcon: ...
    def visibleName(self) -> str: ...
    def type(self) -> str: ...


class QgsSensorGuiRegistry(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    sensorAdded: typing.ClassVar[QtCore.pyqtSignal]
    def sensorTypes(self) -> dict[str, str]: ...
    def createSensorWidget(self, sensor: _core.QgsAbstractSensor|None) -> 'QgsAbstractSensorWidget|None': ...
    def createSensor(self, type: str|None, parent: QtCore.QObject|None = ...) -> _core.QgsAbstractSensor|None: ...
    def addSensorGuiMetadata(self, metadata: QgsSensorAbstractGuiMetadata|None) -> bool: ...
    def sensorMetadata(self, type: str|None) -> QgsSensorAbstractGuiMetadata|None: ...
    def populate(self) -> bool: ...


class QgsAbstractSensorWidget(QtWidgets.QWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    changed: typing.ClassVar[QtCore.pyqtSignal]
    def setSensor(self, sensor: _core.QgsAbstractSensor|None) -> bool: ...
    def updateSensor(self, sensor: _core.QgsAbstractSensor|None) -> bool: ...
    def createSensor(self) -> _core.QgsAbstractSensor|None: ...


class QgsSettingsEditorWidgetWrapper(QtCore.QObject):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def dynamicKeyPartList(self) -> list[str]: ...
    def configureAutomaticUpdate(self, dialog: QtWidgets.QDialog|None = ...) -> None: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def configureEditor(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> bool: ...
    def createEditor(self, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ..., parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> 'QgsSettingsEditorWidgetWrapper|None': ...
    def id(self) -> str: ...
    @staticmethod
    def fromWidget(widget: QtWidgets.QWidget|None) -> 'QgsSettingsEditorWidgetWrapper|None': ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryStringQLineEditQStringBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryString|None: ...
    def editor(self) -> QtWidgets.QLineEdit|None: ...
    def valueFromWidget(self) -> str: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: str|None) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsStringLineEditWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryStringQLineEditQStringBase):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def setWidgetValue(self, value: str|None) -> bool: ...
    def valueFromWidget(self) -> str: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryStringQComboBoxQStringBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryString|None: ...
    def editor(self) -> QtWidgets.QComboBox|None: ...
    def valueFromWidget(self) -> str: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: str|None) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsStringComboBoxWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryStringQComboBoxQStringBase):

    class Mode(enum.IntEnum):
        Text = ... # type: QgsSettingsStringComboBoxWrapper.Mode
        Data = ... # type: QgsSettingsStringComboBoxWrapper.Mode

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, mode: 'QgsSettingsStringComboBoxWrapper.Mode', dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, mode: 'QgsSettingsStringComboBoxWrapper.Mode', role: int, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def setWidgetValue(self, value: str|None) -> bool: ...
    def valueFromWidget(self) -> str: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryBoolQCheckBoxboolBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryBool|None: ...
    def editor(self) -> QtWidgets.QCheckBox|None: ...
    def valueFromWidget(self) -> bool: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: bool) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsBoolCheckBoxWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryBoolQCheckBoxboolBase):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def setWidgetValue(self, value: bool) -> bool: ...
    def valueFromWidget(self) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryBoolQGroupBoxboolBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryBool|None: ...
    def editor(self) -> QtWidgets.QGroupBox|None: ...
    def valueFromWidget(self) -> bool: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: bool) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsBoolGroupBoxWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryBoolQGroupBoxboolBase):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def enableAutomaticUpdatePrivate(self) -> None: ...
    def setWidgetValue(self, value: bool) -> bool: ...
    def valueFromWidget(self) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryIntegerQSpinBoxintBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryInteger|None: ...
    def editor(self) -> QtWidgets.QSpinBox|None: ...
    def valueFromWidget(self) -> int: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: int) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsIntegerSpinBoxWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryIntegerQSpinBoxintBase):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def setWidgetValue(self, value: int) -> bool: ...
    def valueFromWidget(self) -> int: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryDoubleQDoubleSpinBoxdoubleBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryDouble|None: ...
    def editor(self) -> QtWidgets.QDoubleSpinBox|None: ...
    def valueFromWidget(self) -> float: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: float) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsDoubleSpinBoxWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryDoubleQDoubleSpinBoxdoubleBase):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def setWidgetValue(self, value: float) -> bool: ...
    def valueFromWidget(self) -> float: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryColorQgsColorButtonQColorBase(QgsSettingsEditorWidgetWrapper):

    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...

    def configureEditorPrivateImplementation(self) -> None: ...
    def configureEditorPrivate(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None) -> bool: ...
    def createEditorPrivate(self, parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...
    def setting(self) -> _core.QgsSettingsEntryColor|None: ...
    def editor(self) -> QgsColorButton|None: ...
    def valueFromWidget(self) -> QtGui.QColor: ...
    def variantValueFromWidget(self) -> typing.Any: ...
    def setWidgetValue(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> bool: ...
    def setWidgetFromVariant(self, value: typing.Any) -> bool: ...
    def setSettingFromWidget(self) -> bool: ...
    def setWidgetFromSetting(self) -> bool: ...
    def id(self) -> str: ...


class QgsSettingsColorButtonWrapper(QgsSettingsEditorWidgetWrapperTemplateQgsSettingsEntryColorQgsColorButtonQColorBase):

    @typing.overload
    def __init__(self, parent: QtCore.QObject|None = ...) -> None: ...
    @typing.overload
    def __init__(self, editor: QtWidgets.QWidget|None, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None] = ...) -> None: ...

    def enableAutomaticUpdatePrivate(self) -> None: ...
    def configureEditorPrivateImplementation(self) -> None: ...
    def setWidgetValue(self, value: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> bool: ...
    def valueFromWidget(self) -> QtGui.QColor: ...
    def setSettingFromWidget(self) -> bool: ...
    def id(self) -> str: ...
    def createWrapper(self, parent: QtCore.QObject|None = ...) -> QgsSettingsEditorWidgetWrapper|None: ...


class QgsSettingsEditorWidgetRegistry(PyQt6.sip.wrapper):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsEditorWidgetRegistry') -> None: ...

    def createEditor(self, setting: _core.QgsSettingsEntryBase|None, dynamicKeyPartList: collections.abc.Iterable[str|None], parent: QtWidgets.QWidget|None = ...) -> QtWidgets.QWidget|None: ...
    def createWrapper(self, id: str|None, parent: QtCore.QObject|None) -> QgsSettingsEditorWidgetWrapper|None: ...
    def addWrapperForSetting(self, wrapper: QgsSettingsEditorWidgetWrapper|None, setting: _core.QgsSettingsEntryBase|None) -> None: ...
    def addWrapper(self, wrapper: QgsSettingsEditorWidgetWrapper|None) -> bool: ...


class QgsSettingsRegistryGui(_core.QgsSettingsRegistry):

    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, a0: 'QgsSettingsRegistryGui') -> None: ...


class QgsSettingsTreeModel(QtCore.QAbstractItemModel):

    class Column(enum.Enum):
        Name = ... # type: QgsSettingsTreeModel.Column
        Value = ... # type: QgsSettingsTreeModel.Column
        Description = ... # type: QgsSettingsTreeModel.Column

    def __init__(self, rootNode: _core.QgsSettingsTreeNode|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def setData(self, index: QtCore.QModelIndex, value: typing.Any, role: int) -> bool: ...
    def flags(self, index: QtCore.QModelIndex) -> QtCore.Qt.ItemFlag: ...
    def headerData(self, section: int, orientation: QtCore.Qt.Orientation, role: int) -> typing.Any: ...
    def data(self, index: QtCore.QModelIndex, role: int) -> typing.Any: ...
    def columnCount(self, parent: QtCore.QModelIndex) -> int: ...
    def rowCount(self, parent: QtCore.QModelIndex) -> int: ...
    def parent(self, child: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def index(self, row: int, column: int, parent: QtCore.QModelIndex) -> QtCore.QModelIndex: ...
    def applyChanges(self) -> None: ...


class QgsSettingsTreeProxyModel(QtCore.QSortFilterProxyModel):

    def __init__(self, rootNode: _core.QgsSettingsTreeNode|None = ..., parent: QtCore.QObject|None = ...) -> None: ...

    def filterAcceptsRow(self, source_row: int, source_parent: QtCore.QModelIndex) -> bool: ...
    def setFilterText(self, filterText: str|None = ...) -> None: ...
    def applyChanges(self) -> None: ...


class QgsSettingsTreeWidget(QtWidgets.QWidget, QgsOptionsDialogHighlightWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def reset(self) -> None: ...
    def highlightText(self, text: str|None) -> bool: ...
    def searchText(self, text: str|None) -> bool: ...
    def applyChanges(self) -> None: ...


class QgsTableEditorDialog(QtWidgets.QMainWindow):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def closeEvent(self, a0: QtGui.QCloseEvent|None) -> None: ...
    includeHeaderChanged: typing.ClassVar[QtCore.pyqtSignal]
    tableChanged: typing.ClassVar[QtCore.pyqtSignal]
    def setLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def layer(self) -> _core.QgsMapLayer|None: ...
    def registerExpressionContextGenerator(self, generator: _core.QgsExpressionContextGenerator|None) -> None: ...
    def setTableHeaders(self, headers: collections.abc.Iterable[typing.Any]) -> None: ...
    def tableHeaders(self) -> list[typing.Any]: ...
    def setIncludeTableHeader(self, included: bool) -> None: ...
    def includeTableHeader(self) -> bool: ...
    def setTableColumnWidth(self, column: int, width: float) -> None: ...
    def setTableRowHeight(self, row: int, height: float) -> None: ...
    def tableColumnWidth(self, column: int) -> float: ...
    def tableRowHeight(self, row: int) -> float: ...
    def tableContents(self) -> typing.Any: ...
    def setTableContentsFromClipboard(self) -> bool: ...
    def setTableContents(self, contents: typing.Any) -> None: ...


class QgsTableEditorWidget(QtWidgets.QTableWidget):

    def __init__(self, parent: QtWidgets.QWidget|None = ...) -> None: ...

    activeCellChanged: typing.ClassVar[QtCore.pyqtSignal]
    tableChanged: typing.ClassVar[QtCore.pyqtSignal]
    def keyPressEvent(self, event: QtGui.QKeyEvent|None) -> None: ...
    def splitSelectedCells(self) -> None: ...
    def mergeSelectedCells(self) -> None: ...
    def setTableHeaders(self, headers: collections.abc.Iterable[typing.Any]) -> None: ...
    def setIncludeTableHeader(self, included: bool) -> None: ...
    def setSelectionColumnWidth(self, height: float) -> None: ...
    def setSelectionRowHeight(self, height: float) -> None: ...
    def setSelectionTextFormat(self, format: _core.QgsTextFormat) -> None: ...
    def setSelectionCellProperty(self, property: _core.QgsProperty) -> None: ...
    def setSelectionVerticalAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def setSelectionHorizontalAlignment(self, alignment: QtCore.Qt.AlignmentFlag) -> None: ...
    def setSelectionBackgroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    @deprecated("""""")
    def setSelectionForegroundColor(self, color: QtGui.QColor|QtCore.Qt.GlobalColor|int) -> None: ...
    def clearSelectedCells(self) -> None: ...
    def expandColumnSelection(self) -> None: ...
    def expandRowSelection(self) -> None: ...
    def deleteColumns(self) -> None: ...
    def deleteRows(self) -> None: ...
    def insertColumnsAfter(self) -> None: ...
    def insertColumnsBefore(self) -> None: ...
    def insertRowsAbove(self) -> None: ...
    def insertRowsBelow(self) -> None: ...
    def canSplitSelection(self) -> bool: ...
    def canMergeSelection(self) -> bool: ...
    def isHeaderCellSelected(self) -> bool: ...
    def tableHeaders(self) -> list[typing.Any]: ...
    def columnsAssociatedWithSelection(self) -> list[int]: ...
    def rowsAssociatedWithSelection(self) -> list[int]: ...
    def setTableColumnWidth(self, column: int, width: float) -> None: ...
    def setTableRowHeight(self, row: int, height: float) -> None: ...
    def tableColumnWidth(self, column: int) -> float: ...
    def tableRowHeight(self, row: int) -> float: ...
    def selectionColumnWidth(self) -> float: ...
    def selectionRowHeight(self) -> float: ...
    def selectionTextFormat(self) -> _core.QgsTextFormat: ...
    def selectionCellProperty(self) -> _core.QgsProperty: ...
    def selectionVerticalAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def selectionHorizontalAlignment(self) -> QtCore.Qt.AlignmentFlag: ...
    def selectionBackgroundColor(self) -> QtGui.QColor: ...
    @deprecated("""""")
    def selectionForegroundColor(self) -> QtGui.QColor: ...
    def hasMixedSelectionNumericFormat(self) -> bool: ...
    def selectionNumericFormat(self) -> _core.QgsNumericFormat|None: ...
    def setSelectionNumericFormat(self, format: _core.QgsNumericFormat|None) -> None: ...
    def tableContents(self) -> typing.Any: ...
    def setTableContents(self, contents: typing.Any) -> None: ...


class QgsTiledSceneRendererPropertiesWidget(QgsMapLayerConfigWidget):

    def __init__(self, layer: _core.QgsTiledSceneLayer|None, style: _core.QgsStyle|None, parent: QtWidgets.QWidget|None = ...) -> None: ...

    def apply(self) -> None: ...
    def setDockMode(self, dockMode: bool) -> None: ...
    def syncToLayer(self, layer: _core.QgsMapLayer|None) -> None: ...
    def setContext(self, context: QgsSymbolWidgetContext) -> None: ...


class QgsTiledSceneRendererWidget(QgsPanelWidget):

    def __init__(self, layer: _core.QgsTiledSceneLayer|None, style: _core.QgsStyle|None) -> None: ...

    def layer(self) -> _core.QgsTiledSceneLayer|None: ...
    def context(self) -> QgsSymbolWidgetContext: ...
    def setContext(self, context: QgsSymbolWidgetContext) -> None: ...
    def renderer(self) -> _core.QgsTiledSceneRenderer|None: ...


class QgsVectorTileLayerProperties(QgsLayerPropertiesDialog):

    def __init__(self, lyr: _core.QgsVectorTileLayer|None, canvas: QgsMapCanvas|None, messageBar: QgsMessageBar|None, parent: QtWidgets.QWidget|None = ..., a4: QtCore.Qt.WindowType = ...) -> None: ...

    @deprecated("""""")
    def saveStyleAs(self) -> None: ...
    def loadStyle(self) -> None: ...
    @deprecated("""""")
    def saveDefaultStyle(self) -> None: ...
